package configchange
import "google.golang.org/genproto/googleapis/api/configchange"
Index ¶
- Variables
- type Advice
- func (*Advice) Descriptor() ([]byte, []int)
- func (x *Advice) GetDescription() string
- func (*Advice) ProtoMessage()
- func (x *Advice) ProtoReflect() protoreflect.Message
- func (x *Advice) Reset()
- func (x *Advice) String() string
- type ChangeType
- func (ChangeType) Descriptor() protoreflect.EnumDescriptor
- func (x ChangeType) Enum() *ChangeType
- func (ChangeType) EnumDescriptor() ([]byte, []int)
- func (x ChangeType) Number() protoreflect.EnumNumber
- func (x ChangeType) String() string
- func (ChangeType) Type() protoreflect.EnumType
- type ConfigChange
- func (*ConfigChange) Descriptor() ([]byte, []int)
- func (x *ConfigChange) GetAdvices() []*Advice
- func (x *ConfigChange) GetChangeType() ChangeType
- func (x *ConfigChange) GetElement() string
- func (x *ConfigChange) GetNewValue() string
- func (x *ConfigChange) GetOldValue() string
- func (*ConfigChange) ProtoMessage()
- func (x *ConfigChange) ProtoReflect() protoreflect.Message
- func (x *ConfigChange) Reset()
- func (x *ConfigChange) String() string
Variables ¶
var ( ChangeType_name = map[int32]string{ 0: "CHANGE_TYPE_UNSPECIFIED", 1: "ADDED", 2: "REMOVED", 3: "MODIFIED", } ChangeType_value = map[string]int32{ "CHANGE_TYPE_UNSPECIFIED": 0, "ADDED": 1, "REMOVED": 2, "MODIFIED": 3, } )
Enum value maps for ChangeType.
var File_google_api_config_change_proto protoreflect.FileDescriptor
Types ¶
type Advice ¶
type Advice struct {
// Useful description for why this advice was applied and what actions should
// be taken to mitigate any implied risks.
Description string `protobuf:"bytes,2,opt,name=description,proto3" json:"description,omitempty"`
// contains filtered or unexported fields
}
Generated advice about this change, used for providing more information about how a change will affect the existing service.
func (*Advice) Descriptor ¶
Deprecated: Use Advice.ProtoReflect.Descriptor instead.
func (*Advice) GetDescription ¶
func (*Advice) ProtoMessage ¶
func (*Advice) ProtoMessage()
func (*Advice) ProtoReflect ¶
func (x *Advice) ProtoReflect() protoreflect.Message
func (*Advice) Reset ¶
func (x *Advice) Reset()
func (*Advice) String ¶
type ChangeType ¶
type ChangeType int32
Classifies set of possible modifications to an object in the service configuration.
const ( // No value was provided. ChangeType_CHANGE_TYPE_UNSPECIFIED ChangeType = 0 // The changed object exists in the 'new' service configuration, but not // in the 'old' service configuration. ChangeType_ADDED ChangeType = 1 // The changed object exists in the 'old' service configuration, but not // in the 'new' service configuration. ChangeType_REMOVED ChangeType = 2 // The changed object exists in both service configurations, but its value // is different. ChangeType_MODIFIED ChangeType = 3 )
func (ChangeType) Descriptor ¶
func (ChangeType) Descriptor() protoreflect.EnumDescriptor
func (ChangeType) Enum ¶
func (x ChangeType) Enum() *ChangeType
func (ChangeType) EnumDescriptor ¶
func (ChangeType) EnumDescriptor() ([]byte, []int)
Deprecated: Use ChangeType.Descriptor instead.
func (ChangeType) Number ¶
func (x ChangeType) Number() protoreflect.EnumNumber
func (ChangeType) String ¶
func (x ChangeType) String() string
func (ChangeType) Type ¶
func (ChangeType) Type() protoreflect.EnumType
type ConfigChange ¶
type ConfigChange struct {
// Object hierarchy path to the change, with levels separated by a '.'
// character. For repeated fields, an applicable unique identifier field is
// used for the index (usually selector, name, or id). For maps, the term
// 'key' is used. If the field has no unique identifier, the numeric index
// is used.
// Examples:
// - visibility.rules[selector=="google.LibraryService.ListBooks"].restriction
// - quota.metric_rules[selector=="google"].metric_costs[key=="reads"].value
// - logging.producer_destinations[0]
Element string `protobuf:"bytes,1,opt,name=element,proto3" json:"element,omitempty"`
// Value of the changed object in the old Service configuration,
// in JSON format. This field will not be populated if ChangeType == ADDED.
OldValue string `protobuf:"bytes,2,opt,name=old_value,json=oldValue,proto3" json:"old_value,omitempty"`
// Value of the changed object in the new Service configuration,
// in JSON format. This field will not be populated if ChangeType == REMOVED.
NewValue string `protobuf:"bytes,3,opt,name=new_value,json=newValue,proto3" json:"new_value,omitempty"`
// The type for this change, either ADDED, REMOVED, or MODIFIED.
ChangeType ChangeType `protobuf:"varint,4,opt,name=change_type,json=changeType,proto3,enum=google.api.ChangeType" json:"change_type,omitempty"`
// Collection of advice provided for this change, useful for determining the
// possible impact of this change.
Advices []*Advice `protobuf:"bytes,5,rep,name=advices,proto3" json:"advices,omitempty"`
// contains filtered or unexported fields
}
Output generated from semantically comparing two versions of a service configuration.
Includes detailed information about a field that have changed with applicable advice about potential consequences for the change, such as backwards-incompatibility.
func (*ConfigChange) Descriptor ¶
func (*ConfigChange) Descriptor() ([]byte, []int)
Deprecated: Use ConfigChange.ProtoReflect.Descriptor instead.
func (*ConfigChange) GetAdvices ¶
func (x *ConfigChange) GetAdvices() []*Advice
func (*ConfigChange) GetChangeType ¶
func (x *ConfigChange) GetChangeType() ChangeType
func (*ConfigChange) GetElement ¶
func (x *ConfigChange) GetElement() string
func (*ConfigChange) GetNewValue ¶
func (x *ConfigChange) GetNewValue() string
func (*ConfigChange) GetOldValue ¶
func (x *ConfigChange) GetOldValue() string
func (*ConfigChange) ProtoMessage ¶
func (*ConfigChange) ProtoMessage()
func (*ConfigChange) ProtoReflect ¶
func (x *ConfigChange) ProtoReflect() protoreflect.Message
func (*ConfigChange) Reset ¶
func (x *ConfigChange) Reset()
func (*ConfigChange) String ¶
func (x *ConfigChange) String() string
Source Files ¶
config_change.pb.go
- Version
- v0.0.0-20250324211829-b45e905df463 (latest)
- Published
- Mar 24, 2025
- Platform
- linux/amd64
- Imports
- 4 packages
- Last checked
- 1 year ago –
Tools for package owners.