Documentation
¶
Index ¶
- Variables
- type Metric
- type MetricDescriptor
- func (*MetricDescriptor) Descriptor() ([]byte, []int)deprecated
- func (x *MetricDescriptor) GetDescription() string
- func (x *MetricDescriptor) GetDisplayName() string
- func (x *MetricDescriptor) GetLabels() []*label.LabelDescriptor
- func (x *MetricDescriptor) GetLaunchStage() api.LaunchStage
- func (x *MetricDescriptor) GetMetadata() *MetricDescriptor_MetricDescriptorMetadata
- func (x *MetricDescriptor) GetMetricKind() MetricDescriptor_MetricKind
- func (x *MetricDescriptor) GetMonitoredResourceTypes() []string
- func (x *MetricDescriptor) GetName() string
- func (x *MetricDescriptor) GetType() string
- func (x *MetricDescriptor) GetUnit() string
- func (x *MetricDescriptor) GetValueType() MetricDescriptor_ValueType
- func (*MetricDescriptor) ProtoMessage()
- func (x *MetricDescriptor) ProtoReflect() protoreflect.Message
- func (x *MetricDescriptor) Reset()
- func (x *MetricDescriptor) String() string
- type MetricDescriptor_MetricDescriptorMetadata
- func (*MetricDescriptor_MetricDescriptorMetadata) Descriptor() ([]byte, []int)deprecated
- func (x *MetricDescriptor_MetricDescriptorMetadata) GetIngestDelay() *durationpb.Duration
- func (x *MetricDescriptor_MetricDescriptorMetadata) GetLaunchStage() api.LaunchStagedeprecated
- func (x *MetricDescriptor_MetricDescriptorMetadata) GetSamplePeriod() *durationpb.Duration
- func (x *MetricDescriptor_MetricDescriptorMetadata) GetTimeSeriesResourceHierarchyLevel() []MetricDescriptor_MetricDescriptorMetadata_TimeSeriesResourceHierarchyLevel
- func (*MetricDescriptor_MetricDescriptorMetadata) ProtoMessage()
- func (x *MetricDescriptor_MetricDescriptorMetadata) ProtoReflect() protoreflect.Message
- func (x *MetricDescriptor_MetricDescriptorMetadata) Reset()
- func (x *MetricDescriptor_MetricDescriptorMetadata) String() string
- type MetricDescriptor_MetricDescriptorMetadata_TimeSeriesResourceHierarchyLevel
- func (MetricDescriptor_MetricDescriptorMetadata_TimeSeriesResourceHierarchyLevel) Descriptor() protoreflect.EnumDescriptor
- func (x MetricDescriptor_MetricDescriptorMetadata_TimeSeriesResourceHierarchyLevel) Enum() *MetricDescriptor_MetricDescriptorMetadata_TimeSeriesResourceHierarchyLevel
- func (MetricDescriptor_MetricDescriptorMetadata_TimeSeriesResourceHierarchyLevel) EnumDescriptor() ([]byte, []int)deprecated
- func (x MetricDescriptor_MetricDescriptorMetadata_TimeSeriesResourceHierarchyLevel) Number() protoreflect.EnumNumber
- func (x MetricDescriptor_MetricDescriptorMetadata_TimeSeriesResourceHierarchyLevel) String() string
- func (MetricDescriptor_MetricDescriptorMetadata_TimeSeriesResourceHierarchyLevel) Type() protoreflect.EnumType
- type MetricDescriptor_MetricKind
- func (MetricDescriptor_MetricKind) Descriptor() protoreflect.EnumDescriptor
- func (x MetricDescriptor_MetricKind) Enum() *MetricDescriptor_MetricKind
- func (MetricDescriptor_MetricKind) EnumDescriptor() ([]byte, []int)deprecated
- func (x MetricDescriptor_MetricKind) Number() protoreflect.EnumNumber
- func (x MetricDescriptor_MetricKind) String() string
- func (MetricDescriptor_MetricKind) Type() protoreflect.EnumType
- type MetricDescriptor_ValueType
- func (MetricDescriptor_ValueType) Descriptor() protoreflect.EnumDescriptor
- func (x MetricDescriptor_ValueType) Enum() *MetricDescriptor_ValueType
- func (MetricDescriptor_ValueType) EnumDescriptor() ([]byte, []int)deprecated
- func (x MetricDescriptor_ValueType) Number() protoreflect.EnumNumber
- func (x MetricDescriptor_ValueType) String() string
- func (MetricDescriptor_ValueType) Type() protoreflect.EnumType
Constants ¶
This section is empty.
Variables ¶
var ( MetricDescriptor_MetricKind_name = map[int32]string{ 0: "METRIC_KIND_UNSPECIFIED", 1: "GAUGE", 2: "DELTA", 3: "CUMULATIVE", } MetricDescriptor_MetricKind_value = map[string]int32{ "METRIC_KIND_UNSPECIFIED": 0, "GAUGE": 1, "DELTA": 2, "CUMULATIVE": 3, } )
Enum value maps for MetricDescriptor_MetricKind.
var ( MetricDescriptor_ValueType_name = map[int32]string{ 0: "VALUE_TYPE_UNSPECIFIED", 1: "BOOL", 2: "INT64", 3: "DOUBLE", 4: "STRING", 5: "DISTRIBUTION", 6: "MONEY", } MetricDescriptor_ValueType_value = map[string]int32{ "VALUE_TYPE_UNSPECIFIED": 0, "BOOL": 1, "INT64": 2, "DOUBLE": 3, "STRING": 4, "DISTRIBUTION": 5, "MONEY": 6, } )
Enum value maps for MetricDescriptor_ValueType.
var ( MetricDescriptor_MetricDescriptorMetadata_TimeSeriesResourceHierarchyLevel_name = map[int32]string{ 0: "TIME_SERIES_RESOURCE_HIERARCHY_LEVEL_UNSPECIFIED", 1: "PROJECT", 2: "ORGANIZATION", 3: "FOLDER", } MetricDescriptor_MetricDescriptorMetadata_TimeSeriesResourceHierarchyLevel_value = map[string]int32{ "TIME_SERIES_RESOURCE_HIERARCHY_LEVEL_UNSPECIFIED": 0, "PROJECT": 1, "ORGANIZATION": 2, "FOLDER": 3, } )
Enum value maps for MetricDescriptor_MetricDescriptorMetadata_TimeSeriesResourceHierarchyLevel.
var File_google_api_metric_proto protoreflect.FileDescriptor
Functions ¶
This section is empty.
Types ¶
type Metric ¶
type Metric struct {
// An existing metric type, see
// [google.api.MetricDescriptor][google.api.MetricDescriptor]. For example,
// `custom.googleapis.com/invoice/paid/amount`.
Type string `protobuf:"bytes,3,opt,name=type,proto3" json:"type,omitempty"`
// The set of label values that uniquely identify this metric. All
// labels listed in the `MetricDescriptor` must be assigned values.
Labels map[string]string `` /* 153-byte string literal not displayed */
// contains filtered or unexported fields
}
A specific metric, identified by specifying values for all of the labels of a [`MetricDescriptor`][google.api.MetricDescriptor].
func (*Metric) Descriptor
deprecated
func (*Metric) ProtoMessage ¶
func (*Metric) ProtoMessage()
func (*Metric) ProtoReflect ¶
func (x *Metric) ProtoReflect() protoreflect.Message
type MetricDescriptor ¶
type MetricDescriptor struct {
// The resource name of the metric descriptor.
Name string `protobuf:"bytes,1,opt,name=name,proto3" json:"name,omitempty"`
// The metric type, including its DNS name prefix. The type is not
// URL-encoded. All user-defined metric types have the DNS name
// `custom.googleapis.com` or `external.googleapis.com`. Metric types should
// use a natural hierarchical grouping. For example:
//
// "custom.googleapis.com/invoice/paid/amount"
// "external.googleapis.com/prometheus/up"
// "appengine.googleapis.com/http/server/response_latencies"
Type string `protobuf:"bytes,8,opt,name=type,proto3" json:"type,omitempty"`
// The set of labels that can be used to describe a specific
// instance of this metric type. For example, the
// `appengine.googleapis.com/http/server/response_latencies` metric
// type has a label for the HTTP response code, `response_code`, so
// you can look at latencies for successful responses or just
// for responses that failed.
Labels []*label.LabelDescriptor `protobuf:"bytes,2,rep,name=labels,proto3" json:"labels,omitempty"`
// Whether the metric records instantaneous values, changes to a value, etc.
// Some combinations of `metric_kind` and `value_type` might not be supported.
MetricKind MetricDescriptor_MetricKind `` /* 136-byte string literal not displayed */
// Whether the measurement is an integer, a floating-point number, etc.
// Some combinations of `metric_kind` and `value_type` might not be supported.
ValueType MetricDescriptor_ValueType `` /* 132-byte string literal not displayed */
// The units in which the metric value is reported. It is only applicable
// if the `value_type` is `INT64`, `DOUBLE`, or `DISTRIBUTION`. The `unit`
// defines the representation of the stored metric values.
//
// Different systems might scale the values to be more easily displayed (so a
// value of `0.02kBy` _might_ be displayed as `20By`, and a value of
// `3523kBy` _might_ be displayed as `3.5MBy`). However, if the `unit` is
// `kBy`, then the value of the metric is always in thousands of bytes, no
// matter how it might be displayed.
//
// If you want a custom metric to record the exact number of CPU-seconds used
// by a job, you can create an `INT64 CUMULATIVE` metric whose `unit` is
// `s{CPU}` (or equivalently `1s{CPU}` or just `s`). If the job uses 12,005
// CPU-seconds, then the value is written as `12005`.
//
// Alternatively, if you want a custom metric to record data in a more
// granular way, you can create a `DOUBLE CUMULATIVE` metric whose `unit` is
// `ks{CPU}`, and then write the value `12.005` (which is `12005/1000`),
// or use `Kis{CPU}` and write `11.723` (which is `12005/1024`).
//
// The supported units are a subset of [The Unified Code for Units of
// Measure](https://unitsofmeasure.org/ucum.html) standard:
//
// **Basic units (UNIT)**
//
// * `bit` bit
// * `By` byte
// * `s` second
// * `min` minute
// * `h` hour
// * `d` day
// * `1` dimensionless
//
// **Prefixes (PREFIX)**
//
// * `k` kilo (10^3)
// * `M` mega (10^6)
// * `G` giga (10^9)
// * `T` tera (10^12)
// * `P` peta (10^15)
// * `E` exa (10^18)
// * `Z` zetta (10^21)
// * `Y` yotta (10^24)
//
// * `m` milli (10^-3)
// * `u` micro (10^-6)
// * `n` nano (10^-9)
// * `p` pico (10^-12)
// * `f` femto (10^-15)
// * `a` atto (10^-18)
// * `z` zepto (10^-21)
// * `y` yocto (10^-24)
//
// * `Ki` kibi (2^10)
// * `Mi` mebi (2^20)
// * `Gi` gibi (2^30)
// * `Ti` tebi (2^40)
// * `Pi` pebi (2^50)
//
// **Grammar**
//
// The grammar also includes these connectors:
//
// - `/` division or ratio (as an infix operator). For examples,
// `kBy/{email}` or `MiBy/10ms` (although you should almost never
// have `/s` in a metric `unit`; rates should always be computed at
// query time from the underlying cumulative or delta value).
// - `.` multiplication or composition (as an infix operator). For
// examples, `GBy.d` or `k{watt}.h`.
//
// The grammar for a unit is as follows:
//
// Expression = Component { "." Component } { "/" Component } ;
//
// Component = ( [ PREFIX ] UNIT | "%" ) [ Annotation ]
// | Annotation
// | "1"
// ;
//
// Annotation = "{" NAME "}" ;
//
// Notes:
//
// - `Annotation` is just a comment if it follows a `UNIT`. If the annotation
// is used alone, then the unit is equivalent to `1`. For examples,
// `{request}/s == 1/s`, `By{transmitted}/s == By/s`.
// - `NAME` is a sequence of non-blank printable ASCII characters not
// containing `{` or `}`.
// - `1` represents a unitary [dimensionless
// unit](https://en.wikipedia.org/wiki/Dimensionless_quantity) of 1, such
// as in `1/s`. It is typically used when none of the basic units are
// appropriate. For example, "new users per day" can be represented as
// `1/d` or `{new-users}/d` (and a metric value `5` would mean "5 new
// users). Alternatively, "thousands of page views per day" would be
// represented as `1000/d` or `k1/d` or `k{page_views}/d` (and a metric
// value of `5.3` would mean "5300 page views per day").
// - `%` represents dimensionless value of 1/100, and annotates values giving
// a percentage (so the metric values are typically in the range of 0..100,
// and a metric value `3` means "3 percent").
// - `10^2.%` indicates a metric contains a ratio, typically in the range
// 0..1, that will be multiplied by 100 and displayed as a percentage
// (so a metric value `0.03` means "3 percent").
Unit string `protobuf:"bytes,5,opt,name=unit,proto3" json:"unit,omitempty"`
// A detailed description of the metric, which can be used in documentation.
Description string `protobuf:"bytes,6,opt,name=description,proto3" json:"description,omitempty"`
// A concise name for the metric, which can be displayed in user interfaces.
// Use sentence case without an ending period, for example "Request count".
// This field is optional but it is recommended to be set for any metrics
// associated with user-visible concepts, such as Quota.
DisplayName string `protobuf:"bytes,7,opt,name=display_name,json=displayName,proto3" json:"display_name,omitempty"`
// Optional. Metadata which can be used to guide usage of the metric.
Metadata *MetricDescriptor_MetricDescriptorMetadata `protobuf:"bytes,10,opt,name=metadata,proto3" json:"metadata,omitempty"`
// Optional. The launch stage of the metric definition.
LaunchStage api.LaunchStage `protobuf:"varint,12,opt,name=launch_stage,json=launchStage,proto3,enum=google.api.LaunchStage" json:"launch_stage,omitempty"`
// Read-only. If present, then a [time
// series][google.monitoring.v3.TimeSeries], which is identified partially by
// a metric type and a
// [MonitoredResourceDescriptor][google.api.MonitoredResourceDescriptor], that
// is associated with this metric type can only be associated with one of the
// monitored resource types listed here.
MonitoredResourceTypes []string `` /* 130-byte string literal not displayed */
// contains filtered or unexported fields
}
Defines a metric type and its schema. Once a metric descriptor is created, deleting or altering it stops data collection and makes the metric type's existing data unusable.
func (*MetricDescriptor) Descriptor
deprecated
func (*MetricDescriptor) Descriptor() ([]byte, []int)
Deprecated: Use MetricDescriptor.ProtoReflect.Descriptor instead.
func (*MetricDescriptor) GetDescription ¶
func (x *MetricDescriptor) GetDescription() string
func (*MetricDescriptor) GetDisplayName ¶
func (x *MetricDescriptor) GetDisplayName() string
func (*MetricDescriptor) GetLabels ¶
func (x *MetricDescriptor) GetLabels() []*label.LabelDescriptor
func (*MetricDescriptor) GetLaunchStage ¶
func (x *MetricDescriptor) GetLaunchStage() api.LaunchStage
func (*MetricDescriptor) GetMetadata ¶
func (x *MetricDescriptor) GetMetadata() *MetricDescriptor_MetricDescriptorMetadata
func (*MetricDescriptor) GetMetricKind ¶
func (x *MetricDescriptor) GetMetricKind() MetricDescriptor_MetricKind
func (*MetricDescriptor) GetMonitoredResourceTypes ¶
func (x *MetricDescriptor) GetMonitoredResourceTypes() []string
func (*MetricDescriptor) GetName ¶
func (x *MetricDescriptor) GetName() string
func (*MetricDescriptor) GetType ¶
func (x *MetricDescriptor) GetType() string
func (*MetricDescriptor) GetUnit ¶
func (x *MetricDescriptor) GetUnit() string
func (*MetricDescriptor) GetValueType ¶
func (x *MetricDescriptor) GetValueType() MetricDescriptor_ValueType
func (*MetricDescriptor) ProtoMessage ¶
func (*MetricDescriptor) ProtoMessage()
func (*MetricDescriptor) ProtoReflect ¶
func (x *MetricDescriptor) ProtoReflect() protoreflect.Message
func (*MetricDescriptor) Reset ¶
func (x *MetricDescriptor) Reset()
func (*MetricDescriptor) String ¶
func (x *MetricDescriptor) String() string
type MetricDescriptor_MetricDescriptorMetadata ¶
type MetricDescriptor_MetricDescriptorMetadata struct {
// Deprecated. Must use the
// [MetricDescriptor.launch_stage][google.api.MetricDescriptor.launch_stage]
// instead.
//
// Deprecated: Do not use.
LaunchStage api.LaunchStage `protobuf:"varint,1,opt,name=launch_stage,json=launchStage,proto3,enum=google.api.LaunchStage" json:"launch_stage,omitempty"`
// The sampling period of metric data points. For metrics which are written
// periodically, consecutive data points are stored at this time interval,
// excluding data loss due to errors. Metrics with a higher granularity have
// a smaller sampling period.
SamplePeriod *durationpb.Duration `protobuf:"bytes,2,opt,name=sample_period,json=samplePeriod,proto3" json:"sample_period,omitempty"`
// The delay of data points caused by ingestion. Data points older than this
// age are guaranteed to be ingested and available to be read, excluding
// data loss due to errors.
IngestDelay *durationpb.Duration `protobuf:"bytes,3,opt,name=ingest_delay,json=ingestDelay,proto3" json:"ingest_delay,omitempty"`
// The scope of the timeseries data of the metric.
TimeSeriesResourceHierarchyLevel []MetricDescriptor_MetricDescriptorMetadata_TimeSeriesResourceHierarchyLevel `` /* 262-byte string literal not displayed */
// contains filtered or unexported fields
}
Additional annotations that can be used to guide the usage of a metric.
func (*MetricDescriptor_MetricDescriptorMetadata) Descriptor
deprecated
func (*MetricDescriptor_MetricDescriptorMetadata) Descriptor() ([]byte, []int)
Deprecated: Use MetricDescriptor_MetricDescriptorMetadata.ProtoReflect.Descriptor instead.
func (*MetricDescriptor_MetricDescriptorMetadata) GetIngestDelay ¶
func (x *MetricDescriptor_MetricDescriptorMetadata) GetIngestDelay() *durationpb.Duration
func (*MetricDescriptor_MetricDescriptorMetadata) GetLaunchStage
deprecated
func (x *MetricDescriptor_MetricDescriptorMetadata) GetLaunchStage() api.LaunchStage
Deprecated: Do not use.
func (*MetricDescriptor_MetricDescriptorMetadata) GetSamplePeriod ¶
func (x *MetricDescriptor_MetricDescriptorMetadata) GetSamplePeriod() *durationpb.Duration
func (*MetricDescriptor_MetricDescriptorMetadata) GetTimeSeriesResourceHierarchyLevel ¶
func (x *MetricDescriptor_MetricDescriptorMetadata) GetTimeSeriesResourceHierarchyLevel() []MetricDescriptor_MetricDescriptorMetadata_TimeSeriesResourceHierarchyLevel
func (*MetricDescriptor_MetricDescriptorMetadata) ProtoMessage ¶
func (*MetricDescriptor_MetricDescriptorMetadata) ProtoMessage()
func (*MetricDescriptor_MetricDescriptorMetadata) ProtoReflect ¶
func (x *MetricDescriptor_MetricDescriptorMetadata) ProtoReflect() protoreflect.Message
func (*MetricDescriptor_MetricDescriptorMetadata) Reset ¶
func (x *MetricDescriptor_MetricDescriptorMetadata) Reset()
func (*MetricDescriptor_MetricDescriptorMetadata) String ¶
func (x *MetricDescriptor_MetricDescriptorMetadata) String() string
type MetricDescriptor_MetricDescriptorMetadata_TimeSeriesResourceHierarchyLevel ¶
type MetricDescriptor_MetricDescriptorMetadata_TimeSeriesResourceHierarchyLevel int32
The resource hierarchy level of the timeseries data of a metric.
const ( // Do not use this default value. MetricDescriptor_MetricDescriptorMetadata_TIME_SERIES_RESOURCE_HIERARCHY_LEVEL_UNSPECIFIED MetricDescriptor_MetricDescriptorMetadata_TimeSeriesResourceHierarchyLevel = 0 // Scopes a metric to a project. MetricDescriptor_MetricDescriptorMetadata_PROJECT MetricDescriptor_MetricDescriptorMetadata_TimeSeriesResourceHierarchyLevel = 1 // Scopes a metric to an organization. MetricDescriptor_MetricDescriptorMetadata_ORGANIZATION MetricDescriptor_MetricDescriptorMetadata_TimeSeriesResourceHierarchyLevel = 2 // Scopes a metric to a folder. MetricDescriptor_MetricDescriptorMetadata_FOLDER MetricDescriptor_MetricDescriptorMetadata_TimeSeriesResourceHierarchyLevel = 3 )
func (MetricDescriptor_MetricDescriptorMetadata_TimeSeriesResourceHierarchyLevel) Descriptor ¶
func (MetricDescriptor_MetricDescriptorMetadata_TimeSeriesResourceHierarchyLevel) EnumDescriptor
deprecated
func (MetricDescriptor_MetricDescriptorMetadata_TimeSeriesResourceHierarchyLevel) EnumDescriptor() ([]byte, []int)
Deprecated: Use MetricDescriptor_MetricDescriptorMetadata_TimeSeriesResourceHierarchyLevel.Descriptor instead.
type MetricDescriptor_MetricKind ¶
type MetricDescriptor_MetricKind int32
The kind of measurement. It describes how the data is reported. For information on setting the start time and end time based on the MetricKind, see [TimeInterval][google.monitoring.v3.TimeInterval].
const ( // Do not use this default value. MetricDescriptor_METRIC_KIND_UNSPECIFIED MetricDescriptor_MetricKind = 0 // An instantaneous measurement of a value. MetricDescriptor_GAUGE MetricDescriptor_MetricKind = 1 // The change in a value during a time interval. MetricDescriptor_DELTA MetricDescriptor_MetricKind = 2 // A value accumulated over a time interval. Cumulative // measurements in a time series should have the same start time // and increasing end times, until an event resets the cumulative // value to zero and sets a new start time for the following // points. MetricDescriptor_CUMULATIVE MetricDescriptor_MetricKind = 3 )
func (MetricDescriptor_MetricKind) Descriptor ¶
func (MetricDescriptor_MetricKind) Descriptor() protoreflect.EnumDescriptor
func (MetricDescriptor_MetricKind) Enum ¶
func (x MetricDescriptor_MetricKind) Enum() *MetricDescriptor_MetricKind
func (MetricDescriptor_MetricKind) EnumDescriptor
deprecated
func (MetricDescriptor_MetricKind) EnumDescriptor() ([]byte, []int)
Deprecated: Use MetricDescriptor_MetricKind.Descriptor instead.
func (MetricDescriptor_MetricKind) Number ¶
func (x MetricDescriptor_MetricKind) Number() protoreflect.EnumNumber
func (MetricDescriptor_MetricKind) String ¶
func (x MetricDescriptor_MetricKind) String() string
func (MetricDescriptor_MetricKind) Type ¶
func (MetricDescriptor_MetricKind) Type() protoreflect.EnumType
type MetricDescriptor_ValueType ¶
type MetricDescriptor_ValueType int32
The value type of a metric.
const ( // Do not use this default value. MetricDescriptor_VALUE_TYPE_UNSPECIFIED MetricDescriptor_ValueType = 0 // The value is a boolean. // This value type can be used only if the metric kind is `GAUGE`. MetricDescriptor_BOOL MetricDescriptor_ValueType = 1 // The value is a signed 64-bit integer. MetricDescriptor_INT64 MetricDescriptor_ValueType = 2 // The value is a double precision floating point number. MetricDescriptor_DOUBLE MetricDescriptor_ValueType = 3 // The value is a text string. // This value type can be used only if the metric kind is `GAUGE`. MetricDescriptor_STRING MetricDescriptor_ValueType = 4 // The value is a [`Distribution`][google.api.Distribution]. MetricDescriptor_DISTRIBUTION MetricDescriptor_ValueType = 5 // The value is money. MetricDescriptor_MONEY MetricDescriptor_ValueType = 6 )
func (MetricDescriptor_ValueType) Descriptor ¶
func (MetricDescriptor_ValueType) Descriptor() protoreflect.EnumDescriptor
func (MetricDescriptor_ValueType) Enum ¶
func (x MetricDescriptor_ValueType) Enum() *MetricDescriptor_ValueType
func (MetricDescriptor_ValueType) EnumDescriptor
deprecated
func (MetricDescriptor_ValueType) EnumDescriptor() ([]byte, []int)
Deprecated: Use MetricDescriptor_ValueType.Descriptor instead.
func (MetricDescriptor_ValueType) Number ¶
func (x MetricDescriptor_ValueType) Number() protoreflect.EnumNumber
func (MetricDescriptor_ValueType) String ¶
func (x MetricDescriptor_ValueType) String() string
func (MetricDescriptor_ValueType) Type ¶
func (MetricDescriptor_ValueType) Type() protoreflect.EnumType