package docs
import "google.golang.org/genproto/googleapis/apps/script/type/docs"
Index ¶
- Variables
- type DocsAddOnManifest
- func (*DocsAddOnManifest) Descriptor() ([]byte, []int)
- func (x *DocsAddOnManifest) GetHomepageTrigger() *_type.HomepageExtensionPoint
- func (x *DocsAddOnManifest) GetOnFileScopeGrantedTrigger() *DocsExtensionPoint
- func (*DocsAddOnManifest) ProtoMessage()
- func (x *DocsAddOnManifest) ProtoReflect() protoreflect.Message
- func (x *DocsAddOnManifest) Reset()
- func (x *DocsAddOnManifest) String() string
- type DocsExtensionPoint
Variables ¶
var File_google_apps_script_type_docs_docs_addon_manifest_proto protoreflect.FileDescriptor
Types ¶
type DocsAddOnManifest ¶
type DocsAddOnManifest struct {
// If present, this overrides the configuration from
// `addOns.common.homepageTrigger`.
HomepageTrigger *_type.HomepageExtensionPoint `protobuf:"bytes,1,opt,name=homepage_trigger,json=homepageTrigger,proto3" json:"homepage_trigger,omitempty"`
// Endpoint to execute when file scope authorization is granted
// for this document/user pair.
OnFileScopeGrantedTrigger *DocsExtensionPoint `protobuf:"bytes,2,opt,name=on_file_scope_granted_trigger,json=onFileScopeGrantedTrigger,proto3" json:"on_file_scope_granted_trigger,omitempty"`
// contains filtered or unexported fields
}
Docs add-on manifest.
func (*DocsAddOnManifest) Descriptor ¶
func (*DocsAddOnManifest) Descriptor() ([]byte, []int)
Deprecated: Use DocsAddOnManifest.ProtoReflect.Descriptor instead.
func (*DocsAddOnManifest) GetHomepageTrigger ¶
func (x *DocsAddOnManifest) GetHomepageTrigger() *_type.HomepageExtensionPoint
func (*DocsAddOnManifest) GetOnFileScopeGrantedTrigger ¶
func (x *DocsAddOnManifest) GetOnFileScopeGrantedTrigger() *DocsExtensionPoint
func (*DocsAddOnManifest) ProtoMessage ¶
func (*DocsAddOnManifest) ProtoMessage()
func (*DocsAddOnManifest) ProtoReflect ¶
func (x *DocsAddOnManifest) ProtoReflect() protoreflect.Message
func (*DocsAddOnManifest) Reset ¶
func (x *DocsAddOnManifest) Reset()
func (*DocsAddOnManifest) String ¶
func (x *DocsAddOnManifest) String() string
type DocsExtensionPoint ¶
type DocsExtensionPoint struct {
// Required. The endpoint to execute when this extension point is activated.
RunFunction string `protobuf:"bytes,1,opt,name=run_function,json=runFunction,proto3" json:"run_function,omitempty"`
// contains filtered or unexported fields
}
Common format for declaring a Docs add-on's triggers.
func (*DocsExtensionPoint) Descriptor ¶
func (*DocsExtensionPoint) Descriptor() ([]byte, []int)
Deprecated: Use DocsExtensionPoint.ProtoReflect.Descriptor instead.
func (*DocsExtensionPoint) GetRunFunction ¶
func (x *DocsExtensionPoint) GetRunFunction() string
func (*DocsExtensionPoint) ProtoMessage ¶
func (*DocsExtensionPoint) ProtoMessage()
func (*DocsExtensionPoint) ProtoReflect ¶
func (x *DocsExtensionPoint) ProtoReflect() protoreflect.Message
func (*DocsExtensionPoint) Reset ¶
func (x *DocsExtensionPoint) Reset()
func (*DocsExtensionPoint) String ¶
func (x *DocsExtensionPoint) String() string
Source Files ¶
docs_addon_manifest.pb.go
- Version
- v0.0.0-20260427160629-7cedc36a6bc4 (latest)
- Published
- Apr 27, 2026
- Platform
- linux/amd64
- Imports
- 6 packages
- Last checked
- 2 days ago –
Tools for package owners.