package table
import "google.golang.org/genproto/googleapis/bigtable/admin/table/v1"
Index ¶
- Variables
- func RegisterBigtableTableServiceServer(s *grpc.Server, srv BigtableTableServiceServer)
- type BigtableTableServiceClient
- type BigtableTableServiceServer
- type BulkDeleteRowsRequest
- func (*BulkDeleteRowsRequest) Descriptor() ([]byte, []int)
- func (x *BulkDeleteRowsRequest) GetDeleteAllDataFromTable() bool
- func (x *BulkDeleteRowsRequest) GetRowKeyPrefix() []byte
- func (x *BulkDeleteRowsRequest) GetTableName() string
- func (m *BulkDeleteRowsRequest) GetTarget() isBulkDeleteRowsRequest_Target
- func (*BulkDeleteRowsRequest) ProtoMessage()
- func (x *BulkDeleteRowsRequest) ProtoReflect() protoreflect.Message
- func (x *BulkDeleteRowsRequest) Reset()
- func (x *BulkDeleteRowsRequest) String() string
- type BulkDeleteRowsRequest_DeleteAllDataFromTable
- type BulkDeleteRowsRequest_RowKeyPrefix
- type ColumnFamily
- func (*ColumnFamily) Descriptor() ([]byte, []int)
- func (x *ColumnFamily) GetGcExpression() string
- func (x *ColumnFamily) GetGcRule() *GcRule
- func (x *ColumnFamily) GetName() string
- func (*ColumnFamily) ProtoMessage()
- func (x *ColumnFamily) ProtoReflect() protoreflect.Message
- func (x *ColumnFamily) Reset()
- func (x *ColumnFamily) String() string
- type CreateColumnFamilyRequest
- func (*CreateColumnFamilyRequest) Descriptor() ([]byte, []int)
- func (x *CreateColumnFamilyRequest) GetColumnFamily() *ColumnFamily
- func (x *CreateColumnFamilyRequest) GetColumnFamilyId() string
- func (x *CreateColumnFamilyRequest) GetName() string
- func (*CreateColumnFamilyRequest) ProtoMessage()
- func (x *CreateColumnFamilyRequest) ProtoReflect() protoreflect.Message
- func (x *CreateColumnFamilyRequest) Reset()
- func (x *CreateColumnFamilyRequest) String() string
- type CreateTableRequest
- func (*CreateTableRequest) Descriptor() ([]byte, []int)
- func (x *CreateTableRequest) GetInitialSplitKeys() []string
- func (x *CreateTableRequest) GetName() string
- func (x *CreateTableRequest) GetTable() *Table
- func (x *CreateTableRequest) GetTableId() string
- func (*CreateTableRequest) ProtoMessage()
- func (x *CreateTableRequest) ProtoReflect() protoreflect.Message
- func (x *CreateTableRequest) Reset()
- func (x *CreateTableRequest) String() string
- type DeleteColumnFamilyRequest
- func (*DeleteColumnFamilyRequest) Descriptor() ([]byte, []int)
- func (x *DeleteColumnFamilyRequest) GetName() string
- func (*DeleteColumnFamilyRequest) ProtoMessage()
- func (x *DeleteColumnFamilyRequest) ProtoReflect() protoreflect.Message
- func (x *DeleteColumnFamilyRequest) Reset()
- func (x *DeleteColumnFamilyRequest) String() string
- type DeleteTableRequest
- func (*DeleteTableRequest) Descriptor() ([]byte, []int)
- func (x *DeleteTableRequest) GetName() string
- func (*DeleteTableRequest) ProtoMessage()
- func (x *DeleteTableRequest) ProtoReflect() protoreflect.Message
- func (x *DeleteTableRequest) Reset()
- func (x *DeleteTableRequest) String() string
- type GcRule
- func (*GcRule) Descriptor() ([]byte, []int)
- func (x *GcRule) GetIntersection() *GcRule_Intersection
- func (x *GcRule) GetMaxAge() *durationpb.Duration
- func (x *GcRule) GetMaxNumVersions() int32
- func (m *GcRule) GetRule() isGcRule_Rule
- func (x *GcRule) GetUnion() *GcRule_Union
- func (*GcRule) ProtoMessage()
- func (x *GcRule) ProtoReflect() protoreflect.Message
- func (x *GcRule) Reset()
- func (x *GcRule) String() string
- type GcRule_Intersection
- func (*GcRule_Intersection) Descriptor() ([]byte, []int)
- func (x *GcRule_Intersection) GetRules() []*GcRule
- func (*GcRule_Intersection) ProtoMessage()
- func (x *GcRule_Intersection) ProtoReflect() protoreflect.Message
- func (x *GcRule_Intersection) Reset()
- func (x *GcRule_Intersection) String() string
- type GcRule_Intersection_
- type GcRule_MaxAge
- type GcRule_MaxNumVersions
- type GcRule_Union
- func (*GcRule_Union) Descriptor() ([]byte, []int)
- func (x *GcRule_Union) GetRules() []*GcRule
- func (*GcRule_Union) ProtoMessage()
- func (x *GcRule_Union) ProtoReflect() protoreflect.Message
- func (x *GcRule_Union) Reset()
- func (x *GcRule_Union) String() string
- type GcRule_Union_
- type GetTableRequest
- func (*GetTableRequest) Descriptor() ([]byte, []int)
- func (x *GetTableRequest) GetName() string
- func (*GetTableRequest) ProtoMessage()
- func (x *GetTableRequest) ProtoReflect() protoreflect.Message
- func (x *GetTableRequest) Reset()
- func (x *GetTableRequest) String() string
- type ListTablesRequest
- func (*ListTablesRequest) Descriptor() ([]byte, []int)
- func (x *ListTablesRequest) GetName() string
- func (*ListTablesRequest) ProtoMessage()
- func (x *ListTablesRequest) ProtoReflect() protoreflect.Message
- func (x *ListTablesRequest) Reset()
- func (x *ListTablesRequest) String() string
- type ListTablesResponse
- func (*ListTablesResponse) Descriptor() ([]byte, []int)
- func (x *ListTablesResponse) GetTables() []*Table
- func (*ListTablesResponse) ProtoMessage()
- func (x *ListTablesResponse) ProtoReflect() protoreflect.Message
- func (x *ListTablesResponse) Reset()
- func (x *ListTablesResponse) String() string
- type RenameTableRequest
- func (*RenameTableRequest) Descriptor() ([]byte, []int)
- func (x *RenameTableRequest) GetName() string
- func (x *RenameTableRequest) GetNewId() string
- func (*RenameTableRequest) ProtoMessage()
- func (x *RenameTableRequest) ProtoReflect() protoreflect.Message
- func (x *RenameTableRequest) Reset()
- func (x *RenameTableRequest) String() string
- type Table
- func (*Table) Descriptor() ([]byte, []int)
- func (x *Table) GetColumnFamilies() map[string]*ColumnFamily
- func (x *Table) GetCurrentOperation() *longrunning.Operation
- func (x *Table) GetGranularity() Table_TimestampGranularity
- func (x *Table) GetName() string
- func (*Table) ProtoMessage()
- func (x *Table) ProtoReflect() protoreflect.Message
- func (x *Table) Reset()
- func (x *Table) String() string
- type Table_TimestampGranularity
- func (Table_TimestampGranularity) Descriptor() protoreflect.EnumDescriptor
- func (x Table_TimestampGranularity) Enum() *Table_TimestampGranularity
- func (Table_TimestampGranularity) EnumDescriptor() ([]byte, []int)
- func (x Table_TimestampGranularity) Number() protoreflect.EnumNumber
- func (x Table_TimestampGranularity) String() string
- func (Table_TimestampGranularity) Type() protoreflect.EnumType
- type UnimplementedBigtableTableServiceServer
- func (*UnimplementedBigtableTableServiceServer) BulkDeleteRows(context.Context, *BulkDeleteRowsRequest) (*emptypb.Empty, error)
- func (*UnimplementedBigtableTableServiceServer) CreateColumnFamily(context.Context, *CreateColumnFamilyRequest) (*ColumnFamily, error)
- func (*UnimplementedBigtableTableServiceServer) CreateTable(context.Context, *CreateTableRequest) (*Table, error)
- func (*UnimplementedBigtableTableServiceServer) DeleteColumnFamily(context.Context, *DeleteColumnFamilyRequest) (*emptypb.Empty, error)
- func (*UnimplementedBigtableTableServiceServer) DeleteTable(context.Context, *DeleteTableRequest) (*emptypb.Empty, error)
- func (*UnimplementedBigtableTableServiceServer) GetTable(context.Context, *GetTableRequest) (*Table, error)
- func (*UnimplementedBigtableTableServiceServer) ListTables(context.Context, *ListTablesRequest) (*ListTablesResponse, error)
- func (*UnimplementedBigtableTableServiceServer) RenameTable(context.Context, *RenameTableRequest) (*emptypb.Empty, error)
- func (*UnimplementedBigtableTableServiceServer) UpdateColumnFamily(context.Context, *ColumnFamily) (*ColumnFamily, error)
Variables ¶
var ( Table_TimestampGranularity_name = map[int32]string{ 0: "MILLIS", } Table_TimestampGranularity_value = map[string]int32{ "MILLIS": 0, } )
Enum value maps for Table_TimestampGranularity.
var File_google_bigtable_admin_table_v1_bigtable_table_data_proto protoreflect.FileDescriptor
var File_google_bigtable_admin_table_v1_bigtable_table_service_messages_proto protoreflect.FileDescriptor
var File_google_bigtable_admin_table_v1_bigtable_table_service_proto protoreflect.FileDescriptor
Functions ¶
func RegisterBigtableTableServiceServer ¶
func RegisterBigtableTableServiceServer(s *grpc.Server, srv BigtableTableServiceServer)
Types ¶
type BigtableTableServiceClient ¶
type BigtableTableServiceClient interface {
// Creates a new table, to be served from a specified cluster.
// The table can be created with a full set of initial column families,
// specified in the request.
CreateTable(ctx context.Context, in *CreateTableRequest, opts ...grpc.CallOption) (*Table, error)
// Lists the names of all tables served from a specified cluster.
ListTables(ctx context.Context, in *ListTablesRequest, opts ...grpc.CallOption) (*ListTablesResponse, error)
// Gets the schema of the specified table, including its column families.
GetTable(ctx context.Context, in *GetTableRequest, opts ...grpc.CallOption) (*Table, error)
// Permanently deletes a specified table and all of its data.
DeleteTable(ctx context.Context, in *DeleteTableRequest, opts ...grpc.CallOption) (*emptypb.Empty, error)
// Changes the name of a specified table.
// Cannot be used to move tables between clusters, zones, or projects.
RenameTable(ctx context.Context, in *RenameTableRequest, opts ...grpc.CallOption) (*emptypb.Empty, error)
// Creates a new column family within a specified table.
CreateColumnFamily(ctx context.Context, in *CreateColumnFamilyRequest, opts ...grpc.CallOption) (*ColumnFamily, error)
// Changes the configuration of a specified column family.
UpdateColumnFamily(ctx context.Context, in *ColumnFamily, opts ...grpc.CallOption) (*ColumnFamily, error)
// Permanently deletes a specified column family and all of its data.
DeleteColumnFamily(ctx context.Context, in *DeleteColumnFamilyRequest, opts ...grpc.CallOption) (*emptypb.Empty, error)
// Delete all rows in a table corresponding to a particular prefix
BulkDeleteRows(ctx context.Context, in *BulkDeleteRowsRequest, opts ...grpc.CallOption) (*emptypb.Empty, error)
}
BigtableTableServiceClient is the client API for BigtableTableService service.
For semantics around ctx use and closing/ending streaming RPCs, please refer to https://godoc.org/google.golang.org/grpc#ClientConn.NewStream.
func NewBigtableTableServiceClient ¶
func NewBigtableTableServiceClient(cc grpc.ClientConnInterface) BigtableTableServiceClient
type BigtableTableServiceServer ¶
type BigtableTableServiceServer interface {
// Creates a new table, to be served from a specified cluster.
// The table can be created with a full set of initial column families,
// specified in the request.
CreateTable(context.Context, *CreateTableRequest) (*Table, error)
// Lists the names of all tables served from a specified cluster.
ListTables(context.Context, *ListTablesRequest) (*ListTablesResponse, error)
// Gets the schema of the specified table, including its column families.
GetTable(context.Context, *GetTableRequest) (*Table, error)
// Permanently deletes a specified table and all of its data.
DeleteTable(context.Context, *DeleteTableRequest) (*emptypb.Empty, error)
// Changes the name of a specified table.
// Cannot be used to move tables between clusters, zones, or projects.
RenameTable(context.Context, *RenameTableRequest) (*emptypb.Empty, error)
// Creates a new column family within a specified table.
CreateColumnFamily(context.Context, *CreateColumnFamilyRequest) (*ColumnFamily, error)
// Changes the configuration of a specified column family.
UpdateColumnFamily(context.Context, *ColumnFamily) (*ColumnFamily, error)
// Permanently deletes a specified column family and all of its data.
DeleteColumnFamily(context.Context, *DeleteColumnFamilyRequest) (*emptypb.Empty, error)
// Delete all rows in a table corresponding to a particular prefix
BulkDeleteRows(context.Context, *BulkDeleteRowsRequest) (*emptypb.Empty, error)
}
BigtableTableServiceServer is the server API for BigtableTableService service.
type BulkDeleteRowsRequest ¶
type BulkDeleteRowsRequest struct {
// The unique name of the table on which to perform the bulk delete
TableName string `protobuf:"bytes,1,opt,name=table_name,json=tableName,proto3" json:"table_name,omitempty"`
// Types that are assignable to Target:
// *BulkDeleteRowsRequest_RowKeyPrefix
// *BulkDeleteRowsRequest_DeleteAllDataFromTable
Target isBulkDeleteRowsRequest_Target `protobuf_oneof:"target"`
// contains filtered or unexported fields
}
func (*BulkDeleteRowsRequest) Descriptor ¶
func (*BulkDeleteRowsRequest) Descriptor() ([]byte, []int)
Deprecated: Use BulkDeleteRowsRequest.ProtoReflect.Descriptor instead.
func (*BulkDeleteRowsRequest) GetDeleteAllDataFromTable ¶
func (x *BulkDeleteRowsRequest) GetDeleteAllDataFromTable() bool
func (*BulkDeleteRowsRequest) GetRowKeyPrefix ¶
func (x *BulkDeleteRowsRequest) GetRowKeyPrefix() []byte
func (*BulkDeleteRowsRequest) GetTableName ¶
func (x *BulkDeleteRowsRequest) GetTableName() string
func (*BulkDeleteRowsRequest) GetTarget ¶
func (m *BulkDeleteRowsRequest) GetTarget() isBulkDeleteRowsRequest_Target
func (*BulkDeleteRowsRequest) ProtoMessage ¶
func (*BulkDeleteRowsRequest) ProtoMessage()
func (*BulkDeleteRowsRequest) ProtoReflect ¶
func (x *BulkDeleteRowsRequest) ProtoReflect() protoreflect.Message
func (*BulkDeleteRowsRequest) Reset ¶
func (x *BulkDeleteRowsRequest) Reset()
func (*BulkDeleteRowsRequest) String ¶
func (x *BulkDeleteRowsRequest) String() string
type BulkDeleteRowsRequest_DeleteAllDataFromTable ¶
type BulkDeleteRowsRequest_DeleteAllDataFromTable struct {
// Delete all rows in the table. Setting this to false is a no-op.
DeleteAllDataFromTable bool `protobuf:"varint,3,opt,name=delete_all_data_from_table,json=deleteAllDataFromTable,proto3,oneof"`
}
type BulkDeleteRowsRequest_RowKeyPrefix ¶
type BulkDeleteRowsRequest_RowKeyPrefix struct {
// Delete all rows that start with this row key prefix. Prefix cannot be
// zero length.
RowKeyPrefix []byte `protobuf:"bytes,2,opt,name=row_key_prefix,json=rowKeyPrefix,proto3,oneof"`
}
type ColumnFamily ¶
type ColumnFamily struct {
// A unique identifier of the form <table_name>/columnFamilies/[-_.a-zA-Z0-9]+
// The last segment is the same as the "name" field in
// google.bigtable.v1.Family.
Name string `protobuf:"bytes,1,opt,name=name,proto3" json:"name,omitempty"`
// Garbage collection expression specified by the following grammar:
// GC = EXPR
// | "" ;
// EXPR = EXPR, "||", EXPR (* lowest precedence *)
// | EXPR, "&&", EXPR
// | "(", EXPR, ")" (* highest precedence *)
// | PROP ;
// PROP = "version() >", NUM32
// | "age() >", NUM64, [ UNIT ] ;
// NUM32 = non-zero-digit { digit } ; (* # NUM32 <= 2^32 - 1 *)
// NUM64 = non-zero-digit { digit } ; (* # NUM64 <= 2^63 - 1 *)
// UNIT = "d" | "h" | "m" (* d=days, h=hours, m=minutes, else micros *)
// GC expressions can be up to 500 characters in length
//
// The different types of PROP are defined as follows:
// version() - cell index, counting from most recent and starting at 1
// age() - age of the cell (current time minus cell timestamp)
//
// Example: "version() > 3 || (age() > 3d && version() > 1)"
// drop cells beyond the most recent three, and drop cells older than three
// days unless they're the most recent cell in the row/column
//
// Garbage collection executes opportunistically in the background, and so
// it's possible for reads to return a cell even if it matches the active GC
// expression for its family.
GcExpression string `protobuf:"bytes,2,opt,name=gc_expression,json=gcExpression,proto3" json:"gc_expression,omitempty"`
// Garbage collection rule specified as a protobuf.
// Supersedes `gc_expression`.
// Must serialize to at most 500 bytes.
//
// NOTE: Garbage collection executes opportunistically in the background, and
// so it's possible for reads to return a cell even if it matches the active
// GC expression for its family.
GcRule *GcRule `protobuf:"bytes,3,opt,name=gc_rule,json=gcRule,proto3" json:"gc_rule,omitempty"`
// contains filtered or unexported fields
}
A set of columns within a table which share a common configuration.
func (*ColumnFamily) Descriptor ¶
func (*ColumnFamily) Descriptor() ([]byte, []int)
Deprecated: Use ColumnFamily.ProtoReflect.Descriptor instead.
func (*ColumnFamily) GetGcExpression ¶
func (x *ColumnFamily) GetGcExpression() string
func (*ColumnFamily) GetGcRule ¶
func (x *ColumnFamily) GetGcRule() *GcRule
func (*ColumnFamily) GetName ¶
func (x *ColumnFamily) GetName() string
func (*ColumnFamily) ProtoMessage ¶
func (*ColumnFamily) ProtoMessage()
func (*ColumnFamily) ProtoReflect ¶
func (x *ColumnFamily) ProtoReflect() protoreflect.Message
func (*ColumnFamily) Reset ¶
func (x *ColumnFamily) Reset()
func (*ColumnFamily) String ¶
func (x *ColumnFamily) String() string
type CreateColumnFamilyRequest ¶
type CreateColumnFamilyRequest struct {
// The unique name of the table in which to create the new column family.
Name string `protobuf:"bytes,1,opt,name=name,proto3" json:"name,omitempty"`
// The name by which the new column family should be referred to within the
// table, e.g. "foobar" rather than "<table_name>/columnFamilies/foobar".
ColumnFamilyId string `protobuf:"bytes,2,opt,name=column_family_id,json=columnFamilyId,proto3" json:"column_family_id,omitempty"`
// The column family to create. The `name` field must be left blank.
ColumnFamily *ColumnFamily `protobuf:"bytes,3,opt,name=column_family,json=columnFamily,proto3" json:"column_family,omitempty"`
// contains filtered or unexported fields
}
func (*CreateColumnFamilyRequest) Descriptor ¶
func (*CreateColumnFamilyRequest) Descriptor() ([]byte, []int)
Deprecated: Use CreateColumnFamilyRequest.ProtoReflect.Descriptor instead.
func (*CreateColumnFamilyRequest) GetColumnFamily ¶
func (x *CreateColumnFamilyRequest) GetColumnFamily() *ColumnFamily
func (*CreateColumnFamilyRequest) GetColumnFamilyId ¶
func (x *CreateColumnFamilyRequest) GetColumnFamilyId() string
func (*CreateColumnFamilyRequest) GetName ¶
func (x *CreateColumnFamilyRequest) GetName() string
func (*CreateColumnFamilyRequest) ProtoMessage ¶
func (*CreateColumnFamilyRequest) ProtoMessage()
func (*CreateColumnFamilyRequest) ProtoReflect ¶
func (x *CreateColumnFamilyRequest) ProtoReflect() protoreflect.Message
func (*CreateColumnFamilyRequest) Reset ¶
func (x *CreateColumnFamilyRequest) Reset()
func (*CreateColumnFamilyRequest) String ¶
func (x *CreateColumnFamilyRequest) String() string
type CreateTableRequest ¶
type CreateTableRequest struct {
// The unique name of the cluster in which to create the new table.
Name string `protobuf:"bytes,1,opt,name=name,proto3" json:"name,omitempty"`
// The name by which the new table should be referred to within the cluster,
// e.g. "foobar" rather than "<cluster_name>/tables/foobar".
TableId string `protobuf:"bytes,2,opt,name=table_id,json=tableId,proto3" json:"table_id,omitempty"`
// The Table to create. The `name` field of the Table and all of its
// ColumnFamilies must be left blank, and will be populated in the response.
Table *Table `protobuf:"bytes,3,opt,name=table,proto3" json:"table,omitempty"`
// The optional list of row keys that will be used to initially split the
// table into several tablets (Tablets are similar to HBase regions).
// Given two split keys, "s1" and "s2", three tablets will be created,
// spanning the key ranges: [, s1), [s1, s2), [s2, ).
//
// Example:
// * Row keys := ["a", "apple", "custom", "customer_1", "customer_2",
// "other", "zz"]
// * initial_split_keys := ["apple", "customer_1", "customer_2", "other"]
// * Key assignment:
// - Tablet 1 [, apple) => {"a"}.
// - Tablet 2 [apple, customer_1) => {"apple", "custom"}.
// - Tablet 3 [customer_1, customer_2) => {"customer_1"}.
// - Tablet 4 [customer_2, other) => {"customer_2"}.
// - Tablet 5 [other, ) => {"other", "zz"}.
InitialSplitKeys []string `protobuf:"bytes,4,rep,name=initial_split_keys,json=initialSplitKeys,proto3" json:"initial_split_keys,omitempty"`
// contains filtered or unexported fields
}
func (*CreateTableRequest) Descriptor ¶
func (*CreateTableRequest) Descriptor() ([]byte, []int)
Deprecated: Use CreateTableRequest.ProtoReflect.Descriptor instead.
func (*CreateTableRequest) GetInitialSplitKeys ¶
func (x *CreateTableRequest) GetInitialSplitKeys() []string
func (*CreateTableRequest) GetName ¶
func (x *CreateTableRequest) GetName() string
func (*CreateTableRequest) GetTable ¶
func (x *CreateTableRequest) GetTable() *Table
func (*CreateTableRequest) GetTableId ¶
func (x *CreateTableRequest) GetTableId() string
func (*CreateTableRequest) ProtoMessage ¶
func (*CreateTableRequest) ProtoMessage()
func (*CreateTableRequest) ProtoReflect ¶
func (x *CreateTableRequest) ProtoReflect() protoreflect.Message
func (*CreateTableRequest) Reset ¶
func (x *CreateTableRequest) Reset()
func (*CreateTableRequest) String ¶
func (x *CreateTableRequest) String() string
type DeleteColumnFamilyRequest ¶
type DeleteColumnFamilyRequest struct {
// The unique name of the column family to be deleted.
Name string `protobuf:"bytes,1,opt,name=name,proto3" json:"name,omitempty"`
// contains filtered or unexported fields
}
func (*DeleteColumnFamilyRequest) Descriptor ¶
func (*DeleteColumnFamilyRequest) Descriptor() ([]byte, []int)
Deprecated: Use DeleteColumnFamilyRequest.ProtoReflect.Descriptor instead.
func (*DeleteColumnFamilyRequest) GetName ¶
func (x *DeleteColumnFamilyRequest) GetName() string
func (*DeleteColumnFamilyRequest) ProtoMessage ¶
func (*DeleteColumnFamilyRequest) ProtoMessage()
func (*DeleteColumnFamilyRequest) ProtoReflect ¶
func (x *DeleteColumnFamilyRequest) ProtoReflect() protoreflect.Message
func (*DeleteColumnFamilyRequest) Reset ¶
func (x *DeleteColumnFamilyRequest) Reset()
func (*DeleteColumnFamilyRequest) String ¶
func (x *DeleteColumnFamilyRequest) String() string
type DeleteTableRequest ¶
type DeleteTableRequest struct {
// The unique name of the table to be deleted.
Name string `protobuf:"bytes,1,opt,name=name,proto3" json:"name,omitempty"`
// contains filtered or unexported fields
}
func (*DeleteTableRequest) Descriptor ¶
func (*DeleteTableRequest) Descriptor() ([]byte, []int)
Deprecated: Use DeleteTableRequest.ProtoReflect.Descriptor instead.
func (*DeleteTableRequest) GetName ¶
func (x *DeleteTableRequest) GetName() string
func (*DeleteTableRequest) ProtoMessage ¶
func (*DeleteTableRequest) ProtoMessage()
func (*DeleteTableRequest) ProtoReflect ¶
func (x *DeleteTableRequest) ProtoReflect() protoreflect.Message
func (*DeleteTableRequest) Reset ¶
func (x *DeleteTableRequest) Reset()
func (*DeleteTableRequest) String ¶
func (x *DeleteTableRequest) String() string
type GcRule ¶
type GcRule struct {
// Types that are assignable to Rule:
// *GcRule_MaxNumVersions
// *GcRule_MaxAge
// *GcRule_Intersection_
// *GcRule_Union_
Rule isGcRule_Rule `protobuf_oneof:"rule"`
// contains filtered or unexported fields
}
Rule for determining which cells to delete during garbage collection.
func (*GcRule) Descriptor ¶
Deprecated: Use GcRule.ProtoReflect.Descriptor instead.
func (*GcRule) GetIntersection ¶
func (x *GcRule) GetIntersection() *GcRule_Intersection
func (*GcRule) GetMaxAge ¶
func (x *GcRule) GetMaxAge() *durationpb.Duration
func (*GcRule) GetMaxNumVersions ¶
func (*GcRule) GetRule ¶
func (m *GcRule) GetRule() isGcRule_Rule
func (*GcRule) GetUnion ¶
func (x *GcRule) GetUnion() *GcRule_Union
func (*GcRule) ProtoMessage ¶
func (*GcRule) ProtoMessage()
func (*GcRule) ProtoReflect ¶
func (x *GcRule) ProtoReflect() protoreflect.Message
func (*GcRule) Reset ¶
func (x *GcRule) Reset()
func (*GcRule) String ¶
type GcRule_Intersection ¶
type GcRule_Intersection struct {
// Only delete cells which would be deleted by every element of `rules`.
Rules []*GcRule `protobuf:"bytes,1,rep,name=rules,proto3" json:"rules,omitempty"`
// contains filtered or unexported fields
}
A GcRule which deletes cells matching all of the given rules.
func (*GcRule_Intersection) Descriptor ¶
func (*GcRule_Intersection) Descriptor() ([]byte, []int)
Deprecated: Use GcRule_Intersection.ProtoReflect.Descriptor instead.
func (*GcRule_Intersection) GetRules ¶
func (x *GcRule_Intersection) GetRules() []*GcRule
func (*GcRule_Intersection) ProtoMessage ¶
func (*GcRule_Intersection) ProtoMessage()
func (*GcRule_Intersection) ProtoReflect ¶
func (x *GcRule_Intersection) ProtoReflect() protoreflect.Message
func (*GcRule_Intersection) Reset ¶
func (x *GcRule_Intersection) Reset()
func (*GcRule_Intersection) String ¶
func (x *GcRule_Intersection) String() string
type GcRule_Intersection_ ¶
type GcRule_Intersection_ struct {
// Delete cells that would be deleted by every nested rule.
Intersection *GcRule_Intersection `protobuf:"bytes,3,opt,name=intersection,proto3,oneof"`
}
type GcRule_MaxAge ¶
type GcRule_MaxAge struct {
// Delete cells in a column older than the given age.
// Values must be at least one millisecond, and will be truncated to
// microsecond granularity.
MaxAge *durationpb.Duration `protobuf:"bytes,2,opt,name=max_age,json=maxAge,proto3,oneof"`
}
type GcRule_MaxNumVersions ¶
type GcRule_MaxNumVersions struct {
// Delete all cells in a column except the most recent N.
MaxNumVersions int32 `protobuf:"varint,1,opt,name=max_num_versions,json=maxNumVersions,proto3,oneof"`
}
type GcRule_Union ¶
type GcRule_Union struct {
// Delete cells which would be deleted by any element of `rules`.
Rules []*GcRule `protobuf:"bytes,1,rep,name=rules,proto3" json:"rules,omitempty"`
// contains filtered or unexported fields
}
A GcRule which deletes cells matching any of the given rules.
func (*GcRule_Union) Descriptor ¶
func (*GcRule_Union) Descriptor() ([]byte, []int)
Deprecated: Use GcRule_Union.ProtoReflect.Descriptor instead.
func (*GcRule_Union) GetRules ¶
func (x *GcRule_Union) GetRules() []*GcRule
func (*GcRule_Union) ProtoMessage ¶
func (*GcRule_Union) ProtoMessage()
func (*GcRule_Union) ProtoReflect ¶
func (x *GcRule_Union) ProtoReflect() protoreflect.Message
func (*GcRule_Union) Reset ¶
func (x *GcRule_Union) Reset()
func (*GcRule_Union) String ¶
func (x *GcRule_Union) String() string
type GcRule_Union_ ¶
type GcRule_Union_ struct {
// Delete cells that would be deleted by any nested rule.
Union *GcRule_Union `protobuf:"bytes,4,opt,name=union,proto3,oneof"`
}
type GetTableRequest ¶
type GetTableRequest struct {
// The unique name of the requested table.
Name string `protobuf:"bytes,1,opt,name=name,proto3" json:"name,omitempty"`
// contains filtered or unexported fields
}
func (*GetTableRequest) Descriptor ¶
func (*GetTableRequest) Descriptor() ([]byte, []int)
Deprecated: Use GetTableRequest.ProtoReflect.Descriptor instead.
func (*GetTableRequest) GetName ¶
func (x *GetTableRequest) GetName() string
func (*GetTableRequest) ProtoMessage ¶
func (*GetTableRequest) ProtoMessage()
func (*GetTableRequest) ProtoReflect ¶
func (x *GetTableRequest) ProtoReflect() protoreflect.Message
func (*GetTableRequest) Reset ¶
func (x *GetTableRequest) Reset()
func (*GetTableRequest) String ¶
func (x *GetTableRequest) String() string
type ListTablesRequest ¶
type ListTablesRequest struct {
// The unique name of the cluster for which tables should be listed.
Name string `protobuf:"bytes,1,opt,name=name,proto3" json:"name,omitempty"`
// contains filtered or unexported fields
}
func (*ListTablesRequest) Descriptor ¶
func (*ListTablesRequest) Descriptor() ([]byte, []int)
Deprecated: Use ListTablesRequest.ProtoReflect.Descriptor instead.
func (*ListTablesRequest) GetName ¶
func (x *ListTablesRequest) GetName() string
func (*ListTablesRequest) ProtoMessage ¶
func (*ListTablesRequest) ProtoMessage()
func (*ListTablesRequest) ProtoReflect ¶
func (x *ListTablesRequest) ProtoReflect() protoreflect.Message
func (*ListTablesRequest) Reset ¶
func (x *ListTablesRequest) Reset()
func (*ListTablesRequest) String ¶
func (x *ListTablesRequest) String() string
type ListTablesResponse ¶
type ListTablesResponse struct {
// The tables present in the requested cluster.
// At present, only the names of the tables are populated.
Tables []*Table `protobuf:"bytes,1,rep,name=tables,proto3" json:"tables,omitempty"`
// contains filtered or unexported fields
}
func (*ListTablesResponse) Descriptor ¶
func (*ListTablesResponse) Descriptor() ([]byte, []int)
Deprecated: Use ListTablesResponse.ProtoReflect.Descriptor instead.
func (*ListTablesResponse) GetTables ¶
func (x *ListTablesResponse) GetTables() []*Table
func (*ListTablesResponse) ProtoMessage ¶
func (*ListTablesResponse) ProtoMessage()
func (*ListTablesResponse) ProtoReflect ¶
func (x *ListTablesResponse) ProtoReflect() protoreflect.Message
func (*ListTablesResponse) Reset ¶
func (x *ListTablesResponse) Reset()
func (*ListTablesResponse) String ¶
func (x *ListTablesResponse) String() string
type RenameTableRequest ¶
type RenameTableRequest struct {
// The current unique name of the table.
Name string `protobuf:"bytes,1,opt,name=name,proto3" json:"name,omitempty"`
// The new name by which the table should be referred to within its containing
// cluster, e.g. "foobar" rather than "<cluster_name>/tables/foobar".
NewId string `protobuf:"bytes,2,opt,name=new_id,json=newId,proto3" json:"new_id,omitempty"`
// contains filtered or unexported fields
}
func (*RenameTableRequest) Descriptor ¶
func (*RenameTableRequest) Descriptor() ([]byte, []int)
Deprecated: Use RenameTableRequest.ProtoReflect.Descriptor instead.
func (*RenameTableRequest) GetName ¶
func (x *RenameTableRequest) GetName() string
func (*RenameTableRequest) GetNewId ¶
func (x *RenameTableRequest) GetNewId() string
func (*RenameTableRequest) ProtoMessage ¶
func (*RenameTableRequest) ProtoMessage()
func (*RenameTableRequest) ProtoReflect ¶
func (x *RenameTableRequest) ProtoReflect() protoreflect.Message
func (*RenameTableRequest) Reset ¶
func (x *RenameTableRequest) Reset()
func (*RenameTableRequest) String ¶
func (x *RenameTableRequest) String() string
type Table ¶
type Table struct {
// A unique identifier of the form
// <cluster_name>/tables/[_a-zA-Z0-9][-_.a-zA-Z0-9]*
Name string `protobuf:"bytes,1,opt,name=name,proto3" json:"name,omitempty"`
// If this Table is in the process of being created, the Operation used to
// track its progress. As long as this operation is present, the Table will
// not accept any Table Admin or Read/Write requests.
CurrentOperation *longrunning.Operation `protobuf:"bytes,2,opt,name=current_operation,json=currentOperation,proto3" json:"current_operation,omitempty"`
// The column families configured for this table, mapped by column family id.
ColumnFamilies map[string]*ColumnFamily `protobuf:"bytes,3,rep,name=column_families,json=columnFamilies,proto3" json:"column_families,omitempty" protobuf_key:"bytes,1,opt,name=key,proto3" protobuf_val:"bytes,2,opt,name=value,proto3"`
// The granularity (e.g. MILLIS, MICROS) at which timestamps are stored in
// this table. Timestamps not matching the granularity will be rejected.
// Cannot be changed once the table is created.
Granularity Table_TimestampGranularity `protobuf:"varint,4,opt,name=granularity,proto3,enum=google.bigtable.admin.table.v1.Table_TimestampGranularity" json:"granularity,omitempty"`
// contains filtered or unexported fields
}
A collection of user data indexed by row, column, and timestamp. Each table is served using the resources of its parent cluster.
func (*Table) Descriptor ¶
Deprecated: Use Table.ProtoReflect.Descriptor instead.
func (*Table) GetColumnFamilies ¶
func (x *Table) GetColumnFamilies() map[string]*ColumnFamily
func (*Table) GetCurrentOperation ¶
func (x *Table) GetCurrentOperation() *longrunning.Operation
func (*Table) GetGranularity ¶
func (x *Table) GetGranularity() Table_TimestampGranularity
func (*Table) GetName ¶
func (*Table) ProtoMessage ¶
func (*Table) ProtoMessage()
func (*Table) ProtoReflect ¶
func (x *Table) ProtoReflect() protoreflect.Message
func (*Table) Reset ¶
func (x *Table) Reset()
func (*Table) String ¶
type Table_TimestampGranularity ¶
type Table_TimestampGranularity int32
const ( Table_MILLIS Table_TimestampGranularity = 0 )
func (Table_TimestampGranularity) Descriptor ¶
func (Table_TimestampGranularity) Descriptor() protoreflect.EnumDescriptor
func (Table_TimestampGranularity) Enum ¶
func (x Table_TimestampGranularity) Enum() *Table_TimestampGranularity
func (Table_TimestampGranularity) EnumDescriptor ¶
func (Table_TimestampGranularity) EnumDescriptor() ([]byte, []int)
Deprecated: Use Table_TimestampGranularity.Descriptor instead.
func (Table_TimestampGranularity) Number ¶
func (x Table_TimestampGranularity) Number() protoreflect.EnumNumber
func (Table_TimestampGranularity) String ¶
func (x Table_TimestampGranularity) String() string
func (Table_TimestampGranularity) Type ¶
func (Table_TimestampGranularity) Type() protoreflect.EnumType
type UnimplementedBigtableTableServiceServer ¶
type UnimplementedBigtableTableServiceServer struct {
}
UnimplementedBigtableTableServiceServer can be embedded to have forward compatible implementations.
func (*UnimplementedBigtableTableServiceServer) BulkDeleteRows ¶
func (*UnimplementedBigtableTableServiceServer) BulkDeleteRows(context.Context, *BulkDeleteRowsRequest) (*emptypb.Empty, error)
func (*UnimplementedBigtableTableServiceServer) CreateColumnFamily ¶
func (*UnimplementedBigtableTableServiceServer) CreateColumnFamily(context.Context, *CreateColumnFamilyRequest) (*ColumnFamily, error)
func (*UnimplementedBigtableTableServiceServer) CreateTable ¶
func (*UnimplementedBigtableTableServiceServer) CreateTable(context.Context, *CreateTableRequest) (*Table, error)
func (*UnimplementedBigtableTableServiceServer) DeleteColumnFamily ¶
func (*UnimplementedBigtableTableServiceServer) DeleteColumnFamily(context.Context, *DeleteColumnFamilyRequest) (*emptypb.Empty, error)
func (*UnimplementedBigtableTableServiceServer) DeleteTable ¶
func (*UnimplementedBigtableTableServiceServer) DeleteTable(context.Context, *DeleteTableRequest) (*emptypb.Empty, error)
func (*UnimplementedBigtableTableServiceServer) GetTable ¶
func (*UnimplementedBigtableTableServiceServer) GetTable(context.Context, *GetTableRequest) (*Table, error)
func (*UnimplementedBigtableTableServiceServer) ListTables ¶
func (*UnimplementedBigtableTableServiceServer) ListTables(context.Context, *ListTablesRequest) (*ListTablesResponse, error)
func (*UnimplementedBigtableTableServiceServer) RenameTable ¶
func (*UnimplementedBigtableTableServiceServer) RenameTable(context.Context, *RenameTableRequest) (*emptypb.Empty, error)
func (*UnimplementedBigtableTableServiceServer) UpdateColumnFamily ¶
func (*UnimplementedBigtableTableServiceServer) UpdateColumnFamily(context.Context, *ColumnFamily) (*ColumnFamily, error)
Source Files ¶
bigtable_table_data.pb.go bigtable_table_service.pb.go bigtable_table_service_messages.pb.go
- Version
- v0.0.0-20260427160629-7cedc36a6bc4 (latest)
- Published
- Apr 27, 2026
- Platform
- linux/amd64
- Imports
- 13 packages
- Last checked
- 2 days ago –
Tools for package owners.