package logging
import "google.golang.org/genproto/googleapis/cloud/aiplatform/logging"
Index ¶
- Variables
- type OnlinePredictionLogEntry
- func (*OnlinePredictionLogEntry) Descriptor() ([]byte, []int)
- func (x *OnlinePredictionLogEntry) GetDeployedModelId() string
- func (x *OnlinePredictionLogEntry) GetEndpoint() string
- func (x *OnlinePredictionLogEntry) GetError() *status.Status
- func (x *OnlinePredictionLogEntry) GetInstanceCount() int64
- func (x *OnlinePredictionLogEntry) GetPredictionCount() int64
- func (*OnlinePredictionLogEntry) ProtoMessage()
- func (x *OnlinePredictionLogEntry) ProtoReflect() protoreflect.Message
- func (x *OnlinePredictionLogEntry) Reset()
- func (x *OnlinePredictionLogEntry) String() string
Variables ¶
var File_google_cloud_aiplatform_logging_prediction_proto protoreflect.FileDescriptor
Types ¶
type OnlinePredictionLogEntry ¶
type OnlinePredictionLogEntry struct {
// The resource name of the endpoint as referred to in the original request.
// For example, projects/12323/locations/us-central1/endpoints/123.
Endpoint string `protobuf:"bytes,1,opt,name=endpoint,proto3" json:"endpoint,omitempty"`
// The ID of the deployed model used to serve this predict request.
DeployedModelId string `protobuf:"bytes,2,opt,name=deployed_model_id,json=deployedModelId,proto3" json:"deployed_model_id,omitempty"`
// The number of instances in the prediction request.
InstanceCount int64 `protobuf:"varint,3,opt,name=instance_count,json=instanceCount,proto3" json:"instance_count,omitempty"`
// The number of successfully predicted instances in the response.
// Populated when prediction succeeds.
PredictionCount int64 `protobuf:"varint,4,opt,name=prediction_count,json=predictionCount,proto3" json:"prediction_count,omitempty"`
// The error code and message.
// Populated when prediction fails.
Error *status.Status `protobuf:"bytes,5,opt,name=error,proto3" json:"error,omitempty"`
// contains filtered or unexported fields
}
The access log entry definition of online prediction.
func (*OnlinePredictionLogEntry) Descriptor ¶
func (*OnlinePredictionLogEntry) Descriptor() ([]byte, []int)
Deprecated: Use OnlinePredictionLogEntry.ProtoReflect.Descriptor instead.
func (*OnlinePredictionLogEntry) GetDeployedModelId ¶
func (x *OnlinePredictionLogEntry) GetDeployedModelId() string
func (*OnlinePredictionLogEntry) GetEndpoint ¶
func (x *OnlinePredictionLogEntry) GetEndpoint() string
func (*OnlinePredictionLogEntry) GetError ¶
func (x *OnlinePredictionLogEntry) GetError() *status.Status
func (*OnlinePredictionLogEntry) GetInstanceCount ¶
func (x *OnlinePredictionLogEntry) GetInstanceCount() int64
func (*OnlinePredictionLogEntry) GetPredictionCount ¶
func (x *OnlinePredictionLogEntry) GetPredictionCount() int64
func (*OnlinePredictionLogEntry) ProtoMessage ¶
func (*OnlinePredictionLogEntry) ProtoMessage()
func (*OnlinePredictionLogEntry) ProtoReflect ¶
func (x *OnlinePredictionLogEntry) ProtoReflect() protoreflect.Message
func (*OnlinePredictionLogEntry) Reset ¶
func (x *OnlinePredictionLogEntry) Reset()
func (*OnlinePredictionLogEntry) String ¶
func (x *OnlinePredictionLogEntry) String() string
Source Files ¶
prediction.pb.go
- Version
- v0.0.0-20260427160629-7cedc36a6bc4 (latest)
- Published
- Apr 27, 2026
- Platform
- linux/amd64
- Imports
- 5 packages
- Last checked
- 2 days ago –
Tools for package owners.