package params
import "google.golang.org/genproto/googleapis/cloud/aiplatform/v1/schema/predict/params"
Index ¶
- Variables
- type ImageClassificationPredictionParams
- func (*ImageClassificationPredictionParams) Descriptor() ([]byte, []int)
- func (x *ImageClassificationPredictionParams) GetConfidenceThreshold() float32
- func (x *ImageClassificationPredictionParams) GetMaxPredictions() int32
- func (*ImageClassificationPredictionParams) ProtoMessage()
- func (x *ImageClassificationPredictionParams) ProtoReflect() protoreflect.Message
- func (x *ImageClassificationPredictionParams) Reset()
- func (x *ImageClassificationPredictionParams) String() string
- type ImageObjectDetectionPredictionParams
- func (*ImageObjectDetectionPredictionParams) Descriptor() ([]byte, []int)
- func (x *ImageObjectDetectionPredictionParams) GetConfidenceThreshold() float32
- func (x *ImageObjectDetectionPredictionParams) GetMaxPredictions() int32
- func (*ImageObjectDetectionPredictionParams) ProtoMessage()
- func (x *ImageObjectDetectionPredictionParams) ProtoReflect() protoreflect.Message
- func (x *ImageObjectDetectionPredictionParams) Reset()
- func (x *ImageObjectDetectionPredictionParams) String() string
- type ImageSegmentationPredictionParams
- func (*ImageSegmentationPredictionParams) Descriptor() ([]byte, []int)
- func (x *ImageSegmentationPredictionParams) GetConfidenceThreshold() float32
- func (*ImageSegmentationPredictionParams) ProtoMessage()
- func (x *ImageSegmentationPredictionParams) ProtoReflect() protoreflect.Message
- func (x *ImageSegmentationPredictionParams) Reset()
- func (x *ImageSegmentationPredictionParams) String() string
- type VideoActionRecognitionPredictionParams
- func (*VideoActionRecognitionPredictionParams) Descriptor() ([]byte, []int)
- func (x *VideoActionRecognitionPredictionParams) GetConfidenceThreshold() float32
- func (x *VideoActionRecognitionPredictionParams) GetMaxPredictions() int32
- func (*VideoActionRecognitionPredictionParams) ProtoMessage()
- func (x *VideoActionRecognitionPredictionParams) ProtoReflect() protoreflect.Message
- func (x *VideoActionRecognitionPredictionParams) Reset()
- func (x *VideoActionRecognitionPredictionParams) String() string
- type VideoClassificationPredictionParams
- func (*VideoClassificationPredictionParams) Descriptor() ([]byte, []int)
- func (x *VideoClassificationPredictionParams) GetConfidenceThreshold() float32
- func (x *VideoClassificationPredictionParams) GetMaxPredictions() int32
- func (x *VideoClassificationPredictionParams) GetOneSecIntervalClassification() bool
- func (x *VideoClassificationPredictionParams) GetSegmentClassification() bool
- func (x *VideoClassificationPredictionParams) GetShotClassification() bool
- func (*VideoClassificationPredictionParams) ProtoMessage()
- func (x *VideoClassificationPredictionParams) ProtoReflect() protoreflect.Message
- func (x *VideoClassificationPredictionParams) Reset()
- func (x *VideoClassificationPredictionParams) String() string
- type VideoObjectTrackingPredictionParams
- func (*VideoObjectTrackingPredictionParams) Descriptor() ([]byte, []int)
- func (x *VideoObjectTrackingPredictionParams) GetConfidenceThreshold() float32
- func (x *VideoObjectTrackingPredictionParams) GetMaxPredictions() int32
- func (x *VideoObjectTrackingPredictionParams) GetMinBoundingBoxSize() float32
- func (*VideoObjectTrackingPredictionParams) ProtoMessage()
- func (x *VideoObjectTrackingPredictionParams) ProtoReflect() protoreflect.Message
- func (x *VideoObjectTrackingPredictionParams) Reset()
- func (x *VideoObjectTrackingPredictionParams) String() string
Variables ¶
var File_google_cloud_aiplatform_v1_schema_predict_params_image_classification_proto protoreflect.FileDescriptor
var File_google_cloud_aiplatform_v1_schema_predict_params_image_object_detection_proto protoreflect.FileDescriptor
var File_google_cloud_aiplatform_v1_schema_predict_params_image_segmentation_proto protoreflect.FileDescriptor
var File_google_cloud_aiplatform_v1_schema_predict_params_video_action_recognition_proto protoreflect.FileDescriptor
var File_google_cloud_aiplatform_v1_schema_predict_params_video_classification_proto protoreflect.FileDescriptor
var File_google_cloud_aiplatform_v1_schema_predict_params_video_object_tracking_proto protoreflect.FileDescriptor
Types ¶
type ImageClassificationPredictionParams ¶
type ImageClassificationPredictionParams struct {
// The Model only returns predictions with at least this confidence score.
// Default value is 0.0
ConfidenceThreshold float32 `protobuf:"fixed32,1,opt,name=confidence_threshold,json=confidenceThreshold,proto3" json:"confidence_threshold,omitempty"`
// The Model only returns up to that many top, by confidence score,
// predictions per instance. If this number is very high, the Model may return
// fewer predictions. Default value is 10.
MaxPredictions int32 `protobuf:"varint,2,opt,name=max_predictions,json=maxPredictions,proto3" json:"max_predictions,omitempty"`
// contains filtered or unexported fields
}
Prediction model parameters for Image Classification.
func (*ImageClassificationPredictionParams) Descriptor ¶
func (*ImageClassificationPredictionParams) Descriptor() ([]byte, []int)
Deprecated: Use ImageClassificationPredictionParams.ProtoReflect.Descriptor instead.
func (*ImageClassificationPredictionParams) GetConfidenceThreshold ¶
func (x *ImageClassificationPredictionParams) GetConfidenceThreshold() float32
func (*ImageClassificationPredictionParams) GetMaxPredictions ¶
func (x *ImageClassificationPredictionParams) GetMaxPredictions() int32
func (*ImageClassificationPredictionParams) ProtoMessage ¶
func (*ImageClassificationPredictionParams) ProtoMessage()
func (*ImageClassificationPredictionParams) ProtoReflect ¶
func (x *ImageClassificationPredictionParams) ProtoReflect() protoreflect.Message
func (*ImageClassificationPredictionParams) Reset ¶
func (x *ImageClassificationPredictionParams) Reset()
func (*ImageClassificationPredictionParams) String ¶
func (x *ImageClassificationPredictionParams) String() string
type ImageObjectDetectionPredictionParams ¶
type ImageObjectDetectionPredictionParams struct {
// The Model only returns predictions with at least this confidence score.
// Default value is 0.0
ConfidenceThreshold float32 `protobuf:"fixed32,1,opt,name=confidence_threshold,json=confidenceThreshold,proto3" json:"confidence_threshold,omitempty"`
// The Model only returns up to that many top, by confidence score,
// predictions per instance. Note that number of returned predictions is also
// limited by metadata's predictionsLimit. Default value is 10.
MaxPredictions int32 `protobuf:"varint,2,opt,name=max_predictions,json=maxPredictions,proto3" json:"max_predictions,omitempty"`
// contains filtered or unexported fields
}
Prediction model parameters for Image Object Detection.
func (*ImageObjectDetectionPredictionParams) Descriptor ¶
func (*ImageObjectDetectionPredictionParams) Descriptor() ([]byte, []int)
Deprecated: Use ImageObjectDetectionPredictionParams.ProtoReflect.Descriptor instead.
func (*ImageObjectDetectionPredictionParams) GetConfidenceThreshold ¶
func (x *ImageObjectDetectionPredictionParams) GetConfidenceThreshold() float32
func (*ImageObjectDetectionPredictionParams) GetMaxPredictions ¶
func (x *ImageObjectDetectionPredictionParams) GetMaxPredictions() int32
func (*ImageObjectDetectionPredictionParams) ProtoMessage ¶
func (*ImageObjectDetectionPredictionParams) ProtoMessage()
func (*ImageObjectDetectionPredictionParams) ProtoReflect ¶
func (x *ImageObjectDetectionPredictionParams) ProtoReflect() protoreflect.Message
func (*ImageObjectDetectionPredictionParams) Reset ¶
func (x *ImageObjectDetectionPredictionParams) Reset()
func (*ImageObjectDetectionPredictionParams) String ¶
func (x *ImageObjectDetectionPredictionParams) String() string
type ImageSegmentationPredictionParams ¶
type ImageSegmentationPredictionParams struct {
// When the model predicts category of pixels of the image, it will only
// provide predictions for pixels that it is at least this much confident
// about. All other pixels will be classified as background. Default value is
// 0.5.
ConfidenceThreshold float32 `protobuf:"fixed32,1,opt,name=confidence_threshold,json=confidenceThreshold,proto3" json:"confidence_threshold,omitempty"`
// contains filtered or unexported fields
}
Prediction model parameters for Image Segmentation.
func (*ImageSegmentationPredictionParams) Descriptor ¶
func (*ImageSegmentationPredictionParams) Descriptor() ([]byte, []int)
Deprecated: Use ImageSegmentationPredictionParams.ProtoReflect.Descriptor instead.
func (*ImageSegmentationPredictionParams) GetConfidenceThreshold ¶
func (x *ImageSegmentationPredictionParams) GetConfidenceThreshold() float32
func (*ImageSegmentationPredictionParams) ProtoMessage ¶
func (*ImageSegmentationPredictionParams) ProtoMessage()
func (*ImageSegmentationPredictionParams) ProtoReflect ¶
func (x *ImageSegmentationPredictionParams) ProtoReflect() protoreflect.Message
func (*ImageSegmentationPredictionParams) Reset ¶
func (x *ImageSegmentationPredictionParams) Reset()
func (*ImageSegmentationPredictionParams) String ¶
func (x *ImageSegmentationPredictionParams) String() string
type VideoActionRecognitionPredictionParams ¶
type VideoActionRecognitionPredictionParams struct {
// The Model only returns predictions with at least this confidence score.
// Default value is 0.0
ConfidenceThreshold float32 `protobuf:"fixed32,1,opt,name=confidence_threshold,json=confidenceThreshold,proto3" json:"confidence_threshold,omitempty"`
// The model only returns up to that many top, by confidence score,
// predictions per frame of the video. If this number is very high, the
// Model may return fewer predictions per frame. Default value is 50.
MaxPredictions int32 `protobuf:"varint,2,opt,name=max_predictions,json=maxPredictions,proto3" json:"max_predictions,omitempty"`
// contains filtered or unexported fields
}
Prediction model parameters for Video Action Recognition.
func (*VideoActionRecognitionPredictionParams) Descriptor ¶
func (*VideoActionRecognitionPredictionParams) Descriptor() ([]byte, []int)
Deprecated: Use VideoActionRecognitionPredictionParams.ProtoReflect.Descriptor instead.
func (*VideoActionRecognitionPredictionParams) GetConfidenceThreshold ¶
func (x *VideoActionRecognitionPredictionParams) GetConfidenceThreshold() float32
func (*VideoActionRecognitionPredictionParams) GetMaxPredictions ¶
func (x *VideoActionRecognitionPredictionParams) GetMaxPredictions() int32
func (*VideoActionRecognitionPredictionParams) ProtoMessage ¶
func (*VideoActionRecognitionPredictionParams) ProtoMessage()
func (*VideoActionRecognitionPredictionParams) ProtoReflect ¶
func (x *VideoActionRecognitionPredictionParams) ProtoReflect() protoreflect.Message
func (*VideoActionRecognitionPredictionParams) Reset ¶
func (x *VideoActionRecognitionPredictionParams) Reset()
func (*VideoActionRecognitionPredictionParams) String ¶
func (x *VideoActionRecognitionPredictionParams) String() string
type VideoClassificationPredictionParams ¶
type VideoClassificationPredictionParams struct {
// The Model only returns predictions with at least this confidence score.
// Default value is 0.0
ConfidenceThreshold float32 `protobuf:"fixed32,1,opt,name=confidence_threshold,json=confidenceThreshold,proto3" json:"confidence_threshold,omitempty"`
// The Model only returns up to that many top, by confidence score,
// predictions per instance. If this number is very high, the Model may return
// fewer predictions. Default value is 10,000.
MaxPredictions int32 `protobuf:"varint,2,opt,name=max_predictions,json=maxPredictions,proto3" json:"max_predictions,omitempty"`
// Set to true to request segment-level classification. Vertex AI returns
// labels and their confidence scores for the entire time segment of the
// video that user specified in the input instance.
// Default value is true
SegmentClassification bool `protobuf:"varint,3,opt,name=segment_classification,json=segmentClassification,proto3" json:"segment_classification,omitempty"`
// Set to true to request shot-level classification. Vertex AI determines
// the boundaries for each camera shot in the entire time segment of the
// video that user specified in the input instance. Vertex AI then
// returns labels and their confidence scores for each detected shot, along
// with the start and end time of the shot.
// WARNING: Model evaluation is not done for this classification type,
// the quality of it depends on the training data, but there are no metrics
// provided to describe that quality.
// Default value is false
ShotClassification bool `protobuf:"varint,4,opt,name=shot_classification,json=shotClassification,proto3" json:"shot_classification,omitempty"`
// Set to true to request classification for a video at one-second intervals.
// Vertex AI returns labels and their confidence scores for each second of
// the entire time segment of the video that user specified in the input
// WARNING: Model evaluation is not done for this classification type, the
// quality of it depends on the training data, but there are no metrics
// provided to describe that quality. Default value is false
OneSecIntervalClassification bool `protobuf:"varint,5,opt,name=one_sec_interval_classification,json=oneSecIntervalClassification,proto3" json:"one_sec_interval_classification,omitempty"`
// contains filtered or unexported fields
}
Prediction model parameters for Video Classification.
func (*VideoClassificationPredictionParams) Descriptor ¶
func (*VideoClassificationPredictionParams) Descriptor() ([]byte, []int)
Deprecated: Use VideoClassificationPredictionParams.ProtoReflect.Descriptor instead.
func (*VideoClassificationPredictionParams) GetConfidenceThreshold ¶
func (x *VideoClassificationPredictionParams) GetConfidenceThreshold() float32
func (*VideoClassificationPredictionParams) GetMaxPredictions ¶
func (x *VideoClassificationPredictionParams) GetMaxPredictions() int32
func (*VideoClassificationPredictionParams) GetOneSecIntervalClassification ¶
func (x *VideoClassificationPredictionParams) GetOneSecIntervalClassification() bool
func (*VideoClassificationPredictionParams) GetSegmentClassification ¶
func (x *VideoClassificationPredictionParams) GetSegmentClassification() bool
func (*VideoClassificationPredictionParams) GetShotClassification ¶
func (x *VideoClassificationPredictionParams) GetShotClassification() bool
func (*VideoClassificationPredictionParams) ProtoMessage ¶
func (*VideoClassificationPredictionParams) ProtoMessage()
func (*VideoClassificationPredictionParams) ProtoReflect ¶
func (x *VideoClassificationPredictionParams) ProtoReflect() protoreflect.Message
func (*VideoClassificationPredictionParams) Reset ¶
func (x *VideoClassificationPredictionParams) Reset()
func (*VideoClassificationPredictionParams) String ¶
func (x *VideoClassificationPredictionParams) String() string
type VideoObjectTrackingPredictionParams ¶
type VideoObjectTrackingPredictionParams struct {
// The Model only returns predictions with at least this confidence score.
// Default value is 0.0
ConfidenceThreshold float32 `protobuf:"fixed32,1,opt,name=confidence_threshold,json=confidenceThreshold,proto3" json:"confidence_threshold,omitempty"`
// The model only returns up to that many top, by confidence score,
// predictions per frame of the video. If this number is very high, the
// Model may return fewer predictions per frame. Default value is 50.
MaxPredictions int32 `protobuf:"varint,2,opt,name=max_predictions,json=maxPredictions,proto3" json:"max_predictions,omitempty"`
// Only bounding boxes with shortest edge at least that long as a relative
// value of video frame size are returned. Default value is 0.0.
MinBoundingBoxSize float32 `protobuf:"fixed32,3,opt,name=min_bounding_box_size,json=minBoundingBoxSize,proto3" json:"min_bounding_box_size,omitempty"`
// contains filtered or unexported fields
}
Prediction model parameters for Video Object Tracking.
func (*VideoObjectTrackingPredictionParams) Descriptor ¶
func (*VideoObjectTrackingPredictionParams) Descriptor() ([]byte, []int)
Deprecated: Use VideoObjectTrackingPredictionParams.ProtoReflect.Descriptor instead.
func (*VideoObjectTrackingPredictionParams) GetConfidenceThreshold ¶
func (x *VideoObjectTrackingPredictionParams) GetConfidenceThreshold() float32
func (*VideoObjectTrackingPredictionParams) GetMaxPredictions ¶
func (x *VideoObjectTrackingPredictionParams) GetMaxPredictions() int32
func (*VideoObjectTrackingPredictionParams) GetMinBoundingBoxSize ¶
func (x *VideoObjectTrackingPredictionParams) GetMinBoundingBoxSize() float32
func (*VideoObjectTrackingPredictionParams) ProtoMessage ¶
func (*VideoObjectTrackingPredictionParams) ProtoMessage()
func (*VideoObjectTrackingPredictionParams) ProtoReflect ¶
func (x *VideoObjectTrackingPredictionParams) ProtoReflect() protoreflect.Message
func (*VideoObjectTrackingPredictionParams) Reset ¶
func (x *VideoObjectTrackingPredictionParams) Reset()
func (*VideoObjectTrackingPredictionParams) String ¶
func (x *VideoObjectTrackingPredictionParams) String() string
Source Files ¶
image_classification.pb.go image_object_detection.pb.go image_segmentation.pb.go video_action_recognition.pb.go video_classification.pb.go video_object_tracking.pb.go
- Version
- v0.0.0-20260427160629-7cedc36a6bc4 (latest)
- Published
- Apr 27, 2026
- Platform
- linux/amd64
- Imports
- 4 packages
- Last checked
- 2 days ago –
Tools for package owners.