package instance
import "google.golang.org/genproto/googleapis/cloud/aiplatform/v1beta1/schema/predict/instance"
Index ¶
- Variables
- type ImageClassificationPredictionInstance
- func (*ImageClassificationPredictionInstance) Descriptor() ([]byte, []int)
- func (x *ImageClassificationPredictionInstance) GetContent() string
- func (x *ImageClassificationPredictionInstance) GetMimeType() string
- func (*ImageClassificationPredictionInstance) ProtoMessage()
- func (x *ImageClassificationPredictionInstance) ProtoReflect() protoreflect.Message
- func (x *ImageClassificationPredictionInstance) Reset()
- func (x *ImageClassificationPredictionInstance) String() string
- type ImageObjectDetectionPredictionInstance
- func (*ImageObjectDetectionPredictionInstance) Descriptor() ([]byte, []int)
- func (x *ImageObjectDetectionPredictionInstance) GetContent() string
- func (x *ImageObjectDetectionPredictionInstance) GetMimeType() string
- func (*ImageObjectDetectionPredictionInstance) ProtoMessage()
- func (x *ImageObjectDetectionPredictionInstance) ProtoReflect() protoreflect.Message
- func (x *ImageObjectDetectionPredictionInstance) Reset()
- func (x *ImageObjectDetectionPredictionInstance) String() string
- type ImageSegmentationPredictionInstance
- func (*ImageSegmentationPredictionInstance) Descriptor() ([]byte, []int)
- func (x *ImageSegmentationPredictionInstance) GetContent() string
- func (x *ImageSegmentationPredictionInstance) GetMimeType() string
- func (*ImageSegmentationPredictionInstance) ProtoMessage()
- func (x *ImageSegmentationPredictionInstance) ProtoReflect() protoreflect.Message
- func (x *ImageSegmentationPredictionInstance) Reset()
- func (x *ImageSegmentationPredictionInstance) String() string
- type TextClassificationPredictionInstance
- func (*TextClassificationPredictionInstance) Descriptor() ([]byte, []int)
- func (x *TextClassificationPredictionInstance) GetContent() string
- func (x *TextClassificationPredictionInstance) GetMimeType() string
- func (*TextClassificationPredictionInstance) ProtoMessage()
- func (x *TextClassificationPredictionInstance) ProtoReflect() protoreflect.Message
- func (x *TextClassificationPredictionInstance) Reset()
- func (x *TextClassificationPredictionInstance) String() string
- type TextExtractionPredictionInstance
- func (*TextExtractionPredictionInstance) Descriptor() ([]byte, []int)
- func (x *TextExtractionPredictionInstance) GetContent() string
- func (x *TextExtractionPredictionInstance) GetKey() string
- func (x *TextExtractionPredictionInstance) GetMimeType() string
- func (*TextExtractionPredictionInstance) ProtoMessage()
- func (x *TextExtractionPredictionInstance) ProtoReflect() protoreflect.Message
- func (x *TextExtractionPredictionInstance) Reset()
- func (x *TextExtractionPredictionInstance) String() string
- type TextSentimentPredictionInstance
- func (*TextSentimentPredictionInstance) Descriptor() ([]byte, []int)
- func (x *TextSentimentPredictionInstance) GetContent() string
- func (x *TextSentimentPredictionInstance) GetMimeType() string
- func (*TextSentimentPredictionInstance) ProtoMessage()
- func (x *TextSentimentPredictionInstance) ProtoReflect() protoreflect.Message
- func (x *TextSentimentPredictionInstance) Reset()
- func (x *TextSentimentPredictionInstance) String() string
- type VideoActionRecognitionPredictionInstance
- func (*VideoActionRecognitionPredictionInstance) Descriptor() ([]byte, []int)
- func (x *VideoActionRecognitionPredictionInstance) GetContent() string
- func (x *VideoActionRecognitionPredictionInstance) GetMimeType() string
- func (x *VideoActionRecognitionPredictionInstance) GetTimeSegmentEnd() string
- func (x *VideoActionRecognitionPredictionInstance) GetTimeSegmentStart() string
- func (*VideoActionRecognitionPredictionInstance) ProtoMessage()
- func (x *VideoActionRecognitionPredictionInstance) ProtoReflect() protoreflect.Message
- func (x *VideoActionRecognitionPredictionInstance) Reset()
- func (x *VideoActionRecognitionPredictionInstance) String() string
- type VideoClassificationPredictionInstance
- func (*VideoClassificationPredictionInstance) Descriptor() ([]byte, []int)
- func (x *VideoClassificationPredictionInstance) GetContent() string
- func (x *VideoClassificationPredictionInstance) GetMimeType() string
- func (x *VideoClassificationPredictionInstance) GetTimeSegmentEnd() string
- func (x *VideoClassificationPredictionInstance) GetTimeSegmentStart() string
- func (*VideoClassificationPredictionInstance) ProtoMessage()
- func (x *VideoClassificationPredictionInstance) ProtoReflect() protoreflect.Message
- func (x *VideoClassificationPredictionInstance) Reset()
- func (x *VideoClassificationPredictionInstance) String() string
- type VideoObjectTrackingPredictionInstance
- func (*VideoObjectTrackingPredictionInstance) Descriptor() ([]byte, []int)
- func (x *VideoObjectTrackingPredictionInstance) GetContent() string
- func (x *VideoObjectTrackingPredictionInstance) GetMimeType() string
- func (x *VideoObjectTrackingPredictionInstance) GetTimeSegmentEnd() string
- func (x *VideoObjectTrackingPredictionInstance) GetTimeSegmentStart() string
- func (*VideoObjectTrackingPredictionInstance) ProtoMessage()
- func (x *VideoObjectTrackingPredictionInstance) ProtoReflect() protoreflect.Message
- func (x *VideoObjectTrackingPredictionInstance) Reset()
- func (x *VideoObjectTrackingPredictionInstance) String() string
Variables ¶
var File_google_cloud_aiplatform_v1beta1_schema_predict_instance_image_classification_proto protoreflect.FileDescriptor
var File_google_cloud_aiplatform_v1beta1_schema_predict_instance_image_object_detection_proto protoreflect.FileDescriptor
var File_google_cloud_aiplatform_v1beta1_schema_predict_instance_image_segmentation_proto protoreflect.FileDescriptor
var File_google_cloud_aiplatform_v1beta1_schema_predict_instance_text_classification_proto protoreflect.FileDescriptor
var File_google_cloud_aiplatform_v1beta1_schema_predict_instance_text_extraction_proto protoreflect.FileDescriptor
var File_google_cloud_aiplatform_v1beta1_schema_predict_instance_text_sentiment_proto protoreflect.FileDescriptor
var File_google_cloud_aiplatform_v1beta1_schema_predict_instance_video_action_recognition_proto protoreflect.FileDescriptor
var File_google_cloud_aiplatform_v1beta1_schema_predict_instance_video_classification_proto protoreflect.FileDescriptor
var File_google_cloud_aiplatform_v1beta1_schema_predict_instance_video_object_tracking_proto protoreflect.FileDescriptor
Types ¶
type ImageClassificationPredictionInstance ¶
type ImageClassificationPredictionInstance struct {
// The image bytes or Cloud Storage URI to make the prediction on.
Content string `protobuf:"bytes,1,opt,name=content,proto3" json:"content,omitempty"`
// The MIME type of the content of the image. Only the images in below listed
// MIME types are supported.
// - image/jpeg
// - image/gif
// - image/png
// - image/webp
// - image/bmp
// - image/tiff
// - image/vnd.microsoft.icon
MimeType string `protobuf:"bytes,2,opt,name=mime_type,json=mimeType,proto3" json:"mime_type,omitempty"`
// contains filtered or unexported fields
}
Prediction input format for Image Classification.
func (*ImageClassificationPredictionInstance) Descriptor ¶
func (*ImageClassificationPredictionInstance) Descriptor() ([]byte, []int)
Deprecated: Use ImageClassificationPredictionInstance.ProtoReflect.Descriptor instead.
func (*ImageClassificationPredictionInstance) GetContent ¶
func (x *ImageClassificationPredictionInstance) GetContent() string
func (*ImageClassificationPredictionInstance) GetMimeType ¶
func (x *ImageClassificationPredictionInstance) GetMimeType() string
func (*ImageClassificationPredictionInstance) ProtoMessage ¶
func (*ImageClassificationPredictionInstance) ProtoMessage()
func (*ImageClassificationPredictionInstance) ProtoReflect ¶
func (x *ImageClassificationPredictionInstance) ProtoReflect() protoreflect.Message
func (*ImageClassificationPredictionInstance) Reset ¶
func (x *ImageClassificationPredictionInstance) Reset()
func (*ImageClassificationPredictionInstance) String ¶
func (x *ImageClassificationPredictionInstance) String() string
type ImageObjectDetectionPredictionInstance ¶
type ImageObjectDetectionPredictionInstance struct {
// The image bytes or Cloud Storage URI to make the prediction on.
Content string `protobuf:"bytes,1,opt,name=content,proto3" json:"content,omitempty"`
// The MIME type of the content of the image. Only the images in below listed
// MIME types are supported.
// - image/jpeg
// - image/gif
// - image/png
// - image/webp
// - image/bmp
// - image/tiff
// - image/vnd.microsoft.icon
MimeType string `protobuf:"bytes,2,opt,name=mime_type,json=mimeType,proto3" json:"mime_type,omitempty"`
// contains filtered or unexported fields
}
Prediction input format for Image Object Detection.
func (*ImageObjectDetectionPredictionInstance) Descriptor ¶
func (*ImageObjectDetectionPredictionInstance) Descriptor() ([]byte, []int)
Deprecated: Use ImageObjectDetectionPredictionInstance.ProtoReflect.Descriptor instead.
func (*ImageObjectDetectionPredictionInstance) GetContent ¶
func (x *ImageObjectDetectionPredictionInstance) GetContent() string
func (*ImageObjectDetectionPredictionInstance) GetMimeType ¶
func (x *ImageObjectDetectionPredictionInstance) GetMimeType() string
func (*ImageObjectDetectionPredictionInstance) ProtoMessage ¶
func (*ImageObjectDetectionPredictionInstance) ProtoMessage()
func (*ImageObjectDetectionPredictionInstance) ProtoReflect ¶
func (x *ImageObjectDetectionPredictionInstance) ProtoReflect() protoreflect.Message
func (*ImageObjectDetectionPredictionInstance) Reset ¶
func (x *ImageObjectDetectionPredictionInstance) Reset()
func (*ImageObjectDetectionPredictionInstance) String ¶
func (x *ImageObjectDetectionPredictionInstance) String() string
type ImageSegmentationPredictionInstance ¶
type ImageSegmentationPredictionInstance struct {
// The image bytes to make the predictions on.
Content string `protobuf:"bytes,1,opt,name=content,proto3" json:"content,omitempty"`
// The MIME type of the content of the image. Only the images in below listed
// MIME types are supported.
// - image/jpeg
// - image/png
MimeType string `protobuf:"bytes,2,opt,name=mime_type,json=mimeType,proto3" json:"mime_type,omitempty"`
// contains filtered or unexported fields
}
Prediction input format for Image Segmentation.
func (*ImageSegmentationPredictionInstance) Descriptor ¶
func (*ImageSegmentationPredictionInstance) Descriptor() ([]byte, []int)
Deprecated: Use ImageSegmentationPredictionInstance.ProtoReflect.Descriptor instead.
func (*ImageSegmentationPredictionInstance) GetContent ¶
func (x *ImageSegmentationPredictionInstance) GetContent() string
func (*ImageSegmentationPredictionInstance) GetMimeType ¶
func (x *ImageSegmentationPredictionInstance) GetMimeType() string
func (*ImageSegmentationPredictionInstance) ProtoMessage ¶
func (*ImageSegmentationPredictionInstance) ProtoMessage()
func (*ImageSegmentationPredictionInstance) ProtoReflect ¶
func (x *ImageSegmentationPredictionInstance) ProtoReflect() protoreflect.Message
func (*ImageSegmentationPredictionInstance) Reset ¶
func (x *ImageSegmentationPredictionInstance) Reset()
func (*ImageSegmentationPredictionInstance) String ¶
func (x *ImageSegmentationPredictionInstance) String() string
type TextClassificationPredictionInstance ¶
type TextClassificationPredictionInstance struct {
// The text snippet to make the predictions on.
Content string `protobuf:"bytes,1,opt,name=content,proto3" json:"content,omitempty"`
// The MIME type of the text snippet. The supported MIME types are listed
// below.
// - text/plain
MimeType string `protobuf:"bytes,2,opt,name=mime_type,json=mimeType,proto3" json:"mime_type,omitempty"`
// contains filtered or unexported fields
}
Prediction input format for Text Classification.
func (*TextClassificationPredictionInstance) Descriptor ¶
func (*TextClassificationPredictionInstance) Descriptor() ([]byte, []int)
Deprecated: Use TextClassificationPredictionInstance.ProtoReflect.Descriptor instead.
func (*TextClassificationPredictionInstance) GetContent ¶
func (x *TextClassificationPredictionInstance) GetContent() string
func (*TextClassificationPredictionInstance) GetMimeType ¶
func (x *TextClassificationPredictionInstance) GetMimeType() string
func (*TextClassificationPredictionInstance) ProtoMessage ¶
func (*TextClassificationPredictionInstance) ProtoMessage()
func (*TextClassificationPredictionInstance) ProtoReflect ¶
func (x *TextClassificationPredictionInstance) ProtoReflect() protoreflect.Message
func (*TextClassificationPredictionInstance) Reset ¶
func (x *TextClassificationPredictionInstance) Reset()
func (*TextClassificationPredictionInstance) String ¶
func (x *TextClassificationPredictionInstance) String() string
type TextExtractionPredictionInstance ¶
type TextExtractionPredictionInstance struct {
// The text snippet to make the predictions on.
Content string `protobuf:"bytes,1,opt,name=content,proto3" json:"content,omitempty"`
// The MIME type of the text snippet. The supported MIME types are listed
// below.
// - text/plain
MimeType string `protobuf:"bytes,2,opt,name=mime_type,json=mimeType,proto3" json:"mime_type,omitempty"`
// This field is only used for batch prediction. If a key is provided, the
// batch prediction result will by mapped to this key. If omitted, then the
// batch prediction result will contain the entire input instance. Vertex AI
// will not check if keys in the request are duplicates, so it is up to the
// caller to ensure the keys are unique.
Key string `protobuf:"bytes,3,opt,name=key,proto3" json:"key,omitempty"`
// contains filtered or unexported fields
}
Prediction input format for Text Extraction.
func (*TextExtractionPredictionInstance) Descriptor ¶
func (*TextExtractionPredictionInstance) Descriptor() ([]byte, []int)
Deprecated: Use TextExtractionPredictionInstance.ProtoReflect.Descriptor instead.
func (*TextExtractionPredictionInstance) GetContent ¶
func (x *TextExtractionPredictionInstance) GetContent() string
func (*TextExtractionPredictionInstance) GetKey ¶
func (x *TextExtractionPredictionInstance) GetKey() string
func (*TextExtractionPredictionInstance) GetMimeType ¶
func (x *TextExtractionPredictionInstance) GetMimeType() string
func (*TextExtractionPredictionInstance) ProtoMessage ¶
func (*TextExtractionPredictionInstance) ProtoMessage()
func (*TextExtractionPredictionInstance) ProtoReflect ¶
func (x *TextExtractionPredictionInstance) ProtoReflect() protoreflect.Message
func (*TextExtractionPredictionInstance) Reset ¶
func (x *TextExtractionPredictionInstance) Reset()
func (*TextExtractionPredictionInstance) String ¶
func (x *TextExtractionPredictionInstance) String() string
type TextSentimentPredictionInstance ¶
type TextSentimentPredictionInstance struct {
// The text snippet to make the predictions on.
Content string `protobuf:"bytes,1,opt,name=content,proto3" json:"content,omitempty"`
// The MIME type of the text snippet. The supported MIME types are listed
// below.
// - text/plain
MimeType string `protobuf:"bytes,2,opt,name=mime_type,json=mimeType,proto3" json:"mime_type,omitempty"`
// contains filtered or unexported fields
}
Prediction input format for Text Sentiment.
func (*TextSentimentPredictionInstance) Descriptor ¶
func (*TextSentimentPredictionInstance) Descriptor() ([]byte, []int)
Deprecated: Use TextSentimentPredictionInstance.ProtoReflect.Descriptor instead.
func (*TextSentimentPredictionInstance) GetContent ¶
func (x *TextSentimentPredictionInstance) GetContent() string
func (*TextSentimentPredictionInstance) GetMimeType ¶
func (x *TextSentimentPredictionInstance) GetMimeType() string
func (*TextSentimentPredictionInstance) ProtoMessage ¶
func (*TextSentimentPredictionInstance) ProtoMessage()
func (*TextSentimentPredictionInstance) ProtoReflect ¶
func (x *TextSentimentPredictionInstance) ProtoReflect() protoreflect.Message
func (*TextSentimentPredictionInstance) Reset ¶
func (x *TextSentimentPredictionInstance) Reset()
func (*TextSentimentPredictionInstance) String ¶
func (x *TextSentimentPredictionInstance) String() string
type VideoActionRecognitionPredictionInstance ¶
type VideoActionRecognitionPredictionInstance struct {
// The Google Cloud Storage location of the video on which to perform the
// prediction.
Content string `protobuf:"bytes,1,opt,name=content,proto3" json:"content,omitempty"`
// The MIME type of the content of the video. Only the following are
// supported: video/mp4 video/avi video/quicktime
MimeType string `protobuf:"bytes,2,opt,name=mime_type,json=mimeType,proto3" json:"mime_type,omitempty"`
// The beginning, inclusive, of the video's time segment on which to perform
// the prediction. Expressed as a number of seconds as measured from the
// start of the video, with "s" appended at the end. Fractions are allowed,
// up to a microsecond precision.
TimeSegmentStart string `protobuf:"bytes,3,opt,name=time_segment_start,json=timeSegmentStart,proto3" json:"time_segment_start,omitempty"`
// The end, exclusive, of the video's time segment on which to perform
// the prediction. Expressed as a number of seconds as measured from the
// start of the video, with "s" appended at the end. Fractions are allowed,
// up to a microsecond precision, and "inf" or "Infinity" is allowed, which
// means the end of the video.
TimeSegmentEnd string `protobuf:"bytes,4,opt,name=time_segment_end,json=timeSegmentEnd,proto3" json:"time_segment_end,omitempty"`
// contains filtered or unexported fields
}
Prediction input format for Video Action Recognition.
func (*VideoActionRecognitionPredictionInstance) Descriptor ¶
func (*VideoActionRecognitionPredictionInstance) Descriptor() ([]byte, []int)
Deprecated: Use VideoActionRecognitionPredictionInstance.ProtoReflect.Descriptor instead.
func (*VideoActionRecognitionPredictionInstance) GetContent ¶
func (x *VideoActionRecognitionPredictionInstance) GetContent() string
func (*VideoActionRecognitionPredictionInstance) GetMimeType ¶
func (x *VideoActionRecognitionPredictionInstance) GetMimeType() string
func (*VideoActionRecognitionPredictionInstance) GetTimeSegmentEnd ¶
func (x *VideoActionRecognitionPredictionInstance) GetTimeSegmentEnd() string
func (*VideoActionRecognitionPredictionInstance) GetTimeSegmentStart ¶
func (x *VideoActionRecognitionPredictionInstance) GetTimeSegmentStart() string
func (*VideoActionRecognitionPredictionInstance) ProtoMessage ¶
func (*VideoActionRecognitionPredictionInstance) ProtoMessage()
func (*VideoActionRecognitionPredictionInstance) ProtoReflect ¶
func (x *VideoActionRecognitionPredictionInstance) ProtoReflect() protoreflect.Message
func (*VideoActionRecognitionPredictionInstance) Reset ¶
func (x *VideoActionRecognitionPredictionInstance) Reset()
func (*VideoActionRecognitionPredictionInstance) String ¶
func (x *VideoActionRecognitionPredictionInstance) String() string
type VideoClassificationPredictionInstance ¶
type VideoClassificationPredictionInstance struct {
// The Google Cloud Storage location of the video on which to perform the
// prediction.
Content string `protobuf:"bytes,1,opt,name=content,proto3" json:"content,omitempty"`
// The MIME type of the content of the video. Only the following are
// supported: video/mp4 video/avi video/quicktime
MimeType string `protobuf:"bytes,2,opt,name=mime_type,json=mimeType,proto3" json:"mime_type,omitempty"`
// The beginning, inclusive, of the video's time segment on which to perform
// the prediction. Expressed as a number of seconds as measured from the
// start of the video, with "s" appended at the end. Fractions are allowed,
// up to a microsecond precision.
TimeSegmentStart string `protobuf:"bytes,3,opt,name=time_segment_start,json=timeSegmentStart,proto3" json:"time_segment_start,omitempty"`
// The end, exclusive, of the video's time segment on which to perform
// the prediction. Expressed as a number of seconds as measured from the
// start of the video, with "s" appended at the end. Fractions are allowed,
// up to a microsecond precision, and "inf" or "Infinity" is allowed, which
// means the end of the video.
TimeSegmentEnd string `protobuf:"bytes,4,opt,name=time_segment_end,json=timeSegmentEnd,proto3" json:"time_segment_end,omitempty"`
// contains filtered or unexported fields
}
Prediction input format for Video Classification.
func (*VideoClassificationPredictionInstance) Descriptor ¶
func (*VideoClassificationPredictionInstance) Descriptor() ([]byte, []int)
Deprecated: Use VideoClassificationPredictionInstance.ProtoReflect.Descriptor instead.
func (*VideoClassificationPredictionInstance) GetContent ¶
func (x *VideoClassificationPredictionInstance) GetContent() string
func (*VideoClassificationPredictionInstance) GetMimeType ¶
func (x *VideoClassificationPredictionInstance) GetMimeType() string
func (*VideoClassificationPredictionInstance) GetTimeSegmentEnd ¶
func (x *VideoClassificationPredictionInstance) GetTimeSegmentEnd() string
func (*VideoClassificationPredictionInstance) GetTimeSegmentStart ¶
func (x *VideoClassificationPredictionInstance) GetTimeSegmentStart() string
func (*VideoClassificationPredictionInstance) ProtoMessage ¶
func (*VideoClassificationPredictionInstance) ProtoMessage()
func (*VideoClassificationPredictionInstance) ProtoReflect ¶
func (x *VideoClassificationPredictionInstance) ProtoReflect() protoreflect.Message
func (*VideoClassificationPredictionInstance) Reset ¶
func (x *VideoClassificationPredictionInstance) Reset()
func (*VideoClassificationPredictionInstance) String ¶
func (x *VideoClassificationPredictionInstance) String() string
type VideoObjectTrackingPredictionInstance ¶
type VideoObjectTrackingPredictionInstance struct {
// The Google Cloud Storage location of the video on which to perform the
// prediction.
Content string `protobuf:"bytes,1,opt,name=content,proto3" json:"content,omitempty"`
// The MIME type of the content of the video. Only the following are
// supported: video/mp4 video/avi video/quicktime
MimeType string `protobuf:"bytes,2,opt,name=mime_type,json=mimeType,proto3" json:"mime_type,omitempty"`
// The beginning, inclusive, of the video's time segment on which to perform
// the prediction. Expressed as a number of seconds as measured from the
// start of the video, with "s" appended at the end. Fractions are allowed,
// up to a microsecond precision.
TimeSegmentStart string `protobuf:"bytes,3,opt,name=time_segment_start,json=timeSegmentStart,proto3" json:"time_segment_start,omitempty"`
// The end, exclusive, of the video's time segment on which to perform
// the prediction. Expressed as a number of seconds as measured from the
// start of the video, with "s" appended at the end. Fractions are allowed,
// up to a microsecond precision, and "inf" or "Infinity" is allowed, which
// means the end of the video.
TimeSegmentEnd string `protobuf:"bytes,4,opt,name=time_segment_end,json=timeSegmentEnd,proto3" json:"time_segment_end,omitempty"`
// contains filtered or unexported fields
}
Prediction input format for Video Object Tracking.
func (*VideoObjectTrackingPredictionInstance) Descriptor ¶
func (*VideoObjectTrackingPredictionInstance) Descriptor() ([]byte, []int)
Deprecated: Use VideoObjectTrackingPredictionInstance.ProtoReflect.Descriptor instead.
func (*VideoObjectTrackingPredictionInstance) GetContent ¶
func (x *VideoObjectTrackingPredictionInstance) GetContent() string
func (*VideoObjectTrackingPredictionInstance) GetMimeType ¶
func (x *VideoObjectTrackingPredictionInstance) GetMimeType() string
func (*VideoObjectTrackingPredictionInstance) GetTimeSegmentEnd ¶
func (x *VideoObjectTrackingPredictionInstance) GetTimeSegmentEnd() string
func (*VideoObjectTrackingPredictionInstance) GetTimeSegmentStart ¶
func (x *VideoObjectTrackingPredictionInstance) GetTimeSegmentStart() string
func (*VideoObjectTrackingPredictionInstance) ProtoMessage ¶
func (*VideoObjectTrackingPredictionInstance) ProtoMessage()
func (*VideoObjectTrackingPredictionInstance) ProtoReflect ¶
func (x *VideoObjectTrackingPredictionInstance) ProtoReflect() protoreflect.Message
func (*VideoObjectTrackingPredictionInstance) Reset ¶
func (x *VideoObjectTrackingPredictionInstance) Reset()
func (*VideoObjectTrackingPredictionInstance) String ¶
func (x *VideoObjectTrackingPredictionInstance) String() string
Source Files ¶
image_classification.pb.go image_object_detection.pb.go image_segmentation.pb.go text_classification.pb.go text_extraction.pb.go text_sentiment.pb.go video_action_recognition.pb.go video_classification.pb.go video_object_tracking.pb.go
- Version
- v0.0.0-20260427160629-7cedc36a6bc4 (latest)
- Published
- Apr 27, 2026
- Platform
- linux/amd64
- Imports
- 4 packages
- Last checked
- 2 days ago –
Tools for package owners.