package logging
import "google.golang.org/genproto/googleapis/cloud/backupdr/logging/v1"
Index ¶
- Variables
- type Event
- func (*Event) Descriptor() ([]byte, []int)
- func (x *Event) GetAppName() string
- func (x *Event) GetAppType() string
- func (x *Event) GetApplianceId() int64
- func (x *Event) GetApplianceName() string
- func (x *Event) GetComponent() string
- func (x *Event) GetErrorMessage() string
- func (x *Event) GetEventId() int32
- func (x *Event) GetEventTime() *timestamppb.Timestamp
- func (x *Event) GetJobName() string
- func (x *Event) GetSourceEventTime() *timestamppb.Timestamp
- func (x *Event) GetSrcid() int64
- func (*Event) ProtoMessage()
- func (x *Event) ProtoReflect() protoreflect.Message
- func (x *Event) Reset()
- func (x *Event) String() string
Variables ¶
var File_google_cloud_backupdr_logging_v1_eventlog_proto protoreflect.FileDescriptor
Types ¶
type Event ¶
type Event struct {
// The event_time field displays the time when the event was reported
EventTime *timestamppb.Timestamp `protobuf:"bytes,1,opt,name=event_time,json=eventTime,proto3" json:"event_time,omitempty"`
// The srcid field displays unique id of the event occurred in the backup
// appliance
Srcid int64 `protobuf:"varint,2,opt,name=srcid,proto3" json:"srcid,omitempty"`
// The error_message field describes the detailed error associated with the
// event
ErrorMessage string `protobuf:"bytes,3,opt,name=error_message,json=errorMessage,proto3" json:"error_message,omitempty"`
// The event_id field displays unique id associated with the error
EventId int32 `protobuf:"varint,4,opt,name=event_id,json=eventId,proto3" json:"event_id,omitempty"`
// The component field displays the source of the event
Component string `protobuf:"bytes,5,opt,name=component,proto3" json:"component,omitempty"`
// The appliance_id field displays unique id of the appliance on which event
// occurred
ApplianceId int64 `protobuf:"varint,6,opt,name=appliance_id,json=applianceId,proto3" json:"appliance_id,omitempty"`
// The appliance_name field displays name of the appliance on which event
// occurred
ApplianceName string `protobuf:"bytes,7,opt,name=appliance_name,json=applianceName,proto3" json:"appliance_name,omitempty"`
// The source_event_time field displays the time when the event occurred at
// appliance
SourceEventTime *timestamppb.Timestamp `protobuf:"bytes,8,opt,name=source_event_time,json=sourceEventTime,proto3" json:"source_event_time,omitempty"`
// The app_name field displays name of the application associated with the
// event
AppName string `protobuf:"bytes,9,opt,name=app_name,json=appName,proto3" json:"app_name,omitempty"`
// The app_type field displays type of the application associated with the
// event
AppType string `protobuf:"bytes,10,opt,name=app_type,json=appType,proto3" json:"app_type,omitempty"`
// The job_name field displays name of the job associated with the event
JobName string `protobuf:"bytes,11,opt,name=job_name,json=jobName,proto3" json:"job_name,omitempty"`
// contains filtered or unexported fields
}
This is an event
func (*Event) Descriptor ¶
Deprecated: Use Event.ProtoReflect.Descriptor instead.
func (*Event) GetAppName ¶
func (*Event) GetAppType ¶
func (*Event) GetApplianceId ¶
func (*Event) GetApplianceName ¶
func (*Event) GetComponent ¶
func (*Event) GetErrorMessage ¶
func (*Event) GetEventId ¶
func (*Event) GetEventTime ¶
func (x *Event) GetEventTime() *timestamppb.Timestamp
func (*Event) GetJobName ¶
func (*Event) GetSourceEventTime ¶
func (x *Event) GetSourceEventTime() *timestamppb.Timestamp
func (*Event) GetSrcid ¶
func (*Event) ProtoMessage ¶
func (*Event) ProtoMessage()
func (*Event) ProtoReflect ¶
func (x *Event) ProtoReflect() protoreflect.Message
func (*Event) Reset ¶
func (x *Event) Reset()
func (*Event) String ¶
Source Files ¶
eventlog.pb.go
- Version
- v0.0.0-20260427160629-7cedc36a6bc4 (latest)
- Published
- Apr 27, 2026
- Platform
- linux/amd64
- Imports
- 5 packages
- Last checked
- 2 days ago –
Tools for package owners.