package metering
import "google.golang.org/genproto/googleapis/cloud/gkehub/metering/v1beta"
Index ¶
- Variables
- type MembershipState
- func (*MembershipState) Descriptor() ([]byte, []int)
- func (x *MembershipState) GetLastMeasurementTime() *timestamppb.Timestamp
- func (x *MembershipState) GetPreciseLastMeasuredClusterVcpuCapacity() float32
- func (*MembershipState) ProtoMessage()
- func (x *MembershipState) ProtoReflect() protoreflect.Message
- func (x *MembershipState) Reset()
- func (x *MembershipState) String() string
Variables ¶
var File_google_cloud_gkehub_v1beta_metering_metering_proto protoreflect.FileDescriptor
Types ¶
type MembershipState ¶
type MembershipState struct {
// The time stamp of the most recent measurement of the number of vCPUs
// in the cluster.
LastMeasurementTime *timestamppb.Timestamp `protobuf:"bytes,1,opt,name=last_measurement_time,json=lastMeasurementTime,proto3" json:"last_measurement_time,omitempty"`
// The vCPUs capacity in the cluster according to the most recent
// measurement (1/1000 precision).
PreciseLastMeasuredClusterVcpuCapacity float32 `protobuf:"fixed32,3,opt,name=precise_last_measured_cluster_vcpu_capacity,json=preciseLastMeasuredClusterVcpuCapacity,proto3" json:"precise_last_measured_cluster_vcpu_capacity,omitempty"`
// contains filtered or unexported fields
}
**Metering**: Per-Membership Feature State.
func (*MembershipState) Descriptor ¶
func (*MembershipState) Descriptor() ([]byte, []int)
Deprecated: Use MembershipState.ProtoReflect.Descriptor instead.
func (*MembershipState) GetLastMeasurementTime ¶
func (x *MembershipState) GetLastMeasurementTime() *timestamppb.Timestamp
func (*MembershipState) GetPreciseLastMeasuredClusterVcpuCapacity ¶
func (x *MembershipState) GetPreciseLastMeasuredClusterVcpuCapacity() float32
func (*MembershipState) ProtoMessage ¶
func (*MembershipState) ProtoMessage()
func (*MembershipState) ProtoReflect ¶
func (x *MembershipState) ProtoReflect() protoreflect.Message
func (*MembershipState) Reset ¶
func (x *MembershipState) Reset()
func (*MembershipState) String ¶
func (x *MembershipState) String() string
Source Files ¶
metering.pb.go
- Version
- v0.0.0-20260427160629-7cedc36a6bc4 (latest)
- Published
- Apr 27, 2026
- Platform
- linux/amd64
- Imports
- 5 packages
- Last checked
- 2 days ago –
Tools for package owners.