package gkehub
import "google.golang.org/genproto/googleapis/cloud/gkehub/v1beta"
Index ¶
- Variables
- func RegisterGkeHubServer(s *grpc.Server, srv GkeHubServer)
- type CommonFeatureSpec
- func (*CommonFeatureSpec) Descriptor() ([]byte, []int)
- func (m *CommonFeatureSpec) GetFeatureSpec() isCommonFeatureSpec_FeatureSpec
- func (x *CommonFeatureSpec) GetMulticlusteringress() *v1beta.FeatureSpec
- func (*CommonFeatureSpec) ProtoMessage()
- func (x *CommonFeatureSpec) ProtoReflect() protoreflect.Message
- func (x *CommonFeatureSpec) Reset()
- func (x *CommonFeatureSpec) String() string
- type CommonFeatureSpec_Multiclusteringress
- type CommonFeatureState
- func (*CommonFeatureState) Descriptor() ([]byte, []int)
- func (x *CommonFeatureState) GetState() *FeatureState
- func (*CommonFeatureState) ProtoMessage()
- func (x *CommonFeatureState) ProtoReflect() protoreflect.Message
- func (x *CommonFeatureState) Reset()
- func (x *CommonFeatureState) String() string
- type CreateFeatureRequest
- func (*CreateFeatureRequest) Descriptor() ([]byte, []int)
- func (x *CreateFeatureRequest) GetFeatureId() string
- func (x *CreateFeatureRequest) GetParent() string
- func (x *CreateFeatureRequest) GetRequestId() string
- func (x *CreateFeatureRequest) GetResource() *Feature
- func (*CreateFeatureRequest) ProtoMessage()
- func (x *CreateFeatureRequest) ProtoReflect() protoreflect.Message
- func (x *CreateFeatureRequest) Reset()
- func (x *CreateFeatureRequest) String() string
- type DeleteFeatureRequest
- func (*DeleteFeatureRequest) Descriptor() ([]byte, []int)
- func (x *DeleteFeatureRequest) GetForce() bool
- func (x *DeleteFeatureRequest) GetName() string
- func (x *DeleteFeatureRequest) GetRequestId() string
- func (*DeleteFeatureRequest) ProtoMessage()
- func (x *DeleteFeatureRequest) ProtoReflect() protoreflect.Message
- func (x *DeleteFeatureRequest) Reset()
- func (x *DeleteFeatureRequest) String() string
- type Feature
- func (*Feature) Descriptor() ([]byte, []int)
- func (x *Feature) GetCreateTime() *timestamppb.Timestamp
- func (x *Feature) GetDeleteTime() *timestamppb.Timestamp
- func (x *Feature) GetLabels() map[string]string
- func (x *Feature) GetMembershipSpecs() map[string]*MembershipFeatureSpec
- func (x *Feature) GetMembershipStates() map[string]*MembershipFeatureState
- func (x *Feature) GetName() string
- func (x *Feature) GetResourceState() *FeatureResourceState
- func (x *Feature) GetSpec() *CommonFeatureSpec
- func (x *Feature) GetState() *CommonFeatureState
- func (x *Feature) GetUpdateTime() *timestamppb.Timestamp
- func (*Feature) ProtoMessage()
- func (x *Feature) ProtoReflect() protoreflect.Message
- func (x *Feature) Reset()
- func (x *Feature) String() string
- type FeatureResourceState
- func (*FeatureResourceState) Descriptor() ([]byte, []int)
- func (x *FeatureResourceState) GetState() FeatureResourceState_State
- func (*FeatureResourceState) ProtoMessage()
- func (x *FeatureResourceState) ProtoReflect() protoreflect.Message
- func (x *FeatureResourceState) Reset()
- func (x *FeatureResourceState) String() string
- type FeatureResourceState_State
- func (FeatureResourceState_State) Descriptor() protoreflect.EnumDescriptor
- func (x FeatureResourceState_State) Enum() *FeatureResourceState_State
- func (FeatureResourceState_State) EnumDescriptor() ([]byte, []int)
- func (x FeatureResourceState_State) Number() protoreflect.EnumNumber
- func (x FeatureResourceState_State) String() string
- func (FeatureResourceState_State) Type() protoreflect.EnumType
- type FeatureState
- func (*FeatureState) Descriptor() ([]byte, []int)
- func (x *FeatureState) GetCode() FeatureState_Code
- func (x *FeatureState) GetDescription() string
- func (x *FeatureState) GetUpdateTime() *timestamppb.Timestamp
- func (*FeatureState) ProtoMessage()
- func (x *FeatureState) ProtoReflect() protoreflect.Message
- func (x *FeatureState) Reset()
- func (x *FeatureState) String() string
- type FeatureState_Code
- func (FeatureState_Code) Descriptor() protoreflect.EnumDescriptor
- func (x FeatureState_Code) Enum() *FeatureState_Code
- func (FeatureState_Code) EnumDescriptor() ([]byte, []int)
- func (x FeatureState_Code) Number() protoreflect.EnumNumber
- func (x FeatureState_Code) String() string
- func (FeatureState_Code) Type() protoreflect.EnumType
- type GetFeatureRequest
- func (*GetFeatureRequest) Descriptor() ([]byte, []int)
- func (x *GetFeatureRequest) GetName() string
- func (*GetFeatureRequest) ProtoMessage()
- func (x *GetFeatureRequest) ProtoReflect() protoreflect.Message
- func (x *GetFeatureRequest) Reset()
- func (x *GetFeatureRequest) String() string
- type GkeHubClient
- type GkeHubServer
- type ListFeaturesRequest
- func (*ListFeaturesRequest) Descriptor() ([]byte, []int)
- func (x *ListFeaturesRequest) GetFilter() string
- func (x *ListFeaturesRequest) GetOrderBy() string
- func (x *ListFeaturesRequest) GetPageSize() int32
- func (x *ListFeaturesRequest) GetPageToken() string
- func (x *ListFeaturesRequest) GetParent() string
- func (*ListFeaturesRequest) ProtoMessage()
- func (x *ListFeaturesRequest) ProtoReflect() protoreflect.Message
- func (x *ListFeaturesRequest) Reset()
- func (x *ListFeaturesRequest) String() string
- type ListFeaturesResponse
- func (*ListFeaturesResponse) Descriptor() ([]byte, []int)
- func (x *ListFeaturesResponse) GetNextPageToken() string
- func (x *ListFeaturesResponse) GetResources() []*Feature
- func (*ListFeaturesResponse) ProtoMessage()
- func (x *ListFeaturesResponse) ProtoReflect() protoreflect.Message
- func (x *ListFeaturesResponse) Reset()
- func (x *ListFeaturesResponse) String() string
- type MembershipFeatureSpec
- func (*MembershipFeatureSpec) Descriptor() ([]byte, []int)
- func (x *MembershipFeatureSpec) GetConfigmanagement() *v1beta1.MembershipSpec
- func (m *MembershipFeatureSpec) GetFeatureSpec() isMembershipFeatureSpec_FeatureSpec
- func (*MembershipFeatureSpec) ProtoMessage()
- func (x *MembershipFeatureSpec) ProtoReflect() protoreflect.Message
- func (x *MembershipFeatureSpec) Reset()
- func (x *MembershipFeatureSpec) String() string
- type MembershipFeatureSpec_Configmanagement
- type MembershipFeatureState
- func (*MembershipFeatureState) Descriptor() ([]byte, []int)
- func (x *MembershipFeatureState) GetConfigmanagement() *v1beta1.MembershipState
- func (m *MembershipFeatureState) GetFeatureState() isMembershipFeatureState_FeatureState
- func (x *MembershipFeatureState) GetMetering() *v1beta2.MembershipState
- func (x *MembershipFeatureState) GetState() *FeatureState
- func (*MembershipFeatureState) ProtoMessage()
- func (x *MembershipFeatureState) ProtoReflect() protoreflect.Message
- func (x *MembershipFeatureState) Reset()
- func (x *MembershipFeatureState) String() string
- type MembershipFeatureState_Configmanagement
- type MembershipFeatureState_Metering
- type OperationMetadata
- func (*OperationMetadata) Descriptor() ([]byte, []int)
- func (x *OperationMetadata) GetApiVersion() string
- func (x *OperationMetadata) GetCancelRequested() bool
- func (x *OperationMetadata) GetCreateTime() *timestamppb.Timestamp
- func (x *OperationMetadata) GetEndTime() *timestamppb.Timestamp
- func (x *OperationMetadata) GetStatusDetail() string
- func (x *OperationMetadata) GetTarget() string
- func (x *OperationMetadata) GetVerb() string
- func (*OperationMetadata) ProtoMessage()
- func (x *OperationMetadata) ProtoReflect() protoreflect.Message
- func (x *OperationMetadata) Reset()
- func (x *OperationMetadata) String() string
- type UnimplementedGkeHubServer
- func (*UnimplementedGkeHubServer) CreateFeature(context.Context, *CreateFeatureRequest) (*longrunning.Operation, error)
- func (*UnimplementedGkeHubServer) DeleteFeature(context.Context, *DeleteFeatureRequest) (*longrunning.Operation, error)
- func (*UnimplementedGkeHubServer) GetFeature(context.Context, *GetFeatureRequest) (*Feature, error)
- func (*UnimplementedGkeHubServer) ListFeatures(context.Context, *ListFeaturesRequest) (*ListFeaturesResponse, error)
- func (*UnimplementedGkeHubServer) UpdateFeature(context.Context, *UpdateFeatureRequest) (*longrunning.Operation, error)
- type UpdateFeatureRequest
- func (*UpdateFeatureRequest) Descriptor() ([]byte, []int)
- func (x *UpdateFeatureRequest) GetName() string
- func (x *UpdateFeatureRequest) GetRequestId() string
- func (x *UpdateFeatureRequest) GetResource() *Feature
- func (x *UpdateFeatureRequest) GetUpdateMask() *fieldmaskpb.FieldMask
- func (*UpdateFeatureRequest) ProtoMessage()
- func (x *UpdateFeatureRequest) ProtoReflect() protoreflect.Message
- func (x *UpdateFeatureRequest) Reset()
- func (x *UpdateFeatureRequest) String() string
Variables ¶
var ( FeatureResourceState_State_name = map[int32]string{ 0: "STATE_UNSPECIFIED", 1: "ENABLING", 2: "ACTIVE", 3: "DISABLING", 4: "UPDATING", 5: "SERVICE_UPDATING", } FeatureResourceState_State_value = map[string]int32{ "STATE_UNSPECIFIED": 0, "ENABLING": 1, "ACTIVE": 2, "DISABLING": 3, "UPDATING": 4, "SERVICE_UPDATING": 5, } )
Enum value maps for FeatureResourceState_State.
var ( FeatureState_Code_name = map[int32]string{ 0: "CODE_UNSPECIFIED", 1: "OK", 2: "WARNING", 3: "ERROR", } FeatureState_Code_value = map[string]int32{ "CODE_UNSPECIFIED": 0, "OK": 1, "WARNING": 2, "ERROR": 3, } )
Enum value maps for FeatureState_Code.
var File_google_cloud_gkehub_v1beta_feature_proto protoreflect.FileDescriptor
var File_google_cloud_gkehub_v1beta_service_proto protoreflect.FileDescriptor
Functions ¶
func RegisterGkeHubServer ¶
func RegisterGkeHubServer(s *grpc.Server, srv GkeHubServer)
Types ¶
type CommonFeatureSpec ¶
type CommonFeatureSpec struct {
// Types that are assignable to FeatureSpec:
//
// *CommonFeatureSpec_Multiclusteringress
FeatureSpec isCommonFeatureSpec_FeatureSpec `protobuf_oneof:"feature_spec"`
// contains filtered or unexported fields
}
CommonFeatureSpec contains Hub-wide configuration information
func (*CommonFeatureSpec) Descriptor ¶
func (*CommonFeatureSpec) Descriptor() ([]byte, []int)
Deprecated: Use CommonFeatureSpec.ProtoReflect.Descriptor instead.
func (*CommonFeatureSpec) GetFeatureSpec ¶
func (m *CommonFeatureSpec) GetFeatureSpec() isCommonFeatureSpec_FeatureSpec
func (*CommonFeatureSpec) GetMulticlusteringress ¶
func (x *CommonFeatureSpec) GetMulticlusteringress() *v1beta.FeatureSpec
func (*CommonFeatureSpec) ProtoMessage ¶
func (*CommonFeatureSpec) ProtoMessage()
func (*CommonFeatureSpec) ProtoReflect ¶
func (x *CommonFeatureSpec) ProtoReflect() protoreflect.Message
func (*CommonFeatureSpec) Reset ¶
func (x *CommonFeatureSpec) Reset()
func (*CommonFeatureSpec) String ¶
func (x *CommonFeatureSpec) String() string
type CommonFeatureSpec_Multiclusteringress ¶
type CommonFeatureSpec_Multiclusteringress struct {
// Multicluster Ingress-specific spec.
Multiclusteringress *v1beta.FeatureSpec `protobuf:"bytes,102,opt,name=multiclusteringress,proto3,oneof"`
}
type CommonFeatureState ¶
type CommonFeatureState struct {
// Output only. The "running state" of the Feature in this Hub.
State *FeatureState `protobuf:"bytes,1,opt,name=state,proto3" json:"state,omitempty"`
// contains filtered or unexported fields
}
CommonFeatureState contains Hub-wide Feature status information.
func (*CommonFeatureState) Descriptor ¶
func (*CommonFeatureState) Descriptor() ([]byte, []int)
Deprecated: Use CommonFeatureState.ProtoReflect.Descriptor instead.
func (*CommonFeatureState) GetState ¶
func (x *CommonFeatureState) GetState() *FeatureState
func (*CommonFeatureState) ProtoMessage ¶
func (*CommonFeatureState) ProtoMessage()
func (*CommonFeatureState) ProtoReflect ¶
func (x *CommonFeatureState) ProtoReflect() protoreflect.Message
func (*CommonFeatureState) Reset ¶
func (x *CommonFeatureState) Reset()
func (*CommonFeatureState) String ¶
func (x *CommonFeatureState) String() string
type CreateFeatureRequest ¶
type CreateFeatureRequest struct {
// The parent (project and location) where the Feature will be created.
// Specified in the format `projects/*/locations/*`.
Parent string `protobuf:"bytes,1,opt,name=parent,proto3" json:"parent,omitempty"`
// The ID of the feature to create.
FeatureId string `protobuf:"bytes,2,opt,name=feature_id,json=featureId,proto3" json:"feature_id,omitempty"`
// The Feature resource to create.
Resource *Feature `protobuf:"bytes,3,opt,name=resource,proto3" json:"resource,omitempty"`
// Optional. A request ID to identify requests. Specify a unique request ID
// so that if you must retry your request, the server will know to ignore
// the request if it has already been completed. The server will guarantee
// that for at least 60 minutes after the first request.
//
// For example, consider a situation where you make an initial request and
// the request times out. If you make the request again with the same request
// ID, the server can check if original operation with the same request ID
// was received, and if so, will ignore the second request. This prevents
// clients from accidentally creating duplicate commitments.
//
// The request ID must be a valid UUID with the exception that zero UUID is
// not supported (00000000-0000-0000-0000-000000000000).
RequestId string `protobuf:"bytes,4,opt,name=request_id,json=requestId,proto3" json:"request_id,omitempty"`
// contains filtered or unexported fields
}
Request message for the `GkeHub.CreateFeature` method.
func (*CreateFeatureRequest) Descriptor ¶
func (*CreateFeatureRequest) Descriptor() ([]byte, []int)
Deprecated: Use CreateFeatureRequest.ProtoReflect.Descriptor instead.
func (*CreateFeatureRequest) GetFeatureId ¶
func (x *CreateFeatureRequest) GetFeatureId() string
func (*CreateFeatureRequest) GetParent ¶
func (x *CreateFeatureRequest) GetParent() string
func (*CreateFeatureRequest) GetRequestId ¶
func (x *CreateFeatureRequest) GetRequestId() string
func (*CreateFeatureRequest) GetResource ¶
func (x *CreateFeatureRequest) GetResource() *Feature
func (*CreateFeatureRequest) ProtoMessage ¶
func (*CreateFeatureRequest) ProtoMessage()
func (*CreateFeatureRequest) ProtoReflect ¶
func (x *CreateFeatureRequest) ProtoReflect() protoreflect.Message
func (*CreateFeatureRequest) Reset ¶
func (x *CreateFeatureRequest) Reset()
func (*CreateFeatureRequest) String ¶
func (x *CreateFeatureRequest) String() string
type DeleteFeatureRequest ¶
type DeleteFeatureRequest struct {
// The Feature resource name in the format
// `projects/*/locations/*/features/*`.
Name string `protobuf:"bytes,1,opt,name=name,proto3" json:"name,omitempty"`
// If set to true, the delete will ignore any outstanding resources for
// this Feature (that is, `FeatureState.has_resources` is set to true). These
// resources will NOT be cleaned up or modified in any way.
Force bool `protobuf:"varint,2,opt,name=force,proto3" json:"force,omitempty"`
// Optional. A request ID to identify requests. Specify a unique request ID
// so that if you must retry your request, the server will know to ignore
// the request if it has already been completed. The server will guarantee
// that for at least 60 minutes after the first request.
//
// For example, consider a situation where you make an initial request and
// the request times out. If you make the request again with the same request
// ID, the server can check if original operation with the same request ID
// was received, and if so, will ignore the second request. This prevents
// clients from accidentally creating duplicate commitments.
//
// The request ID must be a valid UUID with the exception that zero UUID is
// not supported (00000000-0000-0000-0000-000000000000).
RequestId string `protobuf:"bytes,3,opt,name=request_id,json=requestId,proto3" json:"request_id,omitempty"`
// contains filtered or unexported fields
}
Request message for `GkeHub.DeleteFeature` method.
func (*DeleteFeatureRequest) Descriptor ¶
func (*DeleteFeatureRequest) Descriptor() ([]byte, []int)
Deprecated: Use DeleteFeatureRequest.ProtoReflect.Descriptor instead.
func (*DeleteFeatureRequest) GetForce ¶
func (x *DeleteFeatureRequest) GetForce() bool
func (*DeleteFeatureRequest) GetName ¶
func (x *DeleteFeatureRequest) GetName() string
func (*DeleteFeatureRequest) GetRequestId ¶
func (x *DeleteFeatureRequest) GetRequestId() string
func (*DeleteFeatureRequest) ProtoMessage ¶
func (*DeleteFeatureRequest) ProtoMessage()
func (*DeleteFeatureRequest) ProtoReflect ¶
func (x *DeleteFeatureRequest) ProtoReflect() protoreflect.Message
func (*DeleteFeatureRequest) Reset ¶
func (x *DeleteFeatureRequest) Reset()
func (*DeleteFeatureRequest) String ¶
func (x *DeleteFeatureRequest) String() string
type Feature ¶
type Feature struct {
// Output only. The full, unique name of this Feature resource in the format
// `projects/*/locations/*/features/*`.
Name string `protobuf:"bytes,1,opt,name=name,proto3" json:"name,omitempty"`
// GCP labels for this Feature.
Labels map[string]string `protobuf:"bytes,2,rep,name=labels,proto3" json:"labels,omitempty" protobuf_key:"bytes,1,opt,name=key,proto3" protobuf_val:"bytes,2,opt,name=value,proto3"`
// Output only. State of the Feature resource itself.
ResourceState *FeatureResourceState `protobuf:"bytes,3,opt,name=resource_state,json=resourceState,proto3" json:"resource_state,omitempty"`
// Optional. Hub-wide Feature configuration. If this Feature does not support any
// Hub-wide configuration, this field may be unused.
Spec *CommonFeatureSpec `protobuf:"bytes,4,opt,name=spec,proto3" json:"spec,omitempty"`
// Optional. Membership-specific configuration for this Feature. If this Feature does
// not support any per-Membership configuration, this field may be unused.
//
// The keys indicate which Membership the configuration is for, in the form:
//
// projects/{p}/locations/{l}/memberships/{m}
//
// Where {p} is the project, {l} is a valid location and {m} is a valid
// Membership in this project at that location. {p} WILL match the Feature's
// project.
//
// {p} will always be returned as the project number, but the project ID is
// also accepted during input. If the same Membership is specified in the map
// twice (using the project ID form, and the project number form), exactly
// ONE of the entries will be saved, with no guarantees as to which. For this
// reason, it is recommended the same format be used for all entries when
// mutating a Feature.
MembershipSpecs map[string]*MembershipFeatureSpec `protobuf:"bytes,5,rep,name=membership_specs,json=membershipSpecs,proto3" json:"membership_specs,omitempty" protobuf_key:"bytes,1,opt,name=key,proto3" protobuf_val:"bytes,2,opt,name=value,proto3"`
// Output only. The Hub-wide Feature state.
State *CommonFeatureState `protobuf:"bytes,6,opt,name=state,proto3" json:"state,omitempty"`
// Output only. Membership-specific Feature status. If this Feature does
// report any per-Membership status, this field may be unused.
//
// The keys indicate which Membership the state is for, in the form:
//
// projects/{p}/locations/{l}/memberships/{m}
//
// Where {p} is the project number, {l} is a valid location and {m} is a valid
// Membership in this project at that location. {p} MUST match the Feature's
// project number.
MembershipStates map[string]*MembershipFeatureState `protobuf:"bytes,7,rep,name=membership_states,json=membershipStates,proto3" json:"membership_states,omitempty" protobuf_key:"bytes,1,opt,name=key,proto3" protobuf_val:"bytes,2,opt,name=value,proto3"`
// Output only. When the Feature resource was created.
CreateTime *timestamppb.Timestamp `protobuf:"bytes,8,opt,name=create_time,json=createTime,proto3" json:"create_time,omitempty"`
// Output only. When the Feature resource was last updated.
UpdateTime *timestamppb.Timestamp `protobuf:"bytes,9,opt,name=update_time,json=updateTime,proto3" json:"update_time,omitempty"`
// Output only. When the Feature resource was deleted.
DeleteTime *timestamppb.Timestamp `protobuf:"bytes,10,opt,name=delete_time,json=deleteTime,proto3" json:"delete_time,omitempty"`
// contains filtered or unexported fields
}
Feature represents the settings and status of any Hub Feature.
func (*Feature) Descriptor ¶
Deprecated: Use Feature.ProtoReflect.Descriptor instead.
func (*Feature) GetCreateTime ¶
func (x *Feature) GetCreateTime() *timestamppb.Timestamp
func (*Feature) GetDeleteTime ¶
func (x *Feature) GetDeleteTime() *timestamppb.Timestamp
func (*Feature) GetLabels ¶
func (*Feature) GetMembershipSpecs ¶
func (x *Feature) GetMembershipSpecs() map[string]*MembershipFeatureSpec
func (*Feature) GetMembershipStates ¶
func (x *Feature) GetMembershipStates() map[string]*MembershipFeatureState
func (*Feature) GetName ¶
func (*Feature) GetResourceState ¶
func (x *Feature) GetResourceState() *FeatureResourceState
func (*Feature) GetSpec ¶
func (x *Feature) GetSpec() *CommonFeatureSpec
func (*Feature) GetState ¶
func (x *Feature) GetState() *CommonFeatureState
func (*Feature) GetUpdateTime ¶
func (x *Feature) GetUpdateTime() *timestamppb.Timestamp
func (*Feature) ProtoMessage ¶
func (*Feature) ProtoMessage()
func (*Feature) ProtoReflect ¶
func (x *Feature) ProtoReflect() protoreflect.Message
func (*Feature) Reset ¶
func (x *Feature) Reset()
func (*Feature) String ¶
type FeatureResourceState ¶
type FeatureResourceState struct {
// The current state of the Feature resource in the Hub API.
State FeatureResourceState_State `protobuf:"varint,1,opt,name=state,proto3,enum=google.cloud.gkehub.v1beta.FeatureResourceState_State" json:"state,omitempty"`
// contains filtered or unexported fields
}
FeatureResourceState describes the state of a Feature *resource* in the GkeHub API. See `FeatureState` for the "running state" of the Feature in the Hub and across Memberships.
func (*FeatureResourceState) Descriptor ¶
func (*FeatureResourceState) Descriptor() ([]byte, []int)
Deprecated: Use FeatureResourceState.ProtoReflect.Descriptor instead.
func (*FeatureResourceState) GetState ¶
func (x *FeatureResourceState) GetState() FeatureResourceState_State
func (*FeatureResourceState) ProtoMessage ¶
func (*FeatureResourceState) ProtoMessage()
func (*FeatureResourceState) ProtoReflect ¶
func (x *FeatureResourceState) ProtoReflect() protoreflect.Message
func (*FeatureResourceState) Reset ¶
func (x *FeatureResourceState) Reset()
func (*FeatureResourceState) String ¶
func (x *FeatureResourceState) String() string
type FeatureResourceState_State ¶
type FeatureResourceState_State int32
State describes the lifecycle status of a Feature.
const ( // State is unknown or not set. FeatureResourceState_STATE_UNSPECIFIED FeatureResourceState_State = 0 // The Feature is being enabled, and the Feature resource is being created. // Once complete, the corresponding Feature will be enabled in this Hub. FeatureResourceState_ENABLING FeatureResourceState_State = 1 // The Feature is enabled in this Hub, and the Feature resource is fully // available. FeatureResourceState_ACTIVE FeatureResourceState_State = 2 // The Feature is being disabled in this Hub, and the Feature resource // is being deleted. FeatureResourceState_DISABLING FeatureResourceState_State = 3 // The Feature resource is being updated. FeatureResourceState_UPDATING FeatureResourceState_State = 4 // The Feature resource is being updated by the Hub Service. FeatureResourceState_SERVICE_UPDATING FeatureResourceState_State = 5 )
func (FeatureResourceState_State) Descriptor ¶
func (FeatureResourceState_State) Descriptor() protoreflect.EnumDescriptor
func (FeatureResourceState_State) Enum ¶
func (x FeatureResourceState_State) Enum() *FeatureResourceState_State
func (FeatureResourceState_State) EnumDescriptor ¶
func (FeatureResourceState_State) EnumDescriptor() ([]byte, []int)
Deprecated: Use FeatureResourceState_State.Descriptor instead.
func (FeatureResourceState_State) Number ¶
func (x FeatureResourceState_State) Number() protoreflect.EnumNumber
func (FeatureResourceState_State) String ¶
func (x FeatureResourceState_State) String() string
func (FeatureResourceState_State) Type ¶
func (FeatureResourceState_State) Type() protoreflect.EnumType
type FeatureState ¶
type FeatureState struct {
// The high-level, machine-readable status of this Feature.
Code FeatureState_Code `protobuf:"varint,1,opt,name=code,proto3,enum=google.cloud.gkehub.v1beta.FeatureState_Code" json:"code,omitempty"`
// A human-readable description of the current status.
Description string `protobuf:"bytes,2,opt,name=description,proto3" json:"description,omitempty"`
// The time this status and any related Feature-specific details were updated.
UpdateTime *timestamppb.Timestamp `protobuf:"bytes,3,opt,name=update_time,json=updateTime,proto3" json:"update_time,omitempty"`
// contains filtered or unexported fields
}
FeatureState describes the high-level state of a Feature. It may be used to describe a Feature's state at the environ-level, or per-membershop, depending on the context.
func (*FeatureState) Descriptor ¶
func (*FeatureState) Descriptor() ([]byte, []int)
Deprecated: Use FeatureState.ProtoReflect.Descriptor instead.
func (*FeatureState) GetCode ¶
func (x *FeatureState) GetCode() FeatureState_Code
func (*FeatureState) GetDescription ¶
func (x *FeatureState) GetDescription() string
func (*FeatureState) GetUpdateTime ¶
func (x *FeatureState) GetUpdateTime() *timestamppb.Timestamp
func (*FeatureState) ProtoMessage ¶
func (*FeatureState) ProtoMessage()
func (*FeatureState) ProtoReflect ¶
func (x *FeatureState) ProtoReflect() protoreflect.Message
func (*FeatureState) Reset ¶
func (x *FeatureState) Reset()
func (*FeatureState) String ¶
func (x *FeatureState) String() string
type FeatureState_Code ¶
type FeatureState_Code int32
Code represents a machine-readable, high-level status of the Feature.
const ( // Unknown or not set. FeatureState_CODE_UNSPECIFIED FeatureState_Code = 0 // The Feature is operating normally. FeatureState_OK FeatureState_Code = 1 // The Feature has encountered an issue, and is operating in a degraded // state. The Feature may need intervention to return to normal operation. // See the description and any associated Feature-specific details for more // information. FeatureState_WARNING FeatureState_Code = 2 // The Feature is not operating or is in a severely degraded state. // The Feature may need intervention to return to normal operation. // See the description and any associated Feature-specific details for more // information. FeatureState_ERROR FeatureState_Code = 3 )
func (FeatureState_Code) Descriptor ¶
func (FeatureState_Code) Descriptor() protoreflect.EnumDescriptor
func (FeatureState_Code) Enum ¶
func (x FeatureState_Code) Enum() *FeatureState_Code
func (FeatureState_Code) EnumDescriptor ¶
func (FeatureState_Code) EnumDescriptor() ([]byte, []int)
Deprecated: Use FeatureState_Code.Descriptor instead.
func (FeatureState_Code) Number ¶
func (x FeatureState_Code) Number() protoreflect.EnumNumber
func (FeatureState_Code) String ¶
func (x FeatureState_Code) String() string
func (FeatureState_Code) Type ¶
func (FeatureState_Code) Type() protoreflect.EnumType
type GetFeatureRequest ¶
type GetFeatureRequest struct {
// The Feature resource name in the format
// `projects/*/locations/*/features/*`
Name string `protobuf:"bytes,1,opt,name=name,proto3" json:"name,omitempty"`
// contains filtered or unexported fields
}
Request message for `GkeHub.GetFeature` method.
func (*GetFeatureRequest) Descriptor ¶
func (*GetFeatureRequest) Descriptor() ([]byte, []int)
Deprecated: Use GetFeatureRequest.ProtoReflect.Descriptor instead.
func (*GetFeatureRequest) GetName ¶
func (x *GetFeatureRequest) GetName() string
func (*GetFeatureRequest) ProtoMessage ¶
func (*GetFeatureRequest) ProtoMessage()
func (*GetFeatureRequest) ProtoReflect ¶
func (x *GetFeatureRequest) ProtoReflect() protoreflect.Message
func (*GetFeatureRequest) Reset ¶
func (x *GetFeatureRequest) Reset()
func (*GetFeatureRequest) String ¶
func (x *GetFeatureRequest) String() string
type GkeHubClient ¶
type GkeHubClient interface {
// Lists Features in a given project and location.
ListFeatures(ctx context.Context, in *ListFeaturesRequest, opts ...grpc.CallOption) (*ListFeaturesResponse, error)
// Gets details of a single Feature.
GetFeature(ctx context.Context, in *GetFeatureRequest, opts ...grpc.CallOption) (*Feature, error)
// Adds a new Feature.
CreateFeature(ctx context.Context, in *CreateFeatureRequest, opts ...grpc.CallOption) (*longrunning.Operation, error)
// Removes a Feature.
DeleteFeature(ctx context.Context, in *DeleteFeatureRequest, opts ...grpc.CallOption) (*longrunning.Operation, error)
// Updates an existing Feature.
UpdateFeature(ctx context.Context, in *UpdateFeatureRequest, opts ...grpc.CallOption) (*longrunning.Operation, error)
}
GkeHubClient is the client API for GkeHub service.
For semantics around ctx use and closing/ending streaming RPCs, please refer to https://godoc.org/google.golang.org/grpc#ClientConn.NewStream.
func NewGkeHubClient ¶
func NewGkeHubClient(cc grpc.ClientConnInterface) GkeHubClient
type GkeHubServer ¶
type GkeHubServer interface {
// Lists Features in a given project and location.
ListFeatures(context.Context, *ListFeaturesRequest) (*ListFeaturesResponse, error)
// Gets details of a single Feature.
GetFeature(context.Context, *GetFeatureRequest) (*Feature, error)
// Adds a new Feature.
CreateFeature(context.Context, *CreateFeatureRequest) (*longrunning.Operation, error)
// Removes a Feature.
DeleteFeature(context.Context, *DeleteFeatureRequest) (*longrunning.Operation, error)
// Updates an existing Feature.
UpdateFeature(context.Context, *UpdateFeatureRequest) (*longrunning.Operation, error)
}
GkeHubServer is the server API for GkeHub service.
type ListFeaturesRequest ¶
type ListFeaturesRequest struct {
// The parent (project and location) where the Features will be listed.
// Specified in the format `projects/*/locations/*`.
Parent string `protobuf:"bytes,1,opt,name=parent,proto3" json:"parent,omitempty"`
// When requesting a 'page' of resources, `page_size` specifies number of
// resources to return. If unspecified or set to 0, all resources will
// be returned.
PageSize int32 `protobuf:"varint,2,opt,name=page_size,json=pageSize,proto3" json:"page_size,omitempty"`
// Token returned by previous call to `ListFeatures` which
// specifies the position in the list from where to continue listing the
// resources.
PageToken string `protobuf:"bytes,3,opt,name=page_token,json=pageToken,proto3" json:"page_token,omitempty"`
// Lists Features that match the filter expression, following the syntax
// outlined in https://google.aip.dev/160.
//
// Examples:
//
// - Feature with the name "servicemesh" in project "foo-proj":
//
// name = "projects/foo-proj/locations/global/features/servicemesh"
//
// - Features that have a label called `foo`:
//
// labels.foo:*
//
// - Features that have a label called `foo` whose value is `bar`:
//
// labels.foo = bar
Filter string `protobuf:"bytes,4,opt,name=filter,proto3" json:"filter,omitempty"`
// One or more fields to compare and use to sort the output.
// See https://google.aip.dev/132#ordering.
OrderBy string `protobuf:"bytes,5,opt,name=order_by,json=orderBy,proto3" json:"order_by,omitempty"`
// contains filtered or unexported fields
}
Request message for `GkeHub.ListFeatures` method.
func (*ListFeaturesRequest) Descriptor ¶
func (*ListFeaturesRequest) Descriptor() ([]byte, []int)
Deprecated: Use ListFeaturesRequest.ProtoReflect.Descriptor instead.
func (*ListFeaturesRequest) GetFilter ¶
func (x *ListFeaturesRequest) GetFilter() string
func (*ListFeaturesRequest) GetOrderBy ¶
func (x *ListFeaturesRequest) GetOrderBy() string
func (*ListFeaturesRequest) GetPageSize ¶
func (x *ListFeaturesRequest) GetPageSize() int32
func (*ListFeaturesRequest) GetPageToken ¶
func (x *ListFeaturesRequest) GetPageToken() string
func (*ListFeaturesRequest) GetParent ¶
func (x *ListFeaturesRequest) GetParent() string
func (*ListFeaturesRequest) ProtoMessage ¶
func (*ListFeaturesRequest) ProtoMessage()
func (*ListFeaturesRequest) ProtoReflect ¶
func (x *ListFeaturesRequest) ProtoReflect() protoreflect.Message
func (*ListFeaturesRequest) Reset ¶
func (x *ListFeaturesRequest) Reset()
func (*ListFeaturesRequest) String ¶
func (x *ListFeaturesRequest) String() string
type ListFeaturesResponse ¶
type ListFeaturesResponse struct {
// The list of matching Features
Resources []*Feature `protobuf:"bytes,1,rep,name=resources,proto3" json:"resources,omitempty"`
// A token to request the next page of resources from the
// `ListFeatures` method. The value of an empty string means
// that there are no more resources to return.
NextPageToken string `protobuf:"bytes,2,opt,name=next_page_token,json=nextPageToken,proto3" json:"next_page_token,omitempty"`
// contains filtered or unexported fields
}
Response message for the `GkeHub.ListFeatures` method.
func (*ListFeaturesResponse) Descriptor ¶
func (*ListFeaturesResponse) Descriptor() ([]byte, []int)
Deprecated: Use ListFeaturesResponse.ProtoReflect.Descriptor instead.
func (*ListFeaturesResponse) GetNextPageToken ¶
func (x *ListFeaturesResponse) GetNextPageToken() string
func (*ListFeaturesResponse) GetResources ¶
func (x *ListFeaturesResponse) GetResources() []*Feature
func (*ListFeaturesResponse) ProtoMessage ¶
func (*ListFeaturesResponse) ProtoMessage()
func (*ListFeaturesResponse) ProtoReflect ¶
func (x *ListFeaturesResponse) ProtoReflect() protoreflect.Message
func (*ListFeaturesResponse) Reset ¶
func (x *ListFeaturesResponse) Reset()
func (*ListFeaturesResponse) String ¶
func (x *ListFeaturesResponse) String() string
type MembershipFeatureSpec ¶
type MembershipFeatureSpec struct {
// Types that are assignable to FeatureSpec:
//
// *MembershipFeatureSpec_Configmanagement
FeatureSpec isMembershipFeatureSpec_FeatureSpec `protobuf_oneof:"feature_spec"`
// contains filtered or unexported fields
}
MembershipFeatureSpec contains configuration information for a single Membership.
func (*MembershipFeatureSpec) Descriptor ¶
func (*MembershipFeatureSpec) Descriptor() ([]byte, []int)
Deprecated: Use MembershipFeatureSpec.ProtoReflect.Descriptor instead.
func (*MembershipFeatureSpec) GetConfigmanagement ¶
func (x *MembershipFeatureSpec) GetConfigmanagement() *v1beta1.MembershipSpec
func (*MembershipFeatureSpec) GetFeatureSpec ¶
func (m *MembershipFeatureSpec) GetFeatureSpec() isMembershipFeatureSpec_FeatureSpec
func (*MembershipFeatureSpec) ProtoMessage ¶
func (*MembershipFeatureSpec) ProtoMessage()
func (*MembershipFeatureSpec) ProtoReflect ¶
func (x *MembershipFeatureSpec) ProtoReflect() protoreflect.Message
func (*MembershipFeatureSpec) Reset ¶
func (x *MembershipFeatureSpec) Reset()
func (*MembershipFeatureSpec) String ¶
func (x *MembershipFeatureSpec) String() string
type MembershipFeatureSpec_Configmanagement ¶
type MembershipFeatureSpec_Configmanagement struct {
// Config Management-specific spec.
Configmanagement *v1beta1.MembershipSpec `protobuf:"bytes,106,opt,name=configmanagement,proto3,oneof"`
}
type MembershipFeatureState ¶
type MembershipFeatureState struct {
// Types that are assignable to FeatureState:
//
// *MembershipFeatureState_Metering
// *MembershipFeatureState_Configmanagement
FeatureState isMembershipFeatureState_FeatureState `protobuf_oneof:"feature_state"`
// The high-level state of this Feature for a single membership.
State *FeatureState `protobuf:"bytes,1,opt,name=state,proto3" json:"state,omitempty"`
// contains filtered or unexported fields
}
MembershipFeatureState contains Feature status information for a single Membership.
func (*MembershipFeatureState) Descriptor ¶
func (*MembershipFeatureState) Descriptor() ([]byte, []int)
Deprecated: Use MembershipFeatureState.ProtoReflect.Descriptor instead.
func (*MembershipFeatureState) GetConfigmanagement ¶
func (x *MembershipFeatureState) GetConfigmanagement() *v1beta1.MembershipState
func (*MembershipFeatureState) GetFeatureState ¶
func (m *MembershipFeatureState) GetFeatureState() isMembershipFeatureState_FeatureState
func (*MembershipFeatureState) GetMetering ¶
func (x *MembershipFeatureState) GetMetering() *v1beta2.MembershipState
func (*MembershipFeatureState) GetState ¶
func (x *MembershipFeatureState) GetState() *FeatureState
func (*MembershipFeatureState) ProtoMessage ¶
func (*MembershipFeatureState) ProtoMessage()
func (*MembershipFeatureState) ProtoReflect ¶
func (x *MembershipFeatureState) ProtoReflect() protoreflect.Message
func (*MembershipFeatureState) Reset ¶
func (x *MembershipFeatureState) Reset()
func (*MembershipFeatureState) String ¶
func (x *MembershipFeatureState) String() string
type MembershipFeatureState_Configmanagement ¶
type MembershipFeatureState_Configmanagement struct {
// Config Management-specific state.
Configmanagement *v1beta1.MembershipState `protobuf:"bytes,106,opt,name=configmanagement,proto3,oneof"`
}
type MembershipFeatureState_Metering ¶
type MembershipFeatureState_Metering struct {
// Metering-specific spec.
Metering *v1beta2.MembershipState `protobuf:"bytes,104,opt,name=metering,proto3,oneof"`
}
type OperationMetadata ¶
type OperationMetadata struct {
// Output only. The time the operation was created.
CreateTime *timestamppb.Timestamp `protobuf:"bytes,1,opt,name=create_time,json=createTime,proto3" json:"create_time,omitempty"`
// Output only. The time the operation finished running.
EndTime *timestamppb.Timestamp `protobuf:"bytes,2,opt,name=end_time,json=endTime,proto3" json:"end_time,omitempty"`
// Output only. Server-defined resource path for the target of the operation.
Target string `protobuf:"bytes,3,opt,name=target,proto3" json:"target,omitempty"`
// Output only. Name of the verb executed by the operation.
Verb string `protobuf:"bytes,4,opt,name=verb,proto3" json:"verb,omitempty"`
// Output only. Human-readable status of the operation, if any.
StatusDetail string `protobuf:"bytes,5,opt,name=status_detail,json=statusDetail,proto3" json:"status_detail,omitempty"`
// Output only. Identifies whether the user has requested cancellation
// of the operation. Operations that have successfully been cancelled
// have [Operation.error][] value with a [google.rpc.Status.code][google.rpc.Status.code] of 1,
// corresponding to `Code.CANCELLED`.
CancelRequested bool `protobuf:"varint,6,opt,name=cancel_requested,json=cancelRequested,proto3" json:"cancel_requested,omitempty"`
// Output only. API version used to start the operation.
ApiVersion string `protobuf:"bytes,7,opt,name=api_version,json=apiVersion,proto3" json:"api_version,omitempty"`
// contains filtered or unexported fields
}
Represents the metadata of the long-running operation.
func (*OperationMetadata) Descriptor ¶
func (*OperationMetadata) Descriptor() ([]byte, []int)
Deprecated: Use OperationMetadata.ProtoReflect.Descriptor instead.
func (*OperationMetadata) GetApiVersion ¶
func (x *OperationMetadata) GetApiVersion() string
func (*OperationMetadata) GetCancelRequested ¶
func (x *OperationMetadata) GetCancelRequested() bool
func (*OperationMetadata) GetCreateTime ¶
func (x *OperationMetadata) GetCreateTime() *timestamppb.Timestamp
func (*OperationMetadata) GetEndTime ¶
func (x *OperationMetadata) GetEndTime() *timestamppb.Timestamp
func (*OperationMetadata) GetStatusDetail ¶
func (x *OperationMetadata) GetStatusDetail() string
func (*OperationMetadata) GetTarget ¶
func (x *OperationMetadata) GetTarget() string
func (*OperationMetadata) GetVerb ¶
func (x *OperationMetadata) GetVerb() string
func (*OperationMetadata) ProtoMessage ¶
func (*OperationMetadata) ProtoMessage()
func (*OperationMetadata) ProtoReflect ¶
func (x *OperationMetadata) ProtoReflect() protoreflect.Message
func (*OperationMetadata) Reset ¶
func (x *OperationMetadata) Reset()
func (*OperationMetadata) String ¶
func (x *OperationMetadata) String() string
type UnimplementedGkeHubServer ¶
type UnimplementedGkeHubServer struct {
}
UnimplementedGkeHubServer can be embedded to have forward compatible implementations.
func (*UnimplementedGkeHubServer) CreateFeature ¶
func (*UnimplementedGkeHubServer) CreateFeature(context.Context, *CreateFeatureRequest) (*longrunning.Operation, error)
func (*UnimplementedGkeHubServer) DeleteFeature ¶
func (*UnimplementedGkeHubServer) DeleteFeature(context.Context, *DeleteFeatureRequest) (*longrunning.Operation, error)
func (*UnimplementedGkeHubServer) GetFeature ¶
func (*UnimplementedGkeHubServer) GetFeature(context.Context, *GetFeatureRequest) (*Feature, error)
func (*UnimplementedGkeHubServer) ListFeatures ¶
func (*UnimplementedGkeHubServer) ListFeatures(context.Context, *ListFeaturesRequest) (*ListFeaturesResponse, error)
func (*UnimplementedGkeHubServer) UpdateFeature ¶
func (*UnimplementedGkeHubServer) UpdateFeature(context.Context, *UpdateFeatureRequest) (*longrunning.Operation, error)
type UpdateFeatureRequest ¶
type UpdateFeatureRequest struct {
// The Feature resource name in the format
// `projects/*/locations/*/features/*`.
Name string `protobuf:"bytes,1,opt,name=name,proto3" json:"name,omitempty"`
// Mask of fields to update.
UpdateMask *fieldmaskpb.FieldMask `protobuf:"bytes,2,opt,name=update_mask,json=updateMask,proto3" json:"update_mask,omitempty"`
// Only fields specified in update_mask are updated.
// If you specify a field in the update_mask but don't specify its value here
// that field will be deleted.
// If you are updating a map field, set the value of a key to null or empty
// string to delete the key from the map. It's not possible to update a key's
// value to the empty string.
// If you specify the update_mask to be a special path "*", fully replaces all
// user-modifiable fields to match `resource`.
Resource *Feature `protobuf:"bytes,3,opt,name=resource,proto3" json:"resource,omitempty"`
// Optional. A request ID to identify requests. Specify a unique request ID
// so that if you must retry your request, the server will know to ignore
// the request if it has already been completed. The server will guarantee
// that for at least 60 minutes after the first request.
//
// For example, consider a situation where you make an initial request and
// the request times out. If you make the request again with the same request
// ID, the server can check if original operation with the same request ID
// was received, and if so, will ignore the second request. This prevents
// clients from accidentally creating duplicate commitments.
//
// The request ID must be a valid UUID with the exception that zero UUID is
// not supported (00000000-0000-0000-0000-000000000000).
RequestId string `protobuf:"bytes,4,opt,name=request_id,json=requestId,proto3" json:"request_id,omitempty"`
// contains filtered or unexported fields
}
Request message for `GkeHub.UpdateFeature` method.
func (*UpdateFeatureRequest) Descriptor ¶
func (*UpdateFeatureRequest) Descriptor() ([]byte, []int)
Deprecated: Use UpdateFeatureRequest.ProtoReflect.Descriptor instead.
func (*UpdateFeatureRequest) GetName ¶
func (x *UpdateFeatureRequest) GetName() string
func (*UpdateFeatureRequest) GetRequestId ¶
func (x *UpdateFeatureRequest) GetRequestId() string
func (*UpdateFeatureRequest) GetResource ¶
func (x *UpdateFeatureRequest) GetResource() *Feature
func (*UpdateFeatureRequest) GetUpdateMask ¶
func (x *UpdateFeatureRequest) GetUpdateMask() *fieldmaskpb.FieldMask
func (*UpdateFeatureRequest) ProtoMessage ¶
func (*UpdateFeatureRequest) ProtoMessage()
func (*UpdateFeatureRequest) ProtoReflect ¶
func (x *UpdateFeatureRequest) ProtoReflect() protoreflect.Message
func (*UpdateFeatureRequest) Reset ¶
func (x *UpdateFeatureRequest) Reset()
func (*UpdateFeatureRequest) String ¶
func (x *UpdateFeatureRequest) String() string
Source Files ¶
feature.pb.go service.pb.go
- Version
- v0.0.0-20260427160629-7cedc36a6bc4 (latest)
- Published
- Apr 27, 2026
- Platform
- linux/amd64
- Imports
- 15 packages
- Last checked
- 2 days ago –
Tools for package owners.