package iap
import "google.golang.org/genproto/googleapis/cloud/iap/v1beta1"
Index ¶
- Variables
- func RegisterIdentityAwareProxyAdminV1Beta1Server(s *grpc.Server, srv IdentityAwareProxyAdminV1Beta1Server)
- type IdentityAwareProxyAdminV1Beta1Client
- type IdentityAwareProxyAdminV1Beta1Server
- type UnimplementedIdentityAwareProxyAdminV1Beta1Server
- func (*UnimplementedIdentityAwareProxyAdminV1Beta1Server) GetIamPolicy(context.Context, *v1.GetIamPolicyRequest) (*v1.Policy, error)
- func (*UnimplementedIdentityAwareProxyAdminV1Beta1Server) SetIamPolicy(context.Context, *v1.SetIamPolicyRequest) (*v1.Policy, error)
- func (*UnimplementedIdentityAwareProxyAdminV1Beta1Server) TestIamPermissions(context.Context, *v1.TestIamPermissionsRequest) (*v1.TestIamPermissionsResponse, error)
Variables ¶
var File_google_cloud_iap_v1beta1_service_proto protoreflect.FileDescriptor
Functions ¶
func RegisterIdentityAwareProxyAdminV1Beta1Server ¶
func RegisterIdentityAwareProxyAdminV1Beta1Server(s *grpc.Server, srv IdentityAwareProxyAdminV1Beta1Server)
Types ¶
type IdentityAwareProxyAdminV1Beta1Client ¶
type IdentityAwareProxyAdminV1Beta1Client interface {
// Sets the access control policy for an Identity-Aware Proxy protected
// resource. Replaces any existing policy.
// More information about managing access via IAP can be found at:
// https://cloud.google.com/iap/docs/managing-access#managing_access_via_the_api
SetIamPolicy(ctx context.Context, in *v1.SetIamPolicyRequest, opts ...grpc.CallOption) (*v1.Policy, error)
// Gets the access control policy for an Identity-Aware Proxy protected
// resource.
// More information about managing access via IAP can be found at:
// https://cloud.google.com/iap/docs/managing-access#managing_access_via_the_api
GetIamPolicy(ctx context.Context, in *v1.GetIamPolicyRequest, opts ...grpc.CallOption) (*v1.Policy, error)
// Returns permissions that a caller has on the Identity-Aware Proxy protected
// resource. If the resource does not exist or the caller does not have
// Identity-Aware Proxy permissions a [google.rpc.Code.PERMISSION_DENIED]
// will be returned.
// More information about managing access via IAP can be found at:
// https://cloud.google.com/iap/docs/managing-access#managing_access_via_the_api
TestIamPermissions(ctx context.Context, in *v1.TestIamPermissionsRequest, opts ...grpc.CallOption) (*v1.TestIamPermissionsResponse, error)
}
IdentityAwareProxyAdminV1Beta1Client is the client API for IdentityAwareProxyAdminV1Beta1 service.
For semantics around ctx use and closing/ending streaming RPCs, please refer to https://godoc.org/google.golang.org/grpc#ClientConn.NewStream.
func NewIdentityAwareProxyAdminV1Beta1Client ¶
func NewIdentityAwareProxyAdminV1Beta1Client(cc grpc.ClientConnInterface) IdentityAwareProxyAdminV1Beta1Client
type IdentityAwareProxyAdminV1Beta1Server ¶
type IdentityAwareProxyAdminV1Beta1Server interface {
// Sets the access control policy for an Identity-Aware Proxy protected
// resource. Replaces any existing policy.
// More information about managing access via IAP can be found at:
// https://cloud.google.com/iap/docs/managing-access#managing_access_via_the_api
SetIamPolicy(context.Context, *v1.SetIamPolicyRequest) (*v1.Policy, error)
// Gets the access control policy for an Identity-Aware Proxy protected
// resource.
// More information about managing access via IAP can be found at:
// https://cloud.google.com/iap/docs/managing-access#managing_access_via_the_api
GetIamPolicy(context.Context, *v1.GetIamPolicyRequest) (*v1.Policy, error)
// Returns permissions that a caller has on the Identity-Aware Proxy protected
// resource. If the resource does not exist or the caller does not have
// Identity-Aware Proxy permissions a [google.rpc.Code.PERMISSION_DENIED]
// will be returned.
// More information about managing access via IAP can be found at:
// https://cloud.google.com/iap/docs/managing-access#managing_access_via_the_api
TestIamPermissions(context.Context, *v1.TestIamPermissionsRequest) (*v1.TestIamPermissionsResponse, error)
}
IdentityAwareProxyAdminV1Beta1Server is the server API for IdentityAwareProxyAdminV1Beta1 service.
type UnimplementedIdentityAwareProxyAdminV1Beta1Server ¶
type UnimplementedIdentityAwareProxyAdminV1Beta1Server struct {
}
UnimplementedIdentityAwareProxyAdminV1Beta1Server can be embedded to have forward compatible implementations.
func (*UnimplementedIdentityAwareProxyAdminV1Beta1Server) GetIamPolicy ¶
func (*UnimplementedIdentityAwareProxyAdminV1Beta1Server) GetIamPolicy(context.Context, *v1.GetIamPolicyRequest) (*v1.Policy, error)
func (*UnimplementedIdentityAwareProxyAdminV1Beta1Server) SetIamPolicy ¶
func (*UnimplementedIdentityAwareProxyAdminV1Beta1Server) SetIamPolicy(context.Context, *v1.SetIamPolicyRequest) (*v1.Policy, error)
func (*UnimplementedIdentityAwareProxyAdminV1Beta1Server) TestIamPermissions ¶
func (*UnimplementedIdentityAwareProxyAdminV1Beta1Server) TestIamPermissions(context.Context, *v1.TestIamPermissionsRequest) (*v1.TestIamPermissionsResponse, error)
Source Files ¶
service.pb.go
- Version
- v0.0.0-20260427160629-7cedc36a6bc4 (latest)
- Published
- Apr 27, 2026
- Platform
- linux/amd64
- Imports
- 9 packages
- Last checked
- 2 days ago –
Tools for package owners.