Documentation
¶
Index ¶
- Variables
- func RegisterCloudMemcacheServer(s *grpc.Server, srv CloudMemcacheServer)
- type ApplyParametersRequest
- func (*ApplyParametersRequest) Descriptor() ([]byte, []int)deprecated
- func (x *ApplyParametersRequest) GetApplyAll() bool
- func (x *ApplyParametersRequest) GetName() string
- func (x *ApplyParametersRequest) GetNodeIds() []string
- func (*ApplyParametersRequest) ProtoMessage()
- func (x *ApplyParametersRequest) ProtoReflect() protoreflect.Message
- func (x *ApplyParametersRequest) Reset()
- func (x *ApplyParametersRequest) String() string
- type CloudMemcacheClient
- type CloudMemcacheServer
- type CreateInstanceRequest
- func (*CreateInstanceRequest) Descriptor() ([]byte, []int)deprecated
- func (x *CreateInstanceRequest) GetInstance() *Instance
- func (x *CreateInstanceRequest) GetInstanceId() string
- func (x *CreateInstanceRequest) GetParent() string
- func (*CreateInstanceRequest) ProtoMessage()
- func (x *CreateInstanceRequest) ProtoReflect() protoreflect.Message
- func (x *CreateInstanceRequest) Reset()
- func (x *CreateInstanceRequest) String() string
- type DeleteInstanceRequest
- func (*DeleteInstanceRequest) Descriptor() ([]byte, []int)deprecated
- func (x *DeleteInstanceRequest) GetName() string
- func (*DeleteInstanceRequest) ProtoMessage()
- func (x *DeleteInstanceRequest) ProtoReflect() protoreflect.Message
- func (x *DeleteInstanceRequest) Reset()
- func (x *DeleteInstanceRequest) String() string
- type GetInstanceRequest
- func (*GetInstanceRequest) Descriptor() ([]byte, []int)deprecated
- func (x *GetInstanceRequest) GetName() string
- func (*GetInstanceRequest) ProtoMessage()
- func (x *GetInstanceRequest) ProtoReflect() protoreflect.Message
- func (x *GetInstanceRequest) Reset()
- func (x *GetInstanceRequest) String() string
- type Instance
- func (*Instance) Descriptor() ([]byte, []int)deprecated
- func (x *Instance) GetAuthorizedNetwork() string
- func (x *Instance) GetCreateTime() *timestamppb.Timestamp
- func (x *Instance) GetDiscoveryEndpoint() string
- func (x *Instance) GetDisplayName() string
- func (x *Instance) GetInstanceMessages() []*Instance_InstanceMessage
- func (x *Instance) GetLabels() map[string]string
- func (x *Instance) GetMemcacheFullVersion() string
- func (x *Instance) GetMemcacheNodes() []*Instance_Node
- func (x *Instance) GetMemcacheVersion() MemcacheVersion
- func (x *Instance) GetName() string
- func (x *Instance) GetNodeConfig() *Instance_NodeConfig
- func (x *Instance) GetNodeCount() int32
- func (x *Instance) GetParameters() *MemcacheParameters
- func (x *Instance) GetState() Instance_State
- func (x *Instance) GetUpdateTime() *timestamppb.Timestamp
- func (x *Instance) GetZones() []string
- func (*Instance) ProtoMessage()
- func (x *Instance) ProtoReflect() protoreflect.Message
- func (x *Instance) Reset()
- func (x *Instance) String() string
- type Instance_InstanceMessage
- func (*Instance_InstanceMessage) Descriptor() ([]byte, []int)deprecated
- func (x *Instance_InstanceMessage) GetCode() Instance_InstanceMessage_Code
- func (x *Instance_InstanceMessage) GetMessage() string
- func (*Instance_InstanceMessage) ProtoMessage()
- func (x *Instance_InstanceMessage) ProtoReflect() protoreflect.Message
- func (x *Instance_InstanceMessage) Reset()
- func (x *Instance_InstanceMessage) String() string
- type Instance_InstanceMessage_Code
- func (Instance_InstanceMessage_Code) Descriptor() protoreflect.EnumDescriptor
- func (x Instance_InstanceMessage_Code) Enum() *Instance_InstanceMessage_Code
- func (Instance_InstanceMessage_Code) EnumDescriptor() ([]byte, []int)deprecated
- func (x Instance_InstanceMessage_Code) Number() protoreflect.EnumNumber
- func (x Instance_InstanceMessage_Code) String() string
- func (Instance_InstanceMessage_Code) Type() protoreflect.EnumType
- type Instance_Node
- func (*Instance_Node) Descriptor() ([]byte, []int)deprecated
- func (x *Instance_Node) GetHost() string
- func (x *Instance_Node) GetNodeId() string
- func (x *Instance_Node) GetParameters() *MemcacheParameters
- func (x *Instance_Node) GetPort() int32
- func (x *Instance_Node) GetState() Instance_Node_State
- func (x *Instance_Node) GetZone() string
- func (*Instance_Node) ProtoMessage()
- func (x *Instance_Node) ProtoReflect() protoreflect.Message
- func (x *Instance_Node) Reset()
- func (x *Instance_Node) String() string
- type Instance_NodeConfig
- func (*Instance_NodeConfig) Descriptor() ([]byte, []int)deprecated
- func (x *Instance_NodeConfig) GetCpuCount() int32
- func (x *Instance_NodeConfig) GetMemorySizeMb() int32
- func (*Instance_NodeConfig) ProtoMessage()
- func (x *Instance_NodeConfig) ProtoReflect() protoreflect.Message
- func (x *Instance_NodeConfig) Reset()
- func (x *Instance_NodeConfig) String() string
- type Instance_Node_State
- func (Instance_Node_State) Descriptor() protoreflect.EnumDescriptor
- func (x Instance_Node_State) Enum() *Instance_Node_State
- func (Instance_Node_State) EnumDescriptor() ([]byte, []int)deprecated
- func (x Instance_Node_State) Number() protoreflect.EnumNumber
- func (x Instance_Node_State) String() string
- func (Instance_Node_State) Type() protoreflect.EnumType
- type Instance_State
- func (Instance_State) Descriptor() protoreflect.EnumDescriptor
- func (x Instance_State) Enum() *Instance_State
- func (Instance_State) EnumDescriptor() ([]byte, []int)deprecated
- func (x Instance_State) Number() protoreflect.EnumNumber
- func (x Instance_State) String() string
- func (Instance_State) Type() protoreflect.EnumType
- type ListInstancesRequest
- func (*ListInstancesRequest) Descriptor() ([]byte, []int)deprecated
- func (x *ListInstancesRequest) GetFilter() string
- func (x *ListInstancesRequest) GetOrderBy() string
- func (x *ListInstancesRequest) GetPageSize() int32
- func (x *ListInstancesRequest) GetPageToken() string
- func (x *ListInstancesRequest) GetParent() string
- func (*ListInstancesRequest) ProtoMessage()
- func (x *ListInstancesRequest) ProtoReflect() protoreflect.Message
- func (x *ListInstancesRequest) Reset()
- func (x *ListInstancesRequest) String() string
- type ListInstancesResponse
- func (*ListInstancesResponse) Descriptor() ([]byte, []int)deprecated
- func (x *ListInstancesResponse) GetInstances() []*Instance
- func (x *ListInstancesResponse) GetNextPageToken() string
- func (x *ListInstancesResponse) GetUnreachable() []string
- func (*ListInstancesResponse) ProtoMessage()
- func (x *ListInstancesResponse) ProtoReflect() protoreflect.Message
- func (x *ListInstancesResponse) Reset()
- func (x *ListInstancesResponse) String() string
- type MemcacheParameters
- func (*MemcacheParameters) Descriptor() ([]byte, []int)deprecated
- func (x *MemcacheParameters) GetId() string
- func (x *MemcacheParameters) GetParams() map[string]string
- func (*MemcacheParameters) ProtoMessage()
- func (x *MemcacheParameters) ProtoReflect() protoreflect.Message
- func (x *MemcacheParameters) Reset()
- func (x *MemcacheParameters) String() string
- type MemcacheVersion
- func (MemcacheVersion) Descriptor() protoreflect.EnumDescriptor
- func (x MemcacheVersion) Enum() *MemcacheVersion
- func (MemcacheVersion) EnumDescriptor() ([]byte, []int)deprecated
- func (x MemcacheVersion) Number() protoreflect.EnumNumber
- func (x MemcacheVersion) String() string
- func (MemcacheVersion) Type() protoreflect.EnumType
- type OperationMetadata
- func (*OperationMetadata) Descriptor() ([]byte, []int)deprecated
- func (x *OperationMetadata) GetApiVersion() string
- func (x *OperationMetadata) GetCancelRequested() bool
- func (x *OperationMetadata) GetCreateTime() *timestamppb.Timestamp
- func (x *OperationMetadata) GetEndTime() *timestamppb.Timestamp
- func (x *OperationMetadata) GetStatusDetail() string
- func (x *OperationMetadata) GetTarget() string
- func (x *OperationMetadata) GetVerb() string
- func (*OperationMetadata) ProtoMessage()
- func (x *OperationMetadata) ProtoReflect() protoreflect.Message
- func (x *OperationMetadata) Reset()
- func (x *OperationMetadata) String() string
- type UnimplementedCloudMemcacheServer
- func (*UnimplementedCloudMemcacheServer) ApplyParameters(context.Context, *ApplyParametersRequest) (*longrunning.Operation, error)
- func (*UnimplementedCloudMemcacheServer) CreateInstance(context.Context, *CreateInstanceRequest) (*longrunning.Operation, error)
- func (*UnimplementedCloudMemcacheServer) DeleteInstance(context.Context, *DeleteInstanceRequest) (*longrunning.Operation, error)
- func (*UnimplementedCloudMemcacheServer) GetInstance(context.Context, *GetInstanceRequest) (*Instance, error)
- func (*UnimplementedCloudMemcacheServer) ListInstances(context.Context, *ListInstancesRequest) (*ListInstancesResponse, error)
- func (*UnimplementedCloudMemcacheServer) UpdateInstance(context.Context, *UpdateInstanceRequest) (*longrunning.Operation, error)
- func (*UnimplementedCloudMemcacheServer) UpdateParameters(context.Context, *UpdateParametersRequest) (*longrunning.Operation, error)
- type UpdateInstanceRequest
- func (*UpdateInstanceRequest) Descriptor() ([]byte, []int)deprecated
- func (x *UpdateInstanceRequest) GetInstance() *Instance
- func (x *UpdateInstanceRequest) GetUpdateMask() *fieldmaskpb.FieldMask
- func (*UpdateInstanceRequest) ProtoMessage()
- func (x *UpdateInstanceRequest) ProtoReflect() protoreflect.Message
- func (x *UpdateInstanceRequest) Reset()
- func (x *UpdateInstanceRequest) String() string
- type UpdateParametersRequest
- func (*UpdateParametersRequest) Descriptor() ([]byte, []int)deprecated
- func (x *UpdateParametersRequest) GetName() string
- func (x *UpdateParametersRequest) GetParameters() *MemcacheParameters
- func (x *UpdateParametersRequest) GetUpdateMask() *fieldmaskpb.FieldMask
- func (*UpdateParametersRequest) ProtoMessage()
- func (x *UpdateParametersRequest) ProtoReflect() protoreflect.Message
- func (x *UpdateParametersRequest) Reset()
- func (x *UpdateParametersRequest) String() string
Constants ¶
This section is empty.
Variables ¶
var ( MemcacheVersion_name = map[int32]string{ 0: "MEMCACHE_VERSION_UNSPECIFIED", 1: "MEMCACHE_1_5", } MemcacheVersion_value = map[string]int32{ "MEMCACHE_VERSION_UNSPECIFIED": 0, "MEMCACHE_1_5": 1, } )
Enum value maps for MemcacheVersion.
var ( Instance_State_name = map[int32]string{ 0: "STATE_UNSPECIFIED", 1: "CREATING", 2: "READY", 4: "DELETING", 5: "PERFORMING_MAINTENANCE", } Instance_State_value = map[string]int32{ "STATE_UNSPECIFIED": 0, "CREATING": 1, "READY": 2, "DELETING": 4, "PERFORMING_MAINTENANCE": 5, } )
Enum value maps for Instance_State.
var ( Instance_Node_State_name = map[int32]string{ 0: "STATE_UNSPECIFIED", 1: "CREATING", 2: "READY", 3: "DELETING", 4: "UPDATING", } Instance_Node_State_value = map[string]int32{ "STATE_UNSPECIFIED": 0, "CREATING": 1, "READY": 2, "DELETING": 3, "UPDATING": 4, } )
Enum value maps for Instance_Node_State.
var ( Instance_InstanceMessage_Code_name = map[int32]string{ 0: "CODE_UNSPECIFIED", 1: "ZONE_DISTRIBUTION_UNBALANCED", } Instance_InstanceMessage_Code_value = map[string]int32{ "CODE_UNSPECIFIED": 0, "ZONE_DISTRIBUTION_UNBALANCED": 1, } )
Enum value maps for Instance_InstanceMessage_Code.
var File_google_cloud_memcache_v1_cloud_memcache_proto protoreflect.FileDescriptor
Functions ¶
func RegisterCloudMemcacheServer ¶
func RegisterCloudMemcacheServer(s *grpc.Server, srv CloudMemcacheServer)
Types ¶
type ApplyParametersRequest ¶
type ApplyParametersRequest struct {
// Required. Resource name of the Memcached instance for which parameter group updates
// should be applied.
Name string `protobuf:"bytes,1,opt,name=name,proto3" json:"name,omitempty"`
// Nodes to which we should apply the instance-level parameter group.
NodeIds []string `protobuf:"bytes,2,rep,name=node_ids,json=nodeIds,proto3" json:"node_ids,omitempty"`
// Whether to apply instance-level parameter group to all nodes. If set to
// true, will explicitly restrict users from specifying any nodes, and apply
// parameter group updates to all nodes within the instance.
ApplyAll bool `protobuf:"varint,3,opt,name=apply_all,json=applyAll,proto3" json:"apply_all,omitempty"`
// contains filtered or unexported fields
}
Request for [ApplyParameters][google.cloud.memcache.v1.CloudMemcache.ApplyParameters].
func (*ApplyParametersRequest) Descriptor
deprecated
func (*ApplyParametersRequest) Descriptor() ([]byte, []int)
Deprecated: Use ApplyParametersRequest.ProtoReflect.Descriptor instead.
func (*ApplyParametersRequest) GetApplyAll ¶
func (x *ApplyParametersRequest) GetApplyAll() bool
func (*ApplyParametersRequest) GetName ¶
func (x *ApplyParametersRequest) GetName() string
func (*ApplyParametersRequest) GetNodeIds ¶
func (x *ApplyParametersRequest) GetNodeIds() []string
func (*ApplyParametersRequest) ProtoMessage ¶
func (*ApplyParametersRequest) ProtoMessage()
func (*ApplyParametersRequest) ProtoReflect ¶
func (x *ApplyParametersRequest) ProtoReflect() protoreflect.Message
func (*ApplyParametersRequest) Reset ¶
func (x *ApplyParametersRequest) Reset()
func (*ApplyParametersRequest) String ¶
func (x *ApplyParametersRequest) String() string
type CloudMemcacheClient ¶
type CloudMemcacheClient interface {
// Lists Instances in a given location.
ListInstances(ctx context.Context, in *ListInstancesRequest, opts ...grpc.CallOption) (*ListInstancesResponse, error)
// Gets details of a single Instance.
GetInstance(ctx context.Context, in *GetInstanceRequest, opts ...grpc.CallOption) (*Instance, error)
// Creates a new Instance in a given location.
CreateInstance(ctx context.Context, in *CreateInstanceRequest, opts ...grpc.CallOption) (*longrunning.Operation, error)
// Updates an existing Instance in a given project and location.
UpdateInstance(ctx context.Context, in *UpdateInstanceRequest, opts ...grpc.CallOption) (*longrunning.Operation, error)
// Updates the defined Memcached Parameters for an existing Instance.
// This method only stages the parameters, it must be followed by
// ApplyParameters to apply the parameters to nodes of the Memcached Instance.
UpdateParameters(ctx context.Context, in *UpdateParametersRequest, opts ...grpc.CallOption) (*longrunning.Operation, error)
// Deletes a single Instance.
DeleteInstance(ctx context.Context, in *DeleteInstanceRequest, opts ...grpc.CallOption) (*longrunning.Operation, error)
// ApplyParameters will restart the set of specified nodes in order to update
// them to the current set of parameters for the Memcached Instance.
ApplyParameters(ctx context.Context, in *ApplyParametersRequest, opts ...grpc.CallOption) (*longrunning.Operation, error)
}
CloudMemcacheClient is the client API for CloudMemcache service.
For semantics around ctx use and closing/ending streaming RPCs, please refer to https://godoc.org/google.golang.org/grpc#ClientConn.NewStream.
func NewCloudMemcacheClient ¶
func NewCloudMemcacheClient(cc grpc.ClientConnInterface) CloudMemcacheClient
type CloudMemcacheServer ¶
type CloudMemcacheServer interface {
// Lists Instances in a given location.
ListInstances(context.Context, *ListInstancesRequest) (*ListInstancesResponse, error)
// Gets details of a single Instance.
GetInstance(context.Context, *GetInstanceRequest) (*Instance, error)
// Creates a new Instance in a given location.
CreateInstance(context.Context, *CreateInstanceRequest) (*longrunning.Operation, error)
// Updates an existing Instance in a given project and location.
UpdateInstance(context.Context, *UpdateInstanceRequest) (*longrunning.Operation, error)
// Updates the defined Memcached Parameters for an existing Instance.
// This method only stages the parameters, it must be followed by
// ApplyParameters to apply the parameters to nodes of the Memcached Instance.
UpdateParameters(context.Context, *UpdateParametersRequest) (*longrunning.Operation, error)
// Deletes a single Instance.
DeleteInstance(context.Context, *DeleteInstanceRequest) (*longrunning.Operation, error)
// ApplyParameters will restart the set of specified nodes in order to update
// them to the current set of parameters for the Memcached Instance.
ApplyParameters(context.Context, *ApplyParametersRequest) (*longrunning.Operation, error)
}
CloudMemcacheServer is the server API for CloudMemcache service.
type CreateInstanceRequest ¶
type CreateInstanceRequest struct {
// Required. The resource name of the instance location using the form:
// `projects/{project_id}/locations/{location_id}`
// where `location_id` refers to a GCP region
Parent string `protobuf:"bytes,1,opt,name=parent,proto3" json:"parent,omitempty"`
// Required. The logical name of the Memcached instance in the user
// project with the following restrictions:
//
// * Must contain only lowercase letters, numbers, and hyphens.
// * Must start with a letter.
// * Must be between 1-40 characters.
// * Must end with a number or a letter.
// * Must be unique within the user project / location
//
// If any of the above are not met, will raise an invalid argument error.
InstanceId string `protobuf:"bytes,2,opt,name=instance_id,json=instanceId,proto3" json:"instance_id,omitempty"`
// Required. A Memcached Instance
Instance *Instance `protobuf:"bytes,3,opt,name=instance,proto3" json:"instance,omitempty"`
// contains filtered or unexported fields
}
Request for [CreateInstance][google.cloud.memcache.v1.CloudMemcache.CreateInstance].
func (*CreateInstanceRequest) Descriptor
deprecated
func (*CreateInstanceRequest) Descriptor() ([]byte, []int)
Deprecated: Use CreateInstanceRequest.ProtoReflect.Descriptor instead.
func (*CreateInstanceRequest) GetInstance ¶
func (x *CreateInstanceRequest) GetInstance() *Instance
func (*CreateInstanceRequest) GetInstanceId ¶
func (x *CreateInstanceRequest) GetInstanceId() string
func (*CreateInstanceRequest) GetParent ¶
func (x *CreateInstanceRequest) GetParent() string
func (*CreateInstanceRequest) ProtoMessage ¶
func (*CreateInstanceRequest) ProtoMessage()
func (*CreateInstanceRequest) ProtoReflect ¶
func (x *CreateInstanceRequest) ProtoReflect() protoreflect.Message
func (*CreateInstanceRequest) Reset ¶
func (x *CreateInstanceRequest) Reset()
func (*CreateInstanceRequest) String ¶
func (x *CreateInstanceRequest) String() string
type DeleteInstanceRequest ¶
type DeleteInstanceRequest struct {
// Required. Memcached instance resource name in the format:
// `projects/{project_id}/locations/{location_id}/instances/{instance_id}`
// where `location_id` refers to a GCP region
Name string `protobuf:"bytes,1,opt,name=name,proto3" json:"name,omitempty"`
// contains filtered or unexported fields
}
Request for [DeleteInstance][google.cloud.memcache.v1.CloudMemcache.DeleteInstance].
func (*DeleteInstanceRequest) Descriptor
deprecated
func (*DeleteInstanceRequest) Descriptor() ([]byte, []int)
Deprecated: Use DeleteInstanceRequest.ProtoReflect.Descriptor instead.
func (*DeleteInstanceRequest) GetName ¶
func (x *DeleteInstanceRequest) GetName() string
func (*DeleteInstanceRequest) ProtoMessage ¶
func (*DeleteInstanceRequest) ProtoMessage()
func (*DeleteInstanceRequest) ProtoReflect ¶
func (x *DeleteInstanceRequest) ProtoReflect() protoreflect.Message
func (*DeleteInstanceRequest) Reset ¶
func (x *DeleteInstanceRequest) Reset()
func (*DeleteInstanceRequest) String ¶
func (x *DeleteInstanceRequest) String() string
type GetInstanceRequest ¶
type GetInstanceRequest struct {
// Required. Memcached instance resource name in the format:
// `projects/{project_id}/locations/{location_id}/instances/{instance_id}`
// where `location_id` refers to a GCP region
Name string `protobuf:"bytes,1,opt,name=name,proto3" json:"name,omitempty"`
// contains filtered or unexported fields
}
Request for [GetInstance][google.cloud.memcache.v1.CloudMemcache.GetInstance].
func (*GetInstanceRequest) Descriptor
deprecated
func (*GetInstanceRequest) Descriptor() ([]byte, []int)
Deprecated: Use GetInstanceRequest.ProtoReflect.Descriptor instead.
func (*GetInstanceRequest) GetName ¶
func (x *GetInstanceRequest) GetName() string
func (*GetInstanceRequest) ProtoMessage ¶
func (*GetInstanceRequest) ProtoMessage()
func (*GetInstanceRequest) ProtoReflect ¶
func (x *GetInstanceRequest) ProtoReflect() protoreflect.Message
func (*GetInstanceRequest) Reset ¶
func (x *GetInstanceRequest) Reset()
func (*GetInstanceRequest) String ¶
func (x *GetInstanceRequest) String() string
type Instance ¶
type Instance struct {
// Required. Unique name of the resource in this scope including project and
// location using the form:
// `projects/{project_id}/locations/{location_id}/instances/{instance_id}`
//
// Note: Memcached instances are managed and addressed at regional level so
// location_id here refers to a GCP region; however, users may choose which
// zones Memcached nodes within an instances should be provisioned in.
// Refer to [zones] field for more details.
Name string `protobuf:"bytes,1,opt,name=name,proto3" json:"name,omitempty"`
// User provided name for the instance only used for display
// purposes. Cannot be more than 80 characters.
DisplayName string `protobuf:"bytes,2,opt,name=display_name,json=displayName,proto3" json:"display_name,omitempty"`
// Resource labels to represent user-provided metadata.
// Refer to cloud documentation on labels for more details.
// https://cloud.google.com/compute/docs/labeling-resources
Labels map[string]string `` /* 153-byte string literal not displayed */
// The full name of the Google Compute Engine
// [network](/compute/docs/networks-and-firewalls#networks) to which the
// instance is connected. If left unspecified, the `default` network
// will be used.
AuthorizedNetwork string `protobuf:"bytes,4,opt,name=authorized_network,json=authorizedNetwork,proto3" json:"authorized_network,omitempty"`
// Zones where Memcached nodes should be provisioned in.
// Memcached nodes will be equally distributed across these zones. If not
// provided, the service will by default create nodes in all zones in the
// region for the instance.
Zones []string `protobuf:"bytes,5,rep,name=zones,proto3" json:"zones,omitempty"`
// Required. Number of nodes in the Memcached instance.
NodeCount int32 `protobuf:"varint,6,opt,name=node_count,json=nodeCount,proto3" json:"node_count,omitempty"`
// Required. Configuration for Memcached nodes.
NodeConfig *Instance_NodeConfig `protobuf:"bytes,7,opt,name=node_config,json=nodeConfig,proto3" json:"node_config,omitempty"`
// The major version of Memcached software.
// If not provided, latest supported version will be used. Currently the
// latest supported major version is MEMCACHE_1_5.
// The minor version will be automatically determined by our system based on
// the latest supported minor version.
MemcacheVersion MemcacheVersion `` /* 153-byte string literal not displayed */
// Optional: User defined parameters to apply to the memcached process
// on each node.
Parameters *MemcacheParameters `protobuf:"bytes,11,opt,name=parameters,proto3" json:"parameters,omitempty"`
// Output only. List of Memcached nodes.
// Refer to [Node] message for more details.
MemcacheNodes []*Instance_Node `protobuf:"bytes,12,rep,name=memcache_nodes,json=memcacheNodes,proto3" json:"memcache_nodes,omitempty"`
// Output only. The time the instance was created.
CreateTime *timestamppb.Timestamp `protobuf:"bytes,13,opt,name=create_time,json=createTime,proto3" json:"create_time,omitempty"`
// Output only. The time the instance was updated.
UpdateTime *timestamppb.Timestamp `protobuf:"bytes,14,opt,name=update_time,json=updateTime,proto3" json:"update_time,omitempty"`
// Output only. The state of this Memcached instance.
State Instance_State `protobuf:"varint,15,opt,name=state,proto3,enum=google.cloud.memcache.v1.Instance_State" json:"state,omitempty"`
// Output only. The full version of memcached server running on this instance.
// System automatically determines the full memcached version for an instance
// based on the input MemcacheVersion.
// The full version format will be "memcached-1.5.16".
MemcacheFullVersion string `protobuf:"bytes,18,opt,name=memcache_full_version,json=memcacheFullVersion,proto3" json:"memcache_full_version,omitempty"`
// List of messages that describe current statuses of memcached instance.
InstanceMessages []*Instance_InstanceMessage `protobuf:"bytes,19,rep,name=instance_messages,json=instanceMessages,proto3" json:"instance_messages,omitempty"`
// Output only. Endpoint for Discovery API
DiscoveryEndpoint string `protobuf:"bytes,20,opt,name=discovery_endpoint,json=discoveryEndpoint,proto3" json:"discovery_endpoint,omitempty"`
// contains filtered or unexported fields
}
func (*Instance) Descriptor
deprecated
func (*Instance) GetAuthorizedNetwork ¶
func (*Instance) GetCreateTime ¶
func (x *Instance) GetCreateTime() *timestamppb.Timestamp
func (*Instance) GetDiscoveryEndpoint ¶
func (*Instance) GetDisplayName ¶
func (*Instance) GetInstanceMessages ¶
func (x *Instance) GetInstanceMessages() []*Instance_InstanceMessage
func (*Instance) GetMemcacheFullVersion ¶
func (*Instance) GetMemcacheNodes ¶
func (x *Instance) GetMemcacheNodes() []*Instance_Node
func (*Instance) GetMemcacheVersion ¶
func (x *Instance) GetMemcacheVersion() MemcacheVersion
func (*Instance) GetNodeConfig ¶
func (x *Instance) GetNodeConfig() *Instance_NodeConfig
func (*Instance) GetNodeCount ¶
func (*Instance) GetParameters ¶
func (x *Instance) GetParameters() *MemcacheParameters
func (*Instance) GetState ¶
func (x *Instance) GetState() Instance_State
func (*Instance) GetUpdateTime ¶
func (x *Instance) GetUpdateTime() *timestamppb.Timestamp
func (*Instance) ProtoMessage ¶
func (*Instance) ProtoMessage()
func (*Instance) ProtoReflect ¶
func (x *Instance) ProtoReflect() protoreflect.Message
type Instance_InstanceMessage ¶
type Instance_InstanceMessage struct {
// A code that correspond to one type of user-facing message.
Code Instance_InstanceMessage_Code `protobuf:"varint,1,opt,name=code,proto3,enum=google.cloud.memcache.v1.Instance_InstanceMessage_Code" json:"code,omitempty"`
// Message on memcached instance which will be exposed to users.
Message string `protobuf:"bytes,2,opt,name=message,proto3" json:"message,omitempty"`
// contains filtered or unexported fields
}
func (*Instance_InstanceMessage) Descriptor
deprecated
func (*Instance_InstanceMessage) Descriptor() ([]byte, []int)
Deprecated: Use Instance_InstanceMessage.ProtoReflect.Descriptor instead.
func (*Instance_InstanceMessage) GetCode ¶
func (x *Instance_InstanceMessage) GetCode() Instance_InstanceMessage_Code
func (*Instance_InstanceMessage) GetMessage ¶
func (x *Instance_InstanceMessage) GetMessage() string
func (*Instance_InstanceMessage) ProtoMessage ¶
func (*Instance_InstanceMessage) ProtoMessage()
func (*Instance_InstanceMessage) ProtoReflect ¶
func (x *Instance_InstanceMessage) ProtoReflect() protoreflect.Message
func (*Instance_InstanceMessage) Reset ¶
func (x *Instance_InstanceMessage) Reset()
func (*Instance_InstanceMessage) String ¶
func (x *Instance_InstanceMessage) String() string
type Instance_InstanceMessage_Code ¶
type Instance_InstanceMessage_Code int32
const ( // Message Code not set. Instance_InstanceMessage_CODE_UNSPECIFIED Instance_InstanceMessage_Code = 0 // Memcached nodes are distributed unevenly. Instance_InstanceMessage_ZONE_DISTRIBUTION_UNBALANCED Instance_InstanceMessage_Code = 1 )
func (Instance_InstanceMessage_Code) Descriptor ¶
func (Instance_InstanceMessage_Code) Descriptor() protoreflect.EnumDescriptor
func (Instance_InstanceMessage_Code) Enum ¶
func (x Instance_InstanceMessage_Code) Enum() *Instance_InstanceMessage_Code
func (Instance_InstanceMessage_Code) EnumDescriptor
deprecated
func (Instance_InstanceMessage_Code) EnumDescriptor() ([]byte, []int)
Deprecated: Use Instance_InstanceMessage_Code.Descriptor instead.
func (Instance_InstanceMessage_Code) Number ¶
func (x Instance_InstanceMessage_Code) Number() protoreflect.EnumNumber
func (Instance_InstanceMessage_Code) String ¶
func (x Instance_InstanceMessage_Code) String() string
func (Instance_InstanceMessage_Code) Type ¶
func (Instance_InstanceMessage_Code) Type() protoreflect.EnumType
type Instance_Node ¶
type Instance_Node struct {
// Output only. Identifier of the Memcached node. The node id does not
// include project or location like the Memcached instance name.
NodeId string `protobuf:"bytes,1,opt,name=node_id,json=nodeId,proto3" json:"node_id,omitempty"`
// Output only. Location (GCP Zone) for the Memcached node.
Zone string `protobuf:"bytes,2,opt,name=zone,proto3" json:"zone,omitempty"`
// Output only. Current state of the Memcached node.
State Instance_Node_State `protobuf:"varint,3,opt,name=state,proto3,enum=google.cloud.memcache.v1.Instance_Node_State" json:"state,omitempty"`
// Output only. Hostname or IP address of the Memcached node used by the
// clients to connect to the Memcached server on this node.
Host string `protobuf:"bytes,4,opt,name=host,proto3" json:"host,omitempty"`
// Output only. The port number of the Memcached server on this node.
Port int32 `protobuf:"varint,5,opt,name=port,proto3" json:"port,omitempty"`
// User defined parameters currently applied to the node.
Parameters *MemcacheParameters `protobuf:"bytes,6,opt,name=parameters,proto3" json:"parameters,omitempty"`
// contains filtered or unexported fields
}
func (*Instance_Node) Descriptor
deprecated
func (*Instance_Node) Descriptor() ([]byte, []int)
Deprecated: Use Instance_Node.ProtoReflect.Descriptor instead.
func (*Instance_Node) GetHost ¶
func (x *Instance_Node) GetHost() string
func (*Instance_Node) GetNodeId ¶
func (x *Instance_Node) GetNodeId() string
func (*Instance_Node) GetParameters ¶
func (x *Instance_Node) GetParameters() *MemcacheParameters
func (*Instance_Node) GetPort ¶
func (x *Instance_Node) GetPort() int32
func (*Instance_Node) GetState ¶
func (x *Instance_Node) GetState() Instance_Node_State
func (*Instance_Node) GetZone ¶
func (x *Instance_Node) GetZone() string
func (*Instance_Node) ProtoMessage ¶
func (*Instance_Node) ProtoMessage()
func (*Instance_Node) ProtoReflect ¶
func (x *Instance_Node) ProtoReflect() protoreflect.Message
func (*Instance_Node) Reset ¶
func (x *Instance_Node) Reset()
func (*Instance_Node) String ¶
func (x *Instance_Node) String() string
type Instance_NodeConfig ¶
type Instance_NodeConfig struct {
// Required. Number of cpus per Memcached node.
CpuCount int32 `protobuf:"varint,1,opt,name=cpu_count,json=cpuCount,proto3" json:"cpu_count,omitempty"`
// Required. Memory size in MiB for each Memcached node.
MemorySizeMb int32 `protobuf:"varint,2,opt,name=memory_size_mb,json=memorySizeMb,proto3" json:"memory_size_mb,omitempty"`
// contains filtered or unexported fields
}
Configuration for a Memcached Node.
func (*Instance_NodeConfig) Descriptor
deprecated
func (*Instance_NodeConfig) Descriptor() ([]byte, []int)
Deprecated: Use Instance_NodeConfig.ProtoReflect.Descriptor instead.
func (*Instance_NodeConfig) GetCpuCount ¶
func (x *Instance_NodeConfig) GetCpuCount() int32
func (*Instance_NodeConfig) GetMemorySizeMb ¶
func (x *Instance_NodeConfig) GetMemorySizeMb() int32
func (*Instance_NodeConfig) ProtoMessage ¶
func (*Instance_NodeConfig) ProtoMessage()
func (*Instance_NodeConfig) ProtoReflect ¶
func (x *Instance_NodeConfig) ProtoReflect() protoreflect.Message
func (*Instance_NodeConfig) Reset ¶
func (x *Instance_NodeConfig) Reset()
func (*Instance_NodeConfig) String ¶
func (x *Instance_NodeConfig) String() string
type Instance_Node_State ¶
type Instance_Node_State int32
Different states of a Memcached node.
const ( // Node state is not set. Instance_Node_STATE_UNSPECIFIED Instance_Node_State = 0 // Node is being created. Instance_Node_CREATING Instance_Node_State = 1 // Node has been created and ready to be used. Instance_Node_READY Instance_Node_State = 2 // Node is being deleted. Instance_Node_DELETING Instance_Node_State = 3 // Node is being updated. Instance_Node_UPDATING Instance_Node_State = 4 )
func (Instance_Node_State) Descriptor ¶
func (Instance_Node_State) Descriptor() protoreflect.EnumDescriptor
func (Instance_Node_State) Enum ¶
func (x Instance_Node_State) Enum() *Instance_Node_State
func (Instance_Node_State) EnumDescriptor
deprecated
func (Instance_Node_State) EnumDescriptor() ([]byte, []int)
Deprecated: Use Instance_Node_State.Descriptor instead.
func (Instance_Node_State) Number ¶
func (x Instance_Node_State) Number() protoreflect.EnumNumber
func (Instance_Node_State) String ¶
func (x Instance_Node_State) String() string
func (Instance_Node_State) Type ¶
func (Instance_Node_State) Type() protoreflect.EnumType
type Instance_State ¶
type Instance_State int32
Different states of a Memcached instance.
const ( // State not set. Instance_STATE_UNSPECIFIED Instance_State = 0 // Memcached instance is being created. Instance_CREATING Instance_State = 1 // Memcached instance has been created and ready to be used. Instance_READY Instance_State = 2 // Memcached instance is being deleted. Instance_DELETING Instance_State = 4 // Memcached instance is going through maintenance, e.g. data plane rollout. Instance_PERFORMING_MAINTENANCE Instance_State = 5 )
func (Instance_State) Descriptor ¶
func (Instance_State) Descriptor() protoreflect.EnumDescriptor
func (Instance_State) Enum ¶
func (x Instance_State) Enum() *Instance_State
func (Instance_State) EnumDescriptor
deprecated
func (Instance_State) EnumDescriptor() ([]byte, []int)
Deprecated: Use Instance_State.Descriptor instead.
func (Instance_State) Number ¶
func (x Instance_State) Number() protoreflect.EnumNumber
func (Instance_State) String ¶
func (x Instance_State) String() string
func (Instance_State) Type ¶
func (Instance_State) Type() protoreflect.EnumType
type ListInstancesRequest ¶
type ListInstancesRequest struct {
// Required. The resource name of the instance location using the form:
// `projects/{project_id}/locations/{location_id}`
// where `location_id` refers to a GCP region
Parent string `protobuf:"bytes,1,opt,name=parent,proto3" json:"parent,omitempty"`
// The maximum number of items to return.
//
// If not specified, a default value of 1000 will be used by the service.
// Regardless of the page_size value, the response may include a partial list
// and a caller should only rely on response's
// [next_page_token][CloudMemcache.ListInstancesResponse.next_page_token]
// to determine if there are more instances left to be queried.
PageSize int32 `protobuf:"varint,2,opt,name=page_size,json=pageSize,proto3" json:"page_size,omitempty"`
// The next_page_token value returned from a previous List request,
// if any.
PageToken string `protobuf:"bytes,3,opt,name=page_token,json=pageToken,proto3" json:"page_token,omitempty"`
// List filter. For example, exclude all Memcached instances with name as
// my-instance by specifying "name != my-instance".
Filter string `protobuf:"bytes,4,opt,name=filter,proto3" json:"filter,omitempty"`
// Sort results. Supported values are "name", "name desc" or "" (unsorted).
OrderBy string `protobuf:"bytes,5,opt,name=order_by,json=orderBy,proto3" json:"order_by,omitempty"`
// contains filtered or unexported fields
}
Request for [ListInstances][google.cloud.memcache.v1.CloudMemcache.ListInstances].
func (*ListInstancesRequest) Descriptor
deprecated
func (*ListInstancesRequest) Descriptor() ([]byte, []int)
Deprecated: Use ListInstancesRequest.ProtoReflect.Descriptor instead.
func (*ListInstancesRequest) GetFilter ¶
func (x *ListInstancesRequest) GetFilter() string
func (*ListInstancesRequest) GetOrderBy ¶
func (x *ListInstancesRequest) GetOrderBy() string
func (*ListInstancesRequest) GetPageSize ¶
func (x *ListInstancesRequest) GetPageSize() int32
func (*ListInstancesRequest) GetPageToken ¶
func (x *ListInstancesRequest) GetPageToken() string
func (*ListInstancesRequest) GetParent ¶
func (x *ListInstancesRequest) GetParent() string
func (*ListInstancesRequest) ProtoMessage ¶
func (*ListInstancesRequest) ProtoMessage()
func (*ListInstancesRequest) ProtoReflect ¶
func (x *ListInstancesRequest) ProtoReflect() protoreflect.Message
func (*ListInstancesRequest) Reset ¶
func (x *ListInstancesRequest) Reset()
func (*ListInstancesRequest) String ¶
func (x *ListInstancesRequest) String() string
type ListInstancesResponse ¶
type ListInstancesResponse struct {
// A list of Memcached instances in the project in the specified location,
// or across all locations.
//
// If the `location_id` in the parent field of the request is "-", all regions
// available to the project are queried, and the results aggregated.
Instances []*Instance `protobuf:"bytes,1,rep,name=instances,proto3" json:"instances,omitempty"`
// Token to retrieve the next page of results, or empty if there are no more
// results in the list.
NextPageToken string `protobuf:"bytes,2,opt,name=next_page_token,json=nextPageToken,proto3" json:"next_page_token,omitempty"`
// Locations that could not be reached.
Unreachable []string `protobuf:"bytes,3,rep,name=unreachable,proto3" json:"unreachable,omitempty"`
// contains filtered or unexported fields
}
Response for [ListInstances][google.cloud.memcache.v1.CloudMemcache.ListInstances].
func (*ListInstancesResponse) Descriptor
deprecated
func (*ListInstancesResponse) Descriptor() ([]byte, []int)
Deprecated: Use ListInstancesResponse.ProtoReflect.Descriptor instead.
func (*ListInstancesResponse) GetInstances ¶
func (x *ListInstancesResponse) GetInstances() []*Instance
func (*ListInstancesResponse) GetNextPageToken ¶
func (x *ListInstancesResponse) GetNextPageToken() string
func (*ListInstancesResponse) GetUnreachable ¶
func (x *ListInstancesResponse) GetUnreachable() []string
func (*ListInstancesResponse) ProtoMessage ¶
func (*ListInstancesResponse) ProtoMessage()
func (*ListInstancesResponse) ProtoReflect ¶
func (x *ListInstancesResponse) ProtoReflect() protoreflect.Message
func (*ListInstancesResponse) Reset ¶
func (x *ListInstancesResponse) Reset()
func (*ListInstancesResponse) String ¶
func (x *ListInstancesResponse) String() string
type MemcacheParameters ¶
type MemcacheParameters struct {
// Output only. The unique ID associated with this set of parameters. Users
// can use this id to determine if the parameters associated with the instance
// differ from the parameters associated with the nodes and any action needs
// to be taken to apply parameters on nodes.
Id string `protobuf:"bytes,1,opt,name=id,proto3" json:"id,omitempty"`
// User defined set of parameters to use in the memcached process.
Params map[string]string `` /* 153-byte string literal not displayed */
// contains filtered or unexported fields
}
func (*MemcacheParameters) Descriptor
deprecated
func (*MemcacheParameters) Descriptor() ([]byte, []int)
Deprecated: Use MemcacheParameters.ProtoReflect.Descriptor instead.
func (*MemcacheParameters) GetId ¶
func (x *MemcacheParameters) GetId() string
func (*MemcacheParameters) GetParams ¶
func (x *MemcacheParameters) GetParams() map[string]string
func (*MemcacheParameters) ProtoMessage ¶
func (*MemcacheParameters) ProtoMessage()
func (*MemcacheParameters) ProtoReflect ¶
func (x *MemcacheParameters) ProtoReflect() protoreflect.Message
func (*MemcacheParameters) Reset ¶
func (x *MemcacheParameters) Reset()
func (*MemcacheParameters) String ¶
func (x *MemcacheParameters) String() string
type MemcacheVersion ¶
type MemcacheVersion int32
Memcached versions supported by our service.
const ( MemcacheVersion_MEMCACHE_VERSION_UNSPECIFIED MemcacheVersion = 0 // Memcached 1.5 version. MemcacheVersion_MEMCACHE_1_5 MemcacheVersion = 1 )
func (MemcacheVersion) Descriptor ¶
func (MemcacheVersion) Descriptor() protoreflect.EnumDescriptor
func (MemcacheVersion) Enum ¶
func (x MemcacheVersion) Enum() *MemcacheVersion
func (MemcacheVersion) EnumDescriptor
deprecated
func (MemcacheVersion) EnumDescriptor() ([]byte, []int)
Deprecated: Use MemcacheVersion.Descriptor instead.
func (MemcacheVersion) Number ¶
func (x MemcacheVersion) Number() protoreflect.EnumNumber
func (MemcacheVersion) String ¶
func (x MemcacheVersion) String() string
func (MemcacheVersion) Type ¶
func (MemcacheVersion) Type() protoreflect.EnumType
type OperationMetadata ¶
type OperationMetadata struct {
// Output only. Time when the operation was created.
CreateTime *timestamppb.Timestamp `protobuf:"bytes,1,opt,name=create_time,json=createTime,proto3" json:"create_time,omitempty"`
// Output only. Time when the operation finished running.
EndTime *timestamppb.Timestamp `protobuf:"bytes,2,opt,name=end_time,json=endTime,proto3" json:"end_time,omitempty"`
// Output only. Server-defined resource path for the target of the operation.
Target string `protobuf:"bytes,3,opt,name=target,proto3" json:"target,omitempty"`
// Output only. Name of the verb executed by the operation.
Verb string `protobuf:"bytes,4,opt,name=verb,proto3" json:"verb,omitempty"`
// Output only. Human-readable status of the operation, if any.
StatusDetail string `protobuf:"bytes,5,opt,name=status_detail,json=statusDetail,proto3" json:"status_detail,omitempty"`
// Output only. Identifies whether the user has requested cancellation
// of the operation. Operations that have successfully been cancelled
// have [Operation.error][] value with a [google.rpc.Status.code][google.rpc.Status.code] of 1,
// corresponding to `Code.CANCELLED`.
CancelRequested bool `protobuf:"varint,6,opt,name=cancel_requested,json=cancelRequested,proto3" json:"cancel_requested,omitempty"`
// Output only. API version used to start the operation.
ApiVersion string `protobuf:"bytes,7,opt,name=api_version,json=apiVersion,proto3" json:"api_version,omitempty"`
// contains filtered or unexported fields
}
Represents the metadata of a long-running operation.
func (*OperationMetadata) Descriptor
deprecated
func (*OperationMetadata) Descriptor() ([]byte, []int)
Deprecated: Use OperationMetadata.ProtoReflect.Descriptor instead.
func (*OperationMetadata) GetApiVersion ¶
func (x *OperationMetadata) GetApiVersion() string
func (*OperationMetadata) GetCancelRequested ¶
func (x *OperationMetadata) GetCancelRequested() bool
func (*OperationMetadata) GetCreateTime ¶
func (x *OperationMetadata) GetCreateTime() *timestamppb.Timestamp
func (*OperationMetadata) GetEndTime ¶
func (x *OperationMetadata) GetEndTime() *timestamppb.Timestamp
func (*OperationMetadata) GetStatusDetail ¶
func (x *OperationMetadata) GetStatusDetail() string
func (*OperationMetadata) GetTarget ¶
func (x *OperationMetadata) GetTarget() string
func (*OperationMetadata) GetVerb ¶
func (x *OperationMetadata) GetVerb() string
func (*OperationMetadata) ProtoMessage ¶
func (*OperationMetadata) ProtoMessage()
func (*OperationMetadata) ProtoReflect ¶
func (x *OperationMetadata) ProtoReflect() protoreflect.Message
func (*OperationMetadata) Reset ¶
func (x *OperationMetadata) Reset()
func (*OperationMetadata) String ¶
func (x *OperationMetadata) String() string
type UnimplementedCloudMemcacheServer ¶
type UnimplementedCloudMemcacheServer struct {
}
UnimplementedCloudMemcacheServer can be embedded to have forward compatible implementations.
func (*UnimplementedCloudMemcacheServer) ApplyParameters ¶
func (*UnimplementedCloudMemcacheServer) ApplyParameters(context.Context, *ApplyParametersRequest) (*longrunning.Operation, error)
func (*UnimplementedCloudMemcacheServer) CreateInstance ¶
func (*UnimplementedCloudMemcacheServer) CreateInstance(context.Context, *CreateInstanceRequest) (*longrunning.Operation, error)
func (*UnimplementedCloudMemcacheServer) DeleteInstance ¶
func (*UnimplementedCloudMemcacheServer) DeleteInstance(context.Context, *DeleteInstanceRequest) (*longrunning.Operation, error)
func (*UnimplementedCloudMemcacheServer) GetInstance ¶
func (*UnimplementedCloudMemcacheServer) GetInstance(context.Context, *GetInstanceRequest) (*Instance, error)
func (*UnimplementedCloudMemcacheServer) ListInstances ¶
func (*UnimplementedCloudMemcacheServer) ListInstances(context.Context, *ListInstancesRequest) (*ListInstancesResponse, error)
func (*UnimplementedCloudMemcacheServer) UpdateInstance ¶
func (*UnimplementedCloudMemcacheServer) UpdateInstance(context.Context, *UpdateInstanceRequest) (*longrunning.Operation, error)
func (*UnimplementedCloudMemcacheServer) UpdateParameters ¶
func (*UnimplementedCloudMemcacheServer) UpdateParameters(context.Context, *UpdateParametersRequest) (*longrunning.Operation, error)
type UpdateInstanceRequest ¶
type UpdateInstanceRequest struct {
// Required. Mask of fields to update.
// * `displayName`
UpdateMask *fieldmaskpb.FieldMask `protobuf:"bytes,1,opt,name=update_mask,json=updateMask,proto3" json:"update_mask,omitempty"`
// Required. A Memcached Instance.
// Only fields specified in update_mask are updated.
Instance *Instance `protobuf:"bytes,2,opt,name=instance,proto3" json:"instance,omitempty"`
// contains filtered or unexported fields
}
Request for [UpdateInstance][google.cloud.memcache.v1.CloudMemcache.UpdateInstance].
func (*UpdateInstanceRequest) Descriptor
deprecated
func (*UpdateInstanceRequest) Descriptor() ([]byte, []int)
Deprecated: Use UpdateInstanceRequest.ProtoReflect.Descriptor instead.
func (*UpdateInstanceRequest) GetInstance ¶
func (x *UpdateInstanceRequest) GetInstance() *Instance
func (*UpdateInstanceRequest) GetUpdateMask ¶
func (x *UpdateInstanceRequest) GetUpdateMask() *fieldmaskpb.FieldMask
func (*UpdateInstanceRequest) ProtoMessage ¶
func (*UpdateInstanceRequest) ProtoMessage()
func (*UpdateInstanceRequest) ProtoReflect ¶
func (x *UpdateInstanceRequest) ProtoReflect() protoreflect.Message
func (*UpdateInstanceRequest) Reset ¶
func (x *UpdateInstanceRequest) Reset()
func (*UpdateInstanceRequest) String ¶
func (x *UpdateInstanceRequest) String() string
type UpdateParametersRequest ¶
type UpdateParametersRequest struct {
// Required. Resource name of the Memcached instance for which the parameters should be
// updated.
Name string `protobuf:"bytes,1,opt,name=name,proto3" json:"name,omitempty"`
// Required. Mask of fields to update.
UpdateMask *fieldmaskpb.FieldMask `protobuf:"bytes,2,opt,name=update_mask,json=updateMask,proto3" json:"update_mask,omitempty"`
// The parameters to apply to the instance.
Parameters *MemcacheParameters `protobuf:"bytes,3,opt,name=parameters,proto3" json:"parameters,omitempty"`
// contains filtered or unexported fields
}
Request for [UpdateParameters][google.cloud.memcache.v1.CloudMemcache.UpdateParameters].
func (*UpdateParametersRequest) Descriptor
deprecated
func (*UpdateParametersRequest) Descriptor() ([]byte, []int)
Deprecated: Use UpdateParametersRequest.ProtoReflect.Descriptor instead.
func (*UpdateParametersRequest) GetName ¶
func (x *UpdateParametersRequest) GetName() string
func (*UpdateParametersRequest) GetParameters ¶
func (x *UpdateParametersRequest) GetParameters() *MemcacheParameters
func (*UpdateParametersRequest) GetUpdateMask ¶
func (x *UpdateParametersRequest) GetUpdateMask() *fieldmaskpb.FieldMask
func (*UpdateParametersRequest) ProtoMessage ¶
func (*UpdateParametersRequest) ProtoMessage()
func (*UpdateParametersRequest) ProtoReflect ¶
func (x *UpdateParametersRequest) ProtoReflect() protoreflect.Message
func (*UpdateParametersRequest) Reset ¶
func (x *UpdateParametersRequest) Reset()
func (*UpdateParametersRequest) String ¶
func (x *UpdateParametersRequest) String() string