package logging
import "google.golang.org/genproto/googleapis/cloud/retail/logging"
Index ¶
- Variables
- type ErrorContext
- func (*ErrorContext) Descriptor() ([]byte, []int)
- func (x *ErrorContext) GetHttpRequest() *HttpRequestContext
- func (x *ErrorContext) GetReportLocation() *SourceLocation
- func (*ErrorContext) ProtoMessage()
- func (x *ErrorContext) ProtoReflect() protoreflect.Message
- func (x *ErrorContext) Reset()
- func (x *ErrorContext) String() string
- type ErrorLog
- func (*ErrorLog) Descriptor() ([]byte, []int)
- func (x *ErrorLog) GetContext() *ErrorContext
- func (x *ErrorLog) GetImportPayload() *ImportErrorContext
- func (x *ErrorLog) GetMessage() string
- func (x *ErrorLog) GetRequestPayload() *structpb.Struct
- func (x *ErrorLog) GetResponsePayload() *structpb.Struct
- func (x *ErrorLog) GetServiceContext() *ServiceContext
- func (x *ErrorLog) GetStatus() *status.Status
- func (*ErrorLog) ProtoMessage()
- func (x *ErrorLog) ProtoReflect() protoreflect.Message
- func (x *ErrorLog) Reset()
- func (x *ErrorLog) String() string
- type HttpRequestContext
- func (*HttpRequestContext) Descriptor() ([]byte, []int)
- func (x *HttpRequestContext) GetResponseStatusCode() int32
- func (*HttpRequestContext) ProtoMessage()
- func (x *HttpRequestContext) ProtoReflect() protoreflect.Message
- func (x *HttpRequestContext) Reset()
- func (x *HttpRequestContext) String() string
- type ImportErrorContext
- func (*ImportErrorContext) Descriptor() ([]byte, []int)
- func (x *ImportErrorContext) GetCatalogItem() string
- func (x *ImportErrorContext) GetGcsPath() string
- func (m *ImportErrorContext) GetLineContent() isImportErrorContext_LineContent
- func (x *ImportErrorContext) GetLineNumber() string
- func (x *ImportErrorContext) GetOperationName() string
- func (x *ImportErrorContext) GetProduct() string
- func (x *ImportErrorContext) GetUserEvent() string
- func (*ImportErrorContext) ProtoMessage()
- func (x *ImportErrorContext) ProtoReflect() protoreflect.Message
- func (x *ImportErrorContext) Reset()
- func (x *ImportErrorContext) String() string
- type ImportErrorContext_CatalogItem
- type ImportErrorContext_Product
- type ImportErrorContext_UserEvent
- type ServiceContext
- func (*ServiceContext) Descriptor() ([]byte, []int)
- func (x *ServiceContext) GetService() string
- func (*ServiceContext) ProtoMessage()
- func (x *ServiceContext) ProtoReflect() protoreflect.Message
- func (x *ServiceContext) Reset()
- func (x *ServiceContext) String() string
- type SourceLocation
Variables ¶
var File_google_cloud_retail_logging_error_log_proto protoreflect.FileDescriptor
Types ¶
type ErrorContext ¶
type ErrorContext struct {
// The HTTP request which was processed when the error was triggered.
HttpRequest *HttpRequestContext `protobuf:"bytes,1,opt,name=http_request,json=httpRequest,proto3" json:"http_request,omitempty"`
// The location in the source code where the decision was made to
// report the error, usually the place where it was logged.
ReportLocation *SourceLocation `protobuf:"bytes,2,opt,name=report_location,json=reportLocation,proto3" json:"report_location,omitempty"`
// contains filtered or unexported fields
}
A description of the context in which an error occurred.
func (*ErrorContext) Descriptor ¶
func (*ErrorContext) Descriptor() ([]byte, []int)
Deprecated: Use ErrorContext.ProtoReflect.Descriptor instead.
func (*ErrorContext) GetHttpRequest ¶
func (x *ErrorContext) GetHttpRequest() *HttpRequestContext
func (*ErrorContext) GetReportLocation ¶
func (x *ErrorContext) GetReportLocation() *SourceLocation
func (*ErrorContext) ProtoMessage ¶
func (*ErrorContext) ProtoMessage()
func (*ErrorContext) ProtoReflect ¶
func (x *ErrorContext) ProtoReflect() protoreflect.Message
func (*ErrorContext) Reset ¶
func (x *ErrorContext) Reset()
func (*ErrorContext) String ¶
func (x *ErrorContext) String() string
type ErrorLog ¶
type ErrorLog struct {
// The service context in which this error has occurred.
ServiceContext *ServiceContext `protobuf:"bytes,1,opt,name=service_context,json=serviceContext,proto3" json:"service_context,omitempty"`
// A description of the context in which the error occurred.
Context *ErrorContext `protobuf:"bytes,2,opt,name=context,proto3" json:"context,omitempty"`
// A message describing the error.
Message string `protobuf:"bytes,3,opt,name=message,proto3" json:"message,omitempty"`
// The RPC status associated with the error log.
Status *status.Status `protobuf:"bytes,4,opt,name=status,proto3" json:"status,omitempty"`
// The API request payload, represented as a protocol buffer.
//
// Most API request types are supported. For example:
//
// "type.googleapis.com/google.cloud.retail.v2.ProductService.CreateProductRequest"
// "type.googleapis.com/google.cloud.retail.v2.UserEventService.WriteUserEventRequest"
RequestPayload *structpb.Struct `protobuf:"bytes,5,opt,name=request_payload,json=requestPayload,proto3" json:"request_payload,omitempty"`
// The API response payload, represented as a protocol buffer.
//
// This is used to log some "soft errors", where the response is valid but we
// consider there are some quality issues like unjoined events.
//
// The following API responses are supported and no PII is included:
//
// "google.cloud.retail.v2.PredictionService.Predict"
// "google.cloud.retail.v2.UserEventService.WriteUserEvent"
// "google.cloud.retail.v2.UserEventService.CollectUserEvent"
ResponsePayload *structpb.Struct `protobuf:"bytes,6,opt,name=response_payload,json=responsePayload,proto3" json:"response_payload,omitempty"`
// The error payload that is populated on LRO import APIs.
ImportPayload *ImportErrorContext `protobuf:"bytes,7,opt,name=import_payload,json=importPayload,proto3" json:"import_payload,omitempty"`
// contains filtered or unexported fields
}
An error log which is reported to the Error Reporting system. This proto a superset of google.devtools.clouderrorreporting.v1beta1.ReportedErrorEvent.
func (*ErrorLog) Descriptor ¶
Deprecated: Use ErrorLog.ProtoReflect.Descriptor instead.
func (*ErrorLog) GetContext ¶
func (x *ErrorLog) GetContext() *ErrorContext
func (*ErrorLog) GetImportPayload ¶
func (x *ErrorLog) GetImportPayload() *ImportErrorContext
func (*ErrorLog) GetMessage ¶
func (*ErrorLog) GetRequestPayload ¶
func (*ErrorLog) GetResponsePayload ¶
func (*ErrorLog) GetServiceContext ¶
func (x *ErrorLog) GetServiceContext() *ServiceContext
func (*ErrorLog) GetStatus ¶
func (*ErrorLog) ProtoMessage ¶
func (*ErrorLog) ProtoMessage()
func (*ErrorLog) ProtoReflect ¶
func (x *ErrorLog) ProtoReflect() protoreflect.Message
func (*ErrorLog) Reset ¶
func (x *ErrorLog) Reset()
func (*ErrorLog) String ¶
type HttpRequestContext ¶
type HttpRequestContext struct {
// The HTTP response status code for the request.
ResponseStatusCode int32 `protobuf:"varint,1,opt,name=response_status_code,json=responseStatusCode,proto3" json:"response_status_code,omitempty"`
// contains filtered or unexported fields
}
HTTP request data that is related to a reported error.
func (*HttpRequestContext) Descriptor ¶
func (*HttpRequestContext) Descriptor() ([]byte, []int)
Deprecated: Use HttpRequestContext.ProtoReflect.Descriptor instead.
func (*HttpRequestContext) GetResponseStatusCode ¶
func (x *HttpRequestContext) GetResponseStatusCode() int32
func (*HttpRequestContext) ProtoMessage ¶
func (*HttpRequestContext) ProtoMessage()
func (*HttpRequestContext) ProtoReflect ¶
func (x *HttpRequestContext) ProtoReflect() protoreflect.Message
func (*HttpRequestContext) Reset ¶
func (x *HttpRequestContext) Reset()
func (*HttpRequestContext) String ¶
func (x *HttpRequestContext) String() string
type ImportErrorContext ¶
type ImportErrorContext struct {
// The operation resource name of the LRO.
OperationName string `protobuf:"bytes,1,opt,name=operation_name,json=operationName,proto3" json:"operation_name,omitempty"`
// Cloud Storage file path of the import source.
// Can be set for batch operation error.
GcsPath string `protobuf:"bytes,2,opt,name=gcs_path,json=gcsPath,proto3" json:"gcs_path,omitempty"`
// Line number of the content in file.
// Should be empty for permission or batch operation error.
LineNumber string `protobuf:"bytes,3,opt,name=line_number,json=lineNumber,proto3" json:"line_number,omitempty"`
// Detailed content which caused the error.
// Should be empty for permission or batch operation error.
//
// Types that are assignable to LineContent:
//
// *ImportErrorContext_CatalogItem
// *ImportErrorContext_Product
// *ImportErrorContext_UserEvent
LineContent isImportErrorContext_LineContent `protobuf_oneof:"line_content"`
// contains filtered or unexported fields
}
The error payload that is populated on LRO import APIs, including
"google.cloud.retail.v2.ProductService.ImportProducts" and "google.cloud.retail.v2.EventService.ImportUserEvents".
func (*ImportErrorContext) Descriptor ¶
func (*ImportErrorContext) Descriptor() ([]byte, []int)
Deprecated: Use ImportErrorContext.ProtoReflect.Descriptor instead.
func (*ImportErrorContext) GetCatalogItem ¶
func (x *ImportErrorContext) GetCatalogItem() string
func (*ImportErrorContext) GetGcsPath ¶
func (x *ImportErrorContext) GetGcsPath() string
func (*ImportErrorContext) GetLineContent ¶
func (m *ImportErrorContext) GetLineContent() isImportErrorContext_LineContent
func (*ImportErrorContext) GetLineNumber ¶
func (x *ImportErrorContext) GetLineNumber() string
func (*ImportErrorContext) GetOperationName ¶
func (x *ImportErrorContext) GetOperationName() string
func (*ImportErrorContext) GetProduct ¶
func (x *ImportErrorContext) GetProduct() string
func (*ImportErrorContext) GetUserEvent ¶
func (x *ImportErrorContext) GetUserEvent() string
func (*ImportErrorContext) ProtoMessage ¶
func (*ImportErrorContext) ProtoMessage()
func (*ImportErrorContext) ProtoReflect ¶
func (x *ImportErrorContext) ProtoReflect() protoreflect.Message
func (*ImportErrorContext) Reset ¶
func (x *ImportErrorContext) Reset()
func (*ImportErrorContext) String ¶
func (x *ImportErrorContext) String() string
type ImportErrorContext_CatalogItem ¶
type ImportErrorContext_CatalogItem struct {
// The detailed content which caused the error on importing a catalog item.
CatalogItem string `protobuf:"bytes,4,opt,name=catalog_item,json=catalogItem,proto3,oneof"`
}
type ImportErrorContext_Product ¶
type ImportErrorContext_Product struct {
// The detailed content which caused the error on importing a product.
Product string `protobuf:"bytes,5,opt,name=product,proto3,oneof"`
}
type ImportErrorContext_UserEvent ¶
type ImportErrorContext_UserEvent struct {
// The detailed content which caused the error on importing a user event.
UserEvent string `protobuf:"bytes,6,opt,name=user_event,json=userEvent,proto3,oneof"`
}
type ServiceContext ¶
type ServiceContext struct {
// An identifier of the service.
// For example, "retail.googleapis.com".
Service string `protobuf:"bytes,1,opt,name=service,proto3" json:"service,omitempty"`
// contains filtered or unexported fields
}
Describes a running service that sends errors.
func (*ServiceContext) Descriptor ¶
func (*ServiceContext) Descriptor() ([]byte, []int)
Deprecated: Use ServiceContext.ProtoReflect.Descriptor instead.
func (*ServiceContext) GetService ¶
func (x *ServiceContext) GetService() string
func (*ServiceContext) ProtoMessage ¶
func (*ServiceContext) ProtoMessage()
func (*ServiceContext) ProtoReflect ¶
func (x *ServiceContext) ProtoReflect() protoreflect.Message
func (*ServiceContext) Reset ¶
func (x *ServiceContext) Reset()
func (*ServiceContext) String ¶
func (x *ServiceContext) String() string
type SourceLocation ¶
type SourceLocation struct {
// Human-readable name of a function or method.
// For example, "google.cloud.retail.v2.UserEventService.ImportUserEvents".
FunctionName string `protobuf:"bytes,1,opt,name=function_name,json=functionName,proto3" json:"function_name,omitempty"`
// contains filtered or unexported fields
}
Indicates a location in the source code of the service for which errors are reported.
func (*SourceLocation) Descriptor ¶
func (*SourceLocation) Descriptor() ([]byte, []int)
Deprecated: Use SourceLocation.ProtoReflect.Descriptor instead.
func (*SourceLocation) GetFunctionName ¶
func (x *SourceLocation) GetFunctionName() string
func (*SourceLocation) ProtoMessage ¶
func (*SourceLocation) ProtoMessage()
func (*SourceLocation) ProtoReflect ¶
func (x *SourceLocation) ProtoReflect() protoreflect.Message
func (*SourceLocation) Reset ¶
func (x *SourceLocation) Reset()
func (*SourceLocation) String ¶
func (x *SourceLocation) String() string
Source Files ¶
error_log.pb.go
- Version
- v0.0.0-20260427160629-7cedc36a6bc4 (latest)
- Published
- Apr 27, 2026
- Platform
- linux/amd64
- Imports
- 6 packages
- Last checked
- 2 days ago –
Tools for package owners.