package support
import "google.golang.org/genproto/googleapis/cloud/support/v1alpha1"
Index ¶
- Variables
- func RegisterCloudSupportServer(s *grpc.Server, srv CloudSupportServer)
- type CloudSupportClient
- type CloudSupportServer
- type CreateCaseRequest
- func (*CreateCaseRequest) Descriptor() ([]byte, []int)
- func (x *CreateCaseRequest) GetCase() *common.Case
- func (x *CreateCaseRequest) GetParent() string
- func (*CreateCaseRequest) ProtoMessage()
- func (x *CreateCaseRequest) ProtoReflect() protoreflect.Message
- func (x *CreateCaseRequest) Reset()
- func (x *CreateCaseRequest) String() string
- type CreateCommentRequest
- func (*CreateCommentRequest) Descriptor() ([]byte, []int)
- func (x *CreateCommentRequest) GetComment() *common.Comment
- func (x *CreateCommentRequest) GetName() string
- func (*CreateCommentRequest) ProtoMessage()
- func (x *CreateCommentRequest) ProtoReflect() protoreflect.Message
- func (x *CreateCommentRequest) Reset()
- func (x *CreateCommentRequest) String() string
- type GetCaseRequest
- func (*GetCaseRequest) Descriptor() ([]byte, []int)
- func (x *GetCaseRequest) GetName() string
- func (*GetCaseRequest) ProtoMessage()
- func (x *GetCaseRequest) ProtoReflect() protoreflect.Message
- func (x *GetCaseRequest) Reset()
- func (x *GetCaseRequest) String() string
- type GetIssueTaxonomyRequest
- func (*GetIssueTaxonomyRequest) Descriptor() ([]byte, []int)
- func (*GetIssueTaxonomyRequest) ProtoMessage()
- func (x *GetIssueTaxonomyRequest) ProtoReflect() protoreflect.Message
- func (x *GetIssueTaxonomyRequest) Reset()
- func (x *GetIssueTaxonomyRequest) String() string
- type GetSupportAccountRequest
- func (*GetSupportAccountRequest) Descriptor() ([]byte, []int)
- func (x *GetSupportAccountRequest) GetName() string
- func (*GetSupportAccountRequest) ProtoMessage()
- func (x *GetSupportAccountRequest) ProtoReflect() protoreflect.Message
- func (x *GetSupportAccountRequest) Reset()
- func (x *GetSupportAccountRequest) String() string
- type ListCasesRequest
- func (*ListCasesRequest) Descriptor() ([]byte, []int)
- func (x *ListCasesRequest) GetFilter() string
- func (x *ListCasesRequest) GetName() string
- func (x *ListCasesRequest) GetPageSize() int64
- func (x *ListCasesRequest) GetPageToken() string
- func (*ListCasesRequest) ProtoMessage()
- func (x *ListCasesRequest) ProtoReflect() protoreflect.Message
- func (x *ListCasesRequest) Reset()
- func (x *ListCasesRequest) String() string
- type ListCasesResponse
- func (*ListCasesResponse) Descriptor() ([]byte, []int)
- func (x *ListCasesResponse) GetCases() []*common.Case
- func (x *ListCasesResponse) GetNextPageToken() string
- func (*ListCasesResponse) ProtoMessage()
- func (x *ListCasesResponse) ProtoReflect() protoreflect.Message
- func (x *ListCasesResponse) Reset()
- func (x *ListCasesResponse) String() string
- type ListCommentsRequest
- func (*ListCommentsRequest) Descriptor() ([]byte, []int)
- func (x *ListCommentsRequest) GetName() string
- func (*ListCommentsRequest) ProtoMessage()
- func (x *ListCommentsRequest) ProtoReflect() protoreflect.Message
- func (x *ListCommentsRequest) Reset()
- func (x *ListCommentsRequest) String() string
- type ListCommentsResponse
- func (*ListCommentsResponse) Descriptor() ([]byte, []int)
- func (x *ListCommentsResponse) GetComments() []*common.Comment
- func (*ListCommentsResponse) ProtoMessage()
- func (x *ListCommentsResponse) ProtoReflect() protoreflect.Message
- func (x *ListCommentsResponse) Reset()
- func (x *ListCommentsResponse) String() string
- type ListSupportAccountsRequest
- func (*ListSupportAccountsRequest) Descriptor() ([]byte, []int)
- func (x *ListSupportAccountsRequest) GetFilter() string
- func (x *ListSupportAccountsRequest) GetPageSize() int64
- func (x *ListSupportAccountsRequest) GetPageToken() string
- func (*ListSupportAccountsRequest) ProtoMessage()
- func (x *ListSupportAccountsRequest) ProtoReflect() protoreflect.Message
- func (x *ListSupportAccountsRequest) Reset()
- func (x *ListSupportAccountsRequest) String() string
- type ListSupportAccountsResponse
- func (*ListSupportAccountsResponse) Descriptor() ([]byte, []int)
- func (x *ListSupportAccountsResponse) GetAccounts() []*common.SupportAccount
- func (x *ListSupportAccountsResponse) GetNextPageToken() string
- func (*ListSupportAccountsResponse) ProtoMessage()
- func (x *ListSupportAccountsResponse) ProtoReflect() protoreflect.Message
- func (x *ListSupportAccountsResponse) Reset()
- func (x *ListSupportAccountsResponse) String() string
- type UnimplementedCloudSupportServer
- func (*UnimplementedCloudSupportServer) CreateCase(context.Context, *CreateCaseRequest) (*common.Case, error)
- func (*UnimplementedCloudSupportServer) CreateComment(context.Context, *CreateCommentRequest) (*common.Comment, error)
- func (*UnimplementedCloudSupportServer) GetCase(context.Context, *GetCaseRequest) (*common.Case, error)
- func (*UnimplementedCloudSupportServer) GetIssueTaxonomy(context.Context, *GetIssueTaxonomyRequest) (*common.IssueTaxonomy, error)
- func (*UnimplementedCloudSupportServer) GetSupportAccount(context.Context, *GetSupportAccountRequest) (*common.SupportAccount, error)
- func (*UnimplementedCloudSupportServer) ListCases(context.Context, *ListCasesRequest) (*ListCasesResponse, error)
- func (*UnimplementedCloudSupportServer) ListComments(context.Context, *ListCommentsRequest) (*ListCommentsResponse, error)
- func (*UnimplementedCloudSupportServer) ListSupportAccounts(context.Context, *ListSupportAccountsRequest) (*ListSupportAccountsResponse, error)
- func (*UnimplementedCloudSupportServer) UpdateCase(context.Context, *UpdateCaseRequest) (*common.Case, error)
- type UpdateCaseRequest
- func (*UpdateCaseRequest) Descriptor() ([]byte, []int)
- func (x *UpdateCaseRequest) GetCase() *common.Case
- func (x *UpdateCaseRequest) GetUpdateMask() *fieldmaskpb.FieldMask
- func (*UpdateCaseRequest) ProtoMessage()
- func (x *UpdateCaseRequest) ProtoReflect() protoreflect.Message
- func (x *UpdateCaseRequest) Reset()
- func (x *UpdateCaseRequest) String() string
Variables ¶
var File_google_cloud_support_v1alpha1_cloud_support_proto protoreflect.FileDescriptor
Functions ¶
func RegisterCloudSupportServer ¶
func RegisterCloudSupportServer(s *grpc.Server, srv CloudSupportServer)
Types ¶
type CloudSupportClient ¶
type CloudSupportClient interface {
// Retrieves the support account details given an account identifier.
// The authenticated user calling this method must be the account owner.
GetSupportAccount(ctx context.Context, in *GetSupportAccountRequest, opts ...grpc.CallOption) (*common.SupportAccount, error)
// Retrieves the list of accounts the current authenticated user has access
// to.
ListSupportAccounts(ctx context.Context, in *ListSupportAccountsRequest, opts ...grpc.CallOption) (*ListSupportAccountsResponse, error)
// Retrieves the details for a support case. The current authenticated user
// calling this method must have permissions to view this case.
GetCase(ctx context.Context, in *GetCaseRequest, opts ...grpc.CallOption) (*common.Case, error)
// Retrieves the list of support cases associated with an account. The current
// authenticated user must have the permission to list and view these cases.
ListCases(ctx context.Context, in *ListCasesRequest, opts ...grpc.CallOption) (*ListCasesResponse, error)
// Lists all comments from a case.
ListComments(ctx context.Context, in *ListCommentsRequest, opts ...grpc.CallOption) (*ListCommentsResponse, error)
// Creates a case and associates it with a
// [SupportAccount][google.cloud.support.v1alpha2.SupportAcccount]. The
// authenticated user attempting this action must have permissions to create a
// `Case` under that [SupportAccount].
CreateCase(ctx context.Context, in *CreateCaseRequest, opts ...grpc.CallOption) (*common.Case, error)
// Updates a support case. Only a small set of details (priority, subject and
// cc_address) can be update after a case is created.
UpdateCase(ctx context.Context, in *UpdateCaseRequest, opts ...grpc.CallOption) (*common.Case, error)
// Adds a new comment to a case.
CreateComment(ctx context.Context, in *CreateCommentRequest, opts ...grpc.CallOption) (*common.Comment, error)
// Retrieves the taxonomy of product categories and components to be used
// while creating a support case.
GetIssueTaxonomy(ctx context.Context, in *GetIssueTaxonomyRequest, opts ...grpc.CallOption) (*common.IssueTaxonomy, error)
}
CloudSupportClient is the client API for CloudSupport service.
For semantics around ctx use and closing/ending streaming RPCs, please refer to https://godoc.org/google.golang.org/grpc#ClientConn.NewStream.
func NewCloudSupportClient ¶
func NewCloudSupportClient(cc grpc.ClientConnInterface) CloudSupportClient
type CloudSupportServer ¶
type CloudSupportServer interface {
// Retrieves the support account details given an account identifier.
// The authenticated user calling this method must be the account owner.
GetSupportAccount(context.Context, *GetSupportAccountRequest) (*common.SupportAccount, error)
// Retrieves the list of accounts the current authenticated user has access
// to.
ListSupportAccounts(context.Context, *ListSupportAccountsRequest) (*ListSupportAccountsResponse, error)
// Retrieves the details for a support case. The current authenticated user
// calling this method must have permissions to view this case.
GetCase(context.Context, *GetCaseRequest) (*common.Case, error)
// Retrieves the list of support cases associated with an account. The current
// authenticated user must have the permission to list and view these cases.
ListCases(context.Context, *ListCasesRequest) (*ListCasesResponse, error)
// Lists all comments from a case.
ListComments(context.Context, *ListCommentsRequest) (*ListCommentsResponse, error)
// Creates a case and associates it with a
// [SupportAccount][google.cloud.support.v1alpha2.SupportAcccount]. The
// authenticated user attempting this action must have permissions to create a
// `Case` under that [SupportAccount].
CreateCase(context.Context, *CreateCaseRequest) (*common.Case, error)
// Updates a support case. Only a small set of details (priority, subject and
// cc_address) can be update after a case is created.
UpdateCase(context.Context, *UpdateCaseRequest) (*common.Case, error)
// Adds a new comment to a case.
CreateComment(context.Context, *CreateCommentRequest) (*common.Comment, error)
// Retrieves the taxonomy of product categories and components to be used
// while creating a support case.
GetIssueTaxonomy(context.Context, *GetIssueTaxonomyRequest) (*common.IssueTaxonomy, error)
}
CloudSupportServer is the server API for CloudSupport service.
type CreateCaseRequest ¶
type CreateCaseRequest struct {
// The resource name for `SupportAccount` under which this case is created.
Parent string `protobuf:"bytes,1,opt,name=parent,proto3" json:"parent,omitempty"`
// The case resource to create.
Case *common.Case `protobuf:"bytes,2,opt,name=case,proto3" json:"case,omitempty"`
// contains filtered or unexported fields
}
The request message for `CreateCase` method.
func (*CreateCaseRequest) Descriptor ¶
func (*CreateCaseRequest) Descriptor() ([]byte, []int)
Deprecated: Use CreateCaseRequest.ProtoReflect.Descriptor instead.
func (*CreateCaseRequest) GetCase ¶
func (x *CreateCaseRequest) GetCase() *common.Case
func (*CreateCaseRequest) GetParent ¶
func (x *CreateCaseRequest) GetParent() string
func (*CreateCaseRequest) ProtoMessage ¶
func (*CreateCaseRequest) ProtoMessage()
func (*CreateCaseRequest) ProtoReflect ¶
func (x *CreateCaseRequest) ProtoReflect() protoreflect.Message
func (*CreateCaseRequest) Reset ¶
func (x *CreateCaseRequest) Reset()
func (*CreateCaseRequest) String ¶
func (x *CreateCaseRequest) String() string
type CreateCommentRequest ¶
type CreateCommentRequest struct {
// The resource name of case to which this comment should be added.
Name string `protobuf:"bytes,1,opt,name=name,proto3" json:"name,omitempty"`
// The `Comment` to be added to this case.
Comment *common.Comment `protobuf:"bytes,2,opt,name=comment,proto3" json:"comment,omitempty"`
// contains filtered or unexported fields
}
The request message for `CreateComment` method.
func (*CreateCommentRequest) Descriptor ¶
func (*CreateCommentRequest) Descriptor() ([]byte, []int)
Deprecated: Use CreateCommentRequest.ProtoReflect.Descriptor instead.
func (*CreateCommentRequest) GetComment ¶
func (x *CreateCommentRequest) GetComment() *common.Comment
func (*CreateCommentRequest) GetName ¶
func (x *CreateCommentRequest) GetName() string
func (*CreateCommentRequest) ProtoMessage ¶
func (*CreateCommentRequest) ProtoMessage()
func (*CreateCommentRequest) ProtoReflect ¶
func (x *CreateCommentRequest) ProtoReflect() protoreflect.Message
func (*CreateCommentRequest) Reset ¶
func (x *CreateCommentRequest) Reset()
func (*CreateCommentRequest) String ¶
func (x *CreateCommentRequest) String() string
type GetCaseRequest ¶
type GetCaseRequest struct {
// Name of case resource requested.
// For example: "supportAccounts/accountA/cases/123"
Name string `protobuf:"bytes,1,opt,name=name,proto3" json:"name,omitempty"`
// contains filtered or unexported fields
}
The request message for `GetCase` method.
func (*GetCaseRequest) Descriptor ¶
func (*GetCaseRequest) Descriptor() ([]byte, []int)
Deprecated: Use GetCaseRequest.ProtoReflect.Descriptor instead.
func (*GetCaseRequest) GetName ¶
func (x *GetCaseRequest) GetName() string
func (*GetCaseRequest) ProtoMessage ¶
func (*GetCaseRequest) ProtoMessage()
func (*GetCaseRequest) ProtoReflect ¶
func (x *GetCaseRequest) ProtoReflect() protoreflect.Message
func (*GetCaseRequest) Reset ¶
func (x *GetCaseRequest) Reset()
func (*GetCaseRequest) String ¶
func (x *GetCaseRequest) String() string
type GetIssueTaxonomyRequest ¶
type GetIssueTaxonomyRequest struct {
// contains filtered or unexported fields
}
The request message for `GetIssueTaxonomy` method.
func (*GetIssueTaxonomyRequest) Descriptor ¶
func (*GetIssueTaxonomyRequest) Descriptor() ([]byte, []int)
Deprecated: Use GetIssueTaxonomyRequest.ProtoReflect.Descriptor instead.
func (*GetIssueTaxonomyRequest) ProtoMessage ¶
func (*GetIssueTaxonomyRequest) ProtoMessage()
func (*GetIssueTaxonomyRequest) ProtoReflect ¶
func (x *GetIssueTaxonomyRequest) ProtoReflect() protoreflect.Message
func (*GetIssueTaxonomyRequest) Reset ¶
func (x *GetIssueTaxonomyRequest) Reset()
func (*GetIssueTaxonomyRequest) String ¶
func (x *GetIssueTaxonomyRequest) String() string
type GetSupportAccountRequest ¶
type GetSupportAccountRequest struct {
// The resource name of the support accounts. For example:
// `supportAccounts/accountA`.
Name string `protobuf:"bytes,1,opt,name=name,proto3" json:"name,omitempty"`
// contains filtered or unexported fields
}
The request message for `GetSupportAccount`.
func (*GetSupportAccountRequest) Descriptor ¶
func (*GetSupportAccountRequest) Descriptor() ([]byte, []int)
Deprecated: Use GetSupportAccountRequest.ProtoReflect.Descriptor instead.
func (*GetSupportAccountRequest) GetName ¶
func (x *GetSupportAccountRequest) GetName() string
func (*GetSupportAccountRequest) ProtoMessage ¶
func (*GetSupportAccountRequest) ProtoMessage()
func (*GetSupportAccountRequest) ProtoReflect ¶
func (x *GetSupportAccountRequest) ProtoReflect() protoreflect.Message
func (*GetSupportAccountRequest) Reset ¶
func (x *GetSupportAccountRequest) Reset()
func (*GetSupportAccountRequest) String ¶
func (x *GetSupportAccountRequest) String() string
type ListCasesRequest ¶
type ListCasesRequest struct {
// Name of the account resource for which cases are requested. For example:
// "supportAccounts/accountA"
Name string `protobuf:"bytes,1,opt,name=name,proto3" json:"name,omitempty"`
// The filter applied to the search results. Currently it only accepts "OPEN"
// or "CLOSED" strings, filtering out cases that are open or resolved.
Filter string `protobuf:"bytes,2,opt,name=filter,proto3" json:"filter,omitempty"`
// Maximum number of cases fetched with each request.
PageSize int64 `protobuf:"varint,3,opt,name=page_size,json=pageSize,proto3" json:"page_size,omitempty"`
// A token identifying the page of results to return. If unspecified, the
// first page is retrieved.
PageToken string `protobuf:"bytes,4,opt,name=page_token,json=pageToken,proto3" json:"page_token,omitempty"`
// contains filtered or unexported fields
}
The request message for `ListCase` method.
func (*ListCasesRequest) Descriptor ¶
func (*ListCasesRequest) Descriptor() ([]byte, []int)
Deprecated: Use ListCasesRequest.ProtoReflect.Descriptor instead.
func (*ListCasesRequest) GetFilter ¶
func (x *ListCasesRequest) GetFilter() string
func (*ListCasesRequest) GetName ¶
func (x *ListCasesRequest) GetName() string
func (*ListCasesRequest) GetPageSize ¶
func (x *ListCasesRequest) GetPageSize() int64
func (*ListCasesRequest) GetPageToken ¶
func (x *ListCasesRequest) GetPageToken() string
func (*ListCasesRequest) ProtoMessage ¶
func (*ListCasesRequest) ProtoMessage()
func (*ListCasesRequest) ProtoReflect ¶
func (x *ListCasesRequest) ProtoReflect() protoreflect.Message
func (*ListCasesRequest) Reset ¶
func (x *ListCasesRequest) Reset()
func (*ListCasesRequest) String ¶
func (x *ListCasesRequest) String() string
type ListCasesResponse ¶
type ListCasesResponse struct {
// A list of cases.
Cases []*common.Case `protobuf:"bytes,1,rep,name=cases,proto3" json:"cases,omitempty"`
// A token to retrieve the next page of results. This should be passed on in
// `page_token` field of `ListCaseRequest` for next request. If unspecified,
// there are no more results to retrieve.
NextPageToken string `protobuf:"bytes,2,opt,name=next_page_token,json=nextPageToken,proto3" json:"next_page_token,omitempty"`
// contains filtered or unexported fields
}
The response message for `ListCase` method.
func (*ListCasesResponse) Descriptor ¶
func (*ListCasesResponse) Descriptor() ([]byte, []int)
Deprecated: Use ListCasesResponse.ProtoReflect.Descriptor instead.
func (*ListCasesResponse) GetCases ¶
func (x *ListCasesResponse) GetCases() []*common.Case
func (*ListCasesResponse) GetNextPageToken ¶
func (x *ListCasesResponse) GetNextPageToken() string
func (*ListCasesResponse) ProtoMessage ¶
func (*ListCasesResponse) ProtoMessage()
func (*ListCasesResponse) ProtoReflect ¶
func (x *ListCasesResponse) ProtoReflect() protoreflect.Message
func (*ListCasesResponse) Reset ¶
func (x *ListCasesResponse) Reset()
func (*ListCasesResponse) String ¶
func (x *ListCasesResponse) String() string
type ListCommentsRequest ¶
type ListCommentsRequest struct {
// The resource name of case for which comments should be listed.
Name string `protobuf:"bytes,1,opt,name=name,proto3" json:"name,omitempty"`
// contains filtered or unexported fields
}
The request message for `ListComments` method.
func (*ListCommentsRequest) Descriptor ¶
func (*ListCommentsRequest) Descriptor() ([]byte, []int)
Deprecated: Use ListCommentsRequest.ProtoReflect.Descriptor instead.
func (*ListCommentsRequest) GetName ¶
func (x *ListCommentsRequest) GetName() string
func (*ListCommentsRequest) ProtoMessage ¶
func (*ListCommentsRequest) ProtoMessage()
func (*ListCommentsRequest) ProtoReflect ¶
func (x *ListCommentsRequest) ProtoReflect() protoreflect.Message
func (*ListCommentsRequest) Reset ¶
func (x *ListCommentsRequest) Reset()
func (*ListCommentsRequest) String ¶
func (x *ListCommentsRequest) String() string
type ListCommentsResponse ¶
type ListCommentsResponse struct {
// A list of comments.
Comments []*common.Comment `protobuf:"bytes,1,rep,name=comments,proto3" json:"comments,omitempty"`
// contains filtered or unexported fields
}
The response message for `ListComments` method.
func (*ListCommentsResponse) Descriptor ¶
func (*ListCommentsResponse) Descriptor() ([]byte, []int)
Deprecated: Use ListCommentsResponse.ProtoReflect.Descriptor instead.
func (*ListCommentsResponse) GetComments ¶
func (x *ListCommentsResponse) GetComments() []*common.Comment
func (*ListCommentsResponse) ProtoMessage ¶
func (*ListCommentsResponse) ProtoMessage()
func (*ListCommentsResponse) ProtoReflect ¶
func (x *ListCommentsResponse) ProtoReflect() protoreflect.Message
func (*ListCommentsResponse) Reset ¶
func (x *ListCommentsResponse) Reset()
func (*ListCommentsResponse) String ¶
func (x *ListCommentsResponse) String() string
type ListSupportAccountsRequest ¶
type ListSupportAccountsRequest struct {
// The filter applied to search results. It only supports filtering a support
// account list by a cloud_resource. For example, to filter results by support
// accounts associated with an Organization, its value should be:
// "cloud_resource:organizations/<organization_id>"
Filter string `protobuf:"bytes,1,opt,name=filter,proto3" json:"filter,omitempty"`
// Maximum number of accounts fetched with each request.
PageSize int64 `protobuf:"varint,2,opt,name=page_size,json=pageSize,proto3" json:"page_size,omitempty"`
// A token identifying the page of results to return. If unspecified, the
// first page is retrieved.
PageToken string `protobuf:"bytes,3,opt,name=page_token,json=pageToken,proto3" json:"page_token,omitempty"`
// contains filtered or unexported fields
}
The request message for `ListSupportAccount`.
func (*ListSupportAccountsRequest) Descriptor ¶
func (*ListSupportAccountsRequest) Descriptor() ([]byte, []int)
Deprecated: Use ListSupportAccountsRequest.ProtoReflect.Descriptor instead.
func (*ListSupportAccountsRequest) GetFilter ¶
func (x *ListSupportAccountsRequest) GetFilter() string
func (*ListSupportAccountsRequest) GetPageSize ¶
func (x *ListSupportAccountsRequest) GetPageSize() int64
func (*ListSupportAccountsRequest) GetPageToken ¶
func (x *ListSupportAccountsRequest) GetPageToken() string
func (*ListSupportAccountsRequest) ProtoMessage ¶
func (*ListSupportAccountsRequest) ProtoMessage()
func (*ListSupportAccountsRequest) ProtoReflect ¶
func (x *ListSupportAccountsRequest) ProtoReflect() protoreflect.Message
func (*ListSupportAccountsRequest) Reset ¶
func (x *ListSupportAccountsRequest) Reset()
func (*ListSupportAccountsRequest) String ¶
func (x *ListSupportAccountsRequest) String() string
type ListSupportAccountsResponse ¶
type ListSupportAccountsResponse struct {
// A list of support accounts.
Accounts []*common.SupportAccount `protobuf:"bytes,1,rep,name=accounts,proto3" json:"accounts,omitempty"`
// A token to retrieve the next page of results. This should be passed on in
// `page_token` field of `ListSupportAccountRequest` for next request. If
// unspecified, there are no more results to retrieve.
NextPageToken string `protobuf:"bytes,2,opt,name=next_page_token,json=nextPageToken,proto3" json:"next_page_token,omitempty"`
// contains filtered or unexported fields
}
The response message for `ListSupportAccount`.
func (*ListSupportAccountsResponse) Descriptor ¶
func (*ListSupportAccountsResponse) Descriptor() ([]byte, []int)
Deprecated: Use ListSupportAccountsResponse.ProtoReflect.Descriptor instead.
func (*ListSupportAccountsResponse) GetAccounts ¶
func (x *ListSupportAccountsResponse) GetAccounts() []*common.SupportAccount
func (*ListSupportAccountsResponse) GetNextPageToken ¶
func (x *ListSupportAccountsResponse) GetNextPageToken() string
func (*ListSupportAccountsResponse) ProtoMessage ¶
func (*ListSupportAccountsResponse) ProtoMessage()
func (*ListSupportAccountsResponse) ProtoReflect ¶
func (x *ListSupportAccountsResponse) ProtoReflect() protoreflect.Message
func (*ListSupportAccountsResponse) Reset ¶
func (x *ListSupportAccountsResponse) Reset()
func (*ListSupportAccountsResponse) String ¶
func (x *ListSupportAccountsResponse) String() string
type UnimplementedCloudSupportServer ¶
type UnimplementedCloudSupportServer struct {
}
UnimplementedCloudSupportServer can be embedded to have forward compatible implementations.
func (*UnimplementedCloudSupportServer) CreateCase ¶
func (*UnimplementedCloudSupportServer) CreateCase(context.Context, *CreateCaseRequest) (*common.Case, error)
func (*UnimplementedCloudSupportServer) CreateComment ¶
func (*UnimplementedCloudSupportServer) CreateComment(context.Context, *CreateCommentRequest) (*common.Comment, error)
func (*UnimplementedCloudSupportServer) GetCase ¶
func (*UnimplementedCloudSupportServer) GetCase(context.Context, *GetCaseRequest) (*common.Case, error)
func (*UnimplementedCloudSupportServer) GetIssueTaxonomy ¶
func (*UnimplementedCloudSupportServer) GetIssueTaxonomy(context.Context, *GetIssueTaxonomyRequest) (*common.IssueTaxonomy, error)
func (*UnimplementedCloudSupportServer) GetSupportAccount ¶
func (*UnimplementedCloudSupportServer) GetSupportAccount(context.Context, *GetSupportAccountRequest) (*common.SupportAccount, error)
func (*UnimplementedCloudSupportServer) ListCases ¶
func (*UnimplementedCloudSupportServer) ListCases(context.Context, *ListCasesRequest) (*ListCasesResponse, error)
func (*UnimplementedCloudSupportServer) ListComments ¶
func (*UnimplementedCloudSupportServer) ListComments(context.Context, *ListCommentsRequest) (*ListCommentsResponse, error)
func (*UnimplementedCloudSupportServer) ListSupportAccounts ¶
func (*UnimplementedCloudSupportServer) ListSupportAccounts(context.Context, *ListSupportAccountsRequest) (*ListSupportAccountsResponse, error)
func (*UnimplementedCloudSupportServer) UpdateCase ¶
func (*UnimplementedCloudSupportServer) UpdateCase(context.Context, *UpdateCaseRequest) (*common.Case, error)
type UpdateCaseRequest ¶
type UpdateCaseRequest struct {
// The case resource to update.
Case *common.Case `protobuf:"bytes,1,opt,name=case,proto3" json:"case,omitempty"`
// A field that represents attributes of a Case object that should be updated
// as part of this request.
UpdateMask *fieldmaskpb.FieldMask `protobuf:"bytes,2,opt,name=update_mask,json=updateMask,proto3" json:"update_mask,omitempty"`
// contains filtered or unexported fields
}
The request message for `UpdateCase` method.
func (*UpdateCaseRequest) Descriptor ¶
func (*UpdateCaseRequest) Descriptor() ([]byte, []int)
Deprecated: Use UpdateCaseRequest.ProtoReflect.Descriptor instead.
func (*UpdateCaseRequest) GetCase ¶
func (x *UpdateCaseRequest) GetCase() *common.Case
func (*UpdateCaseRequest) GetUpdateMask ¶
func (x *UpdateCaseRequest) GetUpdateMask() *fieldmaskpb.FieldMask
func (*UpdateCaseRequest) ProtoMessage ¶
func (*UpdateCaseRequest) ProtoMessage()
func (*UpdateCaseRequest) ProtoReflect ¶
func (x *UpdateCaseRequest) ProtoReflect() protoreflect.Message
func (*UpdateCaseRequest) Reset ¶
func (x *UpdateCaseRequest) Reset()
func (*UpdateCaseRequest) String ¶
func (x *UpdateCaseRequest) String() string
Source Files ¶
cloud_support.pb.go
- Version
- v0.0.0-20260427160629-7cedc36a6bc4 (latest)
- Published
- Apr 27, 2026
- Platform
- linux/amd64
- Imports
- 12 packages
- Last checked
- 2 days ago –
Tools for package owners.