package videointelligence
import "google.golang.org/genproto/googleapis/cloud/videointelligence/v1p2beta1"
Index ¶
- Variables
- func RegisterVideoIntelligenceServiceServer(s *grpc.Server, srv VideoIntelligenceServiceServer)
- type AnnotateVideoProgress
- func (*AnnotateVideoProgress) Descriptor() ([]byte, []int)
- func (x *AnnotateVideoProgress) GetAnnotationProgress() []*VideoAnnotationProgress
- func (*AnnotateVideoProgress) ProtoMessage()
- func (x *AnnotateVideoProgress) ProtoReflect() protoreflect.Message
- func (x *AnnotateVideoProgress) Reset()
- func (x *AnnotateVideoProgress) String() string
- type AnnotateVideoRequest
- func (*AnnotateVideoRequest) Descriptor() ([]byte, []int)
- func (x *AnnotateVideoRequest) GetFeatures() []Feature
- func (x *AnnotateVideoRequest) GetInputContent() []byte
- func (x *AnnotateVideoRequest) GetInputUri() string
- func (x *AnnotateVideoRequest) GetLocationId() string
- func (x *AnnotateVideoRequest) GetOutputUri() string
- func (x *AnnotateVideoRequest) GetVideoContext() *VideoContext
- func (*AnnotateVideoRequest) ProtoMessage()
- func (x *AnnotateVideoRequest) ProtoReflect() protoreflect.Message
- func (x *AnnotateVideoRequest) Reset()
- func (x *AnnotateVideoRequest) String() string
- type AnnotateVideoResponse
- func (*AnnotateVideoResponse) Descriptor() ([]byte, []int)
- func (x *AnnotateVideoResponse) GetAnnotationResults() []*VideoAnnotationResults
- func (*AnnotateVideoResponse) ProtoMessage()
- func (x *AnnotateVideoResponse) ProtoReflect() protoreflect.Message
- func (x *AnnotateVideoResponse) Reset()
- func (x *AnnotateVideoResponse) String() string
- type Entity
- func (*Entity) Descriptor() ([]byte, []int)
- func (x *Entity) GetDescription() string
- func (x *Entity) GetEntityId() string
- func (x *Entity) GetLanguageCode() string
- func (*Entity) ProtoMessage()
- func (x *Entity) ProtoReflect() protoreflect.Message
- func (x *Entity) Reset()
- func (x *Entity) String() string
- type ExplicitContentAnnotation
- func (*ExplicitContentAnnotation) Descriptor() ([]byte, []int)
- func (x *ExplicitContentAnnotation) GetFrames() []*ExplicitContentFrame
- func (*ExplicitContentAnnotation) ProtoMessage()
- func (x *ExplicitContentAnnotation) ProtoReflect() protoreflect.Message
- func (x *ExplicitContentAnnotation) Reset()
- func (x *ExplicitContentAnnotation) String() string
- type ExplicitContentDetectionConfig
- func (*ExplicitContentDetectionConfig) Descriptor() ([]byte, []int)
- func (x *ExplicitContentDetectionConfig) GetModel() string
- func (*ExplicitContentDetectionConfig) ProtoMessage()
- func (x *ExplicitContentDetectionConfig) ProtoReflect() protoreflect.Message
- func (x *ExplicitContentDetectionConfig) Reset()
- func (x *ExplicitContentDetectionConfig) String() string
- type ExplicitContentFrame
- func (*ExplicitContentFrame) Descriptor() ([]byte, []int)
- func (x *ExplicitContentFrame) GetPornographyLikelihood() Likelihood
- func (x *ExplicitContentFrame) GetTimeOffset() *durationpb.Duration
- func (*ExplicitContentFrame) ProtoMessage()
- func (x *ExplicitContentFrame) ProtoReflect() protoreflect.Message
- func (x *ExplicitContentFrame) Reset()
- func (x *ExplicitContentFrame) String() string
- type Feature
- func (Feature) Descriptor() protoreflect.EnumDescriptor
- func (x Feature) Enum() *Feature
- func (Feature) EnumDescriptor() ([]byte, []int)
- func (x Feature) Number() protoreflect.EnumNumber
- func (x Feature) String() string
- func (Feature) Type() protoreflect.EnumType
- type LabelAnnotation
- func (*LabelAnnotation) Descriptor() ([]byte, []int)
- func (x *LabelAnnotation) GetCategoryEntities() []*Entity
- func (x *LabelAnnotation) GetEntity() *Entity
- func (x *LabelAnnotation) GetFrames() []*LabelFrame
- func (x *LabelAnnotation) GetSegments() []*LabelSegment
- func (*LabelAnnotation) ProtoMessage()
- func (x *LabelAnnotation) ProtoReflect() protoreflect.Message
- func (x *LabelAnnotation) Reset()
- func (x *LabelAnnotation) String() string
- type LabelDetectionConfig
- func (*LabelDetectionConfig) Descriptor() ([]byte, []int)
- func (x *LabelDetectionConfig) GetLabelDetectionMode() LabelDetectionMode
- func (x *LabelDetectionConfig) GetModel() string
- func (x *LabelDetectionConfig) GetStationaryCamera() bool
- func (*LabelDetectionConfig) ProtoMessage()
- func (x *LabelDetectionConfig) ProtoReflect() protoreflect.Message
- func (x *LabelDetectionConfig) Reset()
- func (x *LabelDetectionConfig) String() string
- type LabelDetectionMode
- func (LabelDetectionMode) Descriptor() protoreflect.EnumDescriptor
- func (x LabelDetectionMode) Enum() *LabelDetectionMode
- func (LabelDetectionMode) EnumDescriptor() ([]byte, []int)
- func (x LabelDetectionMode) Number() protoreflect.EnumNumber
- func (x LabelDetectionMode) String() string
- func (LabelDetectionMode) Type() protoreflect.EnumType
- type LabelFrame
- func (*LabelFrame) Descriptor() ([]byte, []int)
- func (x *LabelFrame) GetConfidence() float32
- func (x *LabelFrame) GetTimeOffset() *durationpb.Duration
- func (*LabelFrame) ProtoMessage()
- func (x *LabelFrame) ProtoReflect() protoreflect.Message
- func (x *LabelFrame) Reset()
- func (x *LabelFrame) String() string
- type LabelSegment
- func (*LabelSegment) Descriptor() ([]byte, []int)
- func (x *LabelSegment) GetConfidence() float32
- func (x *LabelSegment) GetSegment() *VideoSegment
- func (*LabelSegment) ProtoMessage()
- func (x *LabelSegment) ProtoReflect() protoreflect.Message
- func (x *LabelSegment) Reset()
- func (x *LabelSegment) String() string
- type Likelihood
- func (Likelihood) Descriptor() protoreflect.EnumDescriptor
- func (x Likelihood) Enum() *Likelihood
- func (Likelihood) EnumDescriptor() ([]byte, []int)
- func (x Likelihood) Number() protoreflect.EnumNumber
- func (x Likelihood) String() string
- func (Likelihood) Type() protoreflect.EnumType
- type NormalizedBoundingBox
- func (*NormalizedBoundingBox) Descriptor() ([]byte, []int)
- func (x *NormalizedBoundingBox) GetBottom() float32
- func (x *NormalizedBoundingBox) GetLeft() float32
- func (x *NormalizedBoundingBox) GetRight() float32
- func (x *NormalizedBoundingBox) GetTop() float32
- func (*NormalizedBoundingBox) ProtoMessage()
- func (x *NormalizedBoundingBox) ProtoReflect() protoreflect.Message
- func (x *NormalizedBoundingBox) Reset()
- func (x *NormalizedBoundingBox) String() string
- type NormalizedBoundingPoly
- func (*NormalizedBoundingPoly) Descriptor() ([]byte, []int)
- func (x *NormalizedBoundingPoly) GetVertices() []*NormalizedVertex
- func (*NormalizedBoundingPoly) ProtoMessage()
- func (x *NormalizedBoundingPoly) ProtoReflect() protoreflect.Message
- func (x *NormalizedBoundingPoly) Reset()
- func (x *NormalizedBoundingPoly) String() string
- type NormalizedVertex
- func (*NormalizedVertex) Descriptor() ([]byte, []int)
- func (x *NormalizedVertex) GetX() float32
- func (x *NormalizedVertex) GetY() float32
- func (*NormalizedVertex) ProtoMessage()
- func (x *NormalizedVertex) ProtoReflect() protoreflect.Message
- func (x *NormalizedVertex) Reset()
- func (x *NormalizedVertex) String() string
- type ObjectTrackingAnnotation
- func (*ObjectTrackingAnnotation) Descriptor() ([]byte, []int)
- func (x *ObjectTrackingAnnotation) GetConfidence() float32
- func (x *ObjectTrackingAnnotation) GetEntity() *Entity
- func (x *ObjectTrackingAnnotation) GetFrames() []*ObjectTrackingFrame
- func (x *ObjectTrackingAnnotation) GetSegment() *VideoSegment
- func (x *ObjectTrackingAnnotation) GetTrackId() int64
- func (m *ObjectTrackingAnnotation) GetTrackInfo() isObjectTrackingAnnotation_TrackInfo
- func (*ObjectTrackingAnnotation) ProtoMessage()
- func (x *ObjectTrackingAnnotation) ProtoReflect() protoreflect.Message
- func (x *ObjectTrackingAnnotation) Reset()
- func (x *ObjectTrackingAnnotation) String() string
- type ObjectTrackingAnnotation_Segment
- type ObjectTrackingAnnotation_TrackId
- type ObjectTrackingFrame
- func (*ObjectTrackingFrame) Descriptor() ([]byte, []int)
- func (x *ObjectTrackingFrame) GetNormalizedBoundingBox() *NormalizedBoundingBox
- func (x *ObjectTrackingFrame) GetTimeOffset() *durationpb.Duration
- func (*ObjectTrackingFrame) ProtoMessage()
- func (x *ObjectTrackingFrame) ProtoReflect() protoreflect.Message
- func (x *ObjectTrackingFrame) Reset()
- func (x *ObjectTrackingFrame) String() string
- type ShotChangeDetectionConfig
- func (*ShotChangeDetectionConfig) Descriptor() ([]byte, []int)
- func (x *ShotChangeDetectionConfig) GetModel() string
- func (*ShotChangeDetectionConfig) ProtoMessage()
- func (x *ShotChangeDetectionConfig) ProtoReflect() protoreflect.Message
- func (x *ShotChangeDetectionConfig) Reset()
- func (x *ShotChangeDetectionConfig) String() string
- type TextAnnotation
- func (*TextAnnotation) Descriptor() ([]byte, []int)
- func (x *TextAnnotation) GetSegments() []*TextSegment
- func (x *TextAnnotation) GetText() string
- func (*TextAnnotation) ProtoMessage()
- func (x *TextAnnotation) ProtoReflect() protoreflect.Message
- func (x *TextAnnotation) Reset()
- func (x *TextAnnotation) String() string
- type TextDetectionConfig
- func (*TextDetectionConfig) Descriptor() ([]byte, []int)
- func (x *TextDetectionConfig) GetLanguageHints() []string
- func (*TextDetectionConfig) ProtoMessage()
- func (x *TextDetectionConfig) ProtoReflect() protoreflect.Message
- func (x *TextDetectionConfig) Reset()
- func (x *TextDetectionConfig) String() string
- type TextFrame
- func (*TextFrame) Descriptor() ([]byte, []int)
- func (x *TextFrame) GetRotatedBoundingBox() *NormalizedBoundingPoly
- func (x *TextFrame) GetTimeOffset() *durationpb.Duration
- func (*TextFrame) ProtoMessage()
- func (x *TextFrame) ProtoReflect() protoreflect.Message
- func (x *TextFrame) Reset()
- func (x *TextFrame) String() string
- type TextSegment
- func (*TextSegment) Descriptor() ([]byte, []int)
- func (x *TextSegment) GetConfidence() float32
- func (x *TextSegment) GetFrames() []*TextFrame
- func (x *TextSegment) GetSegment() *VideoSegment
- func (*TextSegment) ProtoMessage()
- func (x *TextSegment) ProtoReflect() protoreflect.Message
- func (x *TextSegment) Reset()
- func (x *TextSegment) String() string
- type UnimplementedVideoIntelligenceServiceServer
- type VideoAnnotationProgress
- func (*VideoAnnotationProgress) Descriptor() ([]byte, []int)
- func (x *VideoAnnotationProgress) GetInputUri() string
- func (x *VideoAnnotationProgress) GetProgressPercent() int32
- func (x *VideoAnnotationProgress) GetStartTime() *timestamppb.Timestamp
- func (x *VideoAnnotationProgress) GetUpdateTime() *timestamppb.Timestamp
- func (*VideoAnnotationProgress) ProtoMessage()
- func (x *VideoAnnotationProgress) ProtoReflect() protoreflect.Message
- func (x *VideoAnnotationProgress) Reset()
- func (x *VideoAnnotationProgress) String() string
- type VideoAnnotationResults
- func (*VideoAnnotationResults) Descriptor() ([]byte, []int)
- func (x *VideoAnnotationResults) GetError() *status.Status
- func (x *VideoAnnotationResults) GetExplicitAnnotation() *ExplicitContentAnnotation
- func (x *VideoAnnotationResults) GetFrameLabelAnnotations() []*LabelAnnotation
- func (x *VideoAnnotationResults) GetInputUri() string
- func (x *VideoAnnotationResults) GetObjectAnnotations() []*ObjectTrackingAnnotation
- func (x *VideoAnnotationResults) GetSegmentLabelAnnotations() []*LabelAnnotation
- func (x *VideoAnnotationResults) GetShotAnnotations() []*VideoSegment
- func (x *VideoAnnotationResults) GetShotLabelAnnotations() []*LabelAnnotation
- func (x *VideoAnnotationResults) GetTextAnnotations() []*TextAnnotation
- func (*VideoAnnotationResults) ProtoMessage()
- func (x *VideoAnnotationResults) ProtoReflect() protoreflect.Message
- func (x *VideoAnnotationResults) Reset()
- func (x *VideoAnnotationResults) String() string
- type VideoContext
- func (*VideoContext) Descriptor() ([]byte, []int)
- func (x *VideoContext) GetExplicitContentDetectionConfig() *ExplicitContentDetectionConfig
- func (x *VideoContext) GetLabelDetectionConfig() *LabelDetectionConfig
- func (x *VideoContext) GetSegments() []*VideoSegment
- func (x *VideoContext) GetShotChangeDetectionConfig() *ShotChangeDetectionConfig
- func (x *VideoContext) GetTextDetectionConfig() *TextDetectionConfig
- func (*VideoContext) ProtoMessage()
- func (x *VideoContext) ProtoReflect() protoreflect.Message
- func (x *VideoContext) Reset()
- func (x *VideoContext) String() string
- type VideoIntelligenceServiceClient
- type VideoIntelligenceServiceServer
- type VideoSegment
- func (*VideoSegment) Descriptor() ([]byte, []int)
- func (x *VideoSegment) GetEndTimeOffset() *durationpb.Duration
- func (x *VideoSegment) GetStartTimeOffset() *durationpb.Duration
- func (*VideoSegment) ProtoMessage()
- func (x *VideoSegment) ProtoReflect() protoreflect.Message
- func (x *VideoSegment) Reset()
- func (x *VideoSegment) String() string
Variables ¶
var ( Feature_name = map[int32]string{ 0: "FEATURE_UNSPECIFIED", 1: "LABEL_DETECTION", 2: "SHOT_CHANGE_DETECTION", 3: "EXPLICIT_CONTENT_DETECTION", 7: "TEXT_DETECTION", 9: "OBJECT_TRACKING", } Feature_value = map[string]int32{ "FEATURE_UNSPECIFIED": 0, "LABEL_DETECTION": 1, "SHOT_CHANGE_DETECTION": 2, "EXPLICIT_CONTENT_DETECTION": 3, "TEXT_DETECTION": 7, "OBJECT_TRACKING": 9, } )
Enum value maps for Feature.
var ( LabelDetectionMode_name = map[int32]string{ 0: "LABEL_DETECTION_MODE_UNSPECIFIED", 1: "SHOT_MODE", 2: "FRAME_MODE", 3: "SHOT_AND_FRAME_MODE", } LabelDetectionMode_value = map[string]int32{ "LABEL_DETECTION_MODE_UNSPECIFIED": 0, "SHOT_MODE": 1, "FRAME_MODE": 2, "SHOT_AND_FRAME_MODE": 3, } )
Enum value maps for LabelDetectionMode.
var ( Likelihood_name = map[int32]string{ 0: "LIKELIHOOD_UNSPECIFIED", 1: "VERY_UNLIKELY", 2: "UNLIKELY", 3: "POSSIBLE", 4: "LIKELY", 5: "VERY_LIKELY", } Likelihood_value = map[string]int32{ "LIKELIHOOD_UNSPECIFIED": 0, "VERY_UNLIKELY": 1, "UNLIKELY": 2, "POSSIBLE": 3, "LIKELY": 4, "VERY_LIKELY": 5, } )
Enum value maps for Likelihood.
var File_google_cloud_videointelligence_v1p2beta1_video_intelligence_proto protoreflect.FileDescriptor
Functions ¶
func RegisterVideoIntelligenceServiceServer ¶
func RegisterVideoIntelligenceServiceServer(s *grpc.Server, srv VideoIntelligenceServiceServer)
Types ¶
type AnnotateVideoProgress ¶
type AnnotateVideoProgress struct {
// Progress metadata for all videos specified in `AnnotateVideoRequest`.
AnnotationProgress []*VideoAnnotationProgress `protobuf:"bytes,1,rep,name=annotation_progress,json=annotationProgress,proto3" json:"annotation_progress,omitempty"`
// contains filtered or unexported fields
}
Video annotation progress. Included in the `metadata` field of the `Operation` returned by the `GetOperation` call of the `google::longrunning::Operations` service.
func (*AnnotateVideoProgress) Descriptor ¶
func (*AnnotateVideoProgress) Descriptor() ([]byte, []int)
Deprecated: Use AnnotateVideoProgress.ProtoReflect.Descriptor instead.
func (*AnnotateVideoProgress) GetAnnotationProgress ¶
func (x *AnnotateVideoProgress) GetAnnotationProgress() []*VideoAnnotationProgress
func (*AnnotateVideoProgress) ProtoMessage ¶
func (*AnnotateVideoProgress) ProtoMessage()
func (*AnnotateVideoProgress) ProtoReflect ¶
func (x *AnnotateVideoProgress) ProtoReflect() protoreflect.Message
func (*AnnotateVideoProgress) Reset ¶
func (x *AnnotateVideoProgress) Reset()
func (*AnnotateVideoProgress) String ¶
func (x *AnnotateVideoProgress) String() string
type AnnotateVideoRequest ¶
type AnnotateVideoRequest struct {
// Input video location. Currently, only
// [Google Cloud Storage](https://cloud.google.com/storage/) URIs are
// supported, which must be specified in the following format:
// `gs://bucket-id/object-id` (other URI formats return
// [google.rpc.Code.INVALID_ARGUMENT][google.rpc.Code.INVALID_ARGUMENT]). For more information, see
// [Request URIs](https://cloud.google.com/storage/docs/request-endpoints).
// A video URI may include wildcards in `object-id`, and thus identify
// multiple videos. Supported wildcards: '*' to match 0 or more characters;
// '?' to match 1 character. If unset, the input video should be embedded
// in the request as `input_content`. If set, `input_content` should be unset.
InputUri string `protobuf:"bytes,1,opt,name=input_uri,json=inputUri,proto3" json:"input_uri,omitempty"`
// The video data bytes.
// If unset, the input video(s) should be specified via `input_uri`.
// If set, `input_uri` should be unset.
InputContent []byte `protobuf:"bytes,6,opt,name=input_content,json=inputContent,proto3" json:"input_content,omitempty"`
// Required. Requested video annotation features.
Features []Feature `protobuf:"varint,2,rep,packed,name=features,proto3,enum=google.cloud.videointelligence.v1p2beta1.Feature" json:"features,omitempty"`
// Additional video context and/or feature-specific parameters.
VideoContext *VideoContext `protobuf:"bytes,3,opt,name=video_context,json=videoContext,proto3" json:"video_context,omitempty"`
// Optional. Location where the output (in JSON format) should be stored.
// Currently, only [Google Cloud Storage](https://cloud.google.com/storage/)
// URIs are supported, which must be specified in the following format:
// `gs://bucket-id/object-id` (other URI formats return
// [google.rpc.Code.INVALID_ARGUMENT][google.rpc.Code.INVALID_ARGUMENT]). For more information, see
// [Request URIs](https://cloud.google.com/storage/docs/request-endpoints).
OutputUri string `protobuf:"bytes,4,opt,name=output_uri,json=outputUri,proto3" json:"output_uri,omitempty"`
// Optional. Cloud region where annotation should take place. Supported cloud
// regions: `us-east1`, `us-west1`, `europe-west1`, `asia-east1`. If no region
// is specified, a region will be determined based on video file location.
LocationId string `protobuf:"bytes,5,opt,name=location_id,json=locationId,proto3" json:"location_id,omitempty"`
// contains filtered or unexported fields
}
Video annotation request.
func (*AnnotateVideoRequest) Descriptor ¶
func (*AnnotateVideoRequest) Descriptor() ([]byte, []int)
Deprecated: Use AnnotateVideoRequest.ProtoReflect.Descriptor instead.
func (*AnnotateVideoRequest) GetFeatures ¶
func (x *AnnotateVideoRequest) GetFeatures() []Feature
func (*AnnotateVideoRequest) GetInputContent ¶
func (x *AnnotateVideoRequest) GetInputContent() []byte
func (*AnnotateVideoRequest) GetInputUri ¶
func (x *AnnotateVideoRequest) GetInputUri() string
func (*AnnotateVideoRequest) GetLocationId ¶
func (x *AnnotateVideoRequest) GetLocationId() string
func (*AnnotateVideoRequest) GetOutputUri ¶
func (x *AnnotateVideoRequest) GetOutputUri() string
func (*AnnotateVideoRequest) GetVideoContext ¶
func (x *AnnotateVideoRequest) GetVideoContext() *VideoContext
func (*AnnotateVideoRequest) ProtoMessage ¶
func (*AnnotateVideoRequest) ProtoMessage()
func (*AnnotateVideoRequest) ProtoReflect ¶
func (x *AnnotateVideoRequest) ProtoReflect() protoreflect.Message
func (*AnnotateVideoRequest) Reset ¶
func (x *AnnotateVideoRequest) Reset()
func (*AnnotateVideoRequest) String ¶
func (x *AnnotateVideoRequest) String() string
type AnnotateVideoResponse ¶
type AnnotateVideoResponse struct {
// Annotation results for all videos specified in `AnnotateVideoRequest`.
AnnotationResults []*VideoAnnotationResults `protobuf:"bytes,1,rep,name=annotation_results,json=annotationResults,proto3" json:"annotation_results,omitempty"`
// contains filtered or unexported fields
}
Video annotation response. Included in the `response` field of the `Operation` returned by the `GetOperation` call of the `google::longrunning::Operations` service.
func (*AnnotateVideoResponse) Descriptor ¶
func (*AnnotateVideoResponse) Descriptor() ([]byte, []int)
Deprecated: Use AnnotateVideoResponse.ProtoReflect.Descriptor instead.
func (*AnnotateVideoResponse) GetAnnotationResults ¶
func (x *AnnotateVideoResponse) GetAnnotationResults() []*VideoAnnotationResults
func (*AnnotateVideoResponse) ProtoMessage ¶
func (*AnnotateVideoResponse) ProtoMessage()
func (*AnnotateVideoResponse) ProtoReflect ¶
func (x *AnnotateVideoResponse) ProtoReflect() protoreflect.Message
func (*AnnotateVideoResponse) Reset ¶
func (x *AnnotateVideoResponse) Reset()
func (*AnnotateVideoResponse) String ¶
func (x *AnnotateVideoResponse) String() string
type Entity ¶
type Entity struct {
// Opaque entity ID. Some IDs may be available in
// [Google Knowledge Graph Search
// API](https://developers.google.com/knowledge-graph/).
EntityId string `protobuf:"bytes,1,opt,name=entity_id,json=entityId,proto3" json:"entity_id,omitempty"`
// Textual description, e.g. `Fixed-gear bicycle`.
Description string `protobuf:"bytes,2,opt,name=description,proto3" json:"description,omitempty"`
// Language code for `description` in BCP-47 format.
LanguageCode string `protobuf:"bytes,3,opt,name=language_code,json=languageCode,proto3" json:"language_code,omitempty"`
// contains filtered or unexported fields
}
Detected entity from video analysis.
func (*Entity) Descriptor ¶
Deprecated: Use Entity.ProtoReflect.Descriptor instead.
func (*Entity) GetDescription ¶
func (*Entity) GetEntityId ¶
func (*Entity) GetLanguageCode ¶
func (*Entity) ProtoMessage ¶
func (*Entity) ProtoMessage()
func (*Entity) ProtoReflect ¶
func (x *Entity) ProtoReflect() protoreflect.Message
func (*Entity) Reset ¶
func (x *Entity) Reset()
func (*Entity) String ¶
type ExplicitContentAnnotation ¶
type ExplicitContentAnnotation struct {
// All video frames where explicit content was detected.
Frames []*ExplicitContentFrame `protobuf:"bytes,1,rep,name=frames,proto3" json:"frames,omitempty"`
// contains filtered or unexported fields
}
Explicit content annotation (based on per-frame visual signals only). If no explicit content has been detected in a frame, no annotations are present for that frame.
func (*ExplicitContentAnnotation) Descriptor ¶
func (*ExplicitContentAnnotation) Descriptor() ([]byte, []int)
Deprecated: Use ExplicitContentAnnotation.ProtoReflect.Descriptor instead.
func (*ExplicitContentAnnotation) GetFrames ¶
func (x *ExplicitContentAnnotation) GetFrames() []*ExplicitContentFrame
func (*ExplicitContentAnnotation) ProtoMessage ¶
func (*ExplicitContentAnnotation) ProtoMessage()
func (*ExplicitContentAnnotation) ProtoReflect ¶
func (x *ExplicitContentAnnotation) ProtoReflect() protoreflect.Message
func (*ExplicitContentAnnotation) Reset ¶
func (x *ExplicitContentAnnotation) Reset()
func (*ExplicitContentAnnotation) String ¶
func (x *ExplicitContentAnnotation) String() string
type ExplicitContentDetectionConfig ¶
type ExplicitContentDetectionConfig struct {
// Model to use for explicit content detection.
// Supported values: "builtin/stable" (the default if unset) and
// "builtin/latest".
Model string `protobuf:"bytes,1,opt,name=model,proto3" json:"model,omitempty"`
// contains filtered or unexported fields
}
Config for EXPLICIT_CONTENT_DETECTION.
func (*ExplicitContentDetectionConfig) Descriptor ¶
func (*ExplicitContentDetectionConfig) Descriptor() ([]byte, []int)
Deprecated: Use ExplicitContentDetectionConfig.ProtoReflect.Descriptor instead.
func (*ExplicitContentDetectionConfig) GetModel ¶
func (x *ExplicitContentDetectionConfig) GetModel() string
func (*ExplicitContentDetectionConfig) ProtoMessage ¶
func (*ExplicitContentDetectionConfig) ProtoMessage()
func (*ExplicitContentDetectionConfig) ProtoReflect ¶
func (x *ExplicitContentDetectionConfig) ProtoReflect() protoreflect.Message
func (*ExplicitContentDetectionConfig) Reset ¶
func (x *ExplicitContentDetectionConfig) Reset()
func (*ExplicitContentDetectionConfig) String ¶
func (x *ExplicitContentDetectionConfig) String() string
type ExplicitContentFrame ¶
type ExplicitContentFrame struct {
// Time-offset, relative to the beginning of the video, corresponding to the
// video frame for this location.
TimeOffset *durationpb.Duration `protobuf:"bytes,1,opt,name=time_offset,json=timeOffset,proto3" json:"time_offset,omitempty"`
// Likelihood of the pornography content..
PornographyLikelihood Likelihood `protobuf:"varint,2,opt,name=pornography_likelihood,json=pornographyLikelihood,proto3,enum=google.cloud.videointelligence.v1p2beta1.Likelihood" json:"pornography_likelihood,omitempty"`
// contains filtered or unexported fields
}
Video frame level annotation results for explicit content.
func (*ExplicitContentFrame) Descriptor ¶
func (*ExplicitContentFrame) Descriptor() ([]byte, []int)
Deprecated: Use ExplicitContentFrame.ProtoReflect.Descriptor instead.
func (*ExplicitContentFrame) GetPornographyLikelihood ¶
func (x *ExplicitContentFrame) GetPornographyLikelihood() Likelihood
func (*ExplicitContentFrame) GetTimeOffset ¶
func (x *ExplicitContentFrame) GetTimeOffset() *durationpb.Duration
func (*ExplicitContentFrame) ProtoMessage ¶
func (*ExplicitContentFrame) ProtoMessage()
func (*ExplicitContentFrame) ProtoReflect ¶
func (x *ExplicitContentFrame) ProtoReflect() protoreflect.Message
func (*ExplicitContentFrame) Reset ¶
func (x *ExplicitContentFrame) Reset()
func (*ExplicitContentFrame) String ¶
func (x *ExplicitContentFrame) String() string
type Feature ¶
type Feature int32
Video annotation feature.
const ( // Unspecified. Feature_FEATURE_UNSPECIFIED Feature = 0 // Label detection. Detect objects, such as dog or flower. Feature_LABEL_DETECTION Feature = 1 // Shot change detection. Feature_SHOT_CHANGE_DETECTION Feature = 2 // Explicit content detection. Feature_EXPLICIT_CONTENT_DETECTION Feature = 3 // OCR text detection and tracking. Feature_TEXT_DETECTION Feature = 7 // Object detection and tracking. Feature_OBJECT_TRACKING Feature = 9 )
func (Feature) Descriptor ¶
func (Feature) Descriptor() protoreflect.EnumDescriptor
func (Feature) Enum ¶
func (Feature) EnumDescriptor ¶
Deprecated: Use Feature.Descriptor instead.
func (Feature) Number ¶
func (x Feature) Number() protoreflect.EnumNumber
func (Feature) String ¶
func (Feature) Type ¶
func (Feature) Type() protoreflect.EnumType
type LabelAnnotation ¶
type LabelAnnotation struct {
// Detected entity.
Entity *Entity `protobuf:"bytes,1,opt,name=entity,proto3" json:"entity,omitempty"`
// Common categories for the detected entity.
// E.g. when the label is `Terrier` the category is likely `dog`. And in some
// cases there might be more than one categories e.g. `Terrier` could also be
// a `pet`.
CategoryEntities []*Entity `protobuf:"bytes,2,rep,name=category_entities,json=categoryEntities,proto3" json:"category_entities,omitempty"`
// All video segments where a label was detected.
Segments []*LabelSegment `protobuf:"bytes,3,rep,name=segments,proto3" json:"segments,omitempty"`
// All video frames where a label was detected.
Frames []*LabelFrame `protobuf:"bytes,4,rep,name=frames,proto3" json:"frames,omitempty"`
// contains filtered or unexported fields
}
Label annotation.
func (*LabelAnnotation) Descriptor ¶
func (*LabelAnnotation) Descriptor() ([]byte, []int)
Deprecated: Use LabelAnnotation.ProtoReflect.Descriptor instead.
func (*LabelAnnotation) GetCategoryEntities ¶
func (x *LabelAnnotation) GetCategoryEntities() []*Entity
func (*LabelAnnotation) GetEntity ¶
func (x *LabelAnnotation) GetEntity() *Entity
func (*LabelAnnotation) GetFrames ¶
func (x *LabelAnnotation) GetFrames() []*LabelFrame
func (*LabelAnnotation) GetSegments ¶
func (x *LabelAnnotation) GetSegments() []*LabelSegment
func (*LabelAnnotation) ProtoMessage ¶
func (*LabelAnnotation) ProtoMessage()
func (*LabelAnnotation) ProtoReflect ¶
func (x *LabelAnnotation) ProtoReflect() protoreflect.Message
func (*LabelAnnotation) Reset ¶
func (x *LabelAnnotation) Reset()
func (*LabelAnnotation) String ¶
func (x *LabelAnnotation) String() string
type LabelDetectionConfig ¶
type LabelDetectionConfig struct {
// What labels should be detected with LABEL_DETECTION, in addition to
// video-level labels or segment-level labels.
// If unspecified, defaults to `SHOT_MODE`.
LabelDetectionMode LabelDetectionMode `protobuf:"varint,1,opt,name=label_detection_mode,json=labelDetectionMode,proto3,enum=google.cloud.videointelligence.v1p2beta1.LabelDetectionMode" json:"label_detection_mode,omitempty"`
// Whether the video has been shot from a stationary (i.e. non-moving) camera.
// When set to true, might improve detection accuracy for moving objects.
// Should be used with `SHOT_AND_FRAME_MODE` enabled.
StationaryCamera bool `protobuf:"varint,2,opt,name=stationary_camera,json=stationaryCamera,proto3" json:"stationary_camera,omitempty"`
// Model to use for label detection.
// Supported values: "builtin/stable" (the default if unset) and
// "builtin/latest".
Model string `protobuf:"bytes,3,opt,name=model,proto3" json:"model,omitempty"`
// contains filtered or unexported fields
}
Config for LABEL_DETECTION.
func (*LabelDetectionConfig) Descriptor ¶
func (*LabelDetectionConfig) Descriptor() ([]byte, []int)
Deprecated: Use LabelDetectionConfig.ProtoReflect.Descriptor instead.
func (*LabelDetectionConfig) GetLabelDetectionMode ¶
func (x *LabelDetectionConfig) GetLabelDetectionMode() LabelDetectionMode
func (*LabelDetectionConfig) GetModel ¶
func (x *LabelDetectionConfig) GetModel() string
func (*LabelDetectionConfig) GetStationaryCamera ¶
func (x *LabelDetectionConfig) GetStationaryCamera() bool
func (*LabelDetectionConfig) ProtoMessage ¶
func (*LabelDetectionConfig) ProtoMessage()
func (*LabelDetectionConfig) ProtoReflect ¶
func (x *LabelDetectionConfig) ProtoReflect() protoreflect.Message
func (*LabelDetectionConfig) Reset ¶
func (x *LabelDetectionConfig) Reset()
func (*LabelDetectionConfig) String ¶
func (x *LabelDetectionConfig) String() string
type LabelDetectionMode ¶
type LabelDetectionMode int32
Label detection mode.
const ( // Unspecified. LabelDetectionMode_LABEL_DETECTION_MODE_UNSPECIFIED LabelDetectionMode = 0 // Detect shot-level labels. LabelDetectionMode_SHOT_MODE LabelDetectionMode = 1 // Detect frame-level labels. LabelDetectionMode_FRAME_MODE LabelDetectionMode = 2 // Detect both shot-level and frame-level labels. LabelDetectionMode_SHOT_AND_FRAME_MODE LabelDetectionMode = 3 )
func (LabelDetectionMode) Descriptor ¶
func (LabelDetectionMode) Descriptor() protoreflect.EnumDescriptor
func (LabelDetectionMode) Enum ¶
func (x LabelDetectionMode) Enum() *LabelDetectionMode
func (LabelDetectionMode) EnumDescriptor ¶
func (LabelDetectionMode) EnumDescriptor() ([]byte, []int)
Deprecated: Use LabelDetectionMode.Descriptor instead.
func (LabelDetectionMode) Number ¶
func (x LabelDetectionMode) Number() protoreflect.EnumNumber
func (LabelDetectionMode) String ¶
func (x LabelDetectionMode) String() string
func (LabelDetectionMode) Type ¶
func (LabelDetectionMode) Type() protoreflect.EnumType
type LabelFrame ¶
type LabelFrame struct {
// Time-offset, relative to the beginning of the video, corresponding to the
// video frame for this location.
TimeOffset *durationpb.Duration `protobuf:"bytes,1,opt,name=time_offset,json=timeOffset,proto3" json:"time_offset,omitempty"`
// Confidence that the label is accurate. Range: [0, 1].
Confidence float32 `protobuf:"fixed32,2,opt,name=confidence,proto3" json:"confidence,omitempty"`
// contains filtered or unexported fields
}
Video frame level annotation results for label detection.
func (*LabelFrame) Descriptor ¶
func (*LabelFrame) Descriptor() ([]byte, []int)
Deprecated: Use LabelFrame.ProtoReflect.Descriptor instead.
func (*LabelFrame) GetConfidence ¶
func (x *LabelFrame) GetConfidence() float32
func (*LabelFrame) GetTimeOffset ¶
func (x *LabelFrame) GetTimeOffset() *durationpb.Duration
func (*LabelFrame) ProtoMessage ¶
func (*LabelFrame) ProtoMessage()
func (*LabelFrame) ProtoReflect ¶
func (x *LabelFrame) ProtoReflect() protoreflect.Message
func (*LabelFrame) Reset ¶
func (x *LabelFrame) Reset()
func (*LabelFrame) String ¶
func (x *LabelFrame) String() string
type LabelSegment ¶
type LabelSegment struct {
// Video segment where a label was detected.
Segment *VideoSegment `protobuf:"bytes,1,opt,name=segment,proto3" json:"segment,omitempty"`
// Confidence that the label is accurate. Range: [0, 1].
Confidence float32 `protobuf:"fixed32,2,opt,name=confidence,proto3" json:"confidence,omitempty"`
// contains filtered or unexported fields
}
Video segment level annotation results for label detection.
func (*LabelSegment) Descriptor ¶
func (*LabelSegment) Descriptor() ([]byte, []int)
Deprecated: Use LabelSegment.ProtoReflect.Descriptor instead.
func (*LabelSegment) GetConfidence ¶
func (x *LabelSegment) GetConfidence() float32
func (*LabelSegment) GetSegment ¶
func (x *LabelSegment) GetSegment() *VideoSegment
func (*LabelSegment) ProtoMessage ¶
func (*LabelSegment) ProtoMessage()
func (*LabelSegment) ProtoReflect ¶
func (x *LabelSegment) ProtoReflect() protoreflect.Message
func (*LabelSegment) Reset ¶
func (x *LabelSegment) Reset()
func (*LabelSegment) String ¶
func (x *LabelSegment) String() string
type Likelihood ¶
type Likelihood int32
Bucketized representation of likelihood.
const ( // Unspecified likelihood. Likelihood_LIKELIHOOD_UNSPECIFIED Likelihood = 0 // Very unlikely. Likelihood_VERY_UNLIKELY Likelihood = 1 // Unlikely. Likelihood_UNLIKELY Likelihood = 2 // Possible. Likelihood_POSSIBLE Likelihood = 3 // Likely. Likelihood_LIKELY Likelihood = 4 // Very likely. Likelihood_VERY_LIKELY Likelihood = 5 )
func (Likelihood) Descriptor ¶
func (Likelihood) Descriptor() protoreflect.EnumDescriptor
func (Likelihood) Enum ¶
func (x Likelihood) Enum() *Likelihood
func (Likelihood) EnumDescriptor ¶
func (Likelihood) EnumDescriptor() ([]byte, []int)
Deprecated: Use Likelihood.Descriptor instead.
func (Likelihood) Number ¶
func (x Likelihood) Number() protoreflect.EnumNumber
func (Likelihood) String ¶
func (x Likelihood) String() string
func (Likelihood) Type ¶
func (Likelihood) Type() protoreflect.EnumType
type NormalizedBoundingBox ¶
type NormalizedBoundingBox struct {
// Left X coordinate.
Left float32 `protobuf:"fixed32,1,opt,name=left,proto3" json:"left,omitempty"`
// Top Y coordinate.
Top float32 `protobuf:"fixed32,2,opt,name=top,proto3" json:"top,omitempty"`
// Right X coordinate.
Right float32 `protobuf:"fixed32,3,opt,name=right,proto3" json:"right,omitempty"`
// Bottom Y coordinate.
Bottom float32 `protobuf:"fixed32,4,opt,name=bottom,proto3" json:"bottom,omitempty"`
// contains filtered or unexported fields
}
Normalized bounding box. The normalized vertex coordinates are relative to the original image. Range: [0, 1].
func (*NormalizedBoundingBox) Descriptor ¶
func (*NormalizedBoundingBox) Descriptor() ([]byte, []int)
Deprecated: Use NormalizedBoundingBox.ProtoReflect.Descriptor instead.
func (*NormalizedBoundingBox) GetBottom ¶
func (x *NormalizedBoundingBox) GetBottom() float32
func (*NormalizedBoundingBox) GetLeft ¶
func (x *NormalizedBoundingBox) GetLeft() float32
func (*NormalizedBoundingBox) GetRight ¶
func (x *NormalizedBoundingBox) GetRight() float32
func (*NormalizedBoundingBox) GetTop ¶
func (x *NormalizedBoundingBox) GetTop() float32
func (*NormalizedBoundingBox) ProtoMessage ¶
func (*NormalizedBoundingBox) ProtoMessage()
func (*NormalizedBoundingBox) ProtoReflect ¶
func (x *NormalizedBoundingBox) ProtoReflect() protoreflect.Message
func (*NormalizedBoundingBox) Reset ¶
func (x *NormalizedBoundingBox) Reset()
func (*NormalizedBoundingBox) String ¶
func (x *NormalizedBoundingBox) String() string
type NormalizedBoundingPoly ¶
type NormalizedBoundingPoly struct {
// Normalized vertices of the bounding polygon.
Vertices []*NormalizedVertex `protobuf:"bytes,1,rep,name=vertices,proto3" json:"vertices,omitempty"`
// contains filtered or unexported fields
}
Normalized bounding polygon for text (that might not be aligned with axis). Contains list of the corner points in clockwise order starting from top-left corner. For example, for a rectangular bounding box: When the text is horizontal it might look like:
0----1 | | 3----2
When it's clockwise rotated 180 degrees around the top-left corner it becomes:
2----3 | | 1----0
and the vertex order will still be (0, 1, 2, 3). Note that values can be less than 0, or greater than 1 due to trignometric calculations for location of the box.
func (*NormalizedBoundingPoly) Descriptor ¶
func (*NormalizedBoundingPoly) Descriptor() ([]byte, []int)
Deprecated: Use NormalizedBoundingPoly.ProtoReflect.Descriptor instead.
func (*NormalizedBoundingPoly) GetVertices ¶
func (x *NormalizedBoundingPoly) GetVertices() []*NormalizedVertex
func (*NormalizedBoundingPoly) ProtoMessage ¶
func (*NormalizedBoundingPoly) ProtoMessage()
func (*NormalizedBoundingPoly) ProtoReflect ¶
func (x *NormalizedBoundingPoly) ProtoReflect() protoreflect.Message
func (*NormalizedBoundingPoly) Reset ¶
func (x *NormalizedBoundingPoly) Reset()
func (*NormalizedBoundingPoly) String ¶
func (x *NormalizedBoundingPoly) String() string
type NormalizedVertex ¶
type NormalizedVertex struct {
// X coordinate.
X float32 `protobuf:"fixed32,1,opt,name=x,proto3" json:"x,omitempty"`
// Y coordinate.
Y float32 `protobuf:"fixed32,2,opt,name=y,proto3" json:"y,omitempty"`
// contains filtered or unexported fields
}
A vertex represents a 2D point in the image. NOTE: the normalized vertex coordinates are relative to the original image and range from 0 to 1.
func (*NormalizedVertex) Descriptor ¶
func (*NormalizedVertex) Descriptor() ([]byte, []int)
Deprecated: Use NormalizedVertex.ProtoReflect.Descriptor instead.
func (*NormalizedVertex) GetX ¶
func (x *NormalizedVertex) GetX() float32
func (*NormalizedVertex) GetY ¶
func (x *NormalizedVertex) GetY() float32
func (*NormalizedVertex) ProtoMessage ¶
func (*NormalizedVertex) ProtoMessage()
func (*NormalizedVertex) ProtoReflect ¶
func (x *NormalizedVertex) ProtoReflect() protoreflect.Message
func (*NormalizedVertex) Reset ¶
func (x *NormalizedVertex) Reset()
func (*NormalizedVertex) String ¶
func (x *NormalizedVertex) String() string
type ObjectTrackingAnnotation ¶
type ObjectTrackingAnnotation struct {
// Different representation of tracking info in non-streaming batch
// and streaming modes.
//
// Types that are assignable to TrackInfo:
// *ObjectTrackingAnnotation_Segment
// *ObjectTrackingAnnotation_TrackId
TrackInfo isObjectTrackingAnnotation_TrackInfo `protobuf_oneof:"track_info"`
// Entity to specify the object category that this track is labeled as.
Entity *Entity `protobuf:"bytes,1,opt,name=entity,proto3" json:"entity,omitempty"`
// Object category's labeling confidence of this track.
Confidence float32 `protobuf:"fixed32,4,opt,name=confidence,proto3" json:"confidence,omitempty"`
// Information corresponding to all frames where this object track appears.
Frames []*ObjectTrackingFrame `protobuf:"bytes,2,rep,name=frames,proto3" json:"frames,omitempty"`
// contains filtered or unexported fields
}
Annotations corresponding to one tracked object.
func (*ObjectTrackingAnnotation) Descriptor ¶
func (*ObjectTrackingAnnotation) Descriptor() ([]byte, []int)
Deprecated: Use ObjectTrackingAnnotation.ProtoReflect.Descriptor instead.
func (*ObjectTrackingAnnotation) GetConfidence ¶
func (x *ObjectTrackingAnnotation) GetConfidence() float32
func (*ObjectTrackingAnnotation) GetEntity ¶
func (x *ObjectTrackingAnnotation) GetEntity() *Entity
func (*ObjectTrackingAnnotation) GetFrames ¶
func (x *ObjectTrackingAnnotation) GetFrames() []*ObjectTrackingFrame
func (*ObjectTrackingAnnotation) GetSegment ¶
func (x *ObjectTrackingAnnotation) GetSegment() *VideoSegment
func (*ObjectTrackingAnnotation) GetTrackId ¶
func (x *ObjectTrackingAnnotation) GetTrackId() int64
func (*ObjectTrackingAnnotation) GetTrackInfo ¶
func (m *ObjectTrackingAnnotation) GetTrackInfo() isObjectTrackingAnnotation_TrackInfo
func (*ObjectTrackingAnnotation) ProtoMessage ¶
func (*ObjectTrackingAnnotation) ProtoMessage()
func (*ObjectTrackingAnnotation) ProtoReflect ¶
func (x *ObjectTrackingAnnotation) ProtoReflect() protoreflect.Message
func (*ObjectTrackingAnnotation) Reset ¶
func (x *ObjectTrackingAnnotation) Reset()
func (*ObjectTrackingAnnotation) String ¶
func (x *ObjectTrackingAnnotation) String() string
type ObjectTrackingAnnotation_Segment ¶
type ObjectTrackingAnnotation_Segment struct {
// Non-streaming batch mode ONLY.
// Each object track corresponds to one video segment where it appears.
Segment *VideoSegment `protobuf:"bytes,3,opt,name=segment,proto3,oneof"`
}
type ObjectTrackingAnnotation_TrackId ¶
type ObjectTrackingAnnotation_TrackId struct {
// Streaming mode ONLY.
// In streaming mode, we do not know the end time of a tracked object
// before it is completed. Hence, there is no VideoSegment info returned.
// Instead, we provide a unique identifiable integer track_id so that
// the customers can correlate the results of the ongoing
// ObjectTrackAnnotation of the same track_id over time.
TrackId int64 `protobuf:"varint,5,opt,name=track_id,json=trackId,proto3,oneof"`
}
type ObjectTrackingFrame ¶
type ObjectTrackingFrame struct {
// The normalized bounding box location of this object track for the frame.
NormalizedBoundingBox *NormalizedBoundingBox `protobuf:"bytes,1,opt,name=normalized_bounding_box,json=normalizedBoundingBox,proto3" json:"normalized_bounding_box,omitempty"`
// The timestamp of the frame in microseconds.
TimeOffset *durationpb.Duration `protobuf:"bytes,2,opt,name=time_offset,json=timeOffset,proto3" json:"time_offset,omitempty"`
// contains filtered or unexported fields
}
Video frame level annotations for object detection and tracking. This field stores per frame location, time offset, and confidence.
func (*ObjectTrackingFrame) Descriptor ¶
func (*ObjectTrackingFrame) Descriptor() ([]byte, []int)
Deprecated: Use ObjectTrackingFrame.ProtoReflect.Descriptor instead.
func (*ObjectTrackingFrame) GetNormalizedBoundingBox ¶
func (x *ObjectTrackingFrame) GetNormalizedBoundingBox() *NormalizedBoundingBox
func (*ObjectTrackingFrame) GetTimeOffset ¶
func (x *ObjectTrackingFrame) GetTimeOffset() *durationpb.Duration
func (*ObjectTrackingFrame) ProtoMessage ¶
func (*ObjectTrackingFrame) ProtoMessage()
func (*ObjectTrackingFrame) ProtoReflect ¶
func (x *ObjectTrackingFrame) ProtoReflect() protoreflect.Message
func (*ObjectTrackingFrame) Reset ¶
func (x *ObjectTrackingFrame) Reset()
func (*ObjectTrackingFrame) String ¶
func (x *ObjectTrackingFrame) String() string
type ShotChangeDetectionConfig ¶
type ShotChangeDetectionConfig struct {
// Model to use for shot change detection.
// Supported values: "builtin/stable" (the default if unset) and
// "builtin/latest".
Model string `protobuf:"bytes,1,opt,name=model,proto3" json:"model,omitempty"`
// contains filtered or unexported fields
}
Config for SHOT_CHANGE_DETECTION.
func (*ShotChangeDetectionConfig) Descriptor ¶
func (*ShotChangeDetectionConfig) Descriptor() ([]byte, []int)
Deprecated: Use ShotChangeDetectionConfig.ProtoReflect.Descriptor instead.
func (*ShotChangeDetectionConfig) GetModel ¶
func (x *ShotChangeDetectionConfig) GetModel() string
func (*ShotChangeDetectionConfig) ProtoMessage ¶
func (*ShotChangeDetectionConfig) ProtoMessage()
func (*ShotChangeDetectionConfig) ProtoReflect ¶
func (x *ShotChangeDetectionConfig) ProtoReflect() protoreflect.Message
func (*ShotChangeDetectionConfig) Reset ¶
func (x *ShotChangeDetectionConfig) Reset()
func (*ShotChangeDetectionConfig) String ¶
func (x *ShotChangeDetectionConfig) String() string
type TextAnnotation ¶
type TextAnnotation struct {
// The detected text.
Text string `protobuf:"bytes,1,opt,name=text,proto3" json:"text,omitempty"`
// All video segments where OCR detected text appears.
Segments []*TextSegment `protobuf:"bytes,2,rep,name=segments,proto3" json:"segments,omitempty"`
// contains filtered or unexported fields
}
Annotations related to one detected OCR text snippet. This will contain the corresponding text, confidence value, and frame level information for each detection.
func (*TextAnnotation) Descriptor ¶
func (*TextAnnotation) Descriptor() ([]byte, []int)
Deprecated: Use TextAnnotation.ProtoReflect.Descriptor instead.
func (*TextAnnotation) GetSegments ¶
func (x *TextAnnotation) GetSegments() []*TextSegment
func (*TextAnnotation) GetText ¶
func (x *TextAnnotation) GetText() string
func (*TextAnnotation) ProtoMessage ¶
func (*TextAnnotation) ProtoMessage()
func (*TextAnnotation) ProtoReflect ¶
func (x *TextAnnotation) ProtoReflect() protoreflect.Message
func (*TextAnnotation) Reset ¶
func (x *TextAnnotation) Reset()
func (*TextAnnotation) String ¶
func (x *TextAnnotation) String() string
type TextDetectionConfig ¶
type TextDetectionConfig struct {
// Language hint can be specified if the language to be detected is known a
// priori. It can increase the accuracy of the detection. Language hint must
// be language code in BCP-47 format.
//
// Automatic language detection is performed if no hint is provided.
LanguageHints []string `protobuf:"bytes,1,rep,name=language_hints,json=languageHints,proto3" json:"language_hints,omitempty"`
// contains filtered or unexported fields
}
Config for TEXT_DETECTION.
func (*TextDetectionConfig) Descriptor ¶
func (*TextDetectionConfig) Descriptor() ([]byte, []int)
Deprecated: Use TextDetectionConfig.ProtoReflect.Descriptor instead.
func (*TextDetectionConfig) GetLanguageHints ¶
func (x *TextDetectionConfig) GetLanguageHints() []string
func (*TextDetectionConfig) ProtoMessage ¶
func (*TextDetectionConfig) ProtoMessage()
func (*TextDetectionConfig) ProtoReflect ¶
func (x *TextDetectionConfig) ProtoReflect() protoreflect.Message
func (*TextDetectionConfig) Reset ¶
func (x *TextDetectionConfig) Reset()
func (*TextDetectionConfig) String ¶
func (x *TextDetectionConfig) String() string
type TextFrame ¶
type TextFrame struct {
// Bounding polygon of the detected text for this frame.
RotatedBoundingBox *NormalizedBoundingPoly `protobuf:"bytes,1,opt,name=rotated_bounding_box,json=rotatedBoundingBox,proto3" json:"rotated_bounding_box,omitempty"`
// Timestamp of this frame.
TimeOffset *durationpb.Duration `protobuf:"bytes,2,opt,name=time_offset,json=timeOffset,proto3" json:"time_offset,omitempty"`
// contains filtered or unexported fields
}
Video frame level annotation results for text annotation (OCR). Contains information regarding timestamp and bounding box locations for the frames containing detected OCR text snippets.
func (*TextFrame) Descriptor ¶
Deprecated: Use TextFrame.ProtoReflect.Descriptor instead.
func (*TextFrame) GetRotatedBoundingBox ¶
func (x *TextFrame) GetRotatedBoundingBox() *NormalizedBoundingPoly
func (*TextFrame) GetTimeOffset ¶
func (x *TextFrame) GetTimeOffset() *durationpb.Duration
func (*TextFrame) ProtoMessage ¶
func (*TextFrame) ProtoMessage()
func (*TextFrame) ProtoReflect ¶
func (x *TextFrame) ProtoReflect() protoreflect.Message
func (*TextFrame) Reset ¶
func (x *TextFrame) Reset()
func (*TextFrame) String ¶
type TextSegment ¶
type TextSegment struct {
// Video segment where a text snippet was detected.
Segment *VideoSegment `protobuf:"bytes,1,opt,name=segment,proto3" json:"segment,omitempty"`
// Confidence for the track of detected text. It is calculated as the highest
// over all frames where OCR detected text appears.
Confidence float32 `protobuf:"fixed32,2,opt,name=confidence,proto3" json:"confidence,omitempty"`
// Information related to the frames where OCR detected text appears.
Frames []*TextFrame `protobuf:"bytes,3,rep,name=frames,proto3" json:"frames,omitempty"`
// contains filtered or unexported fields
}
Video segment level annotation results for text detection.
func (*TextSegment) Descriptor ¶
func (*TextSegment) Descriptor() ([]byte, []int)
Deprecated: Use TextSegment.ProtoReflect.Descriptor instead.
func (*TextSegment) GetConfidence ¶
func (x *TextSegment) GetConfidence() float32
func (*TextSegment) GetFrames ¶
func (x *TextSegment) GetFrames() []*TextFrame
func (*TextSegment) GetSegment ¶
func (x *TextSegment) GetSegment() *VideoSegment
func (*TextSegment) ProtoMessage ¶
func (*TextSegment) ProtoMessage()
func (*TextSegment) ProtoReflect ¶
func (x *TextSegment) ProtoReflect() protoreflect.Message
func (*TextSegment) Reset ¶
func (x *TextSegment) Reset()
func (*TextSegment) String ¶
func (x *TextSegment) String() string
type UnimplementedVideoIntelligenceServiceServer ¶
type UnimplementedVideoIntelligenceServiceServer struct {
}
UnimplementedVideoIntelligenceServiceServer can be embedded to have forward compatible implementations.
func (*UnimplementedVideoIntelligenceServiceServer) AnnotateVideo ¶
func (*UnimplementedVideoIntelligenceServiceServer) AnnotateVideo(context.Context, *AnnotateVideoRequest) (*longrunning.Operation, error)
type VideoAnnotationProgress ¶
type VideoAnnotationProgress struct {
// Video file location in
// [Google Cloud Storage](https://cloud.google.com/storage/).
InputUri string `protobuf:"bytes,1,opt,name=input_uri,json=inputUri,proto3" json:"input_uri,omitempty"`
// Approximate percentage processed thus far. Guaranteed to be
// 100 when fully processed.
ProgressPercent int32 `protobuf:"varint,2,opt,name=progress_percent,json=progressPercent,proto3" json:"progress_percent,omitempty"`
// Time when the request was received.
StartTime *timestamppb.Timestamp `protobuf:"bytes,3,opt,name=start_time,json=startTime,proto3" json:"start_time,omitempty"`
// Time of the most recent update.
UpdateTime *timestamppb.Timestamp `protobuf:"bytes,4,opt,name=update_time,json=updateTime,proto3" json:"update_time,omitempty"`
// contains filtered or unexported fields
}
Annotation progress for a single video.
func (*VideoAnnotationProgress) Descriptor ¶
func (*VideoAnnotationProgress) Descriptor() ([]byte, []int)
Deprecated: Use VideoAnnotationProgress.ProtoReflect.Descriptor instead.
func (*VideoAnnotationProgress) GetInputUri ¶
func (x *VideoAnnotationProgress) GetInputUri() string
func (*VideoAnnotationProgress) GetProgressPercent ¶
func (x *VideoAnnotationProgress) GetProgressPercent() int32
func (*VideoAnnotationProgress) GetStartTime ¶
func (x *VideoAnnotationProgress) GetStartTime() *timestamppb.Timestamp
func (*VideoAnnotationProgress) GetUpdateTime ¶
func (x *VideoAnnotationProgress) GetUpdateTime() *timestamppb.Timestamp
func (*VideoAnnotationProgress) ProtoMessage ¶
func (*VideoAnnotationProgress) ProtoMessage()
func (*VideoAnnotationProgress) ProtoReflect ¶
func (x *VideoAnnotationProgress) ProtoReflect() protoreflect.Message
func (*VideoAnnotationProgress) Reset ¶
func (x *VideoAnnotationProgress) Reset()
func (*VideoAnnotationProgress) String ¶
func (x *VideoAnnotationProgress) String() string
type VideoAnnotationResults ¶
type VideoAnnotationResults struct {
// Video file location in
// [Google Cloud Storage](https://cloud.google.com/storage/).
InputUri string `protobuf:"bytes,1,opt,name=input_uri,json=inputUri,proto3" json:"input_uri,omitempty"`
// Label annotations on video level or user specified segment level.
// There is exactly one element for each unique label.
SegmentLabelAnnotations []*LabelAnnotation `protobuf:"bytes,2,rep,name=segment_label_annotations,json=segmentLabelAnnotations,proto3" json:"segment_label_annotations,omitempty"`
// Label annotations on shot level.
// There is exactly one element for each unique label.
ShotLabelAnnotations []*LabelAnnotation `protobuf:"bytes,3,rep,name=shot_label_annotations,json=shotLabelAnnotations,proto3" json:"shot_label_annotations,omitempty"`
// Label annotations on frame level.
// There is exactly one element for each unique label.
FrameLabelAnnotations []*LabelAnnotation `protobuf:"bytes,4,rep,name=frame_label_annotations,json=frameLabelAnnotations,proto3" json:"frame_label_annotations,omitempty"`
// Shot annotations. Each shot is represented as a video segment.
ShotAnnotations []*VideoSegment `protobuf:"bytes,6,rep,name=shot_annotations,json=shotAnnotations,proto3" json:"shot_annotations,omitempty"`
// Explicit content annotation.
ExplicitAnnotation *ExplicitContentAnnotation `protobuf:"bytes,7,opt,name=explicit_annotation,json=explicitAnnotation,proto3" json:"explicit_annotation,omitempty"`
// OCR text detection and tracking.
// Annotations for list of detected text snippets. Each will have list of
// frame information associated with it.
TextAnnotations []*TextAnnotation `protobuf:"bytes,12,rep,name=text_annotations,json=textAnnotations,proto3" json:"text_annotations,omitempty"`
// Annotations for list of objects detected and tracked in video.
ObjectAnnotations []*ObjectTrackingAnnotation `protobuf:"bytes,14,rep,name=object_annotations,json=objectAnnotations,proto3" json:"object_annotations,omitempty"`
// If set, indicates an error. Note that for a single `AnnotateVideoRequest`
// some videos may succeed and some may fail.
Error *status.Status `protobuf:"bytes,9,opt,name=error,proto3" json:"error,omitempty"`
// contains filtered or unexported fields
}
Annotation results for a single video.
func (*VideoAnnotationResults) Descriptor ¶
func (*VideoAnnotationResults) Descriptor() ([]byte, []int)
Deprecated: Use VideoAnnotationResults.ProtoReflect.Descriptor instead.
func (*VideoAnnotationResults) GetError ¶
func (x *VideoAnnotationResults) GetError() *status.Status
func (*VideoAnnotationResults) GetExplicitAnnotation ¶
func (x *VideoAnnotationResults) GetExplicitAnnotation() *ExplicitContentAnnotation
func (*VideoAnnotationResults) GetFrameLabelAnnotations ¶
func (x *VideoAnnotationResults) GetFrameLabelAnnotations() []*LabelAnnotation
func (*VideoAnnotationResults) GetInputUri ¶
func (x *VideoAnnotationResults) GetInputUri() string
func (*VideoAnnotationResults) GetObjectAnnotations ¶
func (x *VideoAnnotationResults) GetObjectAnnotations() []*ObjectTrackingAnnotation
func (*VideoAnnotationResults) GetSegmentLabelAnnotations ¶
func (x *VideoAnnotationResults) GetSegmentLabelAnnotations() []*LabelAnnotation
func (*VideoAnnotationResults) GetShotAnnotations ¶
func (x *VideoAnnotationResults) GetShotAnnotations() []*VideoSegment
func (*VideoAnnotationResults) GetShotLabelAnnotations ¶
func (x *VideoAnnotationResults) GetShotLabelAnnotations() []*LabelAnnotation
func (*VideoAnnotationResults) GetTextAnnotations ¶
func (x *VideoAnnotationResults) GetTextAnnotations() []*TextAnnotation
func (*VideoAnnotationResults) ProtoMessage ¶
func (*VideoAnnotationResults) ProtoMessage()
func (*VideoAnnotationResults) ProtoReflect ¶
func (x *VideoAnnotationResults) ProtoReflect() protoreflect.Message
func (*VideoAnnotationResults) Reset ¶
func (x *VideoAnnotationResults) Reset()
func (*VideoAnnotationResults) String ¶
func (x *VideoAnnotationResults) String() string
type VideoContext ¶
type VideoContext struct {
// Video segments to annotate. The segments may overlap and are not required
// to be contiguous or span the whole video. If unspecified, each video is
// treated as a single segment.
Segments []*VideoSegment `protobuf:"bytes,1,rep,name=segments,proto3" json:"segments,omitempty"`
// Config for LABEL_DETECTION.
LabelDetectionConfig *LabelDetectionConfig `protobuf:"bytes,2,opt,name=label_detection_config,json=labelDetectionConfig,proto3" json:"label_detection_config,omitempty"`
// Config for SHOT_CHANGE_DETECTION.
ShotChangeDetectionConfig *ShotChangeDetectionConfig `protobuf:"bytes,3,opt,name=shot_change_detection_config,json=shotChangeDetectionConfig,proto3" json:"shot_change_detection_config,omitempty"`
// Config for EXPLICIT_CONTENT_DETECTION.
ExplicitContentDetectionConfig *ExplicitContentDetectionConfig `protobuf:"bytes,4,opt,name=explicit_content_detection_config,json=explicitContentDetectionConfig,proto3" json:"explicit_content_detection_config,omitempty"`
// Config for TEXT_DETECTION.
TextDetectionConfig *TextDetectionConfig `protobuf:"bytes,8,opt,name=text_detection_config,json=textDetectionConfig,proto3" json:"text_detection_config,omitempty"`
// contains filtered or unexported fields
}
Video context and/or feature-specific parameters.
func (*VideoContext) Descriptor ¶
func (*VideoContext) Descriptor() ([]byte, []int)
Deprecated: Use VideoContext.ProtoReflect.Descriptor instead.
func (*VideoContext) GetExplicitContentDetectionConfig ¶
func (x *VideoContext) GetExplicitContentDetectionConfig() *ExplicitContentDetectionConfig
func (*VideoContext) GetLabelDetectionConfig ¶
func (x *VideoContext) GetLabelDetectionConfig() *LabelDetectionConfig
func (*VideoContext) GetSegments ¶
func (x *VideoContext) GetSegments() []*VideoSegment
func (*VideoContext) GetShotChangeDetectionConfig ¶
func (x *VideoContext) GetShotChangeDetectionConfig() *ShotChangeDetectionConfig
func (*VideoContext) GetTextDetectionConfig ¶
func (x *VideoContext) GetTextDetectionConfig() *TextDetectionConfig
func (*VideoContext) ProtoMessage ¶
func (*VideoContext) ProtoMessage()
func (*VideoContext) ProtoReflect ¶
func (x *VideoContext) ProtoReflect() protoreflect.Message
func (*VideoContext) Reset ¶
func (x *VideoContext) Reset()
func (*VideoContext) String ¶
func (x *VideoContext) String() string
type VideoIntelligenceServiceClient ¶
type VideoIntelligenceServiceClient interface {
// Performs asynchronous video annotation. Progress and results can be
// retrieved through the `google.longrunning.Operations` interface.
// `Operation.metadata` contains `AnnotateVideoProgress` (progress).
// `Operation.response` contains `AnnotateVideoResponse` (results).
AnnotateVideo(ctx context.Context, in *AnnotateVideoRequest, opts ...grpc.CallOption) (*longrunning.Operation, error)
}
VideoIntelligenceServiceClient is the client API for VideoIntelligenceService service.
For semantics around ctx use and closing/ending streaming RPCs, please refer to https://godoc.org/google.golang.org/grpc#ClientConn.NewStream.
func NewVideoIntelligenceServiceClient ¶
func NewVideoIntelligenceServiceClient(cc grpc.ClientConnInterface) VideoIntelligenceServiceClient
type VideoIntelligenceServiceServer ¶
type VideoIntelligenceServiceServer interface {
// Performs asynchronous video annotation. Progress and results can be
// retrieved through the `google.longrunning.Operations` interface.
// `Operation.metadata` contains `AnnotateVideoProgress` (progress).
// `Operation.response` contains `AnnotateVideoResponse` (results).
AnnotateVideo(context.Context, *AnnotateVideoRequest) (*longrunning.Operation, error)
}
VideoIntelligenceServiceServer is the server API for VideoIntelligenceService service.
type VideoSegment ¶
type VideoSegment struct {
// Time-offset, relative to the beginning of the video,
// corresponding to the start of the segment (inclusive).
StartTimeOffset *durationpb.Duration `protobuf:"bytes,1,opt,name=start_time_offset,json=startTimeOffset,proto3" json:"start_time_offset,omitempty"`
// Time-offset, relative to the beginning of the video,
// corresponding to the end of the segment (inclusive).
EndTimeOffset *durationpb.Duration `protobuf:"bytes,2,opt,name=end_time_offset,json=endTimeOffset,proto3" json:"end_time_offset,omitempty"`
// contains filtered or unexported fields
}
Video segment.
func (*VideoSegment) Descriptor ¶
func (*VideoSegment) Descriptor() ([]byte, []int)
Deprecated: Use VideoSegment.ProtoReflect.Descriptor instead.
func (*VideoSegment) GetEndTimeOffset ¶
func (x *VideoSegment) GetEndTimeOffset() *durationpb.Duration
func (*VideoSegment) GetStartTimeOffset ¶
func (x *VideoSegment) GetStartTimeOffset() *durationpb.Duration
func (*VideoSegment) ProtoMessage ¶
func (*VideoSegment) ProtoMessage()
func (*VideoSegment) ProtoReflect ¶
func (x *VideoSegment) ProtoReflect() protoreflect.Message
func (*VideoSegment) Reset ¶
func (x *VideoSegment) Reset()
func (*VideoSegment) String ¶
func (x *VideoSegment) String() string
Source Files ¶
video_intelligence.pb.go
- Version
- v0.0.0-20260427160629-7cedc36a6bc4 (latest)
- Published
- Apr 27, 2026
- Platform
- linux/amd64
- Imports
- 13 packages
- Last checked
- 2 days ago –
Tools for package owners.