package _type
import "google.golang.org/genproto/googleapis/cloud/workflows/type"
Index ¶
- Variables
- type EngineCallLog
- func (*EngineCallLog) Descriptor() ([]byte, []int)
- func (x *EngineCallLog) GetActivityTime() *timestamppb.Timestamp
- func (x *EngineCallLog) GetBegun() *EngineCallLog_Begun
- func (x *EngineCallLog) GetCallee() string
- func (m *EngineCallLog) GetDetails() isEngineCallLog_Details
- func (x *EngineCallLog) GetExceptionHandled() *EngineCallLog_ExceptionHandled
- func (x *EngineCallLog) GetExceptionRaised() *EngineCallLog_ExceptionRaised
- func (x *EngineCallLog) GetExecutionId() string
- func (x *EngineCallLog) GetState() EngineCallLog_State
- func (x *EngineCallLog) GetStep() string
- func (x *EngineCallLog) GetSucceeded() *EngineCallLog_Succeeded
- func (*EngineCallLog) ProtoMessage()
- func (x *EngineCallLog) ProtoReflect() protoreflect.Message
- func (x *EngineCallLog) Reset()
- func (x *EngineCallLog) String() string
- type EngineCallLog_Begun
- func (*EngineCallLog_Begun) Descriptor() ([]byte, []int)
- func (x *EngineCallLog_Begun) GetArgs() []*EngineCallLog_CallArg
- func (x *EngineCallLog_Begun) GetNamedArgs() map[string]*structpb.Value
- func (*EngineCallLog_Begun) ProtoMessage()
- func (x *EngineCallLog_Begun) ProtoReflect() protoreflect.Message
- func (x *EngineCallLog_Begun) Reset()
- func (x *EngineCallLog_Begun) String() string
- type EngineCallLog_Begun_
- type EngineCallLog_CallArg
- func (*EngineCallLog_CallArg) Descriptor() ([]byte, []int)
- func (x *EngineCallLog_CallArg) GetArgument() string
- func (*EngineCallLog_CallArg) ProtoMessage()
- func (x *EngineCallLog_CallArg) ProtoReflect() protoreflect.Message
- func (x *EngineCallLog_CallArg) Reset()
- func (x *EngineCallLog_CallArg) String() string
- type EngineCallLog_ExceptionHandled
- func (*EngineCallLog_ExceptionHandled) Descriptor() ([]byte, []int)
- func (x *EngineCallLog_ExceptionHandled) GetCallStartTime() *timestamppb.Timestamp
- func (x *EngineCallLog_ExceptionHandled) GetException() string
- func (x *EngineCallLog_ExceptionHandled) GetOrigin() string
- func (*EngineCallLog_ExceptionHandled) ProtoMessage()
- func (x *EngineCallLog_ExceptionHandled) ProtoReflect() protoreflect.Message
- func (x *EngineCallLog_ExceptionHandled) Reset()
- func (x *EngineCallLog_ExceptionHandled) String() string
- type EngineCallLog_ExceptionHandled_
- type EngineCallLog_ExceptionRaised
- func (*EngineCallLog_ExceptionRaised) Descriptor() ([]byte, []int)
- func (x *EngineCallLog_ExceptionRaised) GetCallStartTime() *timestamppb.Timestamp
- func (x *EngineCallLog_ExceptionRaised) GetException() string
- func (x *EngineCallLog_ExceptionRaised) GetOrigin() string
- func (*EngineCallLog_ExceptionRaised) ProtoMessage()
- func (x *EngineCallLog_ExceptionRaised) ProtoReflect() protoreflect.Message
- func (x *EngineCallLog_ExceptionRaised) Reset()
- func (x *EngineCallLog_ExceptionRaised) String() string
- type EngineCallLog_ExceptionRaised_
- type EngineCallLog_State
- func (EngineCallLog_State) Descriptor() protoreflect.EnumDescriptor
- func (x EngineCallLog_State) Enum() *EngineCallLog_State
- func (EngineCallLog_State) EnumDescriptor() ([]byte, []int)
- func (x EngineCallLog_State) Number() protoreflect.EnumNumber
- func (x EngineCallLog_State) String() string
- func (EngineCallLog_State) Type() protoreflect.EnumType
- type EngineCallLog_Succeeded
- func (*EngineCallLog_Succeeded) Descriptor() ([]byte, []int)
- func (x *EngineCallLog_Succeeded) GetCallStartTime() *timestamppb.Timestamp
- func (x *EngineCallLog_Succeeded) GetResponse() string
- func (*EngineCallLog_Succeeded) ProtoMessage()
- func (x *EngineCallLog_Succeeded) ProtoReflect() protoreflect.Message
- func (x *EngineCallLog_Succeeded) Reset()
- func (x *EngineCallLog_Succeeded) String() string
- type EngineCallLog_Succeeded_
- type ExecutionsSystemLog
- func (*ExecutionsSystemLog) Descriptor() ([]byte, []int)
- func (x *ExecutionsSystemLog) GetActivityTime() *timestamppb.Timestamp
- func (m *ExecutionsSystemLog) GetDetails() isExecutionsSystemLog_Details
- func (x *ExecutionsSystemLog) GetFailure() *ExecutionsSystemLog_Failure
- func (x *ExecutionsSystemLog) GetMessage() string
- func (x *ExecutionsSystemLog) GetStart() *ExecutionsSystemLog_Start
- func (x *ExecutionsSystemLog) GetState() ExecutionsSystemLog_State
- func (x *ExecutionsSystemLog) GetSuccess() *ExecutionsSystemLog_Success
- func (*ExecutionsSystemLog) ProtoMessage()
- func (x *ExecutionsSystemLog) ProtoReflect() protoreflect.Message
- func (x *ExecutionsSystemLog) Reset()
- func (x *ExecutionsSystemLog) String() string
- type ExecutionsSystemLog_Failure
- func (*ExecutionsSystemLog_Failure) Descriptor() ([]byte, []int)
- func (x *ExecutionsSystemLog_Failure) GetException() string
- func (x *ExecutionsSystemLog_Failure) GetSource() string
- func (*ExecutionsSystemLog_Failure) ProtoMessage()
- func (x *ExecutionsSystemLog_Failure) ProtoReflect() protoreflect.Message
- func (x *ExecutionsSystemLog_Failure) Reset()
- func (x *ExecutionsSystemLog_Failure) String() string
- type ExecutionsSystemLog_Failure_
- type ExecutionsSystemLog_Start
- func (*ExecutionsSystemLog_Start) Descriptor() ([]byte, []int)
- func (x *ExecutionsSystemLog_Start) GetArgument() string
- func (*ExecutionsSystemLog_Start) ProtoMessage()
- func (x *ExecutionsSystemLog_Start) ProtoReflect() protoreflect.Message
- func (x *ExecutionsSystemLog_Start) Reset()
- func (x *ExecutionsSystemLog_Start) String() string
- type ExecutionsSystemLog_Start_
- type ExecutionsSystemLog_State
- func (ExecutionsSystemLog_State) Descriptor() protoreflect.EnumDescriptor
- func (x ExecutionsSystemLog_State) Enum() *ExecutionsSystemLog_State
- func (ExecutionsSystemLog_State) EnumDescriptor() ([]byte, []int)
- func (x ExecutionsSystemLog_State) Number() protoreflect.EnumNumber
- func (x ExecutionsSystemLog_State) String() string
- func (ExecutionsSystemLog_State) Type() protoreflect.EnumType
- type ExecutionsSystemLog_Success
- func (*ExecutionsSystemLog_Success) Descriptor() ([]byte, []int)
- func (x *ExecutionsSystemLog_Success) GetResult() string
- func (*ExecutionsSystemLog_Success) ProtoMessage()
- func (x *ExecutionsSystemLog_Success) ProtoReflect() protoreflect.Message
- func (x *ExecutionsSystemLog_Success) Reset()
- func (x *ExecutionsSystemLog_Success) String() string
- type ExecutionsSystemLog_Success_
Variables ¶
var ( EngineCallLog_State_name = map[int32]string{ 0: "STATE_UNSPECIFIED", 1: "BEGUN", 2: "SUCCEEDED", 3: "EXCEPTION_RAISED", 4: "EXCEPTION_HANDLED", } EngineCallLog_State_value = map[string]int32{ "STATE_UNSPECIFIED": 0, "BEGUN": 1, "SUCCEEDED": 2, "EXCEPTION_RAISED": 3, "EXCEPTION_HANDLED": 4, } )
Enum value maps for EngineCallLog_State.
var ( ExecutionsSystemLog_State_name = map[int32]string{ 0: "STATE_UNSPECIFIED", 1: "ACTIVE", 2: "SUCCEEDED", 3: "FAILED", 4: "CANCELLED", } ExecutionsSystemLog_State_value = map[string]int32{ "STATE_UNSPECIFIED": 0, "ACTIVE": 1, "SUCCEEDED": 2, "FAILED": 3, "CANCELLED": 4, } )
Enum value maps for ExecutionsSystemLog_State.
var File_google_cloud_workflows_type_engine_call_proto protoreflect.FileDescriptor
var File_google_cloud_workflows_type_executions_system_proto protoreflect.FileDescriptor
Types ¶
type EngineCallLog ¶
type EngineCallLog struct {
// The execution ID of the execution where the call occurred.
ExecutionId string `protobuf:"bytes,1,opt,name=execution_id,json=executionId,proto3" json:"execution_id,omitempty"`
// The point in time when the activity occurred.
ActivityTime *timestamppb.Timestamp `protobuf:"bytes,2,opt,name=activity_time,json=activityTime,proto3" json:"activity_time,omitempty"`
// The state of the function execution.
State EngineCallLog_State `protobuf:"varint,3,opt,name=state,proto3,enum=google.cloud.workflows.type.EngineCallLog_State" json:"state,omitempty"`
// The name of the step in which the call took place, truncated if necessary.
Step string `protobuf:"bytes,4,opt,name=step,proto3" json:"step,omitempty"`
// The name of the target of the call, truncated if necessary.
Callee string `protobuf:"bytes,5,opt,name=callee,proto3" json:"callee,omitempty"`
// Types that are assignable to Details:
// *EngineCallLog_Begun_
// *EngineCallLog_Succeeded_
// *EngineCallLog_ExceptionRaised_
// *EngineCallLog_ExceptionHandled_
Details isEngineCallLog_Details `protobuf_oneof:"details"`
// contains filtered or unexported fields
}
Logged during a workflow execution if the customer has requested call logging.
func (*EngineCallLog) Descriptor ¶
func (*EngineCallLog) Descriptor() ([]byte, []int)
Deprecated: Use EngineCallLog.ProtoReflect.Descriptor instead.
func (*EngineCallLog) GetActivityTime ¶
func (x *EngineCallLog) GetActivityTime() *timestamppb.Timestamp
func (*EngineCallLog) GetBegun ¶
func (x *EngineCallLog) GetBegun() *EngineCallLog_Begun
func (*EngineCallLog) GetCallee ¶
func (x *EngineCallLog) GetCallee() string
func (*EngineCallLog) GetDetails ¶
func (m *EngineCallLog) GetDetails() isEngineCallLog_Details
func (*EngineCallLog) GetExceptionHandled ¶
func (x *EngineCallLog) GetExceptionHandled() *EngineCallLog_ExceptionHandled
func (*EngineCallLog) GetExceptionRaised ¶
func (x *EngineCallLog) GetExceptionRaised() *EngineCallLog_ExceptionRaised
func (*EngineCallLog) GetExecutionId ¶
func (x *EngineCallLog) GetExecutionId() string
func (*EngineCallLog) GetState ¶
func (x *EngineCallLog) GetState() EngineCallLog_State
func (*EngineCallLog) GetStep ¶
func (x *EngineCallLog) GetStep() string
func (*EngineCallLog) GetSucceeded ¶
func (x *EngineCallLog) GetSucceeded() *EngineCallLog_Succeeded
func (*EngineCallLog) ProtoMessage ¶
func (*EngineCallLog) ProtoMessage()
func (*EngineCallLog) ProtoReflect ¶
func (x *EngineCallLog) ProtoReflect() protoreflect.Message
func (*EngineCallLog) Reset ¶
func (x *EngineCallLog) Reset()
func (*EngineCallLog) String ¶
func (x *EngineCallLog) String() string
type EngineCallLog_Begun ¶
type EngineCallLog_Begun struct {
// The arguments passed to the function. Only one of 'args' and 'named_args'
// will be populated.
Args []*EngineCallLog_CallArg `protobuf:"bytes,1,rep,name=args,proto3" json:"args,omitempty"`
// The arguments passed to the function, as a map with the argument names as
// the keys. The values may be JSON values or they may be the serialized
// string forms of the arguments truncated for size reasons. Only one of
// 'args' and 'named_args' will be populated.
NamedArgs map[string]*structpb.Value `protobuf:"bytes,2,rep,name=named_args,json=namedArgs,proto3" json:"named_args,omitempty" protobuf_key:"bytes,1,opt,name=key,proto3" protobuf_val:"bytes,2,opt,name=value,proto3"`
// contains filtered or unexported fields
}
Information about the start of a call.
func (*EngineCallLog_Begun) Descriptor ¶
func (*EngineCallLog_Begun) Descriptor() ([]byte, []int)
Deprecated: Use EngineCallLog_Begun.ProtoReflect.Descriptor instead.
func (*EngineCallLog_Begun) GetArgs ¶
func (x *EngineCallLog_Begun) GetArgs() []*EngineCallLog_CallArg
func (*EngineCallLog_Begun) GetNamedArgs ¶
func (x *EngineCallLog_Begun) GetNamedArgs() map[string]*structpb.Value
func (*EngineCallLog_Begun) ProtoMessage ¶
func (*EngineCallLog_Begun) ProtoMessage()
func (*EngineCallLog_Begun) ProtoReflect ¶
func (x *EngineCallLog_Begun) ProtoReflect() protoreflect.Message
func (*EngineCallLog_Begun) Reset ¶
func (x *EngineCallLog_Begun) Reset()
func (*EngineCallLog_Begun) String ¶
func (x *EngineCallLog_Begun) String() string
type EngineCallLog_Begun_ ¶
type EngineCallLog_Begun_ struct {
// Appears at the start of a call.
Begun *EngineCallLog_Begun `protobuf:"bytes,6,opt,name=begun,proto3,oneof"`
}
type EngineCallLog_CallArg ¶
type EngineCallLog_CallArg struct {
// A function argument, serialized to a string. This may be truncated for
// size reasons.
Argument string `protobuf:"bytes,1,opt,name=argument,proto3" json:"argument,omitempty"`
// contains filtered or unexported fields
}
Information about an argument to a called function.
func (*EngineCallLog_CallArg) Descriptor ¶
func (*EngineCallLog_CallArg) Descriptor() ([]byte, []int)
Deprecated: Use EngineCallLog_CallArg.ProtoReflect.Descriptor instead.
func (*EngineCallLog_CallArg) GetArgument ¶
func (x *EngineCallLog_CallArg) GetArgument() string
func (*EngineCallLog_CallArg) ProtoMessage ¶
func (*EngineCallLog_CallArg) ProtoMessage()
func (*EngineCallLog_CallArg) ProtoReflect ¶
func (x *EngineCallLog_CallArg) ProtoReflect() protoreflect.Message
func (*EngineCallLog_CallArg) Reset ¶
func (x *EngineCallLog_CallArg) Reset()
func (*EngineCallLog_CallArg) String ¶
func (x *EngineCallLog_CallArg) String() string
type EngineCallLog_ExceptionHandled ¶
type EngineCallLog_ExceptionHandled struct {
// The time when the call started.
CallStartTime *timestamppb.Timestamp `protobuf:"bytes,1,opt,name=call_start_time,json=callStartTime,proto3" json:"call_start_time,omitempty"`
// The exception message which was handled, truncated if necessary.
Exception string `protobuf:"bytes,2,opt,name=exception,proto3" json:"exception,omitempty"`
// The name of the step where the failure originates, if known. Truncated
// if necessary.
Origin string `protobuf:"bytes,3,opt,name=origin,proto3" json:"origin,omitempty"`
// contains filtered or unexported fields
}
Information about an exception which was handled.
func (*EngineCallLog_ExceptionHandled) Descriptor ¶
func (*EngineCallLog_ExceptionHandled) Descriptor() ([]byte, []int)
Deprecated: Use EngineCallLog_ExceptionHandled.ProtoReflect.Descriptor instead.
func (*EngineCallLog_ExceptionHandled) GetCallStartTime ¶
func (x *EngineCallLog_ExceptionHandled) GetCallStartTime() *timestamppb.Timestamp
func (*EngineCallLog_ExceptionHandled) GetException ¶
func (x *EngineCallLog_ExceptionHandled) GetException() string
func (*EngineCallLog_ExceptionHandled) GetOrigin ¶
func (x *EngineCallLog_ExceptionHandled) GetOrigin() string
func (*EngineCallLog_ExceptionHandled) ProtoMessage ¶
func (*EngineCallLog_ExceptionHandled) ProtoMessage()
func (*EngineCallLog_ExceptionHandled) ProtoReflect ¶
func (x *EngineCallLog_ExceptionHandled) ProtoReflect() protoreflect.Message
func (*EngineCallLog_ExceptionHandled) Reset ¶
func (x *EngineCallLog_ExceptionHandled) Reset()
func (*EngineCallLog_ExceptionHandled) String ¶
func (x *EngineCallLog_ExceptionHandled) String() string
type EngineCallLog_ExceptionHandled_ ¶
type EngineCallLog_ExceptionHandled_ struct {
// Appears when an exception is handled and normal execution resumes.
ExceptionHandled *EngineCallLog_ExceptionHandled `protobuf:"bytes,9,opt,name=exception_handled,json=exceptionHandled,proto3,oneof"`
}
type EngineCallLog_ExceptionRaised ¶
type EngineCallLog_ExceptionRaised struct {
// The time when the call started.
CallStartTime *timestamppb.Timestamp `protobuf:"bytes,1,opt,name=call_start_time,json=callStartTime,proto3" json:"call_start_time,omitempty"`
// The exception message which terminated the call, truncated if necessary.
Exception string `protobuf:"bytes,2,opt,name=exception,proto3" json:"exception,omitempty"`
// The name of the step where the failure originates, if known. Truncated
// if necessary.
Origin string `protobuf:"bytes,3,opt,name=origin,proto3" json:"origin,omitempty"`
// contains filtered or unexported fields
}
Information about the end of a failed call.
func (*EngineCallLog_ExceptionRaised) Descriptor ¶
func (*EngineCallLog_ExceptionRaised) Descriptor() ([]byte, []int)
Deprecated: Use EngineCallLog_ExceptionRaised.ProtoReflect.Descriptor instead.
func (*EngineCallLog_ExceptionRaised) GetCallStartTime ¶
func (x *EngineCallLog_ExceptionRaised) GetCallStartTime() *timestamppb.Timestamp
func (*EngineCallLog_ExceptionRaised) GetException ¶
func (x *EngineCallLog_ExceptionRaised) GetException() string
func (*EngineCallLog_ExceptionRaised) GetOrigin ¶
func (x *EngineCallLog_ExceptionRaised) GetOrigin() string
func (*EngineCallLog_ExceptionRaised) ProtoMessage ¶
func (*EngineCallLog_ExceptionRaised) ProtoMessage()
func (*EngineCallLog_ExceptionRaised) ProtoReflect ¶
func (x *EngineCallLog_ExceptionRaised) ProtoReflect() protoreflect.Message
func (*EngineCallLog_ExceptionRaised) Reset ¶
func (x *EngineCallLog_ExceptionRaised) Reset()
func (*EngineCallLog_ExceptionRaised) String ¶
func (x *EngineCallLog_ExceptionRaised) String() string
type EngineCallLog_ExceptionRaised_ ¶
type EngineCallLog_ExceptionRaised_ struct {
// Appears when a call returns because an exception was raised.
ExceptionRaised *EngineCallLog_ExceptionRaised `protobuf:"bytes,8,opt,name=exception_raised,json=exceptionRaised,proto3,oneof"`
}
type EngineCallLog_State ¶
type EngineCallLog_State int32
The state of a function call.
const ( // Function call state is unspecified or unknown. EngineCallLog_STATE_UNSPECIFIED EngineCallLog_State = 0 // Function call is starting. EngineCallLog_BEGUN EngineCallLog_State = 1 // Function call has completed successfully. EngineCallLog_SUCCEEDED EngineCallLog_State = 2 // Function call did not succeed because an exception was raised. EngineCallLog_EXCEPTION_RAISED EngineCallLog_State = 3 // Function call handled an exception and is continuing. EngineCallLog_EXCEPTION_HANDLED EngineCallLog_State = 4 )
func (EngineCallLog_State) Descriptor ¶
func (EngineCallLog_State) Descriptor() protoreflect.EnumDescriptor
func (EngineCallLog_State) Enum ¶
func (x EngineCallLog_State) Enum() *EngineCallLog_State
func (EngineCallLog_State) EnumDescriptor ¶
func (EngineCallLog_State) EnumDescriptor() ([]byte, []int)
Deprecated: Use EngineCallLog_State.Descriptor instead.
func (EngineCallLog_State) Number ¶
func (x EngineCallLog_State) Number() protoreflect.EnumNumber
func (EngineCallLog_State) String ¶
func (x EngineCallLog_State) String() string
func (EngineCallLog_State) Type ¶
func (EngineCallLog_State) Type() protoreflect.EnumType
type EngineCallLog_Succeeded ¶
type EngineCallLog_Succeeded struct {
// The time when the call started.
CallStartTime *timestamppb.Timestamp `protobuf:"bytes,1,opt,name=call_start_time,json=callStartTime,proto3" json:"call_start_time,omitempty"`
// The result of the call, if the call succeeded, serialized to a string.
// This may be truncated for size reasons.
Response string `protobuf:"bytes,2,opt,name=response,proto3" json:"response,omitempty"`
// contains filtered or unexported fields
}
Information about the end of a successful call.
func (*EngineCallLog_Succeeded) Descriptor ¶
func (*EngineCallLog_Succeeded) Descriptor() ([]byte, []int)
Deprecated: Use EngineCallLog_Succeeded.ProtoReflect.Descriptor instead.
func (*EngineCallLog_Succeeded) GetCallStartTime ¶
func (x *EngineCallLog_Succeeded) GetCallStartTime() *timestamppb.Timestamp
func (*EngineCallLog_Succeeded) GetResponse ¶
func (x *EngineCallLog_Succeeded) GetResponse() string
func (*EngineCallLog_Succeeded) ProtoMessage ¶
func (*EngineCallLog_Succeeded) ProtoMessage()
func (*EngineCallLog_Succeeded) ProtoReflect ¶
func (x *EngineCallLog_Succeeded) ProtoReflect() protoreflect.Message
func (*EngineCallLog_Succeeded) Reset ¶
func (x *EngineCallLog_Succeeded) Reset()
func (*EngineCallLog_Succeeded) String ¶
func (x *EngineCallLog_Succeeded) String() string
type EngineCallLog_Succeeded_ ¶
type EngineCallLog_Succeeded_ struct {
// Appears when a call returns successfully.
Succeeded *EngineCallLog_Succeeded `protobuf:"bytes,7,opt,name=succeeded,proto3,oneof"`
}
type ExecutionsSystemLog ¶
type ExecutionsSystemLog struct {
// Human readable contents of the log in English. The size limit is 5 kB.
Message string `protobuf:"bytes,1,opt,name=message,proto3" json:"message,omitempty"`
// The absolute point in time when the activity happened.
ActivityTime *timestamppb.Timestamp `protobuf:"bytes,2,opt,name=activity_time,json=activityTime,proto3" json:"activity_time,omitempty"`
// State of the execution when the log was created.
State ExecutionsSystemLog_State `protobuf:"varint,3,opt,name=state,proto3,enum=google.cloud.workflows.type.ExecutionsSystemLog_State" json:"state,omitempty"`
// Detailed log information.
//
// Types that are assignable to Details:
// *ExecutionsSystemLog_Start_
// *ExecutionsSystemLog_Success_
// *ExecutionsSystemLog_Failure_
Details isExecutionsSystemLog_Details `protobuf_oneof:"details"`
// contains filtered or unexported fields
}
Logged during the lifetime of Workflow Execution.
func (*ExecutionsSystemLog) Descriptor ¶
func (*ExecutionsSystemLog) Descriptor() ([]byte, []int)
Deprecated: Use ExecutionsSystemLog.ProtoReflect.Descriptor instead.
func (*ExecutionsSystemLog) GetActivityTime ¶
func (x *ExecutionsSystemLog) GetActivityTime() *timestamppb.Timestamp
func (*ExecutionsSystemLog) GetDetails ¶
func (m *ExecutionsSystemLog) GetDetails() isExecutionsSystemLog_Details
func (*ExecutionsSystemLog) GetFailure ¶
func (x *ExecutionsSystemLog) GetFailure() *ExecutionsSystemLog_Failure
func (*ExecutionsSystemLog) GetMessage ¶
func (x *ExecutionsSystemLog) GetMessage() string
func (*ExecutionsSystemLog) GetStart ¶
func (x *ExecutionsSystemLog) GetStart() *ExecutionsSystemLog_Start
func (*ExecutionsSystemLog) GetState ¶
func (x *ExecutionsSystemLog) GetState() ExecutionsSystemLog_State
func (*ExecutionsSystemLog) GetSuccess ¶
func (x *ExecutionsSystemLog) GetSuccess() *ExecutionsSystemLog_Success
func (*ExecutionsSystemLog) ProtoMessage ¶
func (*ExecutionsSystemLog) ProtoMessage()
func (*ExecutionsSystemLog) ProtoReflect ¶
func (x *ExecutionsSystemLog) ProtoReflect() protoreflect.Message
func (*ExecutionsSystemLog) Reset ¶
func (x *ExecutionsSystemLog) Reset()
func (*ExecutionsSystemLog) String ¶
func (x *ExecutionsSystemLog) String() string
type ExecutionsSystemLog_Failure ¶
type ExecutionsSystemLog_Failure struct {
// The exception message, e.g. "division by zero". The size limit is 1 kB.
Exception string `protobuf:"bytes,1,opt,name=exception,proto3" json:"exception,omitempty"`
// The code location of the statement that has created the log. For example,
// a log created in subworkflow 'Foo' in step 'bar' will have its source
// equal to 'Foo.bar'. The size limit is 1 kB.
Source string `protobuf:"bytes,2,opt,name=source,proto3" json:"source,omitempty"`
// contains filtered or unexported fields
}
Detailed information about the execution failure.
func (*ExecutionsSystemLog_Failure) Descriptor ¶
func (*ExecutionsSystemLog_Failure) Descriptor() ([]byte, []int)
Deprecated: Use ExecutionsSystemLog_Failure.ProtoReflect.Descriptor instead.
func (*ExecutionsSystemLog_Failure) GetException ¶
func (x *ExecutionsSystemLog_Failure) GetException() string
func (*ExecutionsSystemLog_Failure) GetSource ¶
func (x *ExecutionsSystemLog_Failure) GetSource() string
func (*ExecutionsSystemLog_Failure) ProtoMessage ¶
func (*ExecutionsSystemLog_Failure) ProtoMessage()
func (*ExecutionsSystemLog_Failure) ProtoReflect ¶
func (x *ExecutionsSystemLog_Failure) ProtoReflect() protoreflect.Message
func (*ExecutionsSystemLog_Failure) Reset ¶
func (x *ExecutionsSystemLog_Failure) Reset()
func (*ExecutionsSystemLog_Failure) String ¶
func (x *ExecutionsSystemLog_Failure) String() string
type ExecutionsSystemLog_Failure_ ¶
type ExecutionsSystemLog_Failure_ struct {
// Appears only in the log created when the execution has failed.
Failure *ExecutionsSystemLog_Failure `protobuf:"bytes,6,opt,name=failure,proto3,oneof"`
}
type ExecutionsSystemLog_Start ¶
type ExecutionsSystemLog_Start struct {
// The execution input argument.
Argument string `protobuf:"bytes,2,opt,name=argument,proto3" json:"argument,omitempty"`
// contains filtered or unexported fields
}
Detailed information about the start of the execution.
func (*ExecutionsSystemLog_Start) Descriptor ¶
func (*ExecutionsSystemLog_Start) Descriptor() ([]byte, []int)
Deprecated: Use ExecutionsSystemLog_Start.ProtoReflect.Descriptor instead.
func (*ExecutionsSystemLog_Start) GetArgument ¶
func (x *ExecutionsSystemLog_Start) GetArgument() string
func (*ExecutionsSystemLog_Start) ProtoMessage ¶
func (*ExecutionsSystemLog_Start) ProtoMessage()
func (*ExecutionsSystemLog_Start) ProtoReflect ¶
func (x *ExecutionsSystemLog_Start) ProtoReflect() protoreflect.Message
func (*ExecutionsSystemLog_Start) Reset ¶
func (x *ExecutionsSystemLog_Start) Reset()
func (*ExecutionsSystemLog_Start) String ¶
func (x *ExecutionsSystemLog_Start) String() string
type ExecutionsSystemLog_Start_ ¶
type ExecutionsSystemLog_Start_ struct {
// Appears only in the log created when the execution has started.
Start *ExecutionsSystemLog_Start `protobuf:"bytes,4,opt,name=start,proto3,oneof"`
}
type ExecutionsSystemLog_State ¶
type ExecutionsSystemLog_State int32
Possible states of the execution. There could be more states in the future.
const ( // Invalid state. ExecutionsSystemLog_STATE_UNSPECIFIED ExecutionsSystemLog_State = 0 // The Workflow Execution is in progress. ExecutionsSystemLog_ACTIVE ExecutionsSystemLog_State = 1 // The Workflow Execution has finished successfully. ExecutionsSystemLog_SUCCEEDED ExecutionsSystemLog_State = 2 // The Workflow Execution failed with an error. ExecutionsSystemLog_FAILED ExecutionsSystemLog_State = 3 // The Workflow Execution has been stopped intentionally. ExecutionsSystemLog_CANCELLED ExecutionsSystemLog_State = 4 )
func (ExecutionsSystemLog_State) Descriptor ¶
func (ExecutionsSystemLog_State) Descriptor() protoreflect.EnumDescriptor
func (ExecutionsSystemLog_State) Enum ¶
func (x ExecutionsSystemLog_State) Enum() *ExecutionsSystemLog_State
func (ExecutionsSystemLog_State) EnumDescriptor ¶
func (ExecutionsSystemLog_State) EnumDescriptor() ([]byte, []int)
Deprecated: Use ExecutionsSystemLog_State.Descriptor instead.
func (ExecutionsSystemLog_State) Number ¶
func (x ExecutionsSystemLog_State) Number() protoreflect.EnumNumber
func (ExecutionsSystemLog_State) String ¶
func (x ExecutionsSystemLog_State) String() string
func (ExecutionsSystemLog_State) Type ¶
func (ExecutionsSystemLog_State) Type() protoreflect.EnumType
type ExecutionsSystemLog_Success ¶
type ExecutionsSystemLog_Success struct {
// The final result of the execution.
Result string `protobuf:"bytes,2,opt,name=result,proto3" json:"result,omitempty"`
// contains filtered or unexported fields
}
Detailed information about the successful finish of the execution.
func (*ExecutionsSystemLog_Success) Descriptor ¶
func (*ExecutionsSystemLog_Success) Descriptor() ([]byte, []int)
Deprecated: Use ExecutionsSystemLog_Success.ProtoReflect.Descriptor instead.
func (*ExecutionsSystemLog_Success) GetResult ¶
func (x *ExecutionsSystemLog_Success) GetResult() string
func (*ExecutionsSystemLog_Success) ProtoMessage ¶
func (*ExecutionsSystemLog_Success) ProtoMessage()
func (*ExecutionsSystemLog_Success) ProtoReflect ¶
func (x *ExecutionsSystemLog_Success) ProtoReflect() protoreflect.Message
func (*ExecutionsSystemLog_Success) Reset ¶
func (x *ExecutionsSystemLog_Success) Reset()
func (*ExecutionsSystemLog_Success) String ¶
func (x *ExecutionsSystemLog_Success) String() string
type ExecutionsSystemLog_Success_ ¶
type ExecutionsSystemLog_Success_ struct {
// Appears only in the log created when the execution has finished
// successfully.
Success *ExecutionsSystemLog_Success `protobuf:"bytes,5,opt,name=success,proto3,oneof"`
}
Source Files ¶
engine_call.pb.go executions_system.pb.go
- Version
- v0.0.0-20260427160629-7cedc36a6bc4 (latest)
- Published
- Apr 27, 2026
- Platform
- linux/amd64
- Imports
- 6 packages
- Last checked
- 3 days ago –
Tools for package owners.