package provenance
import "google.golang.org/genproto/googleapis/devtools/containeranalysis/v1beta1/provenance"
Index ¶
- Variables
- type Artifact
- func (*Artifact) Descriptor() ([]byte, []int)
- func (x *Artifact) GetChecksum() string
- func (x *Artifact) GetId() string
- func (x *Artifact) GetNames() []string
- func (*Artifact) ProtoMessage()
- func (x *Artifact) ProtoReflect() protoreflect.Message
- func (x *Artifact) Reset()
- func (x *Artifact) String() string
- type BuildProvenance
- func (*BuildProvenance) Descriptor() ([]byte, []int)
- func (x *BuildProvenance) GetBuildOptions() map[string]string
- func (x *BuildProvenance) GetBuilderVersion() string
- func (x *BuildProvenance) GetBuiltArtifacts() []*Artifact
- func (x *BuildProvenance) GetCommands() []*Command
- func (x *BuildProvenance) GetCreateTime() *timestamppb.Timestamp
- func (x *BuildProvenance) GetCreator() string
- func (x *BuildProvenance) GetEndTime() *timestamppb.Timestamp
- func (x *BuildProvenance) GetId() string
- func (x *BuildProvenance) GetLogsUri() string
- func (x *BuildProvenance) GetProjectId() string
- func (x *BuildProvenance) GetSourceProvenance() *Source
- func (x *BuildProvenance) GetStartTime() *timestamppb.Timestamp
- func (x *BuildProvenance) GetTriggerId() string
- func (*BuildProvenance) ProtoMessage()
- func (x *BuildProvenance) ProtoReflect() protoreflect.Message
- func (x *BuildProvenance) Reset()
- func (x *BuildProvenance) String() string
- type Command
- func (*Command) Descriptor() ([]byte, []int)
- func (x *Command) GetArgs() []string
- func (x *Command) GetDir() string
- func (x *Command) GetEnv() []string
- func (x *Command) GetId() string
- func (x *Command) GetName() string
- func (x *Command) GetWaitFor() []string
- func (*Command) ProtoMessage()
- func (x *Command) ProtoReflect() protoreflect.Message
- func (x *Command) Reset()
- func (x *Command) String() string
- type FileHashes
- func (*FileHashes) Descriptor() ([]byte, []int)
- func (x *FileHashes) GetFileHash() []*Hash
- func (*FileHashes) ProtoMessage()
- func (x *FileHashes) ProtoReflect() protoreflect.Message
- func (x *FileHashes) Reset()
- func (x *FileHashes) String() string
- type Hash
- func (*Hash) Descriptor() ([]byte, []int)
- func (x *Hash) GetType() Hash_HashType
- func (x *Hash) GetValue() []byte
- func (*Hash) ProtoMessage()
- func (x *Hash) ProtoReflect() protoreflect.Message
- func (x *Hash) Reset()
- func (x *Hash) String() string
- type Hash_HashType
- func (Hash_HashType) Descriptor() protoreflect.EnumDescriptor
- func (x Hash_HashType) Enum() *Hash_HashType
- func (Hash_HashType) EnumDescriptor() ([]byte, []int)
- func (x Hash_HashType) Number() protoreflect.EnumNumber
- func (x Hash_HashType) String() string
- func (Hash_HashType) Type() protoreflect.EnumType
- type Source
- func (*Source) Descriptor() ([]byte, []int)
- func (x *Source) GetAdditionalContexts() []*source.SourceContext
- func (x *Source) GetArtifactStorageSourceUri() string
- func (x *Source) GetContext() *source.SourceContext
- func (x *Source) GetFileHashes() map[string]*FileHashes
- func (*Source) ProtoMessage()
- func (x *Source) ProtoReflect() protoreflect.Message
- func (x *Source) Reset()
- func (x *Source) String() string
Variables ¶
var ( Hash_HashType_name = map[int32]string{ 0: "HASH_TYPE_UNSPECIFIED", 1: "SHA256", } Hash_HashType_value = map[string]int32{ "HASH_TYPE_UNSPECIFIED": 0, "SHA256": 1, } )
Enum value maps for Hash_HashType.
var File_google_devtools_containeranalysis_v1beta1_provenance_provenance_proto protoreflect.FileDescriptor
Types ¶
type Artifact ¶
type Artifact struct {
// Hash or checksum value of a binary, or Docker Registry 2.0 digest of a
// container.
Checksum string `protobuf:"bytes,1,opt,name=checksum,proto3" json:"checksum,omitempty"`
// Artifact ID, if any; for container images, this will be a URL by digest
// like `gcr.io/projectID/imagename@sha256:123456`.
Id string `protobuf:"bytes,2,opt,name=id,proto3" json:"id,omitempty"`
// Related artifact names. This may be the path to a binary or jar file, or in
// the case of a container build, the name used to push the container image to
// Google Container Registry, as presented to `docker push`. Note that a
// single Artifact ID can have multiple names, for example if two tags are
// applied to one image.
Names []string `protobuf:"bytes,3,rep,name=names,proto3" json:"names,omitempty"`
// contains filtered or unexported fields
}
Artifact describes a build product.
func (*Artifact) Descriptor ¶
Deprecated: Use Artifact.ProtoReflect.Descriptor instead.
func (*Artifact) GetChecksum ¶
func (*Artifact) GetId ¶
func (*Artifact) GetNames ¶
func (*Artifact) ProtoMessage ¶
func (*Artifact) ProtoMessage()
func (*Artifact) ProtoReflect ¶
func (x *Artifact) ProtoReflect() protoreflect.Message
func (*Artifact) Reset ¶
func (x *Artifact) Reset()
func (*Artifact) String ¶
type BuildProvenance ¶
type BuildProvenance struct {
// Required. Unique identifier of the build.
Id string `protobuf:"bytes,1,opt,name=id,proto3" json:"id,omitempty"`
// ID of the project.
ProjectId string `protobuf:"bytes,2,opt,name=project_id,json=projectId,proto3" json:"project_id,omitempty"`
// Commands requested by the build.
Commands []*Command `protobuf:"bytes,3,rep,name=commands,proto3" json:"commands,omitempty"`
// Output of the build.
BuiltArtifacts []*Artifact `protobuf:"bytes,4,rep,name=built_artifacts,json=builtArtifacts,proto3" json:"built_artifacts,omitempty"`
// Time at which the build was created.
CreateTime *timestamppb.Timestamp `protobuf:"bytes,5,opt,name=create_time,json=createTime,proto3" json:"create_time,omitempty"`
// Time at which execution of the build was started.
StartTime *timestamppb.Timestamp `protobuf:"bytes,6,opt,name=start_time,json=startTime,proto3" json:"start_time,omitempty"`
// Time at which execution of the build was finished.
EndTime *timestamppb.Timestamp `protobuf:"bytes,7,opt,name=end_time,json=endTime,proto3" json:"end_time,omitempty"`
// E-mail address of the user who initiated this build. Note that this was the
// user's e-mail address at the time the build was initiated; this address may
// not represent the same end-user for all time.
Creator string `protobuf:"bytes,8,opt,name=creator,proto3" json:"creator,omitempty"`
// URI where any logs for this provenance were written.
LogsUri string `protobuf:"bytes,9,opt,name=logs_uri,json=logsUri,proto3" json:"logs_uri,omitempty"`
// Details of the Source input to the build.
SourceProvenance *Source `protobuf:"bytes,10,opt,name=source_provenance,json=sourceProvenance,proto3" json:"source_provenance,omitempty"`
// Trigger identifier if the build was triggered automatically; empty if not.
TriggerId string `protobuf:"bytes,11,opt,name=trigger_id,json=triggerId,proto3" json:"trigger_id,omitempty"`
// Special options applied to this build. This is a catch-all field where
// build providers can enter any desired additional details.
BuildOptions map[string]string `protobuf:"bytes,12,rep,name=build_options,json=buildOptions,proto3" json:"build_options,omitempty" protobuf_key:"bytes,1,opt,name=key,proto3" protobuf_val:"bytes,2,opt,name=value,proto3"`
// Version string of the builder at the time this build was executed.
BuilderVersion string `protobuf:"bytes,13,opt,name=builder_version,json=builderVersion,proto3" json:"builder_version,omitempty"`
// contains filtered or unexported fields
}
Provenance of a build. Contains all information needed to verify the full details about the build from source to completion.
func (*BuildProvenance) Descriptor ¶
func (*BuildProvenance) Descriptor() ([]byte, []int)
Deprecated: Use BuildProvenance.ProtoReflect.Descriptor instead.
func (*BuildProvenance) GetBuildOptions ¶
func (x *BuildProvenance) GetBuildOptions() map[string]string
func (*BuildProvenance) GetBuilderVersion ¶
func (x *BuildProvenance) GetBuilderVersion() string
func (*BuildProvenance) GetBuiltArtifacts ¶
func (x *BuildProvenance) GetBuiltArtifacts() []*Artifact
func (*BuildProvenance) GetCommands ¶
func (x *BuildProvenance) GetCommands() []*Command
func (*BuildProvenance) GetCreateTime ¶
func (x *BuildProvenance) GetCreateTime() *timestamppb.Timestamp
func (*BuildProvenance) GetCreator ¶
func (x *BuildProvenance) GetCreator() string
func (*BuildProvenance) GetEndTime ¶
func (x *BuildProvenance) GetEndTime() *timestamppb.Timestamp
func (*BuildProvenance) GetId ¶
func (x *BuildProvenance) GetId() string
func (*BuildProvenance) GetLogsUri ¶
func (x *BuildProvenance) GetLogsUri() string
func (*BuildProvenance) GetProjectId ¶
func (x *BuildProvenance) GetProjectId() string
func (*BuildProvenance) GetSourceProvenance ¶
func (x *BuildProvenance) GetSourceProvenance() *Source
func (*BuildProvenance) GetStartTime ¶
func (x *BuildProvenance) GetStartTime() *timestamppb.Timestamp
func (*BuildProvenance) GetTriggerId ¶
func (x *BuildProvenance) GetTriggerId() string
func (*BuildProvenance) ProtoMessage ¶
func (*BuildProvenance) ProtoMessage()
func (*BuildProvenance) ProtoReflect ¶
func (x *BuildProvenance) ProtoReflect() protoreflect.Message
func (*BuildProvenance) Reset ¶
func (x *BuildProvenance) Reset()
func (*BuildProvenance) String ¶
func (x *BuildProvenance) String() string
type Command ¶
type Command struct {
// Required. Name of the command, as presented on the command line, or if the
// command is packaged as a Docker container, as presented to `docker pull`.
Name string `protobuf:"bytes,1,opt,name=name,proto3" json:"name,omitempty"`
// Environment variables set before running this command.
Env []string `protobuf:"bytes,2,rep,name=env,proto3" json:"env,omitempty"`
// Command-line arguments used when executing this command.
Args []string `protobuf:"bytes,3,rep,name=args,proto3" json:"args,omitempty"`
// Working directory (relative to project source root) used when running this
// command.
Dir string `protobuf:"bytes,4,opt,name=dir,proto3" json:"dir,omitempty"`
// Optional unique identifier for this command, used in wait_for to reference
// this command as a dependency.
Id string `protobuf:"bytes,5,opt,name=id,proto3" json:"id,omitempty"`
// The ID(s) of the command(s) that this command depends on.
WaitFor []string `protobuf:"bytes,6,rep,name=wait_for,json=waitFor,proto3" json:"wait_for,omitempty"`
// contains filtered or unexported fields
}
Command describes a step performed as part of the build pipeline.
func (*Command) Descriptor ¶
Deprecated: Use Command.ProtoReflect.Descriptor instead.
func (*Command) GetArgs ¶
func (*Command) GetDir ¶
func (*Command) GetEnv ¶
func (*Command) GetId ¶
func (*Command) GetName ¶
func (*Command) GetWaitFor ¶
func (*Command) ProtoMessage ¶
func (*Command) ProtoMessage()
func (*Command) ProtoReflect ¶
func (x *Command) ProtoReflect() protoreflect.Message
func (*Command) Reset ¶
func (x *Command) Reset()
func (*Command) String ¶
type FileHashes ¶
type FileHashes struct {
// Required. Collection of file hashes.
FileHash []*Hash `protobuf:"bytes,1,rep,name=file_hash,json=fileHash,proto3" json:"file_hash,omitempty"`
// contains filtered or unexported fields
}
Container message for hashes of byte content of files, used in source messages to verify integrity of source input to the build.
func (*FileHashes) Descriptor ¶
func (*FileHashes) Descriptor() ([]byte, []int)
Deprecated: Use FileHashes.ProtoReflect.Descriptor instead.
func (*FileHashes) GetFileHash ¶
func (x *FileHashes) GetFileHash() []*Hash
func (*FileHashes) ProtoMessage ¶
func (*FileHashes) ProtoMessage()
func (*FileHashes) ProtoReflect ¶
func (x *FileHashes) ProtoReflect() protoreflect.Message
func (*FileHashes) Reset ¶
func (x *FileHashes) Reset()
func (*FileHashes) String ¶
func (x *FileHashes) String() string
type Hash ¶
type Hash struct {
// Required. The type of hash that was performed.
Type Hash_HashType `protobuf:"varint,1,opt,name=type,proto3,enum=grafeas.v1beta1.provenance.Hash_HashType" json:"type,omitempty"`
// Required. The hash value.
Value []byte `protobuf:"bytes,2,opt,name=value,proto3" json:"value,omitempty"`
// contains filtered or unexported fields
}
Container message for hash values.
func (*Hash) Descriptor ¶
Deprecated: Use Hash.ProtoReflect.Descriptor instead.
func (*Hash) GetType ¶
func (x *Hash) GetType() Hash_HashType
func (*Hash) GetValue ¶
func (*Hash) ProtoMessage ¶
func (*Hash) ProtoMessage()
func (*Hash) ProtoReflect ¶
func (x *Hash) ProtoReflect() protoreflect.Message
func (*Hash) Reset ¶
func (x *Hash) Reset()
func (*Hash) String ¶
type Hash_HashType ¶
type Hash_HashType int32
Specifies the hash algorithm.
const ( // Unknown. Hash_HASH_TYPE_UNSPECIFIED Hash_HashType = 0 // A SHA-256 hash. Hash_SHA256 Hash_HashType = 1 )
func (Hash_HashType) Descriptor ¶
func (Hash_HashType) Descriptor() protoreflect.EnumDescriptor
func (Hash_HashType) Enum ¶
func (x Hash_HashType) Enum() *Hash_HashType
func (Hash_HashType) EnumDescriptor ¶
func (Hash_HashType) EnumDescriptor() ([]byte, []int)
Deprecated: Use Hash_HashType.Descriptor instead.
func (Hash_HashType) Number ¶
func (x Hash_HashType) Number() protoreflect.EnumNumber
func (Hash_HashType) String ¶
func (x Hash_HashType) String() string
func (Hash_HashType) Type ¶
func (Hash_HashType) Type() protoreflect.EnumType
type Source ¶
type Source struct {
// If provided, the input binary artifacts for the build came from this
// location.
ArtifactStorageSourceUri string `protobuf:"bytes,1,opt,name=artifact_storage_source_uri,json=artifactStorageSourceUri,proto3" json:"artifact_storage_source_uri,omitempty"`
// Hash(es) of the build source, which can be used to verify that the original
// source integrity was maintained in the build.
//
// The keys to this map are file paths used as build source and the values
// contain the hash values for those files.
//
// If the build source came in a single package such as a gzipped tarfile
// (.tar.gz), the FileHash will be for the single path to that file.
FileHashes map[string]*FileHashes `protobuf:"bytes,2,rep,name=file_hashes,json=fileHashes,proto3" json:"file_hashes,omitempty" protobuf_key:"bytes,1,opt,name=key,proto3" protobuf_val:"bytes,2,opt,name=value,proto3"`
// If provided, the source code used for the build came from this location.
Context *source.SourceContext `protobuf:"bytes,3,opt,name=context,proto3" json:"context,omitempty"`
// If provided, some of the source code used for the build may be found in
// these locations, in the case where the source repository had multiple
// remotes or submodules. This list will not include the context specified in
// the context field.
AdditionalContexts []*source.SourceContext `protobuf:"bytes,4,rep,name=additional_contexts,json=additionalContexts,proto3" json:"additional_contexts,omitempty"`
// contains filtered or unexported fields
}
Source describes the location of the source used for the build.
func (*Source) Descriptor ¶
Deprecated: Use Source.ProtoReflect.Descriptor instead.
func (*Source) GetAdditionalContexts ¶
func (x *Source) GetAdditionalContexts() []*source.SourceContext
func (*Source) GetArtifactStorageSourceUri ¶
func (*Source) GetContext ¶
func (x *Source) GetContext() *source.SourceContext
func (*Source) GetFileHashes ¶
func (x *Source) GetFileHashes() map[string]*FileHashes
func (*Source) ProtoMessage ¶
func (*Source) ProtoMessage()
func (*Source) ProtoReflect ¶
func (x *Source) ProtoReflect() protoreflect.Message
func (*Source) Reset ¶
func (x *Source) Reset()
func (*Source) String ¶
Source Files ¶
provenance.pb.go
- Version
- v0.0.0-20260427160629-7cedc36a6bc4 (latest)
- Published
- Apr 27, 2026
- Platform
- linux/amd64
- Imports
- 6 packages
- Last checked
- 2 days ago –
Tools for package owners.