package source
import "google.golang.org/genproto/googleapis/devtools/source/v1"
Index ¶
- Variables
- type AliasContext
- func (*AliasContext) Descriptor() ([]byte, []int)
- func (x *AliasContext) GetKind() AliasContext_Kind
- func (x *AliasContext) GetName() string
- func (*AliasContext) ProtoMessage()
- func (x *AliasContext) ProtoReflect() protoreflect.Message
- func (x *AliasContext) Reset()
- func (x *AliasContext) String() string
- type AliasContext_Kind
- func (AliasContext_Kind) Descriptor() protoreflect.EnumDescriptor
- func (x AliasContext_Kind) Enum() *AliasContext_Kind
- func (AliasContext_Kind) EnumDescriptor() ([]byte, []int)
- func (x AliasContext_Kind) Number() protoreflect.EnumNumber
- func (x AliasContext_Kind) String() string
- func (AliasContext_Kind) Type() protoreflect.EnumType
- type CloudRepoSourceContext
- func (*CloudRepoSourceContext) Descriptor() ([]byte, []int)
- func (x *CloudRepoSourceContext) GetAliasContext() *AliasContext
- func (x *CloudRepoSourceContext) GetAliasName() string
- func (x *CloudRepoSourceContext) GetRepoId() *RepoId
- func (m *CloudRepoSourceContext) GetRevision() isCloudRepoSourceContext_Revision
- func (x *CloudRepoSourceContext) GetRevisionId() string
- func (*CloudRepoSourceContext) ProtoMessage()
- func (x *CloudRepoSourceContext) ProtoReflect() protoreflect.Message
- func (x *CloudRepoSourceContext) Reset()
- func (x *CloudRepoSourceContext) String() string
- type CloudRepoSourceContext_AliasContext
- type CloudRepoSourceContext_AliasName
- type CloudRepoSourceContext_RevisionId
- type CloudWorkspaceId
- func (*CloudWorkspaceId) Descriptor() ([]byte, []int)
- func (x *CloudWorkspaceId) GetName() string
- func (x *CloudWorkspaceId) GetRepoId() *RepoId
- func (*CloudWorkspaceId) ProtoMessage()
- func (x *CloudWorkspaceId) ProtoReflect() protoreflect.Message
- func (x *CloudWorkspaceId) Reset()
- func (x *CloudWorkspaceId) String() string
- type CloudWorkspaceSourceContext
- func (*CloudWorkspaceSourceContext) Descriptor() ([]byte, []int)
- func (x *CloudWorkspaceSourceContext) GetSnapshotId() string
- func (x *CloudWorkspaceSourceContext) GetWorkspaceId() *CloudWorkspaceId
- func (*CloudWorkspaceSourceContext) ProtoMessage()
- func (x *CloudWorkspaceSourceContext) ProtoReflect() protoreflect.Message
- func (x *CloudWorkspaceSourceContext) Reset()
- func (x *CloudWorkspaceSourceContext) String() string
- type ExtendedSourceContext
- func (*ExtendedSourceContext) Descriptor() ([]byte, []int)
- func (x *ExtendedSourceContext) GetContext() *SourceContext
- func (x *ExtendedSourceContext) GetLabels() map[string]string
- func (*ExtendedSourceContext) ProtoMessage()
- func (x *ExtendedSourceContext) ProtoReflect() protoreflect.Message
- func (x *ExtendedSourceContext) Reset()
- func (x *ExtendedSourceContext) String() string
- type GerritSourceContext
- func (*GerritSourceContext) Descriptor() ([]byte, []int)
- func (x *GerritSourceContext) GetAliasContext() *AliasContext
- func (x *GerritSourceContext) GetAliasName() string
- func (x *GerritSourceContext) GetGerritProject() string
- func (x *GerritSourceContext) GetHostUri() string
- func (m *GerritSourceContext) GetRevision() isGerritSourceContext_Revision
- func (x *GerritSourceContext) GetRevisionId() string
- func (*GerritSourceContext) ProtoMessage()
- func (x *GerritSourceContext) ProtoReflect() protoreflect.Message
- func (x *GerritSourceContext) Reset()
- func (x *GerritSourceContext) String() string
- type GerritSourceContext_AliasContext
- type GerritSourceContext_AliasName
- type GerritSourceContext_RevisionId
- type GitSourceContext
- func (*GitSourceContext) Descriptor() ([]byte, []int)
- func (x *GitSourceContext) GetRevisionId() string
- func (x *GitSourceContext) GetUrl() string
- func (*GitSourceContext) ProtoMessage()
- func (x *GitSourceContext) ProtoReflect() protoreflect.Message
- func (x *GitSourceContext) Reset()
- func (x *GitSourceContext) String() string
- type ProjectRepoId
- func (*ProjectRepoId) Descriptor() ([]byte, []int)
- func (x *ProjectRepoId) GetProjectId() string
- func (x *ProjectRepoId) GetRepoName() string
- func (*ProjectRepoId) ProtoMessage()
- func (x *ProjectRepoId) ProtoReflect() protoreflect.Message
- func (x *ProjectRepoId) Reset()
- func (x *ProjectRepoId) String() string
- type RepoId
- func (*RepoId) Descriptor() ([]byte, []int)
- func (m *RepoId) GetId() isRepoId_Id
- func (x *RepoId) GetProjectRepoId() *ProjectRepoId
- func (x *RepoId) GetUid() string
- func (*RepoId) ProtoMessage()
- func (x *RepoId) ProtoReflect() protoreflect.Message
- func (x *RepoId) Reset()
- func (x *RepoId) String() string
- type RepoId_ProjectRepoId
- type RepoId_Uid
- type SourceContext
- func (*SourceContext) Descriptor() ([]byte, []int)
- func (x *SourceContext) GetCloudRepo() *CloudRepoSourceContext
- func (x *SourceContext) GetCloudWorkspace() *CloudWorkspaceSourceContext
- func (m *SourceContext) GetContext() isSourceContext_Context
- func (x *SourceContext) GetGerrit() *GerritSourceContext
- func (x *SourceContext) GetGit() *GitSourceContext
- func (*SourceContext) ProtoMessage()
- func (x *SourceContext) ProtoReflect() protoreflect.Message
- func (x *SourceContext) Reset()
- func (x *SourceContext) String() string
- type SourceContext_CloudRepo
- type SourceContext_CloudWorkspace
- type SourceContext_Gerrit
- type SourceContext_Git
Variables ¶
var ( AliasContext_Kind_name = map[int32]string{ 0: "ANY", 1: "FIXED", 2: "MOVABLE", 4: "OTHER", } AliasContext_Kind_value = map[string]int32{ "ANY": 0, "FIXED": 1, "MOVABLE": 2, "OTHER": 4, } )
Enum value maps for AliasContext_Kind.
var File_google_devtools_source_v1_source_context_proto protoreflect.FileDescriptor
Types ¶
type AliasContext ¶
type AliasContext struct {
// The alias kind.
Kind AliasContext_Kind `protobuf:"varint,1,opt,name=kind,proto3,enum=google.devtools.source.v1.AliasContext_Kind" json:"kind,omitempty"`
// The alias name.
Name string `protobuf:"bytes,2,opt,name=name,proto3" json:"name,omitempty"`
// contains filtered or unexported fields
}
An alias to a repo revision.
func (*AliasContext) Descriptor ¶
func (*AliasContext) Descriptor() ([]byte, []int)
Deprecated: Use AliasContext.ProtoReflect.Descriptor instead.
func (*AliasContext) GetKind ¶
func (x *AliasContext) GetKind() AliasContext_Kind
func (*AliasContext) GetName ¶
func (x *AliasContext) GetName() string
func (*AliasContext) ProtoMessage ¶
func (*AliasContext) ProtoMessage()
func (*AliasContext) ProtoReflect ¶
func (x *AliasContext) ProtoReflect() protoreflect.Message
func (*AliasContext) Reset ¶
func (x *AliasContext) Reset()
func (*AliasContext) String ¶
func (x *AliasContext) String() string
type AliasContext_Kind ¶
type AliasContext_Kind int32
The type of an Alias.
const ( // Do not use. AliasContext_ANY AliasContext_Kind = 0 // Git tag AliasContext_FIXED AliasContext_Kind = 1 // Git branch AliasContext_MOVABLE AliasContext_Kind = 2 // OTHER is used to specify non-standard aliases, those not of the kinds // above. For example, if a Git repo has a ref named "refs/foo/bar", it // is considered to be of kind OTHER. AliasContext_OTHER AliasContext_Kind = 4 )
func (AliasContext_Kind) Descriptor ¶
func (AliasContext_Kind) Descriptor() protoreflect.EnumDescriptor
func (AliasContext_Kind) Enum ¶
func (x AliasContext_Kind) Enum() *AliasContext_Kind
func (AliasContext_Kind) EnumDescriptor ¶
func (AliasContext_Kind) EnumDescriptor() ([]byte, []int)
Deprecated: Use AliasContext_Kind.Descriptor instead.
func (AliasContext_Kind) Number ¶
func (x AliasContext_Kind) Number() protoreflect.EnumNumber
func (AliasContext_Kind) String ¶
func (x AliasContext_Kind) String() string
func (AliasContext_Kind) Type ¶
func (AliasContext_Kind) Type() protoreflect.EnumType
type CloudRepoSourceContext ¶
type CloudRepoSourceContext struct {
// The ID of the repo.
RepoId *RepoId `protobuf:"bytes,1,opt,name=repo_id,json=repoId,proto3" json:"repo_id,omitempty"`
// A revision in a cloud repository can be identified by either its revision
// ID or its Alias.
//
// Types that are assignable to Revision:
// *CloudRepoSourceContext_RevisionId
// *CloudRepoSourceContext_AliasName
// *CloudRepoSourceContext_AliasContext
Revision isCloudRepoSourceContext_Revision `protobuf_oneof:"revision"`
// contains filtered or unexported fields
}
A CloudRepoSourceContext denotes a particular revision in a cloud repo (a repo hosted by the Google Cloud Platform).
func (*CloudRepoSourceContext) Descriptor ¶
func (*CloudRepoSourceContext) Descriptor() ([]byte, []int)
Deprecated: Use CloudRepoSourceContext.ProtoReflect.Descriptor instead.
func (*CloudRepoSourceContext) GetAliasContext ¶
func (x *CloudRepoSourceContext) GetAliasContext() *AliasContext
func (*CloudRepoSourceContext) GetAliasName ¶
func (x *CloudRepoSourceContext) GetAliasName() string
Deprecated: Do not use.
func (*CloudRepoSourceContext) GetRepoId ¶
func (x *CloudRepoSourceContext) GetRepoId() *RepoId
func (*CloudRepoSourceContext) GetRevision ¶
func (m *CloudRepoSourceContext) GetRevision() isCloudRepoSourceContext_Revision
func (*CloudRepoSourceContext) GetRevisionId ¶
func (x *CloudRepoSourceContext) GetRevisionId() string
func (*CloudRepoSourceContext) ProtoMessage ¶
func (*CloudRepoSourceContext) ProtoMessage()
func (*CloudRepoSourceContext) ProtoReflect ¶
func (x *CloudRepoSourceContext) ProtoReflect() protoreflect.Message
func (*CloudRepoSourceContext) Reset ¶
func (x *CloudRepoSourceContext) Reset()
func (*CloudRepoSourceContext) String ¶
func (x *CloudRepoSourceContext) String() string
type CloudRepoSourceContext_AliasContext ¶
type CloudRepoSourceContext_AliasContext struct {
// An alias, which may be a branch or tag.
AliasContext *AliasContext `protobuf:"bytes,4,opt,name=alias_context,json=aliasContext,proto3,oneof"`
}
type CloudRepoSourceContext_AliasName ¶
type CloudRepoSourceContext_AliasName struct {
// The name of an alias (branch, tag, etc.).
//
// Deprecated: Do not use.
AliasName string `protobuf:"bytes,3,opt,name=alias_name,json=aliasName,proto3,oneof"`
}
type CloudRepoSourceContext_RevisionId ¶
type CloudRepoSourceContext_RevisionId struct {
// A revision ID.
RevisionId string `protobuf:"bytes,2,opt,name=revision_id,json=revisionId,proto3,oneof"`
}
type CloudWorkspaceId ¶
type CloudWorkspaceId struct {
// The ID of the repo containing the workspace.
RepoId *RepoId `protobuf:"bytes,1,opt,name=repo_id,json=repoId,proto3" json:"repo_id,omitempty"`
// The unique name of the workspace within the repo. This is the name
// chosen by the client in the Source API's CreateWorkspace method.
Name string `protobuf:"bytes,2,opt,name=name,proto3" json:"name,omitempty"`
// contains filtered or unexported fields
}
A CloudWorkspaceId is a unique identifier for a cloud workspace. A cloud workspace is a place associated with a repo where modified files can be stored before they are committed.
func (*CloudWorkspaceId) Descriptor ¶
func (*CloudWorkspaceId) Descriptor() ([]byte, []int)
Deprecated: Use CloudWorkspaceId.ProtoReflect.Descriptor instead.
func (*CloudWorkspaceId) GetName ¶
func (x *CloudWorkspaceId) GetName() string
func (*CloudWorkspaceId) GetRepoId ¶
func (x *CloudWorkspaceId) GetRepoId() *RepoId
func (*CloudWorkspaceId) ProtoMessage ¶
func (*CloudWorkspaceId) ProtoMessage()
func (*CloudWorkspaceId) ProtoReflect ¶
func (x *CloudWorkspaceId) ProtoReflect() protoreflect.Message
func (*CloudWorkspaceId) Reset ¶
func (x *CloudWorkspaceId) Reset()
func (*CloudWorkspaceId) String ¶
func (x *CloudWorkspaceId) String() string
type CloudWorkspaceSourceContext ¶
type CloudWorkspaceSourceContext struct {
// The ID of the workspace.
WorkspaceId *CloudWorkspaceId `protobuf:"bytes,1,opt,name=workspace_id,json=workspaceId,proto3" json:"workspace_id,omitempty"`
// The ID of the snapshot.
// An empty snapshot_id refers to the most recent snapshot.
SnapshotId string `protobuf:"bytes,2,opt,name=snapshot_id,json=snapshotId,proto3" json:"snapshot_id,omitempty"`
// contains filtered or unexported fields
}
A CloudWorkspaceSourceContext denotes a workspace at a particular snapshot.
func (*CloudWorkspaceSourceContext) Descriptor ¶
func (*CloudWorkspaceSourceContext) Descriptor() ([]byte, []int)
Deprecated: Use CloudWorkspaceSourceContext.ProtoReflect.Descriptor instead.
func (*CloudWorkspaceSourceContext) GetSnapshotId ¶
func (x *CloudWorkspaceSourceContext) GetSnapshotId() string
func (*CloudWorkspaceSourceContext) GetWorkspaceId ¶
func (x *CloudWorkspaceSourceContext) GetWorkspaceId() *CloudWorkspaceId
func (*CloudWorkspaceSourceContext) ProtoMessage ¶
func (*CloudWorkspaceSourceContext) ProtoMessage()
func (*CloudWorkspaceSourceContext) ProtoReflect ¶
func (x *CloudWorkspaceSourceContext) ProtoReflect() protoreflect.Message
func (*CloudWorkspaceSourceContext) Reset ¶
func (x *CloudWorkspaceSourceContext) Reset()
func (*CloudWorkspaceSourceContext) String ¶
func (x *CloudWorkspaceSourceContext) String() string
type ExtendedSourceContext ¶
type ExtendedSourceContext struct {
// Any source context.
Context *SourceContext `protobuf:"bytes,1,opt,name=context,proto3" json:"context,omitempty"`
// Labels with user defined metadata.
Labels map[string]string `protobuf:"bytes,2,rep,name=labels,proto3" json:"labels,omitempty" protobuf_key:"bytes,1,opt,name=key,proto3" protobuf_val:"bytes,2,opt,name=value,proto3"`
// contains filtered or unexported fields
}
An ExtendedSourceContext is a SourceContext combined with additional details describing the context.
func (*ExtendedSourceContext) Descriptor ¶
func (*ExtendedSourceContext) Descriptor() ([]byte, []int)
Deprecated: Use ExtendedSourceContext.ProtoReflect.Descriptor instead.
func (*ExtendedSourceContext) GetContext ¶
func (x *ExtendedSourceContext) GetContext() *SourceContext
func (*ExtendedSourceContext) GetLabels ¶
func (x *ExtendedSourceContext) GetLabels() map[string]string
func (*ExtendedSourceContext) ProtoMessage ¶
func (*ExtendedSourceContext) ProtoMessage()
func (*ExtendedSourceContext) ProtoReflect ¶
func (x *ExtendedSourceContext) ProtoReflect() protoreflect.Message
func (*ExtendedSourceContext) Reset ¶
func (x *ExtendedSourceContext) Reset()
func (*ExtendedSourceContext) String ¶
func (x *ExtendedSourceContext) String() string
type GerritSourceContext ¶
type GerritSourceContext struct {
// The URI of a running Gerrit instance.
HostUri string `protobuf:"bytes,1,opt,name=host_uri,json=hostUri,proto3" json:"host_uri,omitempty"`
// The full project name within the host. Projects may be nested, so
// "project/subproject" is a valid project name.
// The "repo name" is hostURI/project.
GerritProject string `protobuf:"bytes,2,opt,name=gerrit_project,json=gerritProject,proto3" json:"gerrit_project,omitempty"`
// A revision in a Gerrit project can be identified by either its revision ID
// or its alias.
//
// Types that are assignable to Revision:
// *GerritSourceContext_RevisionId
// *GerritSourceContext_AliasName
// *GerritSourceContext_AliasContext
Revision isGerritSourceContext_Revision `protobuf_oneof:"revision"`
// contains filtered or unexported fields
}
A SourceContext referring to a Gerrit project.
func (*GerritSourceContext) Descriptor ¶
func (*GerritSourceContext) Descriptor() ([]byte, []int)
Deprecated: Use GerritSourceContext.ProtoReflect.Descriptor instead.
func (*GerritSourceContext) GetAliasContext ¶
func (x *GerritSourceContext) GetAliasContext() *AliasContext
func (*GerritSourceContext) GetAliasName ¶
func (x *GerritSourceContext) GetAliasName() string
Deprecated: Do not use.
func (*GerritSourceContext) GetGerritProject ¶
func (x *GerritSourceContext) GetGerritProject() string
func (*GerritSourceContext) GetHostUri ¶
func (x *GerritSourceContext) GetHostUri() string
func (*GerritSourceContext) GetRevision ¶
func (m *GerritSourceContext) GetRevision() isGerritSourceContext_Revision
func (*GerritSourceContext) GetRevisionId ¶
func (x *GerritSourceContext) GetRevisionId() string
func (*GerritSourceContext) ProtoMessage ¶
func (*GerritSourceContext) ProtoMessage()
func (*GerritSourceContext) ProtoReflect ¶
func (x *GerritSourceContext) ProtoReflect() protoreflect.Message
func (*GerritSourceContext) Reset ¶
func (x *GerritSourceContext) Reset()
func (*GerritSourceContext) String ¶
func (x *GerritSourceContext) String() string
type GerritSourceContext_AliasContext ¶
type GerritSourceContext_AliasContext struct {
// An alias, which may be a branch or tag.
AliasContext *AliasContext `protobuf:"bytes,5,opt,name=alias_context,json=aliasContext,proto3,oneof"`
}
type GerritSourceContext_AliasName ¶
type GerritSourceContext_AliasName struct {
// The name of an alias (branch, tag, etc.).
//
// Deprecated: Do not use.
AliasName string `protobuf:"bytes,4,opt,name=alias_name,json=aliasName,proto3,oneof"`
}
type GerritSourceContext_RevisionId ¶
type GerritSourceContext_RevisionId struct {
// A revision (commit) ID.
RevisionId string `protobuf:"bytes,3,opt,name=revision_id,json=revisionId,proto3,oneof"`
}
type GitSourceContext ¶
type GitSourceContext struct {
// Git repository URL.
Url string `protobuf:"bytes,1,opt,name=url,proto3" json:"url,omitempty"`
// Git commit hash.
// required.
RevisionId string `protobuf:"bytes,2,opt,name=revision_id,json=revisionId,proto3" json:"revision_id,omitempty"`
// contains filtered or unexported fields
}
A GitSourceContext denotes a particular revision in a third party Git repository (e.g. GitHub).
func (*GitSourceContext) Descriptor ¶
func (*GitSourceContext) Descriptor() ([]byte, []int)
Deprecated: Use GitSourceContext.ProtoReflect.Descriptor instead.
func (*GitSourceContext) GetRevisionId ¶
func (x *GitSourceContext) GetRevisionId() string
func (*GitSourceContext) GetUrl ¶
func (x *GitSourceContext) GetUrl() string
func (*GitSourceContext) ProtoMessage ¶
func (*GitSourceContext) ProtoMessage()
func (*GitSourceContext) ProtoReflect ¶
func (x *GitSourceContext) ProtoReflect() protoreflect.Message
func (*GitSourceContext) Reset ¶
func (x *GitSourceContext) Reset()
func (*GitSourceContext) String ¶
func (x *GitSourceContext) String() string
type ProjectRepoId ¶
type ProjectRepoId struct {
// The ID of the project.
ProjectId string `protobuf:"bytes,1,opt,name=project_id,json=projectId,proto3" json:"project_id,omitempty"`
// The name of the repo. Leave empty for the default repo.
RepoName string `protobuf:"bytes,2,opt,name=repo_name,json=repoName,proto3" json:"repo_name,omitempty"`
// contains filtered or unexported fields
}
Selects a repo using a Google Cloud Platform project ID (e.g. winged-cargo-31) and a repo name within that project.
func (*ProjectRepoId) Descriptor ¶
func (*ProjectRepoId) Descriptor() ([]byte, []int)
Deprecated: Use ProjectRepoId.ProtoReflect.Descriptor instead.
func (*ProjectRepoId) GetProjectId ¶
func (x *ProjectRepoId) GetProjectId() string
func (*ProjectRepoId) GetRepoName ¶
func (x *ProjectRepoId) GetRepoName() string
func (*ProjectRepoId) ProtoMessage ¶
func (*ProjectRepoId) ProtoMessage()
func (*ProjectRepoId) ProtoReflect ¶
func (x *ProjectRepoId) ProtoReflect() protoreflect.Message
func (*ProjectRepoId) Reset ¶
func (x *ProjectRepoId) Reset()
func (*ProjectRepoId) String ¶
func (x *ProjectRepoId) String() string
type RepoId ¶
type RepoId struct {
// A cloud repository can be identified by either its project ID and
// repository name combination, or its globally unique identifier.
//
// Types that are assignable to Id:
// *RepoId_ProjectRepoId
// *RepoId_Uid
Id isRepoId_Id `protobuf_oneof:"id"`
// contains filtered or unexported fields
}
A unique identifier for a cloud repo.
func (*RepoId) Descriptor ¶
Deprecated: Use RepoId.ProtoReflect.Descriptor instead.
func (*RepoId) GetId ¶
func (m *RepoId) GetId() isRepoId_Id
func (*RepoId) GetProjectRepoId ¶
func (x *RepoId) GetProjectRepoId() *ProjectRepoId
func (*RepoId) GetUid ¶
func (*RepoId) ProtoMessage ¶
func (*RepoId) ProtoMessage()
func (*RepoId) ProtoReflect ¶
func (x *RepoId) ProtoReflect() protoreflect.Message
func (*RepoId) Reset ¶
func (x *RepoId) Reset()
func (*RepoId) String ¶
type RepoId_ProjectRepoId ¶
type RepoId_ProjectRepoId struct {
// A combination of a project ID and a repo name.
ProjectRepoId *ProjectRepoId `protobuf:"bytes,1,opt,name=project_repo_id,json=projectRepoId,proto3,oneof"`
}
type RepoId_Uid ¶
type RepoId_Uid struct {
// A server-assigned, globally unique identifier.
Uid string `protobuf:"bytes,2,opt,name=uid,proto3,oneof"`
}
type SourceContext ¶
type SourceContext struct {
// A SourceContext can refer any one of the following types of repositories.
//
// Types that are assignable to Context:
// *SourceContext_CloudRepo
// *SourceContext_CloudWorkspace
// *SourceContext_Gerrit
// *SourceContext_Git
Context isSourceContext_Context `protobuf_oneof:"context"`
// contains filtered or unexported fields
}
A SourceContext is a reference to a tree of files. A SourceContext together with a path point to a unique revision of a single file or directory.
func (*SourceContext) Descriptor ¶
func (*SourceContext) Descriptor() ([]byte, []int)
Deprecated: Use SourceContext.ProtoReflect.Descriptor instead.
func (*SourceContext) GetCloudRepo ¶
func (x *SourceContext) GetCloudRepo() *CloudRepoSourceContext
func (*SourceContext) GetCloudWorkspace ¶
func (x *SourceContext) GetCloudWorkspace() *CloudWorkspaceSourceContext
func (*SourceContext) GetContext ¶
func (m *SourceContext) GetContext() isSourceContext_Context
func (*SourceContext) GetGerrit ¶
func (x *SourceContext) GetGerrit() *GerritSourceContext
func (*SourceContext) GetGit ¶
func (x *SourceContext) GetGit() *GitSourceContext
func (*SourceContext) ProtoMessage ¶
func (*SourceContext) ProtoMessage()
func (*SourceContext) ProtoReflect ¶
func (x *SourceContext) ProtoReflect() protoreflect.Message
func (*SourceContext) Reset ¶
func (x *SourceContext) Reset()
func (*SourceContext) String ¶
func (x *SourceContext) String() string
type SourceContext_CloudRepo ¶
type SourceContext_CloudRepo struct {
// A SourceContext referring to a revision in a cloud repo.
CloudRepo *CloudRepoSourceContext `protobuf:"bytes,1,opt,name=cloud_repo,json=cloudRepo,proto3,oneof"`
}
type SourceContext_CloudWorkspace ¶
type SourceContext_CloudWorkspace struct {
// A SourceContext referring to a snapshot in a cloud workspace.
CloudWorkspace *CloudWorkspaceSourceContext `protobuf:"bytes,2,opt,name=cloud_workspace,json=cloudWorkspace,proto3,oneof"`
}
type SourceContext_Gerrit ¶
type SourceContext_Gerrit struct {
// A SourceContext referring to a Gerrit project.
Gerrit *GerritSourceContext `protobuf:"bytes,3,opt,name=gerrit,proto3,oneof"`
}
type SourceContext_Git ¶
type SourceContext_Git struct {
// A SourceContext referring to any third party Git repo (e.g. GitHub).
Git *GitSourceContext `protobuf:"bytes,6,opt,name=git,proto3,oneof"`
}
Source Files ¶
source_context.pb.go
- Version
- v0.0.0-20260427160629-7cedc36a6bc4 (latest)
- Published
- Apr 27, 2026
- Platform
- linux/amd64
- Imports
- 4 packages
- Last checked
- 2 days ago –
Tools for package owners.