package metadata
import "google.golang.org/genproto/googleapis/gapic/metadata"
Index ¶
- Variables
- type GapicMetadata
- func (*GapicMetadata) Descriptor() ([]byte, []int)
- func (x *GapicMetadata) GetComment() string
- func (x *GapicMetadata) GetLanguage() string
- func (x *GapicMetadata) GetLibraryPackage() string
- func (x *GapicMetadata) GetProtoPackage() string
- func (x *GapicMetadata) GetSchema() string
- func (x *GapicMetadata) GetServices() map[string]*GapicMetadata_ServiceForTransport
- func (*GapicMetadata) ProtoMessage()
- func (x *GapicMetadata) ProtoReflect() protoreflect.Message
- func (x *GapicMetadata) Reset()
- func (x *GapicMetadata) String() string
- type GapicMetadata_MethodList
- func (*GapicMetadata_MethodList) Descriptor() ([]byte, []int)
- func (x *GapicMetadata_MethodList) GetMethods() []string
- func (*GapicMetadata_MethodList) ProtoMessage()
- func (x *GapicMetadata_MethodList) ProtoReflect() protoreflect.Message
- func (x *GapicMetadata_MethodList) Reset()
- func (x *GapicMetadata_MethodList) String() string
- type GapicMetadata_ServiceAsClient
- func (*GapicMetadata_ServiceAsClient) Descriptor() ([]byte, []int)
- func (x *GapicMetadata_ServiceAsClient) GetLibraryClient() string
- func (x *GapicMetadata_ServiceAsClient) GetRpcs() map[string]*GapicMetadata_MethodList
- func (*GapicMetadata_ServiceAsClient) ProtoMessage()
- func (x *GapicMetadata_ServiceAsClient) ProtoReflect() protoreflect.Message
- func (x *GapicMetadata_ServiceAsClient) Reset()
- func (x *GapicMetadata_ServiceAsClient) String() string
- type GapicMetadata_ServiceForTransport
- func (*GapicMetadata_ServiceForTransport) Descriptor() ([]byte, []int)
- func (x *GapicMetadata_ServiceForTransport) GetApiVersion() string
- func (x *GapicMetadata_ServiceForTransport) GetClients() map[string]*GapicMetadata_ServiceAsClient
- func (*GapicMetadata_ServiceForTransport) ProtoMessage()
- func (x *GapicMetadata_ServiceForTransport) ProtoReflect() protoreflect.Message
- func (x *GapicMetadata_ServiceForTransport) Reset()
- func (x *GapicMetadata_ServiceForTransport) String() string
Variables ¶
var File_gapic_metadata_gapic_metadata_proto protoreflect.FileDescriptor
Types ¶
type GapicMetadata ¶
type GapicMetadata struct {
// Schema version of this proto. Current value: 1.0
Schema string `protobuf:"bytes,1,opt,name=schema,proto3" json:"schema,omitempty"`
// Any human-readable comments to be included in this file.
Comment string `protobuf:"bytes,2,opt,name=comment,proto3" json:"comment,omitempty"`
// Computer language of this generated language. This must be
// spelled out as it spoken in English, with no capitalization or
// separators (e.g. "csharp", "nodejs").
Language string `protobuf:"bytes,3,opt,name=language,proto3" json:"language,omitempty"`
// The proto package containing the API definition for which this
// GAPIC library was generated.
ProtoPackage string `protobuf:"bytes,4,opt,name=proto_package,json=protoPackage,proto3" json:"proto_package,omitempty"`
// The language-specific library package for this GAPIC library.
LibraryPackage string `protobuf:"bytes,5,opt,name=library_package,json=libraryPackage,proto3" json:"library_package,omitempty"`
// A map from each proto-defined service to ServiceForTransports,
// which allows listing information about transport-specific
// implementations of the service.
//
// The key is the name of the service as it appears in the .proto
// file.
Services map[string]*GapicMetadata_ServiceForTransport `protobuf:"bytes,6,rep,name=services,proto3" json:"services,omitempty" protobuf_key:"bytes,1,opt,name=key,proto3" protobuf_val:"bytes,2,opt,name=value,proto3"`
// contains filtered or unexported fields
}
Metadata about a GAPIC library service for a specific combination of API, version, and computer language.
func (*GapicMetadata) Descriptor ¶
func (*GapicMetadata) Descriptor() ([]byte, []int)
Deprecated: Use GapicMetadata.ProtoReflect.Descriptor instead.
func (*GapicMetadata) GetComment ¶
func (x *GapicMetadata) GetComment() string
func (*GapicMetadata) GetLanguage ¶
func (x *GapicMetadata) GetLanguage() string
func (*GapicMetadata) GetLibraryPackage ¶
func (x *GapicMetadata) GetLibraryPackage() string
func (*GapicMetadata) GetProtoPackage ¶
func (x *GapicMetadata) GetProtoPackage() string
func (*GapicMetadata) GetSchema ¶
func (x *GapicMetadata) GetSchema() string
func (*GapicMetadata) GetServices ¶
func (x *GapicMetadata) GetServices() map[string]*GapicMetadata_ServiceForTransport
func (*GapicMetadata) ProtoMessage ¶
func (*GapicMetadata) ProtoMessage()
func (*GapicMetadata) ProtoReflect ¶
func (x *GapicMetadata) ProtoReflect() protoreflect.Message
func (*GapicMetadata) Reset ¶
func (x *GapicMetadata) Reset()
func (*GapicMetadata) String ¶
func (x *GapicMetadata) String() string
type GapicMetadata_MethodList ¶
type GapicMetadata_MethodList struct {
// List of methods for a specific proto-service client in the
// GAPIC. These names should be formatted as they appear in the
// source code.
Methods []string `protobuf:"bytes,1,rep,name=methods,proto3" json:"methods,omitempty"`
// contains filtered or unexported fields
}
List of GAPIC client methods implementing the proto-defined RPC for the transport and service specified in the containing structures.
func (*GapicMetadata_MethodList) Descriptor ¶
func (*GapicMetadata_MethodList) Descriptor() ([]byte, []int)
Deprecated: Use GapicMetadata_MethodList.ProtoReflect.Descriptor instead.
func (*GapicMetadata_MethodList) GetMethods ¶
func (x *GapicMetadata_MethodList) GetMethods() []string
func (*GapicMetadata_MethodList) ProtoMessage ¶
func (*GapicMetadata_MethodList) ProtoMessage()
func (*GapicMetadata_MethodList) ProtoReflect ¶
func (x *GapicMetadata_MethodList) ProtoReflect() protoreflect.Message
func (*GapicMetadata_MethodList) Reset ¶
func (x *GapicMetadata_MethodList) Reset()
func (*GapicMetadata_MethodList) String ¶
func (x *GapicMetadata_MethodList) String() string
type GapicMetadata_ServiceAsClient ¶
type GapicMetadata_ServiceAsClient struct {
// The name of the library client formatted as it appears in the source code
LibraryClient string `protobuf:"bytes,1,opt,name=library_client,json=libraryClient,proto3" json:"library_client,omitempty"`
// A mapping from each proto-defined RPC name to the the list of
// methods in library_client that implement it. There can be more
// than one library_client method for each RPC. RPCs with no
// library_client methods need not be included.
//
// The key name is the name of the RPC as defined and formatted in
// the proto file.
Rpcs map[string]*GapicMetadata_MethodList `protobuf:"bytes,2,rep,name=rpcs,proto3" json:"rpcs,omitempty" protobuf_key:"bytes,1,opt,name=key,proto3" protobuf_val:"bytes,2,opt,name=value,proto3"`
// contains filtered or unexported fields
}
Information about a specific client implementing a proto-defined service.
func (*GapicMetadata_ServiceAsClient) Descriptor ¶
func (*GapicMetadata_ServiceAsClient) Descriptor() ([]byte, []int)
Deprecated: Use GapicMetadata_ServiceAsClient.ProtoReflect.Descriptor instead.
func (*GapicMetadata_ServiceAsClient) GetLibraryClient ¶
func (x *GapicMetadata_ServiceAsClient) GetLibraryClient() string
func (*GapicMetadata_ServiceAsClient) GetRpcs ¶
func (x *GapicMetadata_ServiceAsClient) GetRpcs() map[string]*GapicMetadata_MethodList
func (*GapicMetadata_ServiceAsClient) ProtoMessage ¶
func (*GapicMetadata_ServiceAsClient) ProtoMessage()
func (*GapicMetadata_ServiceAsClient) ProtoReflect ¶
func (x *GapicMetadata_ServiceAsClient) ProtoReflect() protoreflect.Message
func (*GapicMetadata_ServiceAsClient) Reset ¶
func (x *GapicMetadata_ServiceAsClient) Reset()
func (*GapicMetadata_ServiceAsClient) String ¶
func (x *GapicMetadata_ServiceAsClient) String() string
type GapicMetadata_ServiceForTransport ¶
type GapicMetadata_ServiceForTransport struct {
// Map of transport name to ServiceAsClient. The key name is the transport,
// lower-cased with no separators (e.g. "grpc", "rest").
Clients map[string]*GapicMetadata_ServiceAsClient `protobuf:"bytes,1,rep,name=clients,proto3" json:"clients,omitempty" protobuf_key:"bytes,1,opt,name=key,proto3" protobuf_val:"bytes,2,opt,name=value,proto3"`
// The API version for the interface definition found in the
// `google.api.api_version` annotation of this proto-defined service during
// code generation.
// This is the value populated by the client in the API version request
// parameter as per
// [AIP-4236](https://google.aip.dev/client-libraries/4236).
ApiVersion string `protobuf:"bytes,2,opt,name=api_version,json=apiVersion,proto3" json:"api_version,omitempty"`
// contains filtered or unexported fields
}
A map from a transport name to ServiceAsClient, which allows listing information about the client objects that implement the parent RPC service for the specified transport.
func (*GapicMetadata_ServiceForTransport) Descriptor ¶
func (*GapicMetadata_ServiceForTransport) Descriptor() ([]byte, []int)
Deprecated: Use GapicMetadata_ServiceForTransport.ProtoReflect.Descriptor instead.
func (*GapicMetadata_ServiceForTransport) GetApiVersion ¶
func (x *GapicMetadata_ServiceForTransport) GetApiVersion() string
func (*GapicMetadata_ServiceForTransport) GetClients ¶
func (x *GapicMetadata_ServiceForTransport) GetClients() map[string]*GapicMetadata_ServiceAsClient
func (*GapicMetadata_ServiceForTransport) ProtoMessage ¶
func (*GapicMetadata_ServiceForTransport) ProtoMessage()
func (*GapicMetadata_ServiceForTransport) ProtoReflect ¶
func (x *GapicMetadata_ServiceForTransport) ProtoReflect() protoreflect.Message
func (*GapicMetadata_ServiceForTransport) Reset ¶
func (x *GapicMetadata_ServiceForTransport) Reset()
func (*GapicMetadata_ServiceForTransport) String ¶
func (x *GapicMetadata_ServiceForTransport) String() string
Source Files ¶
gapic_metadata.pb.go
- Version
- v0.0.0-20260427160629-7cedc36a6bc4 (latest)
- Published
- Apr 27, 2026
- Platform
- linux/amd64
- Imports
- 4 packages
- Last checked
- 2 days ago –
Tools for package owners.