package routes
import "google.golang.org/genproto/googleapis/maps/routes/v1alpha"
Index ¶
- Variables
- func RegisterRoutesAlphaServer(s *grpc.Server, srv RoutesAlphaServer)
- type RoutesAlphaClient
- type RoutesAlphaServer
- type RoutesAlpha_ComputeRouteMatrixClient
- type RoutesAlpha_ComputeRouteMatrixServer
- type UnimplementedRoutesAlphaServer
- func (*UnimplementedRoutesAlphaServer) ComputeCustomRoutes(context.Context, *v1.ComputeCustomRoutesRequest) (*v1.ComputeCustomRoutesResponse, error)
- func (*UnimplementedRoutesAlphaServer) ComputeRouteMatrix(*v1.ComputeRouteMatrixRequest, RoutesAlpha_ComputeRouteMatrixServer) error
- func (*UnimplementedRoutesAlphaServer) ComputeRoutes(context.Context, *v1.ComputeRoutesRequest) (*v1.ComputeRoutesResponse, error)
Variables ¶
var File_google_maps_routes_v1alpha_route_service_proto protoreflect.FileDescriptor
Functions ¶
func RegisterRoutesAlphaServer ¶
func RegisterRoutesAlphaServer(s *grpc.Server, srv RoutesAlphaServer)
Types ¶
type RoutesAlphaClient ¶
type RoutesAlphaClient interface {
// Returns the primary route along with optional alternate routes, given a set
// of terminal and intermediate waypoints.
//
// **NOTE:** This method requires that you specify a response field mask in
// the input. You can provide the response field mask by using the URL
// parameter `$fields` or `fields`, or by using the HTTP/gRPC header
// `X-Goog-FieldMask` (see the [available URL parameters and
// headers](https://cloud.google.com/apis/docs/system-parameters). The value
// is a comma separated list of field paths. See this detailed documentation
// about [how to construct the field
// paths](https://github.com/protocolbuffers/protobuf/blob/master/src/google/protobuf/field_mask.proto).
//
// For example, in this method:
//
// * Field mask of all available fields (for manual inspection):
// `X-Goog-FieldMask: *`
// * Field mask of Route-level duration, distance, and polyline (an example
// production setup):
// `X-Goog-FieldMask:
// routes.duration,routes.distanceMeters,routes.polyline.encodedPolyline`
//
// Google discourages the use of the wildcard (`*`) response field mask, or
// specifying the field mask at the top level (`routes`), because:
//
// * Selecting only the fields that you need helps our server save computation
// cycles, allowing us to return the result to you with a lower latency.
// * Selecting only the fields that you need in your production job ensures
// stable latency performance. We might add more response fields in the
// future, and those new fields might require extra computation time. If you
// select all fields, or if you select all fields at the top level, then you
// might experience performance degradation because any new field we add will
// be automatically included in the response.
// * Selecting only the fields that you need results in a smaller response
// size, and thus higher network throughput.
ComputeRoutes(ctx context.Context, in *v1.ComputeRoutesRequest, opts ...grpc.CallOption) (*v1.ComputeRoutesResponse, error)
// Takes in a list of origins and destinations and returns a stream containing
// route information for each combination of origin and destination.
//
// **NOTE:** This method requires that you specify a response field mask in
// the input. You can provide the response field mask by using the URL
// parameter `$fields` or `fields`, or by using the HTTP/gRPC header
// `X-Goog-FieldMask` (see the [available URL parameters and
// headers](https://cloud.google.com/apis/docs/system-parameters). The value
// is a comma separated list of field paths. See this detailed documentation
// about [how to construct the field
// paths](https://github.com/protocolbuffers/protobuf/blob/master/src/google/protobuf/field_mask.proto).
//
// For example, in this method:
//
// * Field mask of all available fields (for manual inspection):
// `X-Goog-FieldMask: *`
// * Field mask of route durations, distances, element status, condition, and
// element indices (an example production setup):
// `X-Goog-FieldMask:
// originIndex,destinationIndex,status,condition,distanceMeters,duration`
//
// It is critical that you include `status` in your field mask as otherwise
// all messages will appear to be OK. Google discourages the use of the
// wildcard (`*`) response field mask, because:
//
// * Selecting only the fields that you need helps our server save computation
// cycles, allowing us to return the result to you with a lower latency.
// * Selecting only the fields that you need in your production job ensures
// stable latency performance. We might add more response fields in the
// future, and those new fields might require extra computation time. If you
// select all fields, or if you select all fields at the top level, then you
// might experience performance degradation because any new field we add will
// be automatically included in the response.
// * Selecting only the fields that you need results in a smaller response
// size, and thus higher network throughput.
ComputeRouteMatrix(ctx context.Context, in *v1.ComputeRouteMatrixRequest, opts ...grpc.CallOption) (RoutesAlpha_ComputeRouteMatrixClient, error)
// Given a set of terminal and intermediate waypoints, and a route objective,
// computes the best route for the route objective. Also returns fastest route
// and shortest route as reference routes.
//
// **NOTE:** This method requires that you specify a response field mask in
// the input. You can provide the response field mask by using the URL
// parameter `$fields` or `fields`, or by using the HTTP/gRPC header
// `X-Goog-FieldMask` (see the [available URL parameters and
// headers](https://cloud.google.com/apis/docs/system-parameters). The value
// is a comma separated list of field paths. See this detailed documentation
// about [how to construct the field
// paths](https://github.com/protocolbuffers/protobuf/blob/master/src/google/protobuf/field_mask.proto).
//
// For example, in this method:
//
// * Field mask of all available fields (for manual inspection):
// `X-Goog-FieldMask: *`
// * Field mask of route distances, durations, token and toll info:
// `X-Goog-FieldMask:
// routes.route.distanceMeters,routes.route.duration,routes.token,routes.route.travelAdvisory.tollInfo`
//
// Google discourages the use of the wildcard (`*`) response field mask, or
// specifying the field mask at the top level (`routes`), because:
//
// * Selecting only the fields that you need helps our server save computation
// cycles, allowing us to return the result to you with a lower latency.
// * Selecting only the fields that you need in your production job ensures
// stable latency performance. We might add more response fields in the
// future, and those new fields might require extra computation time. If you
// select all fields, or if you select all fields at the top level, then you
// might experience performance degradation because any new field we add will
// be automatically included in the response.
// * Selecting only the fields that you need results in a smaller response
// size, and thus higher network throughput.
ComputeCustomRoutes(ctx context.Context, in *v1.ComputeCustomRoutesRequest, opts ...grpc.CallOption) (*v1.ComputeCustomRoutesResponse, error)
}
RoutesAlphaClient is the client API for RoutesAlpha service.
For semantics around ctx use and closing/ending streaming RPCs, please refer to https://godoc.org/google.golang.org/grpc#ClientConn.NewStream.
func NewRoutesAlphaClient ¶
func NewRoutesAlphaClient(cc grpc.ClientConnInterface) RoutesAlphaClient
type RoutesAlphaServer ¶
type RoutesAlphaServer interface {
// Returns the primary route along with optional alternate routes, given a set
// of terminal and intermediate waypoints.
//
// **NOTE:** This method requires that you specify a response field mask in
// the input. You can provide the response field mask by using the URL
// parameter `$fields` or `fields`, or by using the HTTP/gRPC header
// `X-Goog-FieldMask` (see the [available URL parameters and
// headers](https://cloud.google.com/apis/docs/system-parameters). The value
// is a comma separated list of field paths. See this detailed documentation
// about [how to construct the field
// paths](https://github.com/protocolbuffers/protobuf/blob/master/src/google/protobuf/field_mask.proto).
//
// For example, in this method:
//
// * Field mask of all available fields (for manual inspection):
// `X-Goog-FieldMask: *`
// * Field mask of Route-level duration, distance, and polyline (an example
// production setup):
// `X-Goog-FieldMask:
// routes.duration,routes.distanceMeters,routes.polyline.encodedPolyline`
//
// Google discourages the use of the wildcard (`*`) response field mask, or
// specifying the field mask at the top level (`routes`), because:
//
// * Selecting only the fields that you need helps our server save computation
// cycles, allowing us to return the result to you with a lower latency.
// * Selecting only the fields that you need in your production job ensures
// stable latency performance. We might add more response fields in the
// future, and those new fields might require extra computation time. If you
// select all fields, or if you select all fields at the top level, then you
// might experience performance degradation because any new field we add will
// be automatically included in the response.
// * Selecting only the fields that you need results in a smaller response
// size, and thus higher network throughput.
ComputeRoutes(context.Context, *v1.ComputeRoutesRequest) (*v1.ComputeRoutesResponse, error)
// Takes in a list of origins and destinations and returns a stream containing
// route information for each combination of origin and destination.
//
// **NOTE:** This method requires that you specify a response field mask in
// the input. You can provide the response field mask by using the URL
// parameter `$fields` or `fields`, or by using the HTTP/gRPC header
// `X-Goog-FieldMask` (see the [available URL parameters and
// headers](https://cloud.google.com/apis/docs/system-parameters). The value
// is a comma separated list of field paths. See this detailed documentation
// about [how to construct the field
// paths](https://github.com/protocolbuffers/protobuf/blob/master/src/google/protobuf/field_mask.proto).
//
// For example, in this method:
//
// * Field mask of all available fields (for manual inspection):
// `X-Goog-FieldMask: *`
// * Field mask of route durations, distances, element status, condition, and
// element indices (an example production setup):
// `X-Goog-FieldMask:
// originIndex,destinationIndex,status,condition,distanceMeters,duration`
//
// It is critical that you include `status` in your field mask as otherwise
// all messages will appear to be OK. Google discourages the use of the
// wildcard (`*`) response field mask, because:
//
// * Selecting only the fields that you need helps our server save computation
// cycles, allowing us to return the result to you with a lower latency.
// * Selecting only the fields that you need in your production job ensures
// stable latency performance. We might add more response fields in the
// future, and those new fields might require extra computation time. If you
// select all fields, or if you select all fields at the top level, then you
// might experience performance degradation because any new field we add will
// be automatically included in the response.
// * Selecting only the fields that you need results in a smaller response
// size, and thus higher network throughput.
ComputeRouteMatrix(*v1.ComputeRouteMatrixRequest, RoutesAlpha_ComputeRouteMatrixServer) error
// Given a set of terminal and intermediate waypoints, and a route objective,
// computes the best route for the route objective. Also returns fastest route
// and shortest route as reference routes.
//
// **NOTE:** This method requires that you specify a response field mask in
// the input. You can provide the response field mask by using the URL
// parameter `$fields` or `fields`, or by using the HTTP/gRPC header
// `X-Goog-FieldMask` (see the [available URL parameters and
// headers](https://cloud.google.com/apis/docs/system-parameters). The value
// is a comma separated list of field paths. See this detailed documentation
// about [how to construct the field
// paths](https://github.com/protocolbuffers/protobuf/blob/master/src/google/protobuf/field_mask.proto).
//
// For example, in this method:
//
// * Field mask of all available fields (for manual inspection):
// `X-Goog-FieldMask: *`
// * Field mask of route distances, durations, token and toll info:
// `X-Goog-FieldMask:
// routes.route.distanceMeters,routes.route.duration,routes.token,routes.route.travelAdvisory.tollInfo`
//
// Google discourages the use of the wildcard (`*`) response field mask, or
// specifying the field mask at the top level (`routes`), because:
//
// * Selecting only the fields that you need helps our server save computation
// cycles, allowing us to return the result to you with a lower latency.
// * Selecting only the fields that you need in your production job ensures
// stable latency performance. We might add more response fields in the
// future, and those new fields might require extra computation time. If you
// select all fields, or if you select all fields at the top level, then you
// might experience performance degradation because any new field we add will
// be automatically included in the response.
// * Selecting only the fields that you need results in a smaller response
// size, and thus higher network throughput.
ComputeCustomRoutes(context.Context, *v1.ComputeCustomRoutesRequest) (*v1.ComputeCustomRoutesResponse, error)
}
RoutesAlphaServer is the server API for RoutesAlpha service.
type RoutesAlpha_ComputeRouteMatrixClient ¶
type RoutesAlpha_ComputeRouteMatrixClient interface {
Recv() (*v1.RouteMatrixElement, error)
grpc.ClientStream
}
type RoutesAlpha_ComputeRouteMatrixServer ¶
type RoutesAlpha_ComputeRouteMatrixServer interface {
Send(*v1.RouteMatrixElement) error
grpc.ServerStream
}
type UnimplementedRoutesAlphaServer ¶
type UnimplementedRoutesAlphaServer struct {
}
UnimplementedRoutesAlphaServer can be embedded to have forward compatible implementations.
func (*UnimplementedRoutesAlphaServer) ComputeCustomRoutes ¶
func (*UnimplementedRoutesAlphaServer) ComputeCustomRoutes(context.Context, *v1.ComputeCustomRoutesRequest) (*v1.ComputeCustomRoutesResponse, error)
func (*UnimplementedRoutesAlphaServer) ComputeRouteMatrix ¶
func (*UnimplementedRoutesAlphaServer) ComputeRouteMatrix(*v1.ComputeRouteMatrixRequest, RoutesAlpha_ComputeRouteMatrixServer) error
func (*UnimplementedRoutesAlphaServer) ComputeRoutes ¶
func (*UnimplementedRoutesAlphaServer) ComputeRoutes(context.Context, *v1.ComputeRoutesRequest) (*v1.ComputeRoutesResponse, error)
Source Files ¶
route_service.pb.go
- Version
- v0.0.0-20260427160629-7cedc36a6bc4 (latest)
- Published
- Apr 27, 2026
- Platform
- linux/amd64
- Imports
- 9 packages
- Last checked
- 2 days ago –
Tools for package owners.