package pubsub
import "google.golang.org/genproto/googleapis/pubsub/v1beta2"
Index ¶
- Variables
- func RegisterPublisherServer(s *grpc.Server, srv PublisherServer)
- func RegisterSubscriberServer(s *grpc.Server, srv SubscriberServer)
- type AcknowledgeRequest
- func (*AcknowledgeRequest) Descriptor() ([]byte, []int)
- func (x *AcknowledgeRequest) GetAckIds() []string
- func (x *AcknowledgeRequest) GetSubscription() string
- func (*AcknowledgeRequest) ProtoMessage()
- func (x *AcknowledgeRequest) ProtoReflect() protoreflect.Message
- func (x *AcknowledgeRequest) Reset()
- func (x *AcknowledgeRequest) String() string
- type DeleteSubscriptionRequest
- func (*DeleteSubscriptionRequest) Descriptor() ([]byte, []int)
- func (x *DeleteSubscriptionRequest) GetSubscription() string
- func (*DeleteSubscriptionRequest) ProtoMessage()
- func (x *DeleteSubscriptionRequest) ProtoReflect() protoreflect.Message
- func (x *DeleteSubscriptionRequest) Reset()
- func (x *DeleteSubscriptionRequest) String() string
- type DeleteTopicRequest
- func (*DeleteTopicRequest) Descriptor() ([]byte, []int)
- func (x *DeleteTopicRequest) GetTopic() string
- func (*DeleteTopicRequest) ProtoMessage()
- func (x *DeleteTopicRequest) ProtoReflect() protoreflect.Message
- func (x *DeleteTopicRequest) Reset()
- func (x *DeleteTopicRequest) String() string
- type GetSubscriptionRequest
- func (*GetSubscriptionRequest) Descriptor() ([]byte, []int)
- func (x *GetSubscriptionRequest) GetSubscription() string
- func (*GetSubscriptionRequest) ProtoMessage()
- func (x *GetSubscriptionRequest) ProtoReflect() protoreflect.Message
- func (x *GetSubscriptionRequest) Reset()
- func (x *GetSubscriptionRequest) String() string
- type GetTopicRequest
- func (*GetTopicRequest) Descriptor() ([]byte, []int)
- func (x *GetTopicRequest) GetTopic() string
- func (*GetTopicRequest) ProtoMessage()
- func (x *GetTopicRequest) ProtoReflect() protoreflect.Message
- func (x *GetTopicRequest) Reset()
- func (x *GetTopicRequest) String() string
- type ListSubscriptionsRequest
- func (*ListSubscriptionsRequest) Descriptor() ([]byte, []int)
- func (x *ListSubscriptionsRequest) GetPageSize() int32
- func (x *ListSubscriptionsRequest) GetPageToken() string
- func (x *ListSubscriptionsRequest) GetProject() string
- func (*ListSubscriptionsRequest) ProtoMessage()
- func (x *ListSubscriptionsRequest) ProtoReflect() protoreflect.Message
- func (x *ListSubscriptionsRequest) Reset()
- func (x *ListSubscriptionsRequest) String() string
- type ListSubscriptionsResponse
- func (*ListSubscriptionsResponse) Descriptor() ([]byte, []int)
- func (x *ListSubscriptionsResponse) GetNextPageToken() string
- func (x *ListSubscriptionsResponse) GetSubscriptions() []*Subscription
- func (*ListSubscriptionsResponse) ProtoMessage()
- func (x *ListSubscriptionsResponse) ProtoReflect() protoreflect.Message
- func (x *ListSubscriptionsResponse) Reset()
- func (x *ListSubscriptionsResponse) String() string
- type ListTopicSubscriptionsRequest
- func (*ListTopicSubscriptionsRequest) Descriptor() ([]byte, []int)
- func (x *ListTopicSubscriptionsRequest) GetPageSize() int32
- func (x *ListTopicSubscriptionsRequest) GetPageToken() string
- func (x *ListTopicSubscriptionsRequest) GetTopic() string
- func (*ListTopicSubscriptionsRequest) ProtoMessage()
- func (x *ListTopicSubscriptionsRequest) ProtoReflect() protoreflect.Message
- func (x *ListTopicSubscriptionsRequest) Reset()
- func (x *ListTopicSubscriptionsRequest) String() string
- type ListTopicSubscriptionsResponse
- func (*ListTopicSubscriptionsResponse) Descriptor() ([]byte, []int)
- func (x *ListTopicSubscriptionsResponse) GetNextPageToken() string
- func (x *ListTopicSubscriptionsResponse) GetSubscriptions() []string
- func (*ListTopicSubscriptionsResponse) ProtoMessage()
- func (x *ListTopicSubscriptionsResponse) ProtoReflect() protoreflect.Message
- func (x *ListTopicSubscriptionsResponse) Reset()
- func (x *ListTopicSubscriptionsResponse) String() string
- type ListTopicsRequest
- func (*ListTopicsRequest) Descriptor() ([]byte, []int)
- func (x *ListTopicsRequest) GetPageSize() int32
- func (x *ListTopicsRequest) GetPageToken() string
- func (x *ListTopicsRequest) GetProject() string
- func (*ListTopicsRequest) ProtoMessage()
- func (x *ListTopicsRequest) ProtoReflect() protoreflect.Message
- func (x *ListTopicsRequest) Reset()
- func (x *ListTopicsRequest) String() string
- type ListTopicsResponse
- func (*ListTopicsResponse) Descriptor() ([]byte, []int)
- func (x *ListTopicsResponse) GetNextPageToken() string
- func (x *ListTopicsResponse) GetTopics() []*Topic
- func (*ListTopicsResponse) ProtoMessage()
- func (x *ListTopicsResponse) ProtoReflect() protoreflect.Message
- func (x *ListTopicsResponse) Reset()
- func (x *ListTopicsResponse) String() string
- type ModifyAckDeadlineRequest
- func (*ModifyAckDeadlineRequest) Descriptor() ([]byte, []int)
- func (x *ModifyAckDeadlineRequest) GetAckDeadlineSeconds() int32
- func (x *ModifyAckDeadlineRequest) GetAckId() string
- func (x *ModifyAckDeadlineRequest) GetSubscription() string
- func (*ModifyAckDeadlineRequest) ProtoMessage()
- func (x *ModifyAckDeadlineRequest) ProtoReflect() protoreflect.Message
- func (x *ModifyAckDeadlineRequest) Reset()
- func (x *ModifyAckDeadlineRequest) String() string
- type ModifyPushConfigRequest
- func (*ModifyPushConfigRequest) Descriptor() ([]byte, []int)
- func (x *ModifyPushConfigRequest) GetPushConfig() *PushConfig
- func (x *ModifyPushConfigRequest) GetSubscription() string
- func (*ModifyPushConfigRequest) ProtoMessage()
- func (x *ModifyPushConfigRequest) ProtoReflect() protoreflect.Message
- func (x *ModifyPushConfigRequest) Reset()
- func (x *ModifyPushConfigRequest) String() string
- type PublishRequest
- func (*PublishRequest) Descriptor() ([]byte, []int)
- func (x *PublishRequest) GetMessages() []*PubsubMessage
- func (x *PublishRequest) GetTopic() string
- func (*PublishRequest) ProtoMessage()
- func (x *PublishRequest) ProtoReflect() protoreflect.Message
- func (x *PublishRequest) Reset()
- func (x *PublishRequest) String() string
- type PublishResponse
- func (*PublishResponse) Descriptor() ([]byte, []int)
- func (x *PublishResponse) GetMessageIds() []string
- func (*PublishResponse) ProtoMessage()
- func (x *PublishResponse) ProtoReflect() protoreflect.Message
- func (x *PublishResponse) Reset()
- func (x *PublishResponse) String() string
- type PublisherClient
- type PublisherServer
- type PubsubMessage
- func (*PubsubMessage) Descriptor() ([]byte, []int)
- func (x *PubsubMessage) GetAttributes() map[string]string
- func (x *PubsubMessage) GetData() []byte
- func (x *PubsubMessage) GetMessageId() string
- func (*PubsubMessage) ProtoMessage()
- func (x *PubsubMessage) ProtoReflect() protoreflect.Message
- func (x *PubsubMessage) Reset()
- func (x *PubsubMessage) String() string
- type PullRequest
- func (*PullRequest) Descriptor() ([]byte, []int)
- func (x *PullRequest) GetMaxMessages() int32
- func (x *PullRequest) GetReturnImmediately() bool
- func (x *PullRequest) GetSubscription() string
- func (*PullRequest) ProtoMessage()
- func (x *PullRequest) ProtoReflect() protoreflect.Message
- func (x *PullRequest) Reset()
- func (x *PullRequest) String() string
- type PullResponse
- func (*PullResponse) Descriptor() ([]byte, []int)
- func (x *PullResponse) GetReceivedMessages() []*ReceivedMessage
- func (*PullResponse) ProtoMessage()
- func (x *PullResponse) ProtoReflect() protoreflect.Message
- func (x *PullResponse) Reset()
- func (x *PullResponse) String() string
- type PushConfig
- func (*PushConfig) Descriptor() ([]byte, []int)
- func (x *PushConfig) GetAttributes() map[string]string
- func (x *PushConfig) GetPushEndpoint() string
- func (*PushConfig) ProtoMessage()
- func (x *PushConfig) ProtoReflect() protoreflect.Message
- func (x *PushConfig) Reset()
- func (x *PushConfig) String() string
- type ReceivedMessage
- func (*ReceivedMessage) Descriptor() ([]byte, []int)
- func (x *ReceivedMessage) GetAckId() string
- func (x *ReceivedMessage) GetMessage() *PubsubMessage
- func (*ReceivedMessage) ProtoMessage()
- func (x *ReceivedMessage) ProtoReflect() protoreflect.Message
- func (x *ReceivedMessage) Reset()
- func (x *ReceivedMessage) String() string
- type SubscriberClient
- type SubscriberServer
- type Subscription
- func (*Subscription) Descriptor() ([]byte, []int)
- func (x *Subscription) GetAckDeadlineSeconds() int32
- func (x *Subscription) GetName() string
- func (x *Subscription) GetPushConfig() *PushConfig
- func (x *Subscription) GetTopic() string
- func (*Subscription) ProtoMessage()
- func (x *Subscription) ProtoReflect() protoreflect.Message
- func (x *Subscription) Reset()
- func (x *Subscription) String() string
- type Topic
- func (*Topic) Descriptor() ([]byte, []int)
- func (x *Topic) GetName() string
- func (*Topic) ProtoMessage()
- func (x *Topic) ProtoReflect() protoreflect.Message
- func (x *Topic) Reset()
- func (x *Topic) String() string
- type UnimplementedPublisherServer
- func (*UnimplementedPublisherServer) CreateTopic(context.Context, *Topic) (*Topic, error)
- func (*UnimplementedPublisherServer) DeleteTopic(context.Context, *DeleteTopicRequest) (*emptypb.Empty, error)
- func (*UnimplementedPublisherServer) GetTopic(context.Context, *GetTopicRequest) (*Topic, error)
- func (*UnimplementedPublisherServer) ListTopicSubscriptions(context.Context, *ListTopicSubscriptionsRequest) (*ListTopicSubscriptionsResponse, error)
- func (*UnimplementedPublisherServer) ListTopics(context.Context, *ListTopicsRequest) (*ListTopicsResponse, error)
- func (*UnimplementedPublisherServer) Publish(context.Context, *PublishRequest) (*PublishResponse, error)
- type UnimplementedSubscriberServer
- func (*UnimplementedSubscriberServer) Acknowledge(context.Context, *AcknowledgeRequest) (*emptypb.Empty, error)
- func (*UnimplementedSubscriberServer) CreateSubscription(context.Context, *Subscription) (*Subscription, error)
- func (*UnimplementedSubscriberServer) DeleteSubscription(context.Context, *DeleteSubscriptionRequest) (*emptypb.Empty, error)
- func (*UnimplementedSubscriberServer) GetSubscription(context.Context, *GetSubscriptionRequest) (*Subscription, error)
- func (*UnimplementedSubscriberServer) ListSubscriptions(context.Context, *ListSubscriptionsRequest) (*ListSubscriptionsResponse, error)
- func (*UnimplementedSubscriberServer) ModifyAckDeadline(context.Context, *ModifyAckDeadlineRequest) (*emptypb.Empty, error)
- func (*UnimplementedSubscriberServer) ModifyPushConfig(context.Context, *ModifyPushConfigRequest) (*emptypb.Empty, error)
- func (*UnimplementedSubscriberServer) Pull(context.Context, *PullRequest) (*PullResponse, error)
Variables ¶
var File_google_pubsub_v1beta2_pubsub_proto protoreflect.FileDescriptor
Functions ¶
func RegisterPublisherServer ¶
func RegisterPublisherServer(s *grpc.Server, srv PublisherServer)
func RegisterSubscriberServer ¶
func RegisterSubscriberServer(s *grpc.Server, srv SubscriberServer)
Types ¶
type AcknowledgeRequest ¶
type AcknowledgeRequest struct {
// The subscription whose message is being acknowledged.
Subscription string `protobuf:"bytes,1,opt,name=subscription,proto3" json:"subscription,omitempty"`
// The acknowledgment ID for the messages being acknowledged that was returned
// by the Pub/Sub system in the Pull response. Must not be empty.
AckIds []string `protobuf:"bytes,2,rep,name=ack_ids,json=ackIds,proto3" json:"ack_ids,omitempty"`
// contains filtered or unexported fields
}
Request for the Acknowledge method.
func (*AcknowledgeRequest) Descriptor ¶
func (*AcknowledgeRequest) Descriptor() ([]byte, []int)
Deprecated: Use AcknowledgeRequest.ProtoReflect.Descriptor instead.
func (*AcknowledgeRequest) GetAckIds ¶
func (x *AcknowledgeRequest) GetAckIds() []string
func (*AcknowledgeRequest) GetSubscription ¶
func (x *AcknowledgeRequest) GetSubscription() string
func (*AcknowledgeRequest) ProtoMessage ¶
func (*AcknowledgeRequest) ProtoMessage()
func (*AcknowledgeRequest) ProtoReflect ¶
func (x *AcknowledgeRequest) ProtoReflect() protoreflect.Message
func (*AcknowledgeRequest) Reset ¶
func (x *AcknowledgeRequest) Reset()
func (*AcknowledgeRequest) String ¶
func (x *AcknowledgeRequest) String() string
type DeleteSubscriptionRequest ¶
type DeleteSubscriptionRequest struct {
// The subscription to delete.
Subscription string `protobuf:"bytes,1,opt,name=subscription,proto3" json:"subscription,omitempty"`
// contains filtered or unexported fields
}
Request for the DeleteSubscription method.
func (*DeleteSubscriptionRequest) Descriptor ¶
func (*DeleteSubscriptionRequest) Descriptor() ([]byte, []int)
Deprecated: Use DeleteSubscriptionRequest.ProtoReflect.Descriptor instead.
func (*DeleteSubscriptionRequest) GetSubscription ¶
func (x *DeleteSubscriptionRequest) GetSubscription() string
func (*DeleteSubscriptionRequest) ProtoMessage ¶
func (*DeleteSubscriptionRequest) ProtoMessage()
func (*DeleteSubscriptionRequest) ProtoReflect ¶
func (x *DeleteSubscriptionRequest) ProtoReflect() protoreflect.Message
func (*DeleteSubscriptionRequest) Reset ¶
func (x *DeleteSubscriptionRequest) Reset()
func (*DeleteSubscriptionRequest) String ¶
func (x *DeleteSubscriptionRequest) String() string
type DeleteTopicRequest ¶
type DeleteTopicRequest struct {
// Name of the topic to delete.
Topic string `protobuf:"bytes,1,opt,name=topic,proto3" json:"topic,omitempty"`
// contains filtered or unexported fields
}
Request for the DeleteTopic method.
func (*DeleteTopicRequest) Descriptor ¶
func (*DeleteTopicRequest) Descriptor() ([]byte, []int)
Deprecated: Use DeleteTopicRequest.ProtoReflect.Descriptor instead.
func (*DeleteTopicRequest) GetTopic ¶
func (x *DeleteTopicRequest) GetTopic() string
func (*DeleteTopicRequest) ProtoMessage ¶
func (*DeleteTopicRequest) ProtoMessage()
func (*DeleteTopicRequest) ProtoReflect ¶
func (x *DeleteTopicRequest) ProtoReflect() protoreflect.Message
func (*DeleteTopicRequest) Reset ¶
func (x *DeleteTopicRequest) Reset()
func (*DeleteTopicRequest) String ¶
func (x *DeleteTopicRequest) String() string
type GetSubscriptionRequest ¶
type GetSubscriptionRequest struct {
// The name of the subscription to get.
Subscription string `protobuf:"bytes,1,opt,name=subscription,proto3" json:"subscription,omitempty"`
// contains filtered or unexported fields
}
Request for the GetSubscription method.
func (*GetSubscriptionRequest) Descriptor ¶
func (*GetSubscriptionRequest) Descriptor() ([]byte, []int)
Deprecated: Use GetSubscriptionRequest.ProtoReflect.Descriptor instead.
func (*GetSubscriptionRequest) GetSubscription ¶
func (x *GetSubscriptionRequest) GetSubscription() string
func (*GetSubscriptionRequest) ProtoMessage ¶
func (*GetSubscriptionRequest) ProtoMessage()
func (*GetSubscriptionRequest) ProtoReflect ¶
func (x *GetSubscriptionRequest) ProtoReflect() protoreflect.Message
func (*GetSubscriptionRequest) Reset ¶
func (x *GetSubscriptionRequest) Reset()
func (*GetSubscriptionRequest) String ¶
func (x *GetSubscriptionRequest) String() string
type GetTopicRequest ¶
type GetTopicRequest struct {
// The name of the topic to get.
Topic string `protobuf:"bytes,1,opt,name=topic,proto3" json:"topic,omitempty"`
// contains filtered or unexported fields
}
Request for the GetTopic method.
func (*GetTopicRequest) Descriptor ¶
func (*GetTopicRequest) Descriptor() ([]byte, []int)
Deprecated: Use GetTopicRequest.ProtoReflect.Descriptor instead.
func (*GetTopicRequest) GetTopic ¶
func (x *GetTopicRequest) GetTopic() string
func (*GetTopicRequest) ProtoMessage ¶
func (*GetTopicRequest) ProtoMessage()
func (*GetTopicRequest) ProtoReflect ¶
func (x *GetTopicRequest) ProtoReflect() protoreflect.Message
func (*GetTopicRequest) Reset ¶
func (x *GetTopicRequest) Reset()
func (*GetTopicRequest) String ¶
func (x *GetTopicRequest) String() string
type ListSubscriptionsRequest ¶
type ListSubscriptionsRequest struct {
// The name of the cloud project that subscriptions belong to.
Project string `protobuf:"bytes,1,opt,name=project,proto3" json:"project,omitempty"`
// Maximum number of subscriptions to return.
PageSize int32 `protobuf:"varint,2,opt,name=page_size,json=pageSize,proto3" json:"page_size,omitempty"`
// The value returned by the last ListSubscriptionsResponse; indicates that
// this is a continuation of a prior ListSubscriptions call, and that the
// system should return the next page of data.
PageToken string `protobuf:"bytes,3,opt,name=page_token,json=pageToken,proto3" json:"page_token,omitempty"`
// contains filtered or unexported fields
}
Request for the ListSubscriptions method.
func (*ListSubscriptionsRequest) Descriptor ¶
func (*ListSubscriptionsRequest) Descriptor() ([]byte, []int)
Deprecated: Use ListSubscriptionsRequest.ProtoReflect.Descriptor instead.
func (*ListSubscriptionsRequest) GetPageSize ¶
func (x *ListSubscriptionsRequest) GetPageSize() int32
func (*ListSubscriptionsRequest) GetPageToken ¶
func (x *ListSubscriptionsRequest) GetPageToken() string
func (*ListSubscriptionsRequest) GetProject ¶
func (x *ListSubscriptionsRequest) GetProject() string
func (*ListSubscriptionsRequest) ProtoMessage ¶
func (*ListSubscriptionsRequest) ProtoMessage()
func (*ListSubscriptionsRequest) ProtoReflect ¶
func (x *ListSubscriptionsRequest) ProtoReflect() protoreflect.Message
func (*ListSubscriptionsRequest) Reset ¶
func (x *ListSubscriptionsRequest) Reset()
func (*ListSubscriptionsRequest) String ¶
func (x *ListSubscriptionsRequest) String() string
type ListSubscriptionsResponse ¶
type ListSubscriptionsResponse struct {
// The subscriptions that match the request.
Subscriptions []*Subscription `protobuf:"bytes,1,rep,name=subscriptions,proto3" json:"subscriptions,omitempty"`
// If not empty, indicates that there may be more subscriptions that match
// the request; this value should be passed in a new ListSubscriptionsRequest
// to get more subscriptions.
NextPageToken string `protobuf:"bytes,2,opt,name=next_page_token,json=nextPageToken,proto3" json:"next_page_token,omitempty"`
// contains filtered or unexported fields
}
Response for the ListSubscriptions method.
func (*ListSubscriptionsResponse) Descriptor ¶
func (*ListSubscriptionsResponse) Descriptor() ([]byte, []int)
Deprecated: Use ListSubscriptionsResponse.ProtoReflect.Descriptor instead.
func (*ListSubscriptionsResponse) GetNextPageToken ¶
func (x *ListSubscriptionsResponse) GetNextPageToken() string
func (*ListSubscriptionsResponse) GetSubscriptions ¶
func (x *ListSubscriptionsResponse) GetSubscriptions() []*Subscription
func (*ListSubscriptionsResponse) ProtoMessage ¶
func (*ListSubscriptionsResponse) ProtoMessage()
func (*ListSubscriptionsResponse) ProtoReflect ¶
func (x *ListSubscriptionsResponse) ProtoReflect() protoreflect.Message
func (*ListSubscriptionsResponse) Reset ¶
func (x *ListSubscriptionsResponse) Reset()
func (*ListSubscriptionsResponse) String ¶
func (x *ListSubscriptionsResponse) String() string
type ListTopicSubscriptionsRequest ¶
type ListTopicSubscriptionsRequest struct {
// The name of the topic that subscriptions are attached to.
Topic string `protobuf:"bytes,1,opt,name=topic,proto3" json:"topic,omitempty"`
// Maximum number of subscription names to return.
PageSize int32 `protobuf:"varint,2,opt,name=page_size,json=pageSize,proto3" json:"page_size,omitempty"`
// The value returned by the last ListTopicSubscriptionsResponse; indicates
// that this is a continuation of a prior ListTopicSubscriptions call, and
// that the system should return the next page of data.
PageToken string `protobuf:"bytes,3,opt,name=page_token,json=pageToken,proto3" json:"page_token,omitempty"`
// contains filtered or unexported fields
}
Request for the ListTopicSubscriptions method.
func (*ListTopicSubscriptionsRequest) Descriptor ¶
func (*ListTopicSubscriptionsRequest) Descriptor() ([]byte, []int)
Deprecated: Use ListTopicSubscriptionsRequest.ProtoReflect.Descriptor instead.
func (*ListTopicSubscriptionsRequest) GetPageSize ¶
func (x *ListTopicSubscriptionsRequest) GetPageSize() int32
func (*ListTopicSubscriptionsRequest) GetPageToken ¶
func (x *ListTopicSubscriptionsRequest) GetPageToken() string
func (*ListTopicSubscriptionsRequest) GetTopic ¶
func (x *ListTopicSubscriptionsRequest) GetTopic() string
func (*ListTopicSubscriptionsRequest) ProtoMessage ¶
func (*ListTopicSubscriptionsRequest) ProtoMessage()
func (*ListTopicSubscriptionsRequest) ProtoReflect ¶
func (x *ListTopicSubscriptionsRequest) ProtoReflect() protoreflect.Message
func (*ListTopicSubscriptionsRequest) Reset ¶
func (x *ListTopicSubscriptionsRequest) Reset()
func (*ListTopicSubscriptionsRequest) String ¶
func (x *ListTopicSubscriptionsRequest) String() string
type ListTopicSubscriptionsResponse ¶
type ListTopicSubscriptionsResponse struct {
// The names of the subscriptions that match the request.
Subscriptions []string `protobuf:"bytes,1,rep,name=subscriptions,proto3" json:"subscriptions,omitempty"`
// If not empty, indicates that there may be more subscriptions that match
// the request; this value should be passed in a new
// ListTopicSubscriptionsRequest to get more subscriptions.
NextPageToken string `protobuf:"bytes,2,opt,name=next_page_token,json=nextPageToken,proto3" json:"next_page_token,omitempty"`
// contains filtered or unexported fields
}
Response for the ListTopicSubscriptions method.
func (*ListTopicSubscriptionsResponse) Descriptor ¶
func (*ListTopicSubscriptionsResponse) Descriptor() ([]byte, []int)
Deprecated: Use ListTopicSubscriptionsResponse.ProtoReflect.Descriptor instead.
func (*ListTopicSubscriptionsResponse) GetNextPageToken ¶
func (x *ListTopicSubscriptionsResponse) GetNextPageToken() string
func (*ListTopicSubscriptionsResponse) GetSubscriptions ¶
func (x *ListTopicSubscriptionsResponse) GetSubscriptions() []string
func (*ListTopicSubscriptionsResponse) ProtoMessage ¶
func (*ListTopicSubscriptionsResponse) ProtoMessage()
func (*ListTopicSubscriptionsResponse) ProtoReflect ¶
func (x *ListTopicSubscriptionsResponse) ProtoReflect() protoreflect.Message
func (*ListTopicSubscriptionsResponse) Reset ¶
func (x *ListTopicSubscriptionsResponse) Reset()
func (*ListTopicSubscriptionsResponse) String ¶
func (x *ListTopicSubscriptionsResponse) String() string
type ListTopicsRequest ¶
type ListTopicsRequest struct {
// The name of the cloud project that topics belong to.
Project string `protobuf:"bytes,1,opt,name=project,proto3" json:"project,omitempty"`
// Maximum number of topics to return.
PageSize int32 `protobuf:"varint,2,opt,name=page_size,json=pageSize,proto3" json:"page_size,omitempty"`
// The value returned by the last ListTopicsResponse; indicates that this is
// a continuation of a prior ListTopics call, and that the system should
// return the next page of data.
PageToken string `protobuf:"bytes,3,opt,name=page_token,json=pageToken,proto3" json:"page_token,omitempty"`
// contains filtered or unexported fields
}
Request for the ListTopics method.
func (*ListTopicsRequest) Descriptor ¶
func (*ListTopicsRequest) Descriptor() ([]byte, []int)
Deprecated: Use ListTopicsRequest.ProtoReflect.Descriptor instead.
func (*ListTopicsRequest) GetPageSize ¶
func (x *ListTopicsRequest) GetPageSize() int32
func (*ListTopicsRequest) GetPageToken ¶
func (x *ListTopicsRequest) GetPageToken() string
func (*ListTopicsRequest) GetProject ¶
func (x *ListTopicsRequest) GetProject() string
func (*ListTopicsRequest) ProtoMessage ¶
func (*ListTopicsRequest) ProtoMessage()
func (*ListTopicsRequest) ProtoReflect ¶
func (x *ListTopicsRequest) ProtoReflect() protoreflect.Message
func (*ListTopicsRequest) Reset ¶
func (x *ListTopicsRequest) Reset()
func (*ListTopicsRequest) String ¶
func (x *ListTopicsRequest) String() string
type ListTopicsResponse ¶
type ListTopicsResponse struct {
// The resulting topics.
Topics []*Topic `protobuf:"bytes,1,rep,name=topics,proto3" json:"topics,omitempty"`
// If not empty, indicates that there may be more topics that match the
// request; this value should be passed in a new ListTopicsRequest.
NextPageToken string `protobuf:"bytes,2,opt,name=next_page_token,json=nextPageToken,proto3" json:"next_page_token,omitempty"`
// contains filtered or unexported fields
}
Response for the ListTopics method.
func (*ListTopicsResponse) Descriptor ¶
func (*ListTopicsResponse) Descriptor() ([]byte, []int)
Deprecated: Use ListTopicsResponse.ProtoReflect.Descriptor instead.
func (*ListTopicsResponse) GetNextPageToken ¶
func (x *ListTopicsResponse) GetNextPageToken() string
func (*ListTopicsResponse) GetTopics ¶
func (x *ListTopicsResponse) GetTopics() []*Topic
func (*ListTopicsResponse) ProtoMessage ¶
func (*ListTopicsResponse) ProtoMessage()
func (*ListTopicsResponse) ProtoReflect ¶
func (x *ListTopicsResponse) ProtoReflect() protoreflect.Message
func (*ListTopicsResponse) Reset ¶
func (x *ListTopicsResponse) Reset()
func (*ListTopicsResponse) String ¶
func (x *ListTopicsResponse) String() string
type ModifyAckDeadlineRequest ¶
type ModifyAckDeadlineRequest struct {
// The name of the subscription.
Subscription string `protobuf:"bytes,1,opt,name=subscription,proto3" json:"subscription,omitempty"`
// The acknowledgment ID.
AckId string `protobuf:"bytes,2,opt,name=ack_id,json=ackId,proto3" json:"ack_id,omitempty"`
// The new ack deadline with respect to the time this request was sent to the
// Pub/Sub system. Must be >= 0. For example, if the value is 10, the new ack
// deadline will expire 10 seconds after the ModifyAckDeadline call was made.
// Specifying zero may immediately make the message available for another pull
// request.
AckDeadlineSeconds int32 `protobuf:"varint,3,opt,name=ack_deadline_seconds,json=ackDeadlineSeconds,proto3" json:"ack_deadline_seconds,omitempty"`
// contains filtered or unexported fields
}
Request for the ModifyAckDeadline method.
func (*ModifyAckDeadlineRequest) Descriptor ¶
func (*ModifyAckDeadlineRequest) Descriptor() ([]byte, []int)
Deprecated: Use ModifyAckDeadlineRequest.ProtoReflect.Descriptor instead.
func (*ModifyAckDeadlineRequest) GetAckDeadlineSeconds ¶
func (x *ModifyAckDeadlineRequest) GetAckDeadlineSeconds() int32
func (*ModifyAckDeadlineRequest) GetAckId ¶
func (x *ModifyAckDeadlineRequest) GetAckId() string
func (*ModifyAckDeadlineRequest) GetSubscription ¶
func (x *ModifyAckDeadlineRequest) GetSubscription() string
func (*ModifyAckDeadlineRequest) ProtoMessage ¶
func (*ModifyAckDeadlineRequest) ProtoMessage()
func (*ModifyAckDeadlineRequest) ProtoReflect ¶
func (x *ModifyAckDeadlineRequest) ProtoReflect() protoreflect.Message
func (*ModifyAckDeadlineRequest) Reset ¶
func (x *ModifyAckDeadlineRequest) Reset()
func (*ModifyAckDeadlineRequest) String ¶
func (x *ModifyAckDeadlineRequest) String() string
type ModifyPushConfigRequest ¶
type ModifyPushConfigRequest struct {
// The name of the subscription.
Subscription string `protobuf:"bytes,1,opt,name=subscription,proto3" json:"subscription,omitempty"`
// The push configuration for future deliveries.
//
// An empty pushConfig indicates that the Pub/Sub system should
// stop pushing messages from the given subscription and allow
// messages to be pulled and acknowledged - effectively pausing
// the subscription if Pull is not called.
PushConfig *PushConfig `protobuf:"bytes,2,opt,name=push_config,json=pushConfig,proto3" json:"push_config,omitempty"`
// contains filtered or unexported fields
}
Request for the ModifyPushConfig method.
func (*ModifyPushConfigRequest) Descriptor ¶
func (*ModifyPushConfigRequest) Descriptor() ([]byte, []int)
Deprecated: Use ModifyPushConfigRequest.ProtoReflect.Descriptor instead.
func (*ModifyPushConfigRequest) GetPushConfig ¶
func (x *ModifyPushConfigRequest) GetPushConfig() *PushConfig
func (*ModifyPushConfigRequest) GetSubscription ¶
func (x *ModifyPushConfigRequest) GetSubscription() string
func (*ModifyPushConfigRequest) ProtoMessage ¶
func (*ModifyPushConfigRequest) ProtoMessage()
func (*ModifyPushConfigRequest) ProtoReflect ¶
func (x *ModifyPushConfigRequest) ProtoReflect() protoreflect.Message
func (*ModifyPushConfigRequest) Reset ¶
func (x *ModifyPushConfigRequest) Reset()
func (*ModifyPushConfigRequest) String ¶
func (x *ModifyPushConfigRequest) String() string
type PublishRequest ¶
type PublishRequest struct {
// The messages in the request will be published on this topic.
Topic string `protobuf:"bytes,1,opt,name=topic,proto3" json:"topic,omitempty"`
// The messages to publish.
Messages []*PubsubMessage `protobuf:"bytes,2,rep,name=messages,proto3" json:"messages,omitempty"`
// contains filtered or unexported fields
}
Request for the Publish method.
func (*PublishRequest) Descriptor ¶
func (*PublishRequest) Descriptor() ([]byte, []int)
Deprecated: Use PublishRequest.ProtoReflect.Descriptor instead.
func (*PublishRequest) GetMessages ¶
func (x *PublishRequest) GetMessages() []*PubsubMessage
func (*PublishRequest) GetTopic ¶
func (x *PublishRequest) GetTopic() string
func (*PublishRequest) ProtoMessage ¶
func (*PublishRequest) ProtoMessage()
func (*PublishRequest) ProtoReflect ¶
func (x *PublishRequest) ProtoReflect() protoreflect.Message
func (*PublishRequest) Reset ¶
func (x *PublishRequest) Reset()
func (*PublishRequest) String ¶
func (x *PublishRequest) String() string
type PublishResponse ¶
type PublishResponse struct {
// The server-assigned ID of each published message, in the same order as
// the messages in the request. IDs are guaranteed to be unique within
// the topic.
MessageIds []string `protobuf:"bytes,1,rep,name=message_ids,json=messageIds,proto3" json:"message_ids,omitempty"`
// contains filtered or unexported fields
}
Response for the Publish method.
func (*PublishResponse) Descriptor ¶
func (*PublishResponse) Descriptor() ([]byte, []int)
Deprecated: Use PublishResponse.ProtoReflect.Descriptor instead.
func (*PublishResponse) GetMessageIds ¶
func (x *PublishResponse) GetMessageIds() []string
func (*PublishResponse) ProtoMessage ¶
func (*PublishResponse) ProtoMessage()
func (*PublishResponse) ProtoReflect ¶
func (x *PublishResponse) ProtoReflect() protoreflect.Message
func (*PublishResponse) Reset ¶
func (x *PublishResponse) Reset()
func (*PublishResponse) String ¶
func (x *PublishResponse) String() string
type PublisherClient ¶
type PublisherClient interface {
// Creates the given topic with the given name.
CreateTopic(ctx context.Context, in *Topic, opts ...grpc.CallOption) (*Topic, error)
// Adds one or more messages to the topic. Returns NOT_FOUND if the topic does
// not exist.
Publish(ctx context.Context, in *PublishRequest, opts ...grpc.CallOption) (*PublishResponse, error)
// Gets the configuration of a topic.
GetTopic(ctx context.Context, in *GetTopicRequest, opts ...grpc.CallOption) (*Topic, error)
// Lists matching topics.
ListTopics(ctx context.Context, in *ListTopicsRequest, opts ...grpc.CallOption) (*ListTopicsResponse, error)
// Lists the name of the subscriptions for this topic.
ListTopicSubscriptions(ctx context.Context, in *ListTopicSubscriptionsRequest, opts ...grpc.CallOption) (*ListTopicSubscriptionsResponse, error)
// Deletes the topic with the given name. Returns NOT_FOUND if the topic does
// not exist. After a topic is deleted, a new topic may be created with the
// same name; this is an entirely new topic with none of the old
// configuration or subscriptions. Existing subscriptions to this topic are
// not deleted.
DeleteTopic(ctx context.Context, in *DeleteTopicRequest, opts ...grpc.CallOption) (*emptypb.Empty, error)
}
PublisherClient is the client API for Publisher service.
For semantics around ctx use and closing/ending streaming RPCs, please refer to https://godoc.org/google.golang.org/grpc#ClientConn.NewStream.
func NewPublisherClient ¶
func NewPublisherClient(cc grpc.ClientConnInterface) PublisherClient
type PublisherServer ¶
type PublisherServer interface {
// Creates the given topic with the given name.
CreateTopic(context.Context, *Topic) (*Topic, error)
// Adds one or more messages to the topic. Returns NOT_FOUND if the topic does
// not exist.
Publish(context.Context, *PublishRequest) (*PublishResponse, error)
// Gets the configuration of a topic.
GetTopic(context.Context, *GetTopicRequest) (*Topic, error)
// Lists matching topics.
ListTopics(context.Context, *ListTopicsRequest) (*ListTopicsResponse, error)
// Lists the name of the subscriptions for this topic.
ListTopicSubscriptions(context.Context, *ListTopicSubscriptionsRequest) (*ListTopicSubscriptionsResponse, error)
// Deletes the topic with the given name. Returns NOT_FOUND if the topic does
// not exist. After a topic is deleted, a new topic may be created with the
// same name; this is an entirely new topic with none of the old
// configuration or subscriptions. Existing subscriptions to this topic are
// not deleted.
DeleteTopic(context.Context, *DeleteTopicRequest) (*emptypb.Empty, error)
}
PublisherServer is the server API for Publisher service.
type PubsubMessage ¶
type PubsubMessage struct {
// The message payload. For JSON requests, the value of this field must be
// base64-encoded.
Data []byte `protobuf:"bytes,1,opt,name=data,proto3" json:"data,omitempty"`
// Optional attributes for this message.
Attributes map[string]string `protobuf:"bytes,2,rep,name=attributes,proto3" json:"attributes,omitempty" protobuf_key:"bytes,1,opt,name=key,proto3" protobuf_val:"bytes,2,opt,name=value,proto3"`
// ID of this message assigned by the server at publication time. Guaranteed
// to be unique within the topic. This value may be read by a subscriber
// that receives a PubsubMessage via a Pull call or a push delivery. It must
// not be populated by a publisher in a Publish call.
MessageId string `protobuf:"bytes,3,opt,name=message_id,json=messageId,proto3" json:"message_id,omitempty"`
// contains filtered or unexported fields
}
A message data and its attributes.
func (*PubsubMessage) Descriptor ¶
func (*PubsubMessage) Descriptor() ([]byte, []int)
Deprecated: Use PubsubMessage.ProtoReflect.Descriptor instead.
func (*PubsubMessage) GetAttributes ¶
func (x *PubsubMessage) GetAttributes() map[string]string
func (*PubsubMessage) GetData ¶
func (x *PubsubMessage) GetData() []byte
func (*PubsubMessage) GetMessageId ¶
func (x *PubsubMessage) GetMessageId() string
func (*PubsubMessage) ProtoMessage ¶
func (*PubsubMessage) ProtoMessage()
func (*PubsubMessage) ProtoReflect ¶
func (x *PubsubMessage) ProtoReflect() protoreflect.Message
func (*PubsubMessage) Reset ¶
func (x *PubsubMessage) Reset()
func (*PubsubMessage) String ¶
func (x *PubsubMessage) String() string
type PullRequest ¶
type PullRequest struct {
// The subscription from which messages should be pulled.
Subscription string `protobuf:"bytes,1,opt,name=subscription,proto3" json:"subscription,omitempty"`
// If this is specified as true the system will respond immediately even if
// it is not able to return a message in the Pull response. Otherwise the
// system is allowed to wait until at least one message is available rather
// than returning no messages. The client may cancel the request if it does
// not wish to wait any longer for the response.
ReturnImmediately bool `protobuf:"varint,2,opt,name=return_immediately,json=returnImmediately,proto3" json:"return_immediately,omitempty"`
// The maximum number of messages returned for this request. The Pub/Sub
// system may return fewer than the number specified.
MaxMessages int32 `protobuf:"varint,3,opt,name=max_messages,json=maxMessages,proto3" json:"max_messages,omitempty"`
// contains filtered or unexported fields
}
Request for the Pull method.
func (*PullRequest) Descriptor ¶
func (*PullRequest) Descriptor() ([]byte, []int)
Deprecated: Use PullRequest.ProtoReflect.Descriptor instead.
func (*PullRequest) GetMaxMessages ¶
func (x *PullRequest) GetMaxMessages() int32
func (*PullRequest) GetReturnImmediately ¶
func (x *PullRequest) GetReturnImmediately() bool
func (*PullRequest) GetSubscription ¶
func (x *PullRequest) GetSubscription() string
func (*PullRequest) ProtoMessage ¶
func (*PullRequest) ProtoMessage()
func (*PullRequest) ProtoReflect ¶
func (x *PullRequest) ProtoReflect() protoreflect.Message
func (*PullRequest) Reset ¶
func (x *PullRequest) Reset()
func (*PullRequest) String ¶
func (x *PullRequest) String() string
type PullResponse ¶
type PullResponse struct {
// Received Pub/Sub messages. The Pub/Sub system will return zero messages if
// there are no more available in the backlog. The Pub/Sub system may return
// fewer than the maxMessages requested even if there are more messages
// available in the backlog.
ReceivedMessages []*ReceivedMessage `protobuf:"bytes,1,rep,name=received_messages,json=receivedMessages,proto3" json:"received_messages,omitempty"`
// contains filtered or unexported fields
}
Response for the Pull method.
func (*PullResponse) Descriptor ¶
func (*PullResponse) Descriptor() ([]byte, []int)
Deprecated: Use PullResponse.ProtoReflect.Descriptor instead.
func (*PullResponse) GetReceivedMessages ¶
func (x *PullResponse) GetReceivedMessages() []*ReceivedMessage
func (*PullResponse) ProtoMessage ¶
func (*PullResponse) ProtoMessage()
func (*PullResponse) ProtoReflect ¶
func (x *PullResponse) ProtoReflect() protoreflect.Message
func (*PullResponse) Reset ¶
func (x *PullResponse) Reset()
func (*PullResponse) String ¶
func (x *PullResponse) String() string
type PushConfig ¶
type PushConfig struct {
// A URL locating the endpoint to which messages should be pushed.
// For example, a Webhook endpoint might use "https://example.com/push".
PushEndpoint string `protobuf:"bytes,1,opt,name=push_endpoint,json=pushEndpoint,proto3" json:"push_endpoint,omitempty"`
// Endpoint configuration attributes.
//
// Every endpoint has a set of API supported attributes that can be used to
// control different aspects of the message delivery.
//
// The currently supported attribute is `x-goog-version`, which you can
// use to change the format of the push message. This attribute
// indicates the version of the data expected by the endpoint. This
// controls the shape of the envelope (i.e. its fields and metadata).
// The endpoint version is based on the version of the Pub/Sub
// API.
//
// If not present during the CreateSubscription call, it will default to
// the version of the API used to make such call. If not present during a
// ModifyPushConfig call, its value will not be changed. GetSubscription
// calls will always return a valid version, even if the subscription was
// created without this attribute.
//
// The possible values for this attribute are:
//
// * `v1beta1`: uses the push format defined in the v1beta1 Pub/Sub API.
// * `v1beta2`: uses the push format defined in the v1beta2 Pub/Sub API.
//
Attributes map[string]string `protobuf:"bytes,2,rep,name=attributes,proto3" json:"attributes,omitempty" protobuf_key:"bytes,1,opt,name=key,proto3" protobuf_val:"bytes,2,opt,name=value,proto3"`
// contains filtered or unexported fields
}
Configuration for a push delivery endpoint.
func (*PushConfig) Descriptor ¶
func (*PushConfig) Descriptor() ([]byte, []int)
Deprecated: Use PushConfig.ProtoReflect.Descriptor instead.
func (*PushConfig) GetAttributes ¶
func (x *PushConfig) GetAttributes() map[string]string
func (*PushConfig) GetPushEndpoint ¶
func (x *PushConfig) GetPushEndpoint() string
func (*PushConfig) ProtoMessage ¶
func (*PushConfig) ProtoMessage()
func (*PushConfig) ProtoReflect ¶
func (x *PushConfig) ProtoReflect() protoreflect.Message
func (*PushConfig) Reset ¶
func (x *PushConfig) Reset()
func (*PushConfig) String ¶
func (x *PushConfig) String() string
type ReceivedMessage ¶
type ReceivedMessage struct {
// This ID can be used to acknowledge the received message.
AckId string `protobuf:"bytes,1,opt,name=ack_id,json=ackId,proto3" json:"ack_id,omitempty"`
// The message.
Message *PubsubMessage `protobuf:"bytes,2,opt,name=message,proto3" json:"message,omitempty"`
// contains filtered or unexported fields
}
A message and its corresponding acknowledgment ID.
func (*ReceivedMessage) Descriptor ¶
func (*ReceivedMessage) Descriptor() ([]byte, []int)
Deprecated: Use ReceivedMessage.ProtoReflect.Descriptor instead.
func (*ReceivedMessage) GetAckId ¶
func (x *ReceivedMessage) GetAckId() string
func (*ReceivedMessage) GetMessage ¶
func (x *ReceivedMessage) GetMessage() *PubsubMessage
func (*ReceivedMessage) ProtoMessage ¶
func (*ReceivedMessage) ProtoMessage()
func (*ReceivedMessage) ProtoReflect ¶
func (x *ReceivedMessage) ProtoReflect() protoreflect.Message
func (*ReceivedMessage) Reset ¶
func (x *ReceivedMessage) Reset()
func (*ReceivedMessage) String ¶
func (x *ReceivedMessage) String() string
type SubscriberClient ¶
type SubscriberClient interface {
// Creates a subscription to a given topic for a given subscriber.
// If the subscription already exists, returns ALREADY_EXISTS.
// If the corresponding topic doesn't exist, returns NOT_FOUND.
//
// If the name is not provided in the request, the server will assign a random
// name for this subscription on the same project as the topic.
CreateSubscription(ctx context.Context, in *Subscription, opts ...grpc.CallOption) (*Subscription, error)
// Gets the configuration details of a subscription.
GetSubscription(ctx context.Context, in *GetSubscriptionRequest, opts ...grpc.CallOption) (*Subscription, error)
// Lists matching subscriptions.
ListSubscriptions(ctx context.Context, in *ListSubscriptionsRequest, opts ...grpc.CallOption) (*ListSubscriptionsResponse, error)
// Deletes an existing subscription. All pending messages in the subscription
// are immediately dropped. Calls to Pull after deletion will return
// NOT_FOUND. After a subscription is deleted, a new one may be created with
// the same name, but the new one has no association with the old
// subscription, or its topic unless the same topic is specified.
DeleteSubscription(ctx context.Context, in *DeleteSubscriptionRequest, opts ...grpc.CallOption) (*emptypb.Empty, error)
// Modifies the ack deadline for a specific message. This method is useful to
// indicate that more time is needed to process a message by the subscriber,
// or to make the message available for redelivery if the processing was
// interrupted.
ModifyAckDeadline(ctx context.Context, in *ModifyAckDeadlineRequest, opts ...grpc.CallOption) (*emptypb.Empty, error)
// Acknowledges the messages associated with the ack tokens in the
// AcknowledgeRequest. The Pub/Sub system can remove the relevant messages
// from the subscription.
//
// Acknowledging a message whose ack deadline has expired may succeed,
// but such a message may be redelivered later. Acknowledging a message more
// than once will not result in an error.
Acknowledge(ctx context.Context, in *AcknowledgeRequest, opts ...grpc.CallOption) (*emptypb.Empty, error)
// Pulls messages from the server. Returns an empty list if there are no
// messages available in the backlog. The server may return UNAVAILABLE if
// there are too many concurrent pull requests pending for the given
// subscription.
Pull(ctx context.Context, in *PullRequest, opts ...grpc.CallOption) (*PullResponse, error)
// Modifies the PushConfig for a specified subscription.
//
// This may be used to change a push subscription to a pull one (signified
// by an empty PushConfig) or vice versa, or change the endpoint URL and other
// attributes of a push subscription. Messages will accumulate for
// delivery continuously through the call regardless of changes to the
// PushConfig.
ModifyPushConfig(ctx context.Context, in *ModifyPushConfigRequest, opts ...grpc.CallOption) (*emptypb.Empty, error)
}
SubscriberClient is the client API for Subscriber service.
For semantics around ctx use and closing/ending streaming RPCs, please refer to https://godoc.org/google.golang.org/grpc#ClientConn.NewStream.
func NewSubscriberClient ¶
func NewSubscriberClient(cc grpc.ClientConnInterface) SubscriberClient
type SubscriberServer ¶
type SubscriberServer interface {
// Creates a subscription to a given topic for a given subscriber.
// If the subscription already exists, returns ALREADY_EXISTS.
// If the corresponding topic doesn't exist, returns NOT_FOUND.
//
// If the name is not provided in the request, the server will assign a random
// name for this subscription on the same project as the topic.
CreateSubscription(context.Context, *Subscription) (*Subscription, error)
// Gets the configuration details of a subscription.
GetSubscription(context.Context, *GetSubscriptionRequest) (*Subscription, error)
// Lists matching subscriptions.
ListSubscriptions(context.Context, *ListSubscriptionsRequest) (*ListSubscriptionsResponse, error)
// Deletes an existing subscription. All pending messages in the subscription
// are immediately dropped. Calls to Pull after deletion will return
// NOT_FOUND. After a subscription is deleted, a new one may be created with
// the same name, but the new one has no association with the old
// subscription, or its topic unless the same topic is specified.
DeleteSubscription(context.Context, *DeleteSubscriptionRequest) (*emptypb.Empty, error)
// Modifies the ack deadline for a specific message. This method is useful to
// indicate that more time is needed to process a message by the subscriber,
// or to make the message available for redelivery if the processing was
// interrupted.
ModifyAckDeadline(context.Context, *ModifyAckDeadlineRequest) (*emptypb.Empty, error)
// Acknowledges the messages associated with the ack tokens in the
// AcknowledgeRequest. The Pub/Sub system can remove the relevant messages
// from the subscription.
//
// Acknowledging a message whose ack deadline has expired may succeed,
// but such a message may be redelivered later. Acknowledging a message more
// than once will not result in an error.
Acknowledge(context.Context, *AcknowledgeRequest) (*emptypb.Empty, error)
// Pulls messages from the server. Returns an empty list if there are no
// messages available in the backlog. The server may return UNAVAILABLE if
// there are too many concurrent pull requests pending for the given
// subscription.
Pull(context.Context, *PullRequest) (*PullResponse, error)
// Modifies the PushConfig for a specified subscription.
//
// This may be used to change a push subscription to a pull one (signified
// by an empty PushConfig) or vice versa, or change the endpoint URL and other
// attributes of a push subscription. Messages will accumulate for
// delivery continuously through the call regardless of changes to the
// PushConfig.
ModifyPushConfig(context.Context, *ModifyPushConfigRequest) (*emptypb.Empty, error)
}
SubscriberServer is the server API for Subscriber service.
type Subscription ¶
type Subscription struct {
// Name of the subscription.
Name string `protobuf:"bytes,1,opt,name=name,proto3" json:"name,omitempty"`
// The name of the topic from which this subscription is receiving messages.
// This will be present if and only if the subscription has not been detached
// from its topic.
Topic string `protobuf:"bytes,2,opt,name=topic,proto3" json:"topic,omitempty"`
// If push delivery is used with this subscription, this field is
// used to configure it. An empty pushConfig signifies that the subscriber
// will pull and ack messages using API methods.
PushConfig *PushConfig `protobuf:"bytes,4,opt,name=push_config,json=pushConfig,proto3" json:"push_config,omitempty"`
// This value is the maximum time after a subscriber receives a message
// before the subscriber should acknowledge the message. After message
// delivery but before the ack deadline expires and before the message is
// acknowledged, it is an outstanding message and will not be delivered
// again during that time (on a best-effort basis).
//
// For pull delivery this value
// is used as the initial value for the ack deadline. It may be overridden
// for a specific message by calling ModifyAckDeadline.
//
// For push delivery, this value is also used to set the request timeout for
// the call to the push endpoint.
//
// If the subscriber never acknowledges the message, the Pub/Sub
// system will eventually redeliver the message.
AckDeadlineSeconds int32 `protobuf:"varint,5,opt,name=ack_deadline_seconds,json=ackDeadlineSeconds,proto3" json:"ack_deadline_seconds,omitempty"`
// contains filtered or unexported fields
}
A subscription resource.
func (*Subscription) Descriptor ¶
func (*Subscription) Descriptor() ([]byte, []int)
Deprecated: Use Subscription.ProtoReflect.Descriptor instead.
func (*Subscription) GetAckDeadlineSeconds ¶
func (x *Subscription) GetAckDeadlineSeconds() int32
func (*Subscription) GetName ¶
func (x *Subscription) GetName() string
func (*Subscription) GetPushConfig ¶
func (x *Subscription) GetPushConfig() *PushConfig
func (*Subscription) GetTopic ¶
func (x *Subscription) GetTopic() string
func (*Subscription) ProtoMessage ¶
func (*Subscription) ProtoMessage()
func (*Subscription) ProtoReflect ¶
func (x *Subscription) ProtoReflect() protoreflect.Message
func (*Subscription) Reset ¶
func (x *Subscription) Reset()
func (*Subscription) String ¶
func (x *Subscription) String() string
type Topic ¶
type Topic struct {
// Name of the topic.
Name string `protobuf:"bytes,1,opt,name=name,proto3" json:"name,omitempty"`
// contains filtered or unexported fields
}
A topic resource.
func (*Topic) Descriptor ¶
Deprecated: Use Topic.ProtoReflect.Descriptor instead.
func (*Topic) GetName ¶
func (*Topic) ProtoMessage ¶
func (*Topic) ProtoMessage()
func (*Topic) ProtoReflect ¶
func (x *Topic) ProtoReflect() protoreflect.Message
func (*Topic) Reset ¶
func (x *Topic) Reset()
func (*Topic) String ¶
type UnimplementedPublisherServer ¶
type UnimplementedPublisherServer struct {
}
UnimplementedPublisherServer can be embedded to have forward compatible implementations.
func (*UnimplementedPublisherServer) CreateTopic ¶
func (*UnimplementedPublisherServer) DeleteTopic ¶
func (*UnimplementedPublisherServer) DeleteTopic(context.Context, *DeleteTopicRequest) (*emptypb.Empty, error)
func (*UnimplementedPublisherServer) GetTopic ¶
func (*UnimplementedPublisherServer) GetTopic(context.Context, *GetTopicRequest) (*Topic, error)
func (*UnimplementedPublisherServer) ListTopicSubscriptions ¶
func (*UnimplementedPublisherServer) ListTopicSubscriptions(context.Context, *ListTopicSubscriptionsRequest) (*ListTopicSubscriptionsResponse, error)
func (*UnimplementedPublisherServer) ListTopics ¶
func (*UnimplementedPublisherServer) ListTopics(context.Context, *ListTopicsRequest) (*ListTopicsResponse, error)
func (*UnimplementedPublisherServer) Publish ¶
func (*UnimplementedPublisherServer) Publish(context.Context, *PublishRequest) (*PublishResponse, error)
type UnimplementedSubscriberServer ¶
type UnimplementedSubscriberServer struct {
}
UnimplementedSubscriberServer can be embedded to have forward compatible implementations.
func (*UnimplementedSubscriberServer) Acknowledge ¶
func (*UnimplementedSubscriberServer) Acknowledge(context.Context, *AcknowledgeRequest) (*emptypb.Empty, error)
func (*UnimplementedSubscriberServer) CreateSubscription ¶
func (*UnimplementedSubscriberServer) CreateSubscription(context.Context, *Subscription) (*Subscription, error)
func (*UnimplementedSubscriberServer) DeleteSubscription ¶
func (*UnimplementedSubscriberServer) DeleteSubscription(context.Context, *DeleteSubscriptionRequest) (*emptypb.Empty, error)
func (*UnimplementedSubscriberServer) GetSubscription ¶
func (*UnimplementedSubscriberServer) GetSubscription(context.Context, *GetSubscriptionRequest) (*Subscription, error)
func (*UnimplementedSubscriberServer) ListSubscriptions ¶
func (*UnimplementedSubscriberServer) ListSubscriptions(context.Context, *ListSubscriptionsRequest) (*ListSubscriptionsResponse, error)
func (*UnimplementedSubscriberServer) ModifyAckDeadline ¶
func (*UnimplementedSubscriberServer) ModifyAckDeadline(context.Context, *ModifyAckDeadlineRequest) (*emptypb.Empty, error)
func (*UnimplementedSubscriberServer) ModifyPushConfig ¶
func (*UnimplementedSubscriberServer) ModifyPushConfig(context.Context, *ModifyPushConfigRequest) (*emptypb.Empty, error)
func (*UnimplementedSubscriberServer) Pull ¶
func (*UnimplementedSubscriberServer) Pull(context.Context, *PullRequest) (*PullResponse, error)
Source Files ¶
pubsub.pb.go
- Version
- v0.0.0-20260427160629-7cedc36a6bc4 (latest)
- Published
- Apr 27, 2026
- Platform
- linux/amd64
- Imports
- 9 packages
- Last checked
- 2 days ago –
Tools for package owners.