package logging
import "google.golang.org/genproto/googleapis/storagetransfer/logging"
Index ¶
- Variables
- type AwsS3BucketMetadata
- func (*AwsS3BucketMetadata) Descriptor() ([]byte, []int)
- func (x *AwsS3BucketMetadata) GetBucket() string
- func (x *AwsS3BucketMetadata) GetPath() string
- func (*AwsS3BucketMetadata) ProtoMessage()
- func (x *AwsS3BucketMetadata) ProtoReflect() protoreflect.Message
- func (x *AwsS3BucketMetadata) Reset()
- func (x *AwsS3BucketMetadata) String() string
- type AwsS3ObjectMetadata
- func (*AwsS3ObjectMetadata) Descriptor() ([]byte, []int)
- func (x *AwsS3ObjectMetadata) GetBucket() string
- func (x *AwsS3ObjectMetadata) GetLastModifiedTime() *timestamppb.Timestamp
- func (x *AwsS3ObjectMetadata) GetMd5() string
- func (x *AwsS3ObjectMetadata) GetObjectKey() string
- func (x *AwsS3ObjectMetadata) GetSize() int64
- func (*AwsS3ObjectMetadata) ProtoMessage()
- func (x *AwsS3ObjectMetadata) ProtoReflect() protoreflect.Message
- func (x *AwsS3ObjectMetadata) Reset()
- func (x *AwsS3ObjectMetadata) String() string
- type AzureBlobContainerMetadata
- func (*AzureBlobContainerMetadata) Descriptor() ([]byte, []int)
- func (x *AzureBlobContainerMetadata) GetAccount() string
- func (x *AzureBlobContainerMetadata) GetContainer() string
- func (x *AzureBlobContainerMetadata) GetPath() string
- func (*AzureBlobContainerMetadata) ProtoMessage()
- func (x *AzureBlobContainerMetadata) ProtoReflect() protoreflect.Message
- func (x *AzureBlobContainerMetadata) Reset()
- func (x *AzureBlobContainerMetadata) String() string
- type AzureBlobMetadata
- func (*AzureBlobMetadata) Descriptor() ([]byte, []int)
- func (x *AzureBlobMetadata) GetAccount() string
- func (x *AzureBlobMetadata) GetBlobName() string
- func (x *AzureBlobMetadata) GetContainer() string
- func (x *AzureBlobMetadata) GetLastModifiedTime() *timestamppb.Timestamp
- func (x *AzureBlobMetadata) GetMd5() string
- func (x *AzureBlobMetadata) GetSize() int64
- func (*AzureBlobMetadata) ProtoMessage()
- func (x *AzureBlobMetadata) ProtoReflect() protoreflect.Message
- func (x *AzureBlobMetadata) Reset()
- func (x *AzureBlobMetadata) String() string
- type ContainerMetadata
- func (*ContainerMetadata) Descriptor() ([]byte, []int)
- func (x *ContainerMetadata) GetAwsS3Bucket() *AwsS3BucketMetadata
- func (x *ContainerMetadata) GetAzureBlobContainer() *AzureBlobContainerMetadata
- func (x *ContainerMetadata) GetGcsBucket() *GcsBucketMetadata
- func (x *ContainerMetadata) GetHttpManifest() *HttpManifestMetadata
- func (m *ContainerMetadata) GetMetadata() isContainerMetadata_Metadata
- func (x *ContainerMetadata) GetPosixDirectory() *PosixFileMetadata
- func (x *ContainerMetadata) GetType() StorageSystemType
- func (*ContainerMetadata) ProtoMessage()
- func (x *ContainerMetadata) ProtoReflect() protoreflect.Message
- func (x *ContainerMetadata) Reset()
- func (x *ContainerMetadata) String() string
- type ContainerMetadata_AwsS3Bucket
- type ContainerMetadata_AzureBlobContainer
- type ContainerMetadata_GcsBucket
- type ContainerMetadata_HttpManifest
- type ContainerMetadata_PosixDirectory
- type GcsBucketMetadata
- func (*GcsBucketMetadata) Descriptor() ([]byte, []int)
- func (x *GcsBucketMetadata) GetBucket() string
- func (x *GcsBucketMetadata) GetPath() string
- func (*GcsBucketMetadata) ProtoMessage()
- func (x *GcsBucketMetadata) ProtoReflect() protoreflect.Message
- func (x *GcsBucketMetadata) Reset()
- func (x *GcsBucketMetadata) String() string
- type GcsObjectMetadata
- func (*GcsObjectMetadata) Descriptor() ([]byte, []int)
- func (x *GcsObjectMetadata) GetBucket() string
- func (x *GcsObjectMetadata) GetCrc32C() string
- func (x *GcsObjectMetadata) GetLastModifiedTime() *timestamppb.Timestamp
- func (x *GcsObjectMetadata) GetMd5() string
- func (x *GcsObjectMetadata) GetObjectKey() string
- func (x *GcsObjectMetadata) GetSize() int64
- func (*GcsObjectMetadata) ProtoMessage()
- func (x *GcsObjectMetadata) ProtoReflect() protoreflect.Message
- func (x *GcsObjectMetadata) Reset()
- func (x *GcsObjectMetadata) String() string
- type HttpFileMetadata
- func (*HttpFileMetadata) Descriptor() ([]byte, []int)
- func (x *HttpFileMetadata) GetMd5() string
- func (x *HttpFileMetadata) GetSize() int64
- func (x *HttpFileMetadata) GetUrl() string
- func (*HttpFileMetadata) ProtoMessage()
- func (x *HttpFileMetadata) ProtoReflect() protoreflect.Message
- func (x *HttpFileMetadata) Reset()
- func (x *HttpFileMetadata) String() string
- type HttpManifestMetadata
- func (*HttpManifestMetadata) Descriptor() ([]byte, []int)
- func (x *HttpManifestMetadata) GetUrl() string
- func (*HttpManifestMetadata) ProtoMessage()
- func (x *HttpManifestMetadata) ProtoReflect() protoreflect.Message
- func (x *HttpManifestMetadata) Reset()
- func (x *HttpManifestMetadata) String() string
- type ObjectMetadata
- func (*ObjectMetadata) Descriptor() ([]byte, []int)
- func (x *ObjectMetadata) GetAwsS3Object() *AwsS3ObjectMetadata
- func (x *ObjectMetadata) GetAzureBlob() *AzureBlobMetadata
- func (x *ObjectMetadata) GetGcsObject() *GcsObjectMetadata
- func (x *ObjectMetadata) GetHttpFile() *HttpFileMetadata
- func (m *ObjectMetadata) GetMetadata() isObjectMetadata_Metadata
- func (x *ObjectMetadata) GetPosixFile() *PosixFileMetadata
- func (x *ObjectMetadata) GetType() StorageSystemType
- func (*ObjectMetadata) ProtoMessage()
- func (x *ObjectMetadata) ProtoReflect() protoreflect.Message
- func (x *ObjectMetadata) Reset()
- func (x *ObjectMetadata) String() string
- type ObjectMetadata_AwsS3Object
- type ObjectMetadata_AzureBlob
- type ObjectMetadata_GcsObject
- type ObjectMetadata_HttpFile
- type ObjectMetadata_PosixFile
- type PosixFileMetadata
- func (*PosixFileMetadata) Descriptor() ([]byte, []int)
- func (x *PosixFileMetadata) GetCrc32C() string
- func (x *PosixFileMetadata) GetLastModifiedTime() *timestamppb.Timestamp
- func (x *PosixFileMetadata) GetPath() string
- func (x *PosixFileMetadata) GetSize() int64
- func (*PosixFileMetadata) ProtoMessage()
- func (x *PosixFileMetadata) ProtoReflect() protoreflect.Message
- func (x *PosixFileMetadata) Reset()
- func (x *PosixFileMetadata) String() string
- type StorageSystemType
- func (StorageSystemType) Descriptor() protoreflect.EnumDescriptor
- func (x StorageSystemType) Enum() *StorageSystemType
- func (StorageSystemType) EnumDescriptor() ([]byte, []int)
- func (x StorageSystemType) Number() protoreflect.EnumNumber
- func (x StorageSystemType) String() string
- func (StorageSystemType) Type() protoreflect.EnumType
- type TransferActivityLog
- func (*TransferActivityLog) Descriptor() ([]byte, []int)
- func (x *TransferActivityLog) GetAction() TransferActivityLog_Action
- func (x *TransferActivityLog) GetCompleteTime() *timestamppb.Timestamp
- func (x *TransferActivityLog) GetDestinationContainer() *ContainerMetadata
- func (x *TransferActivityLog) GetDestinationObject() *ObjectMetadata
- func (x *TransferActivityLog) GetOperation() string
- func (x *TransferActivityLog) GetSourceContainer() *ContainerMetadata
- func (x *TransferActivityLog) GetSourceObject() *ObjectMetadata
- func (x *TransferActivityLog) GetStatus() *TransferActivityLog_Status
- func (*TransferActivityLog) ProtoMessage()
- func (x *TransferActivityLog) ProtoReflect() protoreflect.Message
- func (x *TransferActivityLog) Reset()
- func (x *TransferActivityLog) String() string
- type TransferActivityLog_Action
- func (TransferActivityLog_Action) Descriptor() protoreflect.EnumDescriptor
- func (x TransferActivityLog_Action) Enum() *TransferActivityLog_Action
- func (TransferActivityLog_Action) EnumDescriptor() ([]byte, []int)
- func (x TransferActivityLog_Action) Number() protoreflect.EnumNumber
- func (x TransferActivityLog_Action) String() string
- func (TransferActivityLog_Action) Type() protoreflect.EnumType
- type TransferActivityLog_Status
- func (*TransferActivityLog_Status) Descriptor() ([]byte, []int)
- func (x *TransferActivityLog_Status) GetErrorMessage() string
- func (x *TransferActivityLog_Status) GetErrorType() string
- func (x *TransferActivityLog_Status) GetStatusCode() string
- func (*TransferActivityLog_Status) ProtoMessage()
- func (x *TransferActivityLog_Status) ProtoReflect() protoreflect.Message
- func (x *TransferActivityLog_Status) Reset()
- func (x *TransferActivityLog_Status) String() string
Variables ¶
var ( StorageSystemType_name = map[int32]string{ 0: "STORAGE_SYSTEM_TYPE_UNSPECIFIED", 1: "AWS_S3", 2: "AZURE_BLOB", 3: "GCS", 4: "POSIX_FS", 5: "HTTP", } StorageSystemType_value = map[string]int32{ "STORAGE_SYSTEM_TYPE_UNSPECIFIED": 0, "AWS_S3": 1, "AZURE_BLOB": 2, "GCS": 3, "POSIX_FS": 4, "HTTP": 5, } )
Enum value maps for StorageSystemType.
var ( TransferActivityLog_Action_name = map[int32]string{ 0: "ACTION_UNSPECIFIED", 1: "FIND", 2: "COPY", 3: "DELETE", } TransferActivityLog_Action_value = map[string]int32{ "ACTION_UNSPECIFIED": 0, "FIND": 1, "COPY": 2, "DELETE": 3, } )
Enum value maps for TransferActivityLog_Action.
var File_google_storagetransfer_logging_transfer_activity_log_proto protoreflect.FileDescriptor
Types ¶
type AwsS3BucketMetadata ¶
type AwsS3BucketMetadata struct {
// Required. Name of the S3 bucket.
Bucket string `protobuf:"bytes,1,opt,name=bucket,proto3" json:"bucket,omitempty"`
// The path of transfer objects as an object key prefix ending with "/".
Path string `protobuf:"bytes,2,opt,name=path,proto3" json:"path,omitempty"`
// contains filtered or unexported fields
}
AWS S3 bucket metadata.
func (*AwsS3BucketMetadata) Descriptor ¶
func (*AwsS3BucketMetadata) Descriptor() ([]byte, []int)
Deprecated: Use AwsS3BucketMetadata.ProtoReflect.Descriptor instead.
func (*AwsS3BucketMetadata) GetBucket ¶
func (x *AwsS3BucketMetadata) GetBucket() string
func (*AwsS3BucketMetadata) GetPath ¶
func (x *AwsS3BucketMetadata) GetPath() string
func (*AwsS3BucketMetadata) ProtoMessage ¶
func (*AwsS3BucketMetadata) ProtoMessage()
func (*AwsS3BucketMetadata) ProtoReflect ¶
func (x *AwsS3BucketMetadata) ProtoReflect() protoreflect.Message
func (*AwsS3BucketMetadata) Reset ¶
func (x *AwsS3BucketMetadata) Reset()
func (*AwsS3BucketMetadata) String ¶
func (x *AwsS3BucketMetadata) String() string
type AwsS3ObjectMetadata ¶
type AwsS3ObjectMetadata struct {
// Required. Name of the S3 bucket.
Bucket string `protobuf:"bytes,1,opt,name=bucket,proto3" json:"bucket,omitempty"`
// Required. Name/key of the object.
ObjectKey string `protobuf:"bytes,2,opt,name=object_key,json=objectKey,proto3" json:"object_key,omitempty"`
// Last modified time of the object.
LastModifiedTime *timestamppb.Timestamp `protobuf:"bytes,3,opt,name=last_modified_time,json=lastModifiedTime,proto3" json:"last_modified_time,omitempty"`
// The MD5 checksum of the object's content.
Md5 string `protobuf:"bytes,4,opt,name=md5,proto3" json:"md5,omitempty"`
// Required. Size of the object in bytes.
Size int64 `protobuf:"varint,5,opt,name=size,proto3" json:"size,omitempty"`
// contains filtered or unexported fields
}
AWS S3 object metadata.
func (*AwsS3ObjectMetadata) Descriptor ¶
func (*AwsS3ObjectMetadata) Descriptor() ([]byte, []int)
Deprecated: Use AwsS3ObjectMetadata.ProtoReflect.Descriptor instead.
func (*AwsS3ObjectMetadata) GetBucket ¶
func (x *AwsS3ObjectMetadata) GetBucket() string
func (*AwsS3ObjectMetadata) GetLastModifiedTime ¶
func (x *AwsS3ObjectMetadata) GetLastModifiedTime() *timestamppb.Timestamp
func (*AwsS3ObjectMetadata) GetMd5 ¶
func (x *AwsS3ObjectMetadata) GetMd5() string
func (*AwsS3ObjectMetadata) GetObjectKey ¶
func (x *AwsS3ObjectMetadata) GetObjectKey() string
func (*AwsS3ObjectMetadata) GetSize ¶
func (x *AwsS3ObjectMetadata) GetSize() int64
func (*AwsS3ObjectMetadata) ProtoMessage ¶
func (*AwsS3ObjectMetadata) ProtoMessage()
func (*AwsS3ObjectMetadata) ProtoReflect ¶
func (x *AwsS3ObjectMetadata) ProtoReflect() protoreflect.Message
func (*AwsS3ObjectMetadata) Reset ¶
func (x *AwsS3ObjectMetadata) Reset()
func (*AwsS3ObjectMetadata) String ¶
func (x *AwsS3ObjectMetadata) String() string
type AzureBlobContainerMetadata ¶
type AzureBlobContainerMetadata struct {
// Required. Name of the Azure Blob storage account.
Account string `protobuf:"bytes,1,opt,name=account,proto3" json:"account,omitempty"`
// Required. Name of the container.
Container string `protobuf:"bytes,2,opt,name=container,proto3" json:"container,omitempty"`
// The path of transfer blobs as a blob name prefix ending with "/".
Path string `protobuf:"bytes,3,opt,name=path,proto3" json:"path,omitempty"`
// contains filtered or unexported fields
}
Azure Blob Storage container metadata.
func (*AzureBlobContainerMetadata) Descriptor ¶
func (*AzureBlobContainerMetadata) Descriptor() ([]byte, []int)
Deprecated: Use AzureBlobContainerMetadata.ProtoReflect.Descriptor instead.
func (*AzureBlobContainerMetadata) GetAccount ¶
func (x *AzureBlobContainerMetadata) GetAccount() string
func (*AzureBlobContainerMetadata) GetContainer ¶
func (x *AzureBlobContainerMetadata) GetContainer() string
func (*AzureBlobContainerMetadata) GetPath ¶
func (x *AzureBlobContainerMetadata) GetPath() string
func (*AzureBlobContainerMetadata) ProtoMessage ¶
func (*AzureBlobContainerMetadata) ProtoMessage()
func (*AzureBlobContainerMetadata) ProtoReflect ¶
func (x *AzureBlobContainerMetadata) ProtoReflect() protoreflect.Message
func (*AzureBlobContainerMetadata) Reset ¶
func (x *AzureBlobContainerMetadata) Reset()
func (*AzureBlobContainerMetadata) String ¶
func (x *AzureBlobContainerMetadata) String() string
type AzureBlobMetadata ¶
type AzureBlobMetadata struct {
// Required. Name of the Azure Blob storage account.
Account string `protobuf:"bytes,1,opt,name=account,proto3" json:"account,omitempty"`
// Required. Name of the container.
Container string `protobuf:"bytes,2,opt,name=container,proto3" json:"container,omitempty"`
// Required. Name of the blob.
BlobName string `protobuf:"bytes,3,opt,name=blob_name,json=blobName,proto3" json:"blob_name,omitempty"`
// Last modified time of the blob.
LastModifiedTime *timestamppb.Timestamp `protobuf:"bytes,4,opt,name=last_modified_time,json=lastModifiedTime,proto3" json:"last_modified_time,omitempty"`
// The MD5 checksum of the object's content.
Md5 string `protobuf:"bytes,5,opt,name=md5,proto3" json:"md5,omitempty"`
// Required. Size of the blob in bytes.
Size int64 `protobuf:"varint,6,opt,name=size,proto3" json:"size,omitempty"`
// contains filtered or unexported fields
}
Azure Blob Storage blob metadata.
func (*AzureBlobMetadata) Descriptor ¶
func (*AzureBlobMetadata) Descriptor() ([]byte, []int)
Deprecated: Use AzureBlobMetadata.ProtoReflect.Descriptor instead.
func (*AzureBlobMetadata) GetAccount ¶
func (x *AzureBlobMetadata) GetAccount() string
func (*AzureBlobMetadata) GetBlobName ¶
func (x *AzureBlobMetadata) GetBlobName() string
func (*AzureBlobMetadata) GetContainer ¶
func (x *AzureBlobMetadata) GetContainer() string
func (*AzureBlobMetadata) GetLastModifiedTime ¶
func (x *AzureBlobMetadata) GetLastModifiedTime() *timestamppb.Timestamp
func (*AzureBlobMetadata) GetMd5 ¶
func (x *AzureBlobMetadata) GetMd5() string
func (*AzureBlobMetadata) GetSize ¶
func (x *AzureBlobMetadata) GetSize() int64
func (*AzureBlobMetadata) ProtoMessage ¶
func (*AzureBlobMetadata) ProtoMessage()
func (*AzureBlobMetadata) ProtoReflect ¶
func (x *AzureBlobMetadata) ProtoReflect() protoreflect.Message
func (*AzureBlobMetadata) Reset ¶
func (x *AzureBlobMetadata) Reset()
func (*AzureBlobMetadata) String ¶
func (x *AzureBlobMetadata) String() string
type ContainerMetadata ¶
type ContainerMetadata struct {
// Required. Storage system type of the object.
Type StorageSystemType `protobuf:"varint,1,opt,name=type,proto3,enum=google.storagetransfer.logging.StorageSystemType" json:"type,omitempty"`
// Types that are assignable to Metadata:
//
// *ContainerMetadata_AwsS3Bucket
// *ContainerMetadata_AzureBlobContainer
// *ContainerMetadata_GcsBucket
// *ContainerMetadata_PosixDirectory
// *ContainerMetadata_HttpManifest
Metadata isContainerMetadata_Metadata `protobuf_oneof:"metadata"`
// contains filtered or unexported fields
}
Metadata of a bucket/container/directory
func (*ContainerMetadata) Descriptor ¶
func (*ContainerMetadata) Descriptor() ([]byte, []int)
Deprecated: Use ContainerMetadata.ProtoReflect.Descriptor instead.
func (*ContainerMetadata) GetAwsS3Bucket ¶
func (x *ContainerMetadata) GetAwsS3Bucket() *AwsS3BucketMetadata
func (*ContainerMetadata) GetAzureBlobContainer ¶
func (x *ContainerMetadata) GetAzureBlobContainer() *AzureBlobContainerMetadata
func (*ContainerMetadata) GetGcsBucket ¶
func (x *ContainerMetadata) GetGcsBucket() *GcsBucketMetadata
func (*ContainerMetadata) GetHttpManifest ¶
func (x *ContainerMetadata) GetHttpManifest() *HttpManifestMetadata
func (*ContainerMetadata) GetMetadata ¶
func (m *ContainerMetadata) GetMetadata() isContainerMetadata_Metadata
func (*ContainerMetadata) GetPosixDirectory ¶
func (x *ContainerMetadata) GetPosixDirectory() *PosixFileMetadata
func (*ContainerMetadata) GetType ¶
func (x *ContainerMetadata) GetType() StorageSystemType
func (*ContainerMetadata) ProtoMessage ¶
func (*ContainerMetadata) ProtoMessage()
func (*ContainerMetadata) ProtoReflect ¶
func (x *ContainerMetadata) ProtoReflect() protoreflect.Message
func (*ContainerMetadata) Reset ¶
func (x *ContainerMetadata) Reset()
func (*ContainerMetadata) String ¶
func (x *ContainerMetadata) String() string
type ContainerMetadata_AwsS3Bucket ¶
type ContainerMetadata_AwsS3Bucket struct {
// Bucket metadata of AWS S3.
AwsS3Bucket *AwsS3BucketMetadata `protobuf:"bytes,3,opt,name=aws_s3_bucket,json=awsS3Bucket,proto3,oneof"`
}
type ContainerMetadata_AzureBlobContainer ¶
type ContainerMetadata_AzureBlobContainer struct {
// Container metadata of Azure Blob Storage.
AzureBlobContainer *AzureBlobContainerMetadata `protobuf:"bytes,4,opt,name=azure_blob_container,json=azureBlobContainer,proto3,oneof"`
}
type ContainerMetadata_GcsBucket ¶
type ContainerMetadata_GcsBucket struct {
// Bucket metadata of Google Cloud Storage.
GcsBucket *GcsBucketMetadata `protobuf:"bytes,5,opt,name=gcs_bucket,json=gcsBucket,proto3,oneof"`
}
type ContainerMetadata_HttpManifest ¶
type ContainerMetadata_HttpManifest struct {
// Metadata of a manifest file on a HTTP server.
HttpManifest *HttpManifestMetadata `protobuf:"bytes,7,opt,name=http_manifest,json=httpManifest,proto3,oneof"`
}
type ContainerMetadata_PosixDirectory ¶
type ContainerMetadata_PosixDirectory struct {
// Directory metadata of POSIX file system.
PosixDirectory *PosixFileMetadata `protobuf:"bytes,6,opt,name=posix_directory,json=posixDirectory,proto3,oneof"`
}
type GcsBucketMetadata ¶
type GcsBucketMetadata struct {
// Required. Name of the Cloud Storage bucket.
Bucket string `protobuf:"bytes,1,opt,name=bucket,proto3" json:"bucket,omitempty"`
// The path of transfer objects as an object key prefix ending with "/".
Path string `protobuf:"bytes,2,opt,name=path,proto3" json:"path,omitempty"`
// contains filtered or unexported fields
}
Google Cloud Storage bucket metadata.
func (*GcsBucketMetadata) Descriptor ¶
func (*GcsBucketMetadata) Descriptor() ([]byte, []int)
Deprecated: Use GcsBucketMetadata.ProtoReflect.Descriptor instead.
func (*GcsBucketMetadata) GetBucket ¶
func (x *GcsBucketMetadata) GetBucket() string
func (*GcsBucketMetadata) GetPath ¶
func (x *GcsBucketMetadata) GetPath() string
func (*GcsBucketMetadata) ProtoMessage ¶
func (*GcsBucketMetadata) ProtoMessage()
func (*GcsBucketMetadata) ProtoReflect ¶
func (x *GcsBucketMetadata) ProtoReflect() protoreflect.Message
func (*GcsBucketMetadata) Reset ¶
func (x *GcsBucketMetadata) Reset()
func (*GcsBucketMetadata) String ¶
func (x *GcsBucketMetadata) String() string
type GcsObjectMetadata ¶
type GcsObjectMetadata struct {
// Required. Name of the Cloud Storage bucket.
Bucket string `protobuf:"bytes,1,opt,name=bucket,proto3" json:"bucket,omitempty"`
// Required. Name/key of the object.
ObjectKey string `protobuf:"bytes,2,opt,name=object_key,json=objectKey,proto3" json:"object_key,omitempty"`
// Last modified time of the object.
LastModifiedTime *timestamppb.Timestamp `protobuf:"bytes,3,opt,name=last_modified_time,json=lastModifiedTime,proto3" json:"last_modified_time,omitempty"`
// The MD5 checksum of the object's content.
Md5 string `protobuf:"bytes,4,opt,name=md5,proto3" json:"md5,omitempty"`
// The CRC32C checksum of the object's content.
Crc32C string `protobuf:"bytes,5,opt,name=crc32c,proto3" json:"crc32c,omitempty"`
// Required. Size of the object in bytes.
Size int64 `protobuf:"varint,6,opt,name=size,proto3" json:"size,omitempty"`
// contains filtered or unexported fields
}
Google Cloud Storage object metadata.
func (*GcsObjectMetadata) Descriptor ¶
func (*GcsObjectMetadata) Descriptor() ([]byte, []int)
Deprecated: Use GcsObjectMetadata.ProtoReflect.Descriptor instead.
func (*GcsObjectMetadata) GetBucket ¶
func (x *GcsObjectMetadata) GetBucket() string
func (*GcsObjectMetadata) GetCrc32C ¶
func (x *GcsObjectMetadata) GetCrc32C() string
func (*GcsObjectMetadata) GetLastModifiedTime ¶
func (x *GcsObjectMetadata) GetLastModifiedTime() *timestamppb.Timestamp
func (*GcsObjectMetadata) GetMd5 ¶
func (x *GcsObjectMetadata) GetMd5() string
func (*GcsObjectMetadata) GetObjectKey ¶
func (x *GcsObjectMetadata) GetObjectKey() string
func (*GcsObjectMetadata) GetSize ¶
func (x *GcsObjectMetadata) GetSize() int64
func (*GcsObjectMetadata) ProtoMessage ¶
func (*GcsObjectMetadata) ProtoMessage()
func (*GcsObjectMetadata) ProtoReflect ¶
func (x *GcsObjectMetadata) ProtoReflect() protoreflect.Message
func (*GcsObjectMetadata) Reset ¶
func (x *GcsObjectMetadata) Reset()
func (*GcsObjectMetadata) String ¶
func (x *GcsObjectMetadata) String() string
type HttpFileMetadata ¶
type HttpFileMetadata struct {
// Required. Url of the HTTP file.
Url string `protobuf:"bytes,1,opt,name=url,proto3" json:"url,omitempty"`
// The MD5 checksum of the file's content.
Md5 string `protobuf:"bytes,2,opt,name=md5,proto3" json:"md5,omitempty"`
// Size of the file in bytes.
Size int64 `protobuf:"varint,3,opt,name=size,proto3" json:"size,omitempty"`
// contains filtered or unexported fields
}
HTTP file metadata.
func (*HttpFileMetadata) Descriptor ¶
func (*HttpFileMetadata) Descriptor() ([]byte, []int)
Deprecated: Use HttpFileMetadata.ProtoReflect.Descriptor instead.
func (*HttpFileMetadata) GetMd5 ¶
func (x *HttpFileMetadata) GetMd5() string
func (*HttpFileMetadata) GetSize ¶
func (x *HttpFileMetadata) GetSize() int64
func (*HttpFileMetadata) GetUrl ¶
func (x *HttpFileMetadata) GetUrl() string
func (*HttpFileMetadata) ProtoMessage ¶
func (*HttpFileMetadata) ProtoMessage()
func (*HttpFileMetadata) ProtoReflect ¶
func (x *HttpFileMetadata) ProtoReflect() protoreflect.Message
func (*HttpFileMetadata) Reset ¶
func (x *HttpFileMetadata) Reset()
func (*HttpFileMetadata) String ¶
func (x *HttpFileMetadata) String() string
type HttpManifestMetadata ¶
type HttpManifestMetadata struct {
// Required. Url of the HTTP manifest which contains the list of HTTP files to
// transfer.
Url string `protobuf:"bytes,1,opt,name=url,proto3" json:"url,omitempty"`
// contains filtered or unexported fields
}
HTTP manifest file metadata.
func (*HttpManifestMetadata) Descriptor ¶
func (*HttpManifestMetadata) Descriptor() ([]byte, []int)
Deprecated: Use HttpManifestMetadata.ProtoReflect.Descriptor instead.
func (*HttpManifestMetadata) GetUrl ¶
func (x *HttpManifestMetadata) GetUrl() string
func (*HttpManifestMetadata) ProtoMessage ¶
func (*HttpManifestMetadata) ProtoMessage()
func (*HttpManifestMetadata) ProtoReflect ¶
func (x *HttpManifestMetadata) ProtoReflect() protoreflect.Message
func (*HttpManifestMetadata) Reset ¶
func (x *HttpManifestMetadata) Reset()
func (*HttpManifestMetadata) String ¶
func (x *HttpManifestMetadata) String() string
type ObjectMetadata ¶
type ObjectMetadata struct {
// Required. Storage system type of the object.
Type StorageSystemType `protobuf:"varint,1,opt,name=type,proto3,enum=google.storagetransfer.logging.StorageSystemType" json:"type,omitempty"`
// Types that are assignable to Metadata:
//
// *ObjectMetadata_AwsS3Object
// *ObjectMetadata_AzureBlob
// *ObjectMetadata_GcsObject
// *ObjectMetadata_PosixFile
// *ObjectMetadata_HttpFile
Metadata isObjectMetadata_Metadata `protobuf_oneof:"metadata"`
// contains filtered or unexported fields
}
Metadata of a blob/file/object.
func (*ObjectMetadata) Descriptor ¶
func (*ObjectMetadata) Descriptor() ([]byte, []int)
Deprecated: Use ObjectMetadata.ProtoReflect.Descriptor instead.
func (*ObjectMetadata) GetAwsS3Object ¶
func (x *ObjectMetadata) GetAwsS3Object() *AwsS3ObjectMetadata
func (*ObjectMetadata) GetAzureBlob ¶
func (x *ObjectMetadata) GetAzureBlob() *AzureBlobMetadata
func (*ObjectMetadata) GetGcsObject ¶
func (x *ObjectMetadata) GetGcsObject() *GcsObjectMetadata
func (*ObjectMetadata) GetHttpFile ¶
func (x *ObjectMetadata) GetHttpFile() *HttpFileMetadata
func (*ObjectMetadata) GetMetadata ¶
func (m *ObjectMetadata) GetMetadata() isObjectMetadata_Metadata
func (*ObjectMetadata) GetPosixFile ¶
func (x *ObjectMetadata) GetPosixFile() *PosixFileMetadata
func (*ObjectMetadata) GetType ¶
func (x *ObjectMetadata) GetType() StorageSystemType
func (*ObjectMetadata) ProtoMessage ¶
func (*ObjectMetadata) ProtoMessage()
func (*ObjectMetadata) ProtoReflect ¶
func (x *ObjectMetadata) ProtoReflect() protoreflect.Message
func (*ObjectMetadata) Reset ¶
func (x *ObjectMetadata) Reset()
func (*ObjectMetadata) String ¶
func (x *ObjectMetadata) String() string
type ObjectMetadata_AwsS3Object ¶
type ObjectMetadata_AwsS3Object struct {
// Object metadata of AWS S3.
AwsS3Object *AwsS3ObjectMetadata `protobuf:"bytes,3,opt,name=aws_s3_object,json=awsS3Object,proto3,oneof"`
}
type ObjectMetadata_AzureBlob ¶
type ObjectMetadata_AzureBlob struct {
// Blob metadata of Azure Blob Storage.
AzureBlob *AzureBlobMetadata `protobuf:"bytes,4,opt,name=azure_blob,json=azureBlob,proto3,oneof"`
}
type ObjectMetadata_GcsObject ¶
type ObjectMetadata_GcsObject struct {
// Object metadata of Google Cloud Storage.
GcsObject *GcsObjectMetadata `protobuf:"bytes,5,opt,name=gcs_object,json=gcsObject,proto3,oneof"`
}
type ObjectMetadata_HttpFile ¶
type ObjectMetadata_HttpFile struct {
// Metadata of a file on a HTTP server.
HttpFile *HttpFileMetadata `protobuf:"bytes,7,opt,name=http_file,json=httpFile,proto3,oneof"`
}
type ObjectMetadata_PosixFile ¶
type ObjectMetadata_PosixFile struct {
// File/directory metadata of POSIX file system.
PosixFile *PosixFileMetadata `protobuf:"bytes,6,opt,name=posix_file,json=posixFile,proto3,oneof"`
}
type PosixFileMetadata ¶
type PosixFileMetadata struct {
// Required. Path of a file.
Path string `protobuf:"bytes,1,opt,name=path,proto3" json:"path,omitempty"`
// Last modified time (mtime) of the file.
LastModifiedTime *timestamppb.Timestamp `protobuf:"bytes,2,opt,name=last_modified_time,json=lastModifiedTime,proto3" json:"last_modified_time,omitempty"`
// The CRC32C checksum of the object's content.
Crc32C string `protobuf:"bytes,3,opt,name=crc32c,proto3" json:"crc32c,omitempty"`
// Required. Size of the file in bytes.
Size int64 `protobuf:"varint,4,opt,name=size,proto3" json:"size,omitempty"`
// contains filtered or unexported fields
}
POSIX file metadata.
func (*PosixFileMetadata) Descriptor ¶
func (*PosixFileMetadata) Descriptor() ([]byte, []int)
Deprecated: Use PosixFileMetadata.ProtoReflect.Descriptor instead.
func (*PosixFileMetadata) GetCrc32C ¶
func (x *PosixFileMetadata) GetCrc32C() string
func (*PosixFileMetadata) GetLastModifiedTime ¶
func (x *PosixFileMetadata) GetLastModifiedTime() *timestamppb.Timestamp
func (*PosixFileMetadata) GetPath ¶
func (x *PosixFileMetadata) GetPath() string
func (*PosixFileMetadata) GetSize ¶
func (x *PosixFileMetadata) GetSize() int64
func (*PosixFileMetadata) ProtoMessage ¶
func (*PosixFileMetadata) ProtoMessage()
func (*PosixFileMetadata) ProtoReflect ¶
func (x *PosixFileMetadata) ProtoReflect() protoreflect.Message
func (*PosixFileMetadata) Reset ¶
func (x *PosixFileMetadata) Reset()
func (*PosixFileMetadata) String ¶
func (x *PosixFileMetadata) String() string
type StorageSystemType ¶
type StorageSystemType int32
Type of the storage system.
const ( // Unspecified. StorageSystemType_STORAGE_SYSTEM_TYPE_UNSPECIFIED StorageSystemType = 0 // AWS S3. StorageSystemType_AWS_S3 StorageSystemType = 1 // Azure Blob Storage. StorageSystemType_AZURE_BLOB StorageSystemType = 2 // Google Cloud Storage. StorageSystemType_GCS StorageSystemType = 3 // POSIX file system. StorageSystemType_POSIX_FS StorageSystemType = 4 // HTTP/HTTPS servers. StorageSystemType_HTTP StorageSystemType = 5 )
func (StorageSystemType) Descriptor ¶
func (StorageSystemType) Descriptor() protoreflect.EnumDescriptor
func (StorageSystemType) Enum ¶
func (x StorageSystemType) Enum() *StorageSystemType
func (StorageSystemType) EnumDescriptor ¶
func (StorageSystemType) EnumDescriptor() ([]byte, []int)
Deprecated: Use StorageSystemType.Descriptor instead.
func (StorageSystemType) Number ¶
func (x StorageSystemType) Number() protoreflect.EnumNumber
func (StorageSystemType) String ¶
func (x StorageSystemType) String() string
func (StorageSystemType) Type ¶
func (StorageSystemType) Type() protoreflect.EnumType
type TransferActivityLog ¶
type TransferActivityLog struct {
// Required. Name of the transfer operation.
Operation string `protobuf:"bytes,1,opt,name=operation,proto3" json:"operation,omitempty"`
// Required. The action which the transfer operation made.
Action TransferActivityLog_Action `protobuf:"varint,2,opt,name=action,proto3,enum=google.storagetransfer.logging.TransferActivityLog_Action" json:"action,omitempty"`
// Required. Status of the action.
Status *TransferActivityLog_Status `protobuf:"bytes,3,opt,name=status,proto3" json:"status,omitempty"`
// Metadata of source bucket/container/directory. Only set if the action is
// FIND.
SourceContainer *ContainerMetadata `protobuf:"bytes,4,opt,name=source_container,json=sourceContainer,proto3" json:"source_container,omitempty"`
// Metadata of destination bucket/container/directory. Only set if the action
// is FIND.
DestinationContainer *ContainerMetadata `protobuf:"bytes,5,opt,name=destination_container,json=destinationContainer,proto3" json:"destination_container,omitempty"`
// Metadata of the source blob/file/object. Only set if the action is COPY or
// DELETE when deletion is applied to source.
SourceObject *ObjectMetadata `protobuf:"bytes,6,opt,name=source_object,json=sourceObject,proto3" json:"source_object,omitempty"`
// Metadata of the destination blob/file/object. Only set if the action is
// or DELETE when deletion is applied to destination.
DestinationObject *ObjectMetadata `protobuf:"bytes,7,opt,name=destination_object,json=destinationObject,proto3" json:"destination_object,omitempty"`
// Required. Completion time of the action.
CompleteTime *timestamppb.Timestamp `protobuf:"bytes,8,opt,name=complete_time,json=completeTime,proto3" json:"complete_time,omitempty"`
// contains filtered or unexported fields
}
Schema of log payload of transfer activity.
func (*TransferActivityLog) Descriptor ¶
func (*TransferActivityLog) Descriptor() ([]byte, []int)
Deprecated: Use TransferActivityLog.ProtoReflect.Descriptor instead.
func (*TransferActivityLog) GetAction ¶
func (x *TransferActivityLog) GetAction() TransferActivityLog_Action
func (*TransferActivityLog) GetCompleteTime ¶
func (x *TransferActivityLog) GetCompleteTime() *timestamppb.Timestamp
func (*TransferActivityLog) GetDestinationContainer ¶
func (x *TransferActivityLog) GetDestinationContainer() *ContainerMetadata
func (*TransferActivityLog) GetDestinationObject ¶
func (x *TransferActivityLog) GetDestinationObject() *ObjectMetadata
func (*TransferActivityLog) GetOperation ¶
func (x *TransferActivityLog) GetOperation() string
func (*TransferActivityLog) GetSourceContainer ¶
func (x *TransferActivityLog) GetSourceContainer() *ContainerMetadata
func (*TransferActivityLog) GetSourceObject ¶
func (x *TransferActivityLog) GetSourceObject() *ObjectMetadata
func (*TransferActivityLog) GetStatus ¶
func (x *TransferActivityLog) GetStatus() *TransferActivityLog_Status
func (*TransferActivityLog) ProtoMessage ¶
func (*TransferActivityLog) ProtoMessage()
func (*TransferActivityLog) ProtoReflect ¶
func (x *TransferActivityLog) ProtoReflect() protoreflect.Message
func (*TransferActivityLog) Reset ¶
func (x *TransferActivityLog) Reset()
func (*TransferActivityLog) String ¶
func (x *TransferActivityLog) String() string
type TransferActivityLog_Action ¶
type TransferActivityLog_Action int32
Possible actions which a transfer operation can make.
const ( // Unspeficied action. TransferActivityLog_ACTION_UNSPECIFIED TransferActivityLog_Action = 0 // Finding work to do, such as listing files in a directory or listing // objects in a bucket. TransferActivityLog_FIND TransferActivityLog_Action = 1 // Copying files or objects. TransferActivityLog_COPY TransferActivityLog_Action = 2 // Deleting files or objects at destination. TransferActivityLog_DELETE TransferActivityLog_Action = 3 )
func (TransferActivityLog_Action) Descriptor ¶
func (TransferActivityLog_Action) Descriptor() protoreflect.EnumDescriptor
func (TransferActivityLog_Action) Enum ¶
func (x TransferActivityLog_Action) Enum() *TransferActivityLog_Action
func (TransferActivityLog_Action) EnumDescriptor ¶
func (TransferActivityLog_Action) EnumDescriptor() ([]byte, []int)
Deprecated: Use TransferActivityLog_Action.Descriptor instead.
func (TransferActivityLog_Action) Number ¶
func (x TransferActivityLog_Action) Number() protoreflect.EnumNumber
func (TransferActivityLog_Action) String ¶
func (x TransferActivityLog_Action) String() string
func (TransferActivityLog_Action) Type ¶
func (TransferActivityLog_Action) Type() protoreflect.EnumType
type TransferActivityLog_Status ¶
type TransferActivityLog_Status struct {
// Required. A string value of the Google RPC code as the status of the
// action. The action succeeded if it's `OK`, and failed otherwise.
StatusCode string `protobuf:"bytes,1,opt,name=status_code,json=statusCode,proto3" json:"status_code,omitempty"`
// A string that represents the type of error encountered. Populated only if
// status_code is not `OK`.
ErrorType string `protobuf:"bytes,2,opt,name=error_type,json=errorType,proto3" json:"error_type,omitempty"`
// A human-readable error message for the failure. Populated only if
// status_code is not `OK`.
ErrorMessage string `protobuf:"bytes,3,opt,name=error_message,json=errorMessage,proto3" json:"error_message,omitempty"`
// contains filtered or unexported fields
}
Status of an action.
func (*TransferActivityLog_Status) Descriptor ¶
func (*TransferActivityLog_Status) Descriptor() ([]byte, []int)
Deprecated: Use TransferActivityLog_Status.ProtoReflect.Descriptor instead.
func (*TransferActivityLog_Status) GetErrorMessage ¶
func (x *TransferActivityLog_Status) GetErrorMessage() string
func (*TransferActivityLog_Status) GetErrorType ¶
func (x *TransferActivityLog_Status) GetErrorType() string
func (*TransferActivityLog_Status) GetStatusCode ¶
func (x *TransferActivityLog_Status) GetStatusCode() string
func (*TransferActivityLog_Status) ProtoMessage ¶
func (*TransferActivityLog_Status) ProtoMessage()
func (*TransferActivityLog_Status) ProtoReflect ¶
func (x *TransferActivityLog_Status) ProtoReflect() protoreflect.Message
func (*TransferActivityLog_Status) Reset ¶
func (x *TransferActivityLog_Status) Reset()
func (*TransferActivityLog_Status) String ¶
func (x *TransferActivityLog_Status) String() string
Source Files ¶
transfer_activity_log.pb.go
- Version
- v0.0.0-20260427160629-7cedc36a6bc4 (latest)
- Published
- Apr 27, 2026
- Platform
- linux/amd64
- Imports
- 6 packages
- Last checked
- 2 days ago –
Tools for package owners.