package datetime
import "google.golang.org/genproto/googleapis/type/datetime"
Index ¶
- Variables
- type DateTime
- func (*DateTime) Descriptor() ([]byte, []int)
- func (x *DateTime) GetDay() int32
- func (x *DateTime) GetHours() int32
- func (x *DateTime) GetMinutes() int32
- func (x *DateTime) GetMonth() int32
- func (x *DateTime) GetNanos() int32
- func (x *DateTime) GetSeconds() int32
- func (m *DateTime) GetTimeOffset() isDateTime_TimeOffset
- func (x *DateTime) GetTimeZone() *TimeZone
- func (x *DateTime) GetUtcOffset() *durationpb.Duration
- func (x *DateTime) GetYear() int32
- func (*DateTime) ProtoMessage()
- func (x *DateTime) ProtoReflect() protoreflect.Message
- func (x *DateTime) Reset()
- func (x *DateTime) String() string
- type DateTime_TimeZone
- type DateTime_UtcOffset
- type TimeZone
Variables ¶
var File_google_type_datetime_proto protoreflect.FileDescriptor
Types ¶
type DateTime ¶
type DateTime struct {
// Optional. Year of date. Must be from 1 to 9999, or 0 if specifying a
// datetime without a year.
Year int32 `protobuf:"varint,1,opt,name=year,proto3" json:"year,omitempty"`
// Optional. Month of year. Must be from 1 to 12, or 0 if specifying a
// datetime without a month.
Month int32 `protobuf:"varint,2,opt,name=month,proto3" json:"month,omitempty"`
// Optional. Day of month. Must be from 1 to 31 and valid for the year and
// month, or 0 if specifying a datetime without a day.
Day int32 `protobuf:"varint,3,opt,name=day,proto3" json:"day,omitempty"`
// Optional. Hours of day in 24 hour format. Should be from 0 to 23, defaults
// to 0 (midnight). An API may choose to allow the value "24:00:00" for
// scenarios like business closing time.
Hours int32 `protobuf:"varint,4,opt,name=hours,proto3" json:"hours,omitempty"`
// Optional. Minutes of hour of day. Must be from 0 to 59, defaults to 0.
Minutes int32 `protobuf:"varint,5,opt,name=minutes,proto3" json:"minutes,omitempty"`
// Optional. Seconds of minutes of the time. Must normally be from 0 to 59,
// defaults to 0. An API may allow the value 60 if it allows leap-seconds.
Seconds int32 `protobuf:"varint,6,opt,name=seconds,proto3" json:"seconds,omitempty"`
// Optional. Fractions of seconds in nanoseconds. Must be from 0 to
// 999,999,999, defaults to 0.
Nanos int32 `protobuf:"varint,7,opt,name=nanos,proto3" json:"nanos,omitempty"`
// Optional. Specifies either the UTC offset or the time zone of the DateTime.
// Choose carefully between them, considering that time zone data may change
// in the future (for example, a country modifies their DST start/end dates,
// and future DateTimes in the affected range had already been stored).
// If omitted, the DateTime is considered to be in local time.
//
// Types that are assignable to TimeOffset:
//
// *DateTime_UtcOffset
// *DateTime_TimeZone
TimeOffset isDateTime_TimeOffset `protobuf_oneof:"time_offset"`
// contains filtered or unexported fields
}
Represents civil time (or occasionally physical time).
This type can represent a civil time in one of a few possible ways:
- When utc_offset is set and time_zone is unset: a civil time on a calendar day with a particular offset from UTC.
- When time_zone is set and utc_offset is unset: a civil time on a calendar day in a particular time zone.
- When neither time_zone nor utc_offset is set: a civil time on a calendar day in local time.
The date is relative to the Proleptic Gregorian Calendar.
If year, month, or day are 0, the DateTime is considered not to have a specific year, month, or day respectively.
This type may also be used to represent a physical time if all the date and time fields are set and either case of the `time_offset` oneof is set. Consider using `Timestamp` message for physical time instead. If your use case also would like to store the user's timezone, that can be done in another field.
This type is more flexible than some applications may want. Make sure to document and validate your application's limitations.
func (*DateTime) Descriptor ¶
Deprecated: Use DateTime.ProtoReflect.Descriptor instead.
func (*DateTime) GetDay ¶
func (*DateTime) GetHours ¶
func (*DateTime) GetMinutes ¶
func (*DateTime) GetMonth ¶
func (*DateTime) GetNanos ¶
func (*DateTime) GetSeconds ¶
func (*DateTime) GetTimeOffset ¶
func (m *DateTime) GetTimeOffset() isDateTime_TimeOffset
func (*DateTime) GetTimeZone ¶
func (*DateTime) GetUtcOffset ¶
func (x *DateTime) GetUtcOffset() *durationpb.Duration
func (*DateTime) GetYear ¶
func (*DateTime) ProtoMessage ¶
func (*DateTime) ProtoMessage()
func (*DateTime) ProtoReflect ¶
func (x *DateTime) ProtoReflect() protoreflect.Message
func (*DateTime) Reset ¶
func (x *DateTime) Reset()
func (*DateTime) String ¶
type DateTime_TimeZone ¶
type DateTime_TimeZone struct {
// Time zone.
TimeZone *TimeZone `protobuf:"bytes,9,opt,name=time_zone,json=timeZone,proto3,oneof"`
}
type DateTime_UtcOffset ¶
type DateTime_UtcOffset struct {
// UTC offset. Must be whole seconds, between -18 hours and +18 hours.
// For example, a UTC offset of -4:00 would be represented as
// { seconds: -14400 }.
UtcOffset *durationpb.Duration `protobuf:"bytes,8,opt,name=utc_offset,json=utcOffset,proto3,oneof"`
}
type TimeZone ¶
type TimeZone struct {
// IANA Time Zone Database time zone. For example "America/New_York".
Id string `protobuf:"bytes,1,opt,name=id,proto3" json:"id,omitempty"`
// Optional. IANA Time Zone Database version number. For example "2019a".
Version string `protobuf:"bytes,2,opt,name=version,proto3" json:"version,omitempty"`
// contains filtered or unexported fields
}
Represents a time zone from the [IANA Time Zone Database](https://www.iana.org/time-zones).
func (*TimeZone) Descriptor ¶
Deprecated: Use TimeZone.ProtoReflect.Descriptor instead.
func (*TimeZone) GetId ¶
func (*TimeZone) GetVersion ¶
func (*TimeZone) ProtoMessage ¶
func (*TimeZone) ProtoMessage()
func (*TimeZone) ProtoReflect ¶
func (x *TimeZone) ProtoReflect() protoreflect.Message
func (*TimeZone) Reset ¶
func (x *TimeZone) Reset()
func (*TimeZone) String ¶
Source Files ¶
datetime.pb.go
- Version
- v0.0.0-20260427160629-7cedc36a6bc4 (latest)
- Published
- Apr 27, 2026
- Platform
- linux/amd64
- Imports
- 5 packages
- Last checked
- 2 days ago –
Tools for package owners.