package fraction
import "google.golang.org/genproto/googleapis/type/fraction"
Index ¶
Variables ¶
var File_google_type_fraction_proto protoreflect.FileDescriptor
Types ¶
type Fraction ¶
type Fraction struct {
// The numerator in the fraction, e.g. 2 in 2/3.
Numerator int64 `protobuf:"varint,1,opt,name=numerator,proto3" json:"numerator,omitempty"`
// The value by which the numerator is divided, e.g. 3 in 2/3. Must be
// positive.
Denominator int64 `protobuf:"varint,2,opt,name=denominator,proto3" json:"denominator,omitempty"`
// contains filtered or unexported fields
}
Represents a fraction in terms of a numerator divided by a denominator.
func (*Fraction) Descriptor ¶
Deprecated: Use Fraction.ProtoReflect.Descriptor instead.
func (*Fraction) GetDenominator ¶
func (*Fraction) GetNumerator ¶
func (*Fraction) ProtoMessage ¶
func (*Fraction) ProtoMessage()
func (*Fraction) ProtoReflect ¶
func (x *Fraction) ProtoReflect() protoreflect.Message
func (*Fraction) Reset ¶
func (x *Fraction) Reset()
func (*Fraction) String ¶
Source Files ¶
fraction.pb.go
- Version
- v0.0.0-20260427160629-7cedc36a6bc4 (latest)
- Published
- Apr 27, 2026
- Platform
- linux/amd64
- Imports
- 4 packages
- Last checked
- 3 days ago –
Tools for package owners.