package date
import "google.golang.org/genproto/googleapis/type/date"
Index ¶
Variables ¶
var File_google_type_date_proto protoreflect.FileDescriptor
Types ¶
type Date ¶
type Date struct {
// Year of the date. Must be from 1 to 9999, or 0 to specify a date without
// a year.
Year int32 `protobuf:"varint,1,opt,name=year,proto3" json:"year,omitempty"`
// Month of a year. Must be from 1 to 12, or 0 to specify a year without a
// month and day.
Month int32 `protobuf:"varint,2,opt,name=month,proto3" json:"month,omitempty"`
// Day of a month. Must be from 1 to 31 and valid for the year and month, or 0
// to specify a year by itself or a year and month where the day isn't
// significant.
Day int32 `protobuf:"varint,3,opt,name=day,proto3" json:"day,omitempty"`
// contains filtered or unexported fields
}
Represents a whole or partial calendar date, such as a birthday. The time of day and time zone are either specified elsewhere or are insignificant. The date is relative to the Gregorian Calendar. This can represent one of the following:
- A full date, with non-zero year, month, and day values.
- A month and day, with a zero year (for example, an anniversary).
- A year on its own, with a zero month and a zero day.
- A year and month, with a zero day (for example, a credit card expiration date).
Related types:
* [google.type.TimeOfDay][google.type.TimeOfDay] * [google.type.DateTime][google.type.DateTime] * [google.protobuf.Timestamp][google.protobuf.Timestamp]
func (*Date) Descriptor ¶
Deprecated: Use Date.ProtoReflect.Descriptor instead.
func (*Date) GetDay ¶
func (*Date) GetMonth ¶
func (*Date) GetYear ¶
func (*Date) ProtoMessage ¶
func (*Date) ProtoMessage()
func (*Date) ProtoReflect ¶
func (x *Date) ProtoReflect() protoreflect.Message
func (*Date) Reset ¶
func (x *Date) Reset()
func (*Date) String ¶
Source Files ¶
date.pb.go
- Version
- v0.0.0-20260427160629-7cedc36a6bc4 (latest)
- Published
- Apr 27, 2026
- Platform
- linux/amd64
- Imports
- 4 packages
- Last checked
- 2 days ago –
Tools for package owners.