package latlng
import "google.golang.org/genproto/googleapis/type/latlng"
Index ¶
Variables ¶
var File_google_type_latlng_proto protoreflect.FileDescriptor
Types ¶
type LatLng ¶
type LatLng struct {
// The latitude in degrees. It must be in the range [-90.0, +90.0].
Latitude float64 `protobuf:"fixed64,1,opt,name=latitude,proto3" json:"latitude,omitempty"`
// The longitude in degrees. It must be in the range [-180.0, +180.0].
Longitude float64 `protobuf:"fixed64,2,opt,name=longitude,proto3" json:"longitude,omitempty"`
// contains filtered or unexported fields
}
An object that represents a latitude/longitude pair. This is expressed as a pair of doubles to represent degrees latitude and degrees longitude. Unless specified otherwise, this object must conform to the <a href="https://en.wikipedia.org/wiki/World_Geodetic_System#1984_version"> WGS84 standard</a>. Values must be within normalized ranges.
func (*LatLng) Descriptor ¶
Deprecated: Use LatLng.ProtoReflect.Descriptor instead.
func (*LatLng) GetLatitude ¶
func (*LatLng) GetLongitude ¶
func (*LatLng) ProtoMessage ¶
func (*LatLng) ProtoMessage()
func (*LatLng) ProtoReflect ¶
func (x *LatLng) ProtoReflect() protoreflect.Message
func (*LatLng) Reset ¶
func (x *LatLng) Reset()
func (*LatLng) String ¶
Source Files ¶
latlng.pb.go
- Version
- v0.0.0-20260427160629-7cedc36a6bc4 (latest)
- Published
- Apr 27, 2026
- Platform
- linux/amd64
- Imports
- 4 packages
- Last checked
- 2 days ago –
Tools for package owners.