package timeofday
import "google.golang.org/genproto/googleapis/type/timeofday"
Index ¶
- Variables
- type TimeOfDay
- func (*TimeOfDay) Descriptor() ([]byte, []int)
- func (x *TimeOfDay) GetHours() int32
- func (x *TimeOfDay) GetMinutes() int32
- func (x *TimeOfDay) GetNanos() int32
- func (x *TimeOfDay) GetSeconds() int32
- func (*TimeOfDay) ProtoMessage()
- func (x *TimeOfDay) ProtoReflect() protoreflect.Message
- func (x *TimeOfDay) Reset()
- func (x *TimeOfDay) String() string
Variables ¶
var File_google_type_timeofday_proto protoreflect.FileDescriptor
Types ¶
type TimeOfDay ¶
type TimeOfDay struct {
// Hours of a day in 24 hour format. Must be greater than or equal to 0 and
// typically must be less than or equal to 23. An API may choose to allow the
// value "24:00:00" for scenarios like business closing time.
Hours int32 `protobuf:"varint,1,opt,name=hours,proto3" json:"hours,omitempty"`
// Minutes of an hour. Must be greater than or equal to 0 and less than or
// equal to 59.
Minutes int32 `protobuf:"varint,2,opt,name=minutes,proto3" json:"minutes,omitempty"`
// Seconds of a minute. Must be greater than or equal to 0 and typically must
// be less than or equal to 59. An API may allow the value 60 if it allows
// leap-seconds.
Seconds int32 `protobuf:"varint,3,opt,name=seconds,proto3" json:"seconds,omitempty"`
// Fractions of seconds, in nanoseconds. Must be greater than or equal to 0
// and less than or equal to 999,999,999.
Nanos int32 `protobuf:"varint,4,opt,name=nanos,proto3" json:"nanos,omitempty"`
// contains filtered or unexported fields
}
Represents a time of day. The date and time zone are either not significant or are specified elsewhere. An API may choose to allow leap seconds. Related types are [google.type.Date][google.type.Date] and `google.protobuf.Timestamp`.
func (*TimeOfDay) Descriptor ¶
Deprecated: Use TimeOfDay.ProtoReflect.Descriptor instead.
func (*TimeOfDay) GetHours ¶
func (*TimeOfDay) GetMinutes ¶
func (*TimeOfDay) GetNanos ¶
func (*TimeOfDay) GetSeconds ¶
func (*TimeOfDay) ProtoMessage ¶
func (*TimeOfDay) ProtoMessage()
func (*TimeOfDay) ProtoReflect ¶
func (x *TimeOfDay) ProtoReflect() protoreflect.Message
func (*TimeOfDay) Reset ¶
func (x *TimeOfDay) Reset()
func (*TimeOfDay) String ¶
Source Files ¶
timeofday.pb.go
- Version
- v0.0.0-20260427160629-7cedc36a6bc4 (latest)
- Published
- Apr 27, 2026
- Platform
- linux/amd64
- Imports
- 4 packages
- Last checked
- 2 days ago –
Tools for package owners.